// $Id: AssumptionType.h 1.4 2008/04/25 13:03:30EDT 277133 Development  $
//
// The assumption types allowed in the piadata library.

#pragma once

// {group:Calculation Classes}
// Description: The assumption types allowed in the piadata library.
//
// Remarks: There is an enum and some static functions, but no member
// variables, so there are no instances of this class.
class AssumptionType
{
public:
   // Description: Type of assumptions.
   enum assum_type {
      NONE,  // No assumptions chosen.
      ALTERN_I,  // Alternative 1 from Trustees Report.
      ALTERN_IIB,  // Alternative 2 from Trustees Report.
      ALTERN_III,  // Alternative 3 from Trustees Report.
      ALTERN_IIA,  // Flat assumptions (same as FLAT).
      FLAT,  // Flat assumptions.
      PEBS_ASSUM,  // Old PEBES assumptions.
      OTHER_ASSUM  // User-specified assumptions.
   };
   // Description: True to use a wider range of possible assumptions for
   // Statement calculations.
   static const bool EXPANDED_PEBES = false;
public:
   static void ialtawCheck1( int ialtawt );
   static void ialtawCheck2( int ialtawt );
   static void ialtbiCheck1( int ialtbit );
   static void ialtbiCheck2( int ialtbit );
   // Description: Returns true if argument is not a Trustees Report
   // assumption.
   //
   // Returns: True if argument is not a Trustees Report assumption (FLAT,
   // PEBS_ASSUM, or OTHER_ASSUM).
   //
   // Arguments:
   //   altNum: Assumption type to check.
   static bool isNotTR( int altNum )
   { return (altNum == FLAT || altNum == PEBS_ASSUM || altNum == OTHER_ASSUM); }
   // Description: Returns true if argument is a Trustees Report assumption.
   //
   // Returns: True if argument is a Trustees Report assumption (ALTERN_I,
   // ALTERN_IIB, ALTERN_III, or ALTERN_IIA).
   //
   // Arguments:
   //   altNum: Assumption type to check.
   static bool isTR( int altNum )
   { return (altNum == ALTERN_I || altNum == ALTERN_IIB ||
        altNum == ALTERN_III || altNum == ALTERN_IIA); }
   // Description: Returns true if argument is a statement-type constant-dollar
   //   assumption.
   //
   // Returns: True if argument is a statement-type assumption (FLAT, or 
   //   PEBS_ASSUM).
   //
   // Arguments:
   //   altNum: Assumption type to check.
   static bool isFlatOrPebs(int altNum) 
   { return (altNum == FLAT || altNum == PEBS_ASSUM); }
private:
   AssumptionType();
   AssumptionType( const AssumptionType& );
   ~AssumptionType();
   AssumptionType& operator=( const AssumptionType& );
};
