// $Id: Assumptions.h 1.14 2006/11/08 10:57:57EST 044579 Development  $
//
// Declarations needed for Assumptions class.

#pragma once

#include "cachupf.h"
#include "biproj.h"
#include "AwincDoc.h"

// {group:Calculation Classes}
// Description: Parent of classes that manage the average wage and benefit
//   increase assumptions.
//
// Remarks: One of its subclasses should be instantiated:  AssumptionsFile if
//   it is to be read from disk, AssumptionsNonFile otherwise.
class Assumptions
{
protected:
   // Description: Current year (year after last known benefit increase).
   int istart;
   // Description: Maximum projected year.
   int maxyear;
public:
   Assumptions( int newIstart, int newMaxyear );
   Assumptions( int newMaxyear );
   virtual ~Assumptions();
   // Description: Set average wage increases from stored values.
   virtual void averageWageMenu( int ) = 0;
   // Description: Set benefit increases from stored values.
   virtual void benefitIncMenu( int ) = 0;
   const std::string& getAverageWage( int altNum );
   const std::string& getBenefitInc( int altNum );
   // Description: Returns projected average wage increases.
   //
   // Returns: Projected average wage increases.
   virtual const AwincDoc& getAwincProj() const = 0;
   // Description: Returns projected benefit increases.
   //
   // Returns: Projected benefit increases.
   virtual const Biproj& getBiProj() const = 0;
   // Description: Returns catch-up benefit increases.
   //
   // Returns: Catch-up benefit increases.
   virtual const CatchupDoc& getCatchupDoc() const = 0;
   // Description: Returns current year.
   //
   // Returns: Current year.
   int getIstart() const { return(istart); }
   // Description: Returns maximum projected year.
   //
   // Returns: Maximum projected year.
   int getMaxyear() const { return(maxyear); }
   // Description: Set title of projected average wage increases.
   virtual void setAwincProjTitle( int ) = 0;
   // Description: Set title of projected benefit increases.
   virtual void setBiProjTitle( int ) = 0;
   // Description: Sets the current year, including for the members.
   virtual void setIstart( int ) = 0;
};
