// $Id: AssumptionsFile.h 1.7 2006/11/08 10:57:57EST 044579 Development  $
//
// Declarations needed for AssumptionsFile class.

#pragma once

#include "Assumptions.h"
#include "AwincFile.h"
#include "BiprojFile.h"
#include "CatchupFile.h"

// {group:Calculation Classes}
// Description: Reads the average wage and benefit increase
//   parameters from disk storage.
//
// Remarks: Reads the average wage and benefit increase
//   parameters from disk storage.
class AssumptionsFile : public Assumptions
{
public:
   // Description: Projected average wage increases.
   AwincFile awincProj;
   // Description: Projected benefit increases.
   BiprojFile biProj;
   // Description: Catch-up benefit increases.
   CatchupFile catchupDoc;
public:
   AssumptionsFile( int newIstart, int newMaxyear,
      const std::string& directory );
   ~AssumptionsFile();
   void averageWageMenu( int altNum );
   void benefitIncMenu( int altNum );
   // Description: Returns projected average wage increases.
   //
   // Returns: Projected average wage increases.
   const AwincDoc& getAwincProj() const { return awincProj; }
   // Description: Returns projected benefit increases.
   //
   // Returns: Projected benefit increases.
   const Biproj& getBiProj() const { return biProj; }
   // Description: Returns catch-up benefit increases.
   //
   // Returns: Catch-up benefit increases.
   const CatchupDoc& getCatchupDoc() const { return catchupDoc; }
   // Set title of projected average wage increases.
   //
   // Arguments:
   //   number: Trustees Report assumption.
   void setAwincProjTitle( int number ) { awincProj.setTitle(number); }
   // Set title of projected benefit increases.
   //
   // Arguments:
   //   number: Trustees Report assumption.
   void setBiProjTitle( int number ) { biProj.setTitle(number); }
   void setIstart( int newIstart );
};
