// $Id: AssumptionsNonFile.h 1.7 2006/11/08 10:57:56EST 044579 Development  $
//
// Declarations needed for AssumptionsNonFile class.

#pragma once

#include "Assumptions.h"
#include "AwincNonFile.h"
#include "BiprojNonFile.h"
#include "CatchupNonFile.h"

// {group:Calculation Classes}
// Description: Contains the average wage and benefit 
//   increase assumptions (it does not read from disk).
//
// Remarks: Contains the average wage and benefit 
//   increase assumptions (it does not read from disk).
class AssumptionsNonFile : public Assumptions
{
public:
   // Description: Projected average wage increases.
   AwincNonFile awincProj;
   // Description: Projected benefit increases.
   BiprojNonFile biProj;
   // Description: Catch-up benefit increases.
   CatchupNonFile catchupDoc;
public:
   AssumptionsNonFile( int newIstart, int newMaxyear );
   AssumptionsNonFile( int newMaxyear );
   ~AssumptionsNonFile();
   void averageWageMenu( int altNum );
   void benefitIncMenu( int altNum );
   // Description: Returns projected average wage increases.
   //
   // Returns: Projected average wage increases.
   const AwincDoc& getAwincProj() const { return awincProj; }
   // Description: Returns projected benefit increases.
   //
   // Returns: Projected benefit increases.
   const Biproj& getBiProj() const { return biProj; }
   // Description: Returns catch-up benefit increases.
   //
   // Returns: Catch-up benefit increases.
   const CatchupDoc& getCatchupDoc() const { return catchupDoc; }
   // Set title of projected average wage increases.
   //
   // Arguments:
   //   number: Trustees Report assumption.
   void setAwincProjTitle( int number ) { awincProj.setTitle(number); }
   // Set title of projected benefit increases.
   //
   // Arguments:
   //   number: Trustees Report assumption.
   void setBiProjTitle( int number ) { biProj.setTitle(number); }
   void setIstart( int newIstart );
};
