// $Id: AwbiDataNonFile.h 1.9 2006/11/08 10:57:57EST 044579 Development  $
//
// Class to manage historical Social Security parameters stored with the code.

#pragma once

#include "awbidat.h"
#include "oactcnst.h"

// {group:Calculation Classes}
// Description: Manages the historical Social Security parameters stored in
//   arrays in the code.
//
// Remarks: An instance of this class is used in the Anypia program.
class AwbiDataNonFile : public AwbiData
{
protected:
   static const double cpiincData[];
   static const double fqData[];
   static const double baseOasdiData[];
   static const double base77Data[];
   static const double baseHiData[];
public:
   AwbiDataNonFile( int newLastYear, int newMaxyear );
   explicit AwbiDataNonFile( int newMaxyear );
   void setData();
   // Description: Returns a historical OASDI wage base.
   //
   // Returns: The OASDI wage base for the specified year.
   //
   // Arguments:
   //   year: Year for which OASDI wage base is desired.
   static double getBaseOasdiData( int year )
      { return baseOasdiData[year - YEAR37]; }
   // Description: Returns a historical old-law wage base.
   //
   // Returns: The old-law wage base for the specified year.
   //
   // Arguments:
   //   year: Year for which old-law wage base is desired.
   static double getBase77Data( int year ) { return base77Data[year - 1937]; }
   // Description: Returns a historical HI wage base.
   //
   // Returns: The HI wage base for the specified year.
   //
   // Arguments:
   //   year: Year for which HI wage base is desired.
   static double getBaseHiData( int year )
   { return (year < HI_BASE_YEAR) ?
       baseOasdiData[year - YEAR37] : baseHiData[year - HI_BASE_YEAR]; }
   // Description: Returns a historical benefit increase.
   //
   // Returns: The benefit increase for the specified year.
   //
   // Arguments:
   //   year: Year for which benefit increase is desired.
   static double getCpiincData( int year )
      { return cpiincData[year - YEAR51]; }
   // Description: Returns a historical average indexing wage.
   //
   // Returns: The average indexing wage for the specified year.
   //
   // Arguments:
   //   year: Year for which average indexing wage is desired.
   static double getFqData( int year ) { return fqData[year - YEAR37]; }
};
