// $Id: AwincDoc.h 1.13 2006/11/08 10:57:57EST 044579 Development  $
//
// Declarations for class to manage average wage increases.

#pragma once

#include "awinc.h"

// {group:Calculation Classes}
// Description: Abstract parent of classes that manage the file of projected
//   average wage increases.
//
// Remarks: One of its subclasses should be instantiated:  AwincFile if
//   it is to be read from disk, AwincNonFile otherwise.
class AwincDoc
{
protected:
   // Description: First year of data.
   int firstYear;
   // Description: Title of projected average wage increases.
   std::string awincTitle;
   // Description: Titles of projected average wage increase assumptions.
   std::string avgwage[3];
public:
   // Description: Array of average wage increases.
   Awinc awinc;
public:
   AwincDoc( int newIstart, int newMaxyear );
   virtual ~AwincDoc();
   // Description: Returns first year of data.
   //
   // Returns: First year of data.
   int getFirstYear() const { return firstYear; }
   // Description: Returns title of assumptions.
   //
   // Returns: Title of assumptions.
   const std::string& getTitle() const { return awincTitle; }
   // Description: Read data.
   virtual void read( int ) = 0;
   // Description: Set data for one alternative.
   virtual void setData( int ) = 0;
   virtual void setData( int, const DoubleAnnual& ) = 0;
   void setFirstYear( int newFirstYear );
   void setFqinc( int year, double newfqinc );
   // Description: Sets title for one alternative.
   virtual void setTitle( int ) = 0;
   virtual void setTitle( int, const std::string& ) = 0;
   // Description: Write data.
   virtual void write( int ) = 0;
};
