// $Id: AwincNonFile.h 1.13 2007/05/16 14:00:24EDT 277133 Development  $
//
// Declarations for class to manage average wage increases.

#pragma once

#include "AwincDoc.h"

// {group:Calculation Classes}
// Description: Manages the file of projected average wage increases stored in
//   static arrays.
//
// Remarks: Manages the file of projected average wage increases stored in
//   static arrays.
class AwincNonFile : public AwincDoc
{
public:
   // Description: Dimension limits.
   enum DimLimits {
      // Number of sets of assumptions (4 for 1, 2, 3, and 2b).
      NUMASSUMSETS = 4,
      // Number of annual average wage increases.   This should not normally be 
      // changed because it is the number of blanks on a form in the 
      // detailed calculator.
      NUMPROJYEARS = 16
   };
protected:
   // Description: Historical average wage increases.
   static const double awincHist[];
   // Description: Original titles for Trustees Report.
   static const std::string titletrOriginal[NUMASSUMSETS];
   // Description: Average wage increases for Trustees Report.
   static const double awincprojtrOriginal[NUMASSUMSETS][NUMPROJYEARS];
   // Description: Ultimate average wage increases for Trustees Report.
   static const double awincult[NUMASSUMSETS];
   // Description: Stored Trustees Report assumptions titles.
   std::string titletr[NUMASSUMSETS];
   // Description: Stored Trustees Report assumptions.
   DoubleAnnual awincprojtr[NUMASSUMSETS];
public:
   AwincNonFile( int newIstart, int newMaxyear );
   ~AwincNonFile();
   void read( int altNum );
   void setData ( int altNum );
   virtual void setData ( int altNum, const DoubleAnnual& newData );
   void setTitle( int altNum );
   void setTitle( int altNum, const std::string& newTitle );
   void write( int );
};
