// $Id: BenefitAmountArray.h 1.8 2006/11/08 10:57:57EST 044579 Development  $
//
// Declarations needed for array of Social Security benefit amounts.

#pragma once

#include <vector>
#include "BenefitAmount.h"
#include "oactcnst.h"
#include "PiaException.h"
#include "Resource.h"

// {group:Calculation Classes}
// Description: Manages an array of BenefitAmount's.
//
// Remarks: Manages an array of BenefitAmount's.
class BenefitAmountArray
{
protected:
   // Description: Benefit amount data.
   std::vector< BenefitAmount > theData;
   // Description: Last year of data.
   int lastYear;
   // Description: Indicator for values having been set.
   bool dirty;
public:
   BenefitAmountArray();
   explicit BenefitAmountArray( int year );
   ~BenefitAmountArray();
   // Description: Returns the benefit amount.
   //
   // Remarks: There are const and non-const versions.
   //
   // Returns: The benefit amount for the specified year.
   //
   // Throws: PiaException of type PIA_IDS_BENARRAY2 if year is out of range
   //   (in debug version only).
   //
   // Arguments:
   //   year: Year for which benefit amount is desired.
   BenefitAmount& operator[]( int year )
   {
   #ifndef NDEBUG
      if (year < YEAR37 || year > lastYear)
         throw PiaException(PIA_IDS_BENARRAY2);
   #endif
      return(theData[year - YEAR37]);
   }
   const BenefitAmount operator[]( int year ) const
   {
   #ifndef NDEBUG
      if (year < YEAR37 || year > lastYear)
         throw PiaException(PIA_IDS_BENARRAY2);
   #endif
      return(theData[year - YEAR37]);
   }
   void deleteContents();
   // Description: Returns the last year of data.
   //
   // Returns: The last year of data.
   int getLastYear() const { return(lastYear); }
   void initialize( int newLastYear );
   // Description: Sets indicator for non-zero values.
   void setDirty() { dirty = true; }
};
