// $Id: BiprojNonFile.h 1.15 2007/05/16 14:00:24EDT 277133 Development  $
//
// Declarations for class to manage projected benefit increases stored in
// arrays.

#pragma once

#include <string>
#include "biproj.h"

// {group:Calculation Classes}
// Description: Manages the file of projected benefit increases stored in
//   arrays.
//
// Remarks: Manages the file of projected benefit increases stored in arrays.
class BiprojNonFile : public Biproj
{
public:
   // Dimension limits.
   enum DimLimits {
      // Number of sets of assumptions (4 for 1, 2, 3, and 2b).
      NUMASSUMSETS = 4,
      // Number of annual benefit increases. This should not normally be 
      // changed because it is the number of blanks on a form in the 
      // detailed calculator.
      NUMPROJYEARS = 15
   };
protected:
   // Original titles for Trustees Report.
   static const std::string titletrOriginal[NUMASSUMSETS];
   // Benefit increases for Trustees Report.
   static const double biprojtrOriginal[NUMASSUMSETS][NUMPROJYEARS];
   // Ultimate benefit increases for Trustees Report.
   static const double biult[NUMASSUMSETS];
   // Stored Trustees Report assumptions titles.
   std::string titletr[NUMASSUMSETS];
   // Stored Trustees Report increases.
   DoubleAnnual biprojtr[NUMASSUMSETS];
public:
   BiprojNonFile( int newIstart, int newMaxyear );
   ~BiprojNonFile();
   void read( int altNum );
   void setData ( int altNum );
   void setData ( int altNum, const DoubleAnnual& newData );
   void setTitle( int altNum );
   void setTitle( int altNum, const std::string& newTitle );
   void write( int );
};
