// $Id: BitAnnual.h 1.17 2006/11/08 10:58:17EST 044579 Development  $
//
// Declarations needed for class to manage an array of annual bits.

#pragma once

#include "boost/serialization/access.hpp"
#include "BitAnnualBase.h"
#include "Resource.h"
#include "PiaException.h"

// {group:Miscellaneous Classes}
// Description: Manages an array of annual bits.
//
// Remarks: When adding functions to this class, or changing the implementation
// of existing functions, be careful not to use square brackets ( [] )
// to access 'data' unless you're really sure of what you're doing.
// This is because there are different implementations of this class
// depending on whether you're using NT or Linux. Instead, use the
// setBit and getBit functions.
class BitAnnual
{
   friend class boost::serialization::access;
   // Description: Archives the data.
   //
   // Remarks: When the class Archive corresponds to an output archive, the
   // & operator is defined similar to <<. Likewise, when the class Archive is
   // a type of input archive, the & operator is defined similar to >>.
   //
   // Arguments:
   //   ar: The archive to use.
   //   version: The version of the archive to use.
   template< class Archive >
   void serialize( Archive& ar, const unsigned int version )
      { ar & theData & baseYear & lastYear; }
protected:
   // Description: Bit array.
   BitAnnualData theData;
   // Description: Base year of data.
   int baseYear;
   // Description: Last year of data.
   int lastYear;
public:
   BitAnnual( int newBaseYear, int newLastYear );
   BitAnnual( const BitAnnual& bitAnnual );
   virtual ~BitAnnual();
   bool any() const;
   void assign( const BitAnnual& bitAnnual, int firstYeart, int lastYeart );
   void deleteContents();
   // Description: Returns base year.
   //
   // Returns: Base year.
   int getBaseYear() const { return(baseYear); }
   bool getBit( int year ) const;
   // Description: Returns last year.
   //
   // Returns: Last year.
   int getLastYear() const { return(lastYear); }
   void setBit( int year, int bit );
};

#include "BitAnnualInlines.h"
