// $Id: ChildCareCalc.h 1.12 2006/11/08 10:58:18EST 044579 Development  $
//
// Declarations needed for class to manage childcare dropout year pia
// calculation functions.

#pragma once

#include "WageIndGeneral.h"

// {group:Calculation Classes}
// Description: Manages the functions required for calculation of a wage
//   indexed Social Security benefit using childcare dropout years.
//
// Remarks: Manages the functions required for calculation of a wage
//   indexed Social Security benefit using childcare dropout years.
class ChildCareCalc : public WageIndGeneral
{
protected:
   // Description: Number of computation years adjusted for childcare dropout
   // years.
   int adjustedN;
   // Description: Maximum number of childcare dropout years.
   //
   // Remarks: Under present law, this is a maximum of 3. But it is less than
   // that for a specific person if he/she already has some regular dropout
   // years, or has a low number of computation years.
   int childCareDropMax;
   // Description: Number of usable childcare dropout years.
   int childCareDrop;
public:
   ChildCareCalc( const WorkerDataGeneral& newWorkerData,
      const PiaData& newPiaData, const PiaParams& newPiaParams,
      int newMaxyear );
   virtual ~ChildCareCalc();
   void calculate();
   virtual int childCareDropMaxCal() const;
   void childCareDropoutCal();
   // Description: Returns number of computation years adjusted for childcare
   //   dropout years.
   //
   // Returns: Number of computation years adjusted for childcare
   //   dropout years.
   int getAdjustedN() const { return adjustedN; }
   // Description: Returns number of usable childcare dropout years.
   //
   // Returns: Number of usable childcare dropout years.
   int getChildCareDrop() const { return childCareDrop; }
   // Description: Returns maximum number of childcare dropout years.
   //
   // Returns: Maximum number of childcare dropout years.
   int getChildCareDropMax() const { return childCareDropMax; }
   void initialize();
   bool isApplicable();
   static bool isApplicable( const WorkerDataGeneral& workerData,
      const PiaData& piaData, WorkerDataGeneral::ben_type ioasdi );
private:
   ChildCareCalc operator=( ChildCareCalc newChildCareCalc );
};
