// $Id: DisInsCodeArray.h 1.9 2006/11/08 10:58:37EST 044579 Development  $
//
// Declarations needed for class to manage an array of disability insured
// status codes.

#pragma once

#include <string>
#include <vector>
#include "dinscode.h"
#include "Resource.h"
#include "PiaException.h"

// {group:Calculation Classes}
// Description: Manages an array of annual DisInsCode's.
//
// Remarks: Manages an array of annual DisInsCode's.
class DisInsCodeArray
{
protected:
   // Description: Disability insured status code data.
   std::vector< DisInsCode > theCodes;
   // Description: First year of data.
   int firstYear;
   // Description: Last year of data.
   int lastYear;
public:
   DisInsCodeArray( int newFirstYear, int newLastYear );
   // Description: Returns the disability insured status code at end of year.
   //
   // Remarks: There are both const and non-const versions.
   //
   // Returns: The disability insured status code at end of year.
   //
   // Throws: PiaException if year is out of range (only in debug mode).
   //
   // Arguments:
   //   year: Year for which disability insured status code is desired.
   DisInsCode& operator[]( int year )
   {
   #if !defined(NDEBUG)
      if (year < firstYear || year > lastYear)
         throw PiaException("Year out of range in DisInsCodeArray::operator[]");
   #endif
      return(theCodes[year - firstYear]);
   }
   const DisInsCode operator[]( int year ) const
   {
   #if !defined(NDEBUG)
      if (year < firstYear || year > lastYear)
         throw PiaException("Year out of range in DisInsCodeArray::operator[]");
   #endif
      return(theCodes[year - firstYear]);
   }
   void assign( const DisInsCodeArray& newDataArray, int firstDataYear,
     int lastDataYear);
   void assign( const DisInsCode& newData, int firstDataYear,
     int lastDataYear);
   void deleteContents();
   // Description: Returns the first year of data.
   //
   // Returns: The first year of data.
   int getFirstYear() const { return(firstYear); }
   // Description: Returns the last year of data.
   //
   // Returns: The last year of data.
   int getLastYear() const { return(lastYear); }
   bool isNonzero() const;
   // Description: Sets the first year of data.
   //
   // Arguments:
   //   newFirstYear: New first year of data.
   void setFirstYear( int newFirstYear ) { firstYear = newFirstYear; }
   // Description: Sets the last year of data.
   //
   // Arguments:
   //   newLastYear: New last year of data.
   void setLastYear( int newLastYear ) { lastYear = newLastYear; }
   std::string toString() const;
};
