// $Id: InsCodeArray.h 1.10 2006/11/08 10:58:58EST 044579 Development  $
//
// Declarations needed for class to manage array of insured status codes.

#pragma once

#include <string>
#include <vector>
#include "inscode.h"
#include "Resource.h"
#include "PiaException.h"

// {group:Calculation Classes}
// Description: Manages an array of annual insured status codes.
//
// Remarks: Manages an array of annual insured status codes.
class InsCodeArray
{
protected:
   // Description: Array of insured status codes.
   std::vector< InsCode > theCodes;
   // Description: First year of data.
   int firstYear;
   // Description: Last year of data.
   int lastYear;
public:
   InsCodeArray( int newFirstYear, int newLastYear );
   // Description: Returns the insured status code at end of year.
   //
   // Remarks: There are const and non-const versions.
   //
   // Returns: The insured status code at end of year.
   //
   // Throws: PiaException if year is out of range (only in debug mode).
   //
   // Arguments:
   //   year: Year for which insured status code is desired.
   InsCode& operator[]( int year )
   {
   #if !defined(NDEBUG)
      if (year < firstYear || year > lastYear)
         throw PiaException("Year is out of range in InsCodeArray::operator[]");
   #endif
      return(theCodes[year - firstYear]);
   }
   const InsCode operator[]( int year ) const
   {
   #if !defined(NDEBUG)
      if (year < firstYear || year > lastYear)
         throw PiaException("Year is out of range in InsCodeArray::operator[]");
   #endif
      return(theCodes[year - firstYear]);
   }
   void assign( const InsCodeArray& newDataArray,
     int firstDataYear, int lastDataYear );
   void assign( const InsCode& newData, int firstDataYear,
     int lastDataYear );
   void deleteContents();
   // Description: Returns the first year of data.
   //
   // Returns: The first year of data.
   int getFirstYear() const { return(firstYear); }
   // Description: Returns the last year of data.
   //
   // Returns: The last year of data.
   int getLastYear() const { return(lastYear); }
   bool isNonzero() const;
   // Description: Sets the first year of data.
   //
   // Arguments:
   //   newFirstYear: New first year of data.
   void setFirstYear( int newFirstYear ) { firstYear = newFirstYear; }
   // Description: Sets the last year of data.
   //
   // Arguments:
   //   newLastYear: New last year of data.
   void setLastYear( int newLastYear ) { lastYear = newLastYear; }
   std::string toString() const;
};
