// $Id: LawChangeAGE65COMP.h 1.3 2006/11/08 10:58:59EST 044579 Development  $
//
// Declarations needed for class to manage parameters for a proposal to
// increase the number of elapsed years in a pia calculation.

#pragma once

#include "LawChange.h"

// {group:Calculation Classes}
// Description: Parameters for a proposal to increase the number of elapsed
//   years in a pia calculation.
//
// Remarks: There is one additional data field compared to the base class.
//
// If the indicator is greater than zero, its value of n is the number of years
// of increase in the elapsed years, so that the computation period is measured
// to age 62 + n. The change is phased in over a period of years according to
// the step size. (The computation increases by 1 year every step years.)
class LawChangeAGE65COMP : public LawChange
{
protected:
   // Description: Step size for increase in number of computation years.
   int step;
public:
   LawChangeAGE65COMP();
   // Description: Returns step size when increasing computation period.
   //
   // Returns: Step size when increasing computation period.
   int getStep() const { return step; }
   void prepareStrings( std::vector<std::string> &outputString );
   void read( std::istream& infile );
   // Description: Sets step size when increasing computation period.
   //
   // Arguments:
   //   newStep: New step size when increasing computation period.
   void setStep( int newStep ) { step = newStep; }
   void write( std::ostream& out ) const;
};
