// $Id: LawChangeALLEARN.h 1.4 2006/11/08 10:58:59EST 044579 Development  $
//
// Declarations needed for class to manage parameters for a proposal to
// use all years of earnings in an AIME calculation.

#pragma once

#include "LawChange.h"

// {group:Calculation Classes}
// Description: Parameters for a proposal to use all years of earnings in
// an AIME calculation.
//
// Remarks: There are two additional data fields compared to the base class.
//
// If the indicator is 1, we use all earnings in the numerator of the AIME
// calculation. If the indicator is 2, we use all earnings in the numerator
// after a "phase-in" period. The number of years of earnings used increases
// by 1 every step years, until we use all earnings in the specified year.
class LawChangeALLEARN : public LawChange
{
protected:
   // Description: Step size when phasing in use of all earnings in AIME
   // calculation.
   int step;
   // Description: Year when phase-in begins, when phasing in use
   //   of all earnings in AIME calculation.
   int yearPhasein;
public:
   LawChangeALLEARN();
   // Description: Returns step size when increasing number of earnings years.
   //
   // Returns: Step size when increasing number of earnings years.
   int getStep() const { return step; }
   // Description: Returns starting year when increasing number of earnings
   // years.
   //
   // Returns: Starting year when increasing number of earnings years.
   int getYear() const { return yearPhasein; }
   void prepareStrings( std::vector<std::string> &outputString );
   void read( std::istream& infile );
   // Description: Sets step size when increasing number of earnings years.
   //
   // Arguments:
   //   newStep: New step size when increasing number of earnings years.
   void setStep( int newStep ) { step = newStep; }
   // Description: Sets starting year when increasing number of earnings years.
   //
   // Arguments:
   //   newYear: New starting year when increasing number of earnings years.
   void setYear( int newYear ) { yearPhasein = newYear; }
   void write( std::ostream& out ) const;
};
