// $Id: LawChangeBPFRACWAGE.h 1.3 2006/11/08 10:58:59EST 044579 Development  $
//
// Declarations needed for class to manage parameters for a proposal to
// increase the bend points in the benefit formula by a fraction of average
// wage growth.

#pragma once

#include "LawChange.h"

// {group:Calculation Classes}
// Description: Parameters for a proposal to increase the bend points in
//   the benefit formula by a fraction of average wage growth.
//
// Remarks: There is one additional data field compared to the base class.
class LawChangeBPFRACWAGE : public LawChange
{
protected:
   // Description: Proportion of wage increase applied to bend points.
   double pbp;
public:
   LawChangeBPFRACWAGE();
   // Description: Returns proportion of wage increase applied to bend points.
   //
   // Returns: Proportion of wage increase applied to bend points.
   double getProportionBendPoints() const { return(pbp); }
   void prepareStrings( std::vector<std::string> &outputString );
   void read( std::istream& infile );
   // Description: Sets proportion of wage increase applied to bend points.
   //
   // Arguments:
   //   proportion: New proportion of wage increase applied to bend points.
   void setProportionBendPoints( double proportion ) { pbp = proportion; }
   void write( std::ostream& out ) const;
};
