// $Id: LawChangeBPSPECRATE.h 1.4 2006/11/08 10:58:59EST 044579 Development  $
//
// Declarations needed for class to manage parameters for a proposal to
// increase the bend points in the benefit formula by a specified growth rate.

#pragma once

#include "LawChange.h"
#include "dbleann.h"

// {group:Calculation Classes}
// Description: Parameters for a proposal to increase the bend points in
//   the benefit formula by a specified growth rate.
//
// Remarks: There is one additional data field compared to the base class.
class LawChangeBPSPECRATE : public LawChange
{
protected:
   // Description: Bend point increase percentages for PIA formula.
   DoubleAnnual bpinc;
public:
   LawChangeBPSPECRATE();
   // Description: Returns bend point increase percentage for specified year.
   //
   // Returns: Bend point increase percentage for specified year.
   //
   // Arguments:
   //   year: Year for which bend point increase percentage is desired.
   double getBendPiaInc( int year ) const { return(bpinc[year]); }
   void prepareStrings( std::vector< std::string > &outputString );
   void read( std::istream& infile );
   // Description: Sets bend point increase percentage for specified year.
   //
   // Arguments:
   //   year: Year for which bend point increase percentage is set.
   //   newData: New bend point increase percentage.
   void setBendPiaInc( int year, double newData ) { bpinc[year] = newData; }
   void write( std::ostream& out ) const;
};
