// $Id: LawChangeCHILDCAREDROPOUT.h 1.4 2006/11/08 10:58:58EST 044579 Development  $
//
// Declarations needed for class to manage parameters for a proposal to
// provide child care dropout years.

#pragma once

#include "LawChange.h"

// {group:Calculation Classes}
// Description: Parameters for a proposal to provide child care dropout years.
//
// Remarks: There are three additional data fields compared to the base class.
class LawChangeCHILDCAREDROPOUT : public LawChange
{
protected:
   // Description: Ratio of average earnings limit for a child care dropout
   // year.
   double fqRatio;
   // Description: Maximum age of child to get a child care dropout year.
   int maxAge;
   // Description: Maximum number of child care dropout years.
   int maxYears;
public:
   LawChangeCHILDCAREDROPOUT();
   // Description: Returns ratio of average earnings limit for a child care
   //   dropout year.
   //
   // Returns: Ratio of average earnings limit for a child care dropout year.
   double getFqRatio() const { return fqRatio; }
   // Description: Returns maximum age of child to get a child care dropout
   // year.
   //
   // Returns: Maximum age of child to get a child care dropout year.
   int getMaxAge() const { return maxAge; }
   // Description: Returns maximum number of child care dropout years.
   //
   // Returns: Maximum number of child care dropout years.
   int getMaxYears() const { return maxYears; }
   void prepareStrings( std::vector< std::string > &outputString );
   void read( std::istream& infile );
   // Description: Sets ratio of average earnings limit for a child care
   // dropout year.
   //
   // Arguments:
   //   newFqRatio: New ratio of average earnings limit for a child care
   //     dropout year.
   void setFqRatio( double newFqRatio ) { fqRatio = newFqRatio; }
   // Description: Sets maximum age of child to get a child care dropout year.
   //
   // Arguments:
   //   newMaxAge: New maximum age of child.
   void setMaxAge( int newMaxAge ) { maxAge = newMaxAge; }
   // Description: Sets maximum number of child care dropout years.
   //
   // Arguments:
   //   newMaxYears: New maximum number of child care dropout years.
   void setMaxYears( int newMaxYears ) { maxYears = newMaxYears; }
   void write( std::ostream& out ) const;
};
