// $Id: LawChangeCOLACHANGE.h 1.4 2006/11/08 10:58:59EST 044579 Development  $
//
// Declarations needed for class to manage parameters for a proposal to
// change the benefit increases (COLAs).

#pragma once

#include "LawChange.h"

// {group:Calculation Classes}
// Description: Parameters for a proposal to change the cost-of-living benefit
// increases.
//
// Remarks: Normally the cost-of-living benefit increase equals the inflation
// rate. This class allows two types of changes to the COLA.
//
// If the indicator is set to 1, it adjusts the cola up or down by a specified
// percentage. The percentage is stored in colaAdj.
//
// If the indicator is set to 2, it limits the dollar increase in pia resulting
// from applying the cola to an amount determined by finding a specified
// percentile in the pia distribution. The percentile is stored in
// piaPercentile.
class LawChangeCOLACHANGE : public LawChange
{
protected:
   // Description: Amount by which to adjust the COLA.
   double colaAdj;
   // Description: The PIA percentile to use when indicator == 2.
   int piaPercentile;
public:
   LawChangeCOLACHANGE();
   // Description: Returns the amount of adjustment to COLA.
   //
   // Returns: The amount of adjustment to COLA.
   double getColaAdj() const { return colaAdj; }
   // Description: Returns the PIA percentile to use when indicator == 2.
   //
   // Returns: The PIA percentile to use when COLACHANGE == 2.
   int getPiaPercentile() const { return piaPercentile; }
   void prepareStrings( std::vector< std::string > &outputString );
   void read( std::istream& infile );
   // Description: Sets the amount of adjustment to COLA.
   //
   // Arguments:
   //   newColaAdj: Amount by which to adjust the COLA (negative number means a
   //     smaller COLA, positive number means a bigger COLA).
   void setColaAdj( double newColaAdj ) { colaAdj = newColaAdj; }
   // Description: Sets the PIA percentile to use when indicator == 2.
   //
   // Arguments:
   //   newPiaPercentile: The PIA percentile to use.
   void setPiaPercentile( int newPiaPercentile )
      { piaPercentile = newPiaPercentile; }
   void write( std::ostream& out ) const;
};
