// $Id: LawChangeDROPOUTCHG.h 1.3 2006/11/08 10:58:59EST 044579 Development  $
//
// Declarations needed for class to manage parameters for a proposal to
// reduce the number of dropout years in a pia calculation.

#pragma once

#include "LawChange.h"

// {group:Calculation Classes}
// Description: Parameters for a proposal to reduce the number of dropout
// years in a pia calculation.
//
// Remarks: There is one additional data field compared to the base class.
//
// If the indicator is greater than zero, it indicates the number of years by
// which drop out years are to be decreased, phased in over period of years.
// The number of drop out years decreases by 1 every step years.
class LawChangeDROPOUTCHG : public LawChange
{
protected:
   // Description: Step size for reduction in number of dropout years.
   int step;
public:
   LawChangeDROPOUTCHG();
   // Description: Returns step size when reducing number of dropout years.
   //
   // Returns: Step size when reducing number of dropout years.
   int getStep() const { return step; }
   void prepareStrings( std::vector<std::string> &outputString );
   void read( std::istream& infile );
   // Description: Sets step size when reducing number of dropout years.
   //
   // Arguments:
   //   newStep: New step size when reducing number of dropout years.
   void setStep( int newStep ) { step = newStep; }
   void write( std::ostream& out ) const;
};
