// $Id: LawChangeNEWFORMULA.h 1.5 2006/11/08 10:58:59EST 044579 Development  $
//
// Declarations needed for class to manage parameters for a proposal to
// change the pia formula bend points and/or percentages.

#pragma once

#include "LawChange.h"
#include "dbleann.h"

// {group:Calculation Classes}
// Description: Parameters for a proposal to change the pia formula bend
//   points and/or percentages.
//
// Remarks: There are two additional data fields compared to the base class.
//
// Currently only an indicator of 1 is allowed. Then a new benefit formula of
// 3 percentages and 2 bend points is used for each year in the specified
// period. In the future we hope to allow for an indicator of 2, for a benefit
// formula of 4 percentages and 3 bend points.
class LawChangeNEWFORMULA : public LawChange
{
protected:
   // Description: Alternative PIA formula bend points.
   DoubleAnnual* bendpalt[3];
   // Description: Benefit formula percentages for PIA formula.
   DoubleAnnual* percpa[4];
public:
   LawChangeNEWFORMULA();
   ~LawChangeNEWFORMULA();
   // Description: Returns alternate bend point for specified year.
   //
   // Returns: Alternate bend point for specified year.
   //
   // Arguments:
   //   year: Year for which bend points are desired.
   //   bendNum: Bend point number (1 or 2 for 3-part formula; 1, 2, or 3 for
   //     4-part formula).
   double getAltBendPia( int year, int bendNum ) const
   { if (bendNum > 0 && bendNum < 4) return((*bendpalt[bendNum - 1])[year]);
     else return(0.0); }
   // Description: Returns benefit formula percentage for specified year.
   //
   // Returns: Benefit formula percentage for specified year.
   //
   // Arguments:
   //   year: Year of desired benefit formula percentage.
   //   percNum: Percentage number (0, 1, or 2 for 3-part formula; 0, 1, 2, or
   //     3 for 4-part formula).
   double getAltPercPia( int year, int percNum ) const
   {  if (percNum >= 0 && percNum < 4) return((*percpa[percNum])[year]);
      else return(0.0); }
   void prepareStrings( std::vector<std::string> &outputString );
   void read( std::istream& infile );
   // Description: Sets alternate bend point for specified year.
   //
   // Arguments:
   //   year: Year for which alternate bend point is being set.
   //   bendNum: Bend point number (1 or 2 for 3-part formula; 1, 2, or 3 for
   //     4-part formula).
   //   newAltBendPia: New alternate bend point.
   void setAltBendPia( int year, int bendNum, double newAltBendPia )
   { if (bendNum > 0 && bendNum < 4)
       (*bendpalt[bendNum - 1])[year] = newAltBendPia; }
   // Description: Sets alternate benefit formula percentage.
   //
   // Arguments:
   //   year: Year for which percentage is set.
   //   percNum: Percentage number (0, 1, or 2 for 3-part formula; 0, 1, 2, or
   //     3 for 4-part formula).
   //   newPerc: New alternate percentage.
   void setAltPercPia( int year, int percNum, double newPerc )
   { if (percNum >= 0 && percNum < 4) (*percpa[percNum])[year] = newPerc; }
   void write( std::ostream& out ) const;
};
