// $Id: LawChangeNEWSPECMIN.h 1.5 2006/11/08 10:58:59EST 044579 Development  $
//
// Declarations needed for class to manage parameters for a proposal to
// change the special minimum pia calculation.

#pragma once

#include "LawChange.h"

// {group:Calculation Classes}
// Description: Parameters for a proposal to change the special minimum
// pia calculation.
//
// Remarks: There are three additional data field compared to the base class,
// for changes to the dollar amount, the percentage of the old-law wage base
// required for a year of coverage, and the maximum number of years considered.
//
// If the indicator is greater than zero, it has the following meanings:
//
//   1 = new dollar amount.
//   2 = new maximum years of coverage.
//   3 = new dollar amount and maximum years of coverage.
//   4 = new year of coverage percent.
//   5 = new year of coverage percent and dollar amount.
//   6 = new year of coverage percent and maximum years of coverage.
//   7 = new year of coverage percent, dollar amount, and maximum years of
//       coverage.
class LawChangeNEWSPECMIN : public LawChange
{
protected:
   // Description: Alternative special minimum dollar amount.
   double theAmt;
   // Description: Alternative percent of old-law wage base required for a year
   // of coverage in special minimum method.
   double percent;
   // Description: Alternative maximum number of years of coverage considered
   // in special minimum calculation (30 in PL).
   int maxYearsOfCoverage;
public:
   LawChangeNEWSPECMIN();
   // Description: Returns alternative special minimum dollar amount.
   //
   // Returns: Alternative special minimum dollar amount.
   double getAmount() const { return(theAmt); }
   // Description: Returns alternate special minimum percentage of wage base
   //   required for quarter of coverage.
   //
   // Returns: Alternate special minimum percentage of wage base
   //   required for quarter of coverage.
   double getPercent() const { return percent; }
   // Description: Returns alternative maximum number of years of
   //   coverage considered in special minimum calculation (30 in PL).
   //
   // Returns: Alternative maximum number of years of
   //   coverage considered in special minimum calculation (30 in PL).
   int getYears() const { return(maxYearsOfCoverage); }
   void prepareStrings( std::vector<std::string> &outputString );
   void read( std::istream& infile );
   // Description: Sets alternative special minimum dollar amount.
   //
   // Arguments:
   //   newAmount: New alternative special minimum dollar amount.
   void setAmount( double newAmount ) { theAmt = newAmount; }
   // Description: Sets alternate special minimum percentage of wage base
   //   required for quarter of coverage.
   //
   // Arguments:
   //   newPercent: New alternative special minimum percentage of wage base.
   void setPercent( double newPercent ) { percent = newPercent; }
   // Description: Sets alternative maximum number of years of coverage
   //   considered in special minimum calculation (30 in PL).
   //
   // Arguments:
   //   newYears: New alternative special minimum maximum years of coverage.
   void setYears( int newYears ) { maxYearsOfCoverage = newYears; }
   void write( std::ostream& out ) const;
};
