// $Id: LawChangeTAXRATECHG.h 1.4 2006/11/08 10:59:16EST 044579 Development  $
//
// Declarations needed for class to manage parameters for a proposal to
// change the OASDHI tax rates.

#pragma once

#include "LawChange.h"
#include "TaxRates.h"

// {group:Calculation Classes}
// Description: Parameters for a proposal to change the OASDI tax rates.
//
// Remarks: There are five additional data fields compared to the base class.
//
// If the indicator is 1, the changed tax rates continue to have the
// self-employed rate equal to twice the employee rate. If the indicator is
// 2, the changed tax rates includeself-employed rates that are read in.
class LawChangeTAXRATECHG : public LawChange
{
public:
   // Description: Array sizes.
   enum DimLimits {
      MAXTAXRATES = 10 // Maximum number of new tax rate intervals.
   };
protected:
   // Description: Number of tax rates available.
   int numTaxrates;
   // Description: Years changed tax rates are effective.
   int yearTaxrate[MAXTAXRATES];
   // Description: Di tax rates (employee-employer and self-employed,
   //   for up to MAXTAXRATES intervals).
   double diTaxrate[TaxRates::NUMTAXRATETYPES][MAXTAXRATES];
   // Description: Hi tax rates (employee-employer and self-employed,
   //   for up to MAXTAXRATES intervals).
   double hiTaxrate[TaxRates::NUMTAXRATETYPES][MAXTAXRATES];
   // Description: Oasi tax rates (employee-employer and self-employed,
   //   for up to MAXTAXRATES intervals).
   double oasiTaxrate[TaxRates::NUMTAXRATETYPES][MAXTAXRATES];
public:
   LawChangeTAXRATECHG();
   // Description: Returns number of tax rates available.
   //
   // Returns: Number of tax rates available.
   int getNumTaxrates() const { return numTaxrates; }
   double getTaxrate( int yearNum, TaxRates::taxrateType eeer,
      TaxRates::trustfundType trustfund ) const;
   // Description: Returns year that changed tax rate is effective.
   //
   // Returns: Year that changed tax rate is effective.
   //
   // Arguments:
   //   yearNum: Number of tax rate interval (0 to numTaxrates - 1).
   int getYearTaxrate( int yearNum ) const{ return yearTaxrate[yearNum]; }
   void prepareStrings( std::vector<std::string> &outputString );
   void read( std::istream& infile );
   // Description: Sets number of tax rates available.
   //
   // Arguments:
   //   numRates: New number of tax rates.
   void setNumTaxrates( int numRates ) { numTaxrates = numRates; }
   void setSelfEmpTaxrate( int yearNum );
   void setTaxrate( int yearNum, TaxRates::taxrateType eeer,
      TaxRates::trustfundType trustfund, double newRate );
   // Description: Sets year that changed tax rate is effective.
   //
   // Arguments:
   //   yearNum: Number of tax rate interval (0 to numTaxrates - 1).
   //   year: New year of changed tax rate.
   void setYearTaxrate( int yearNum, int year )
      { yearTaxrate[yearNum] = year; }
   void write( std::ostream& out ) const;
};
