// $Id: LawChangeWAGEBASECHG.h 1.4 2006/11/08 10:59:16EST 044579 Development  $
//
// Declarations needed for class to manage parameters for a proposal to
// change the OASDI and/or old-law wage bases.

#pragma once

#include "LawChange.h"
#include "dbleann.h"

// {group:Calculation Classes}
// Description: Parameters for a proposal to change the OASDI and/or old-law
// wage bases.
//
// Remarks: There are two additional data fields compared to the base class.
//
// If the indicator is greater than zero, it has the following meanings:
//
//   1 = ad hoc OASDI wage bases.
//   2 = ad hoc old-law wage bases.
//   3 = ad hoc OASDI and old-law wage bases.
class LawChangeWAGEBASECHG : public LawChange
{
protected:
   // Description: Ad hoc wage bases.
   DoubleAnnual baseOasdi;
   // Description: Ad hoc 1977-law wage bases.
   DoubleAnnual base77;
public:
   LawChangeWAGEBASECHG();
   // Description: Returns ad hoc wage base for specified year.
   //
   // Returns: Ad hoc wage base for specified year.
   //
   // Arguments:
   //   year: Year of wage base.
   double getBaseOasdi( int year ) const { return baseOasdi[year]; }
   // Description: Returns ad hoc 1977-law wage base for specified year.
   //
   // Returns: Ad hoc 1977-law wage base for specified year.
   //
   // Arguments:
   //   year: Year of wage base.
   double getBase77( int year ) const { return base77[year]; }
   void prepareStrings( std::vector<std::string> &outputString );
   void read( std::istream& infile );
   // Description: Sets ad hoc wage base.
   //
   // Arguments:
   //   year: Year for which to set base.
   //   newBaseOasdi: New value of base.
   void setBaseOasdi( int year, double newBaseOasdi )
      { baseOasdi[year] = newBaseOasdi; }
   // Description: Sets ad hoc 1977-law wage base.
   //
   // Arguments:
   //   year: Year for which to set base.
   //   newBase77: New value of base.
   void setBase77( int year, double newBase77 ) { base77[year] = newBase77; }
   void write( std::ostream& out ) const;
};
