// $Id: MilServDatesVec.h 1.11 2006/04/17 14:49:43EDT 044579 Development  $
//
// Declarations needed for class to manage an array of military service
// dates records.

#pragma once

#include "msdates.h"

// {group:Calculation Classes}
// Description: Manages all the military service dates records for one ssn.
//
// Remarks: An instance of this class is created in WorkerData.
class MilServDatesVec
{
   friend class boost::serialization::access;
   // Description: Archives the data.
   //
   // Remarks: When the class Archive corresponds to an output archive, the
   // & operator is defined similar to <<. Likewise, when the class Archive is
   // a type of input archive, the & operator is defined similar to >>.
   //
   // Arguments:
   //   ar: The archive to use.
   //   version: The version of the archive to use.
   template< class Archive >
   void serialize( Archive& ar, const unsigned int version )
      { ar & msdates & msCount; }
public:
   // Description: The number of MilServDates records allowed.
   static const unsigned MAX_MILSERVDATES = 15;
   // Description: Up to MAX_MILSERVDATES MilServDates records.
   MilServDates msdates[MAX_MILSERVDATES];
protected:
   // Description: How many MilServDates records are being used.
   unsigned msCount;
public:
   MilServDatesVec();
   ~MilServDatesVec();
   void check() const;
   void deleteContents();
   double getEarn3750() const;
   double getEarn( unsigned year ) const;
   // Description: Returns first year with any military service, 0 if none.
   //
   // Returns: First year with any military service, 0 if none.
   int getFirstYear() const
      { return (msCount == 0) ? 0 : msdates[0].startDate.getYear(); }
   // Description: Returns last year with any military service, 0 if none.
   //
   // Returns: Last year with any military service, 0 if none.
   int getLastYear() const
      { return (msCount == 0) ? 0 : msdates[msCount - 1].endDate.getYear(); }
   // Description: Returns the number of records being used.
   //
   // Returns: The number of records being used.
   unsigned getMSCount() const { return(msCount); }
   unsigned getQc3750() const;
   unsigned getQcov( unsigned year ) const;
   void setMSCount( unsigned newMSCount );
   static void msCountCheck( unsigned newMSCount );
};
