// $Id: PageOut.h 1.11 2006/11/08 10:59:16EST 044579 Development  $
//
// Declarations needed for class to manage generic output.

#pragma once

#include <iosfwd>
#include <string>
#include <vector>
#include "outfile.h"

// {group:Miscellaneous Classes}
// Description: Manages a page of printed output.
//
// Remarks: This is a parent of each page of printed output in the Anypia
// program.
class PageOut
{
protected:
   // Description: Strings for output.
   std::vector<std::string> outputString;
public:
   PageOut();
   virtual ~PageOut();
   // Description: Returns number of lines of output.
   //
   // Returns: Number of lines of output.
   unsigned getCount() const { return (unsigned)outputString.size(); }
   // Description: Returns one line of output.
   //
   // Returns: The specified line of output.
   //
   // Arguments:
   //   index: Index of desired line (0-based).
   std::string getString( unsigned index ) const
      { return outputString[index]; }
   // Description: Prepares strings for output.
   virtual void prepareStrings() = 0;
   void print( Outfile& outfile ) const;
   void print( std::ostream& ostrm ) const;
};
