// $Id: PiaException.h 1.12 2007/05/14 10:53:31EDT 277133 Development  $
//
// Declarations for PiaException class.

#pragma once

#include <exception>
#include <string>

// {group:Miscellaneous Classes}
// Description: Manages an exception in the piadata library.
//
// Remarks: The exception could be created with a number, which could be
//   used to look up an associated string in a string table. Alternatively,
//   the exception could be created by a string, in which case the
//   associated number is set to zero.
class PiaException : public std::exception
{
protected:
   // Description: Number of exception.
   int exceptionNum;
   // Description: Message for this exception.
   std::string theMessage;
public:
   PiaException( int newNumber ) throw();
   PiaException( const std::string& newMessage ) throw();
   PiaException( const PiaException& piaException ) throw();
   // Description: Destructor.
   //
   // Remarks: Does nothing.
   ~PiaException() throw() { }
   // Description: Returns number of this exception.
   //
   // Returns: Number of this exception.
   int getNumber() const throw() { return exceptionNum; }
   // Description: Returns string with message about this error.
   //
   // Remarks: Note that this overrides a virtual function in the exception
   // class.
   //
   // Returns: String with message about this error.
   const char *what() const throw() { return theMessage.c_str(); }
private:
   operator=( const PiaException& );
};
