// $Id: Pifc.h 1.10 2006/06/07 07:46:46EDT 044579 Development  $
//
// Declarations needed for type of Social Security pia.

#pragma once

#include "OldStart.h"

// {group:Calculation Classes}
// Description: Represents a pia factor code (type of Social Security pia).
//
// Remarks: Represents a pia factor code (type of Social Security pia).
class Pifc
{
protected:
   // Description: Code for type of pia.
   //
   // Remarks:
   //
   // A - Transitional uninsured or insured PIA (unused).
   // B - AMW PIA.
   // C - Special minimum PIA.
   // E - AMW survivor PIA greater than life PIA (unused).
   // F - Special minimum survivor PIA greater than life PIA (unused).
   // G - AMW survivor PIA equal to life PIA (unused).
   // H - Special minimum survivor PIA equal to life PIA (unused).
   // K - Totalized (prorated) PIA.
   // L - AIME PIA.
   // M - Frozen minimum PIA.
   // N - New-start guarantee PIA.
   // O - Old-start guarantee PIA.
   // S - DIB guarantee PIA.
   // V - Modified old start windfall PIA.
   // W - Widow(er)'s reindexed PIA (used only in OACT code).
   // Y - Child care dropout years method (used only in OACT code).
   // Z - Northern Mariana Islands computation (unused).
   // 5 - Modified new start windfall PIA.
   // 7 - 1990 new start (unused).
   // 8 - 1990 old start.
   char theCode;
public:
   // Description: Initializes code.
   //
   // Arguments:
   //   newCode: New code to use. If omitted, code is set to blank character.
   Pifc( char newCode = ' ' ) : theCode(newCode) { }
   // Description: Returns the pifc code.
   //
   // Returns: The pifc code.
   char get() const { return theCode; }
   // Description: Returns true if able to apply cola to this benefit.
   //
   // Returns: True if able to apply cola to this benefit.
   //
   // Remarks: Code must not be special minimum or frozen minimum pia.
   bool isColable() const { return theCode != 'C' && theCode != 'M'; }
   // Description: Returns true if wage-indexed mfb applies to this benefit.
   //
   // Returns: True if wage-indexed mfb applies to this benefit.
   bool isNewMfb() const { return theCode == 'L' || theCode == 'M' ||
      theCode == 'N' || theCode == 'O' || theCode == 'Y' || theCode == 'V' ||
      theCode == '5'; }
   // Description: Sets the pifc code.
   //
   // Arguments:
   //   newCode: New pifc code.
   void set( char newCode ) { theCode = newCode; }
   static char pifcCal( int appnum, PiaMethod::WindfallElimType indwind,
      OldStart::OldStartType methodOS, bool bamend90, bool btotalize );
};
