// $Id: QcArray.h 1.22 2006/11/08 12:31:11EST 044579 Development  $
//
// Declarations needed for class to manage array of annual quarters of
// coverage.

#pragma once

#include <vector>
#include "boost/serialization/access.hpp"
#include "qc.h"
#include "QcPacked.h"
#include "qtryear.h"

// {group:Calculation Classes}
// Description: Manages an array of annual quarters of coverage.
//
// Remarks: The quarters of coverage are stored in QcPacked structures to
//   save space.
class QcArray
{
   friend class boost::serialization::access;
   // Description: Archives the data.
   //
   // Remarks: When the class Archive corresponds to an output archive, the
   // & operator is defined similar to <<. Likewise, when the class Archive is
   // a type of input archive, the & operator is defined similar to >>.
   //
   // Arguments:
   //   ar: The archive to use.
   //   version: The version of the archive to use.
   template< class Archive >
   void serialize( Archive& ar, const unsigned int version )
      { ar & firstYear & lastYear & theData; }
protected:
   // Description: First year of data.
   unsigned short firstYear;
   // Description: Last year of data.
   unsigned short lastYear;
   // Description: Quarters of coverage data.
   std::vector< QcPacked > theData;
public:
   QcArray( int firstyr, int lastyr );
   QcArray( const QcArray& qcArray );
   // Description: Deletes allocated memory.
   ~QcArray() { }
   unsigned accumulate( int firstyr, int lastyr,
      unsigned startValue ) const;
   unsigned accumulate( const QtrYear& qtrYear1, const QtrYear& qtrYear2,
      unsigned startValue ) const;
   void assign( unsigned value, int firstYeart, int lastYeart );
   void assign( const QcArray &qcArray, int firstYeart, int lastYeart );
   // Description: Sets values to zero.
   //
   // Remarks: The version with no arguments sets all values to zero. The
   // version with 2 arguments sets values to zero in the specified range.
   void deleteContents() { deleteContents(firstYear, lastYear); }
   void deleteContents( int firstyr, int lastyr );
   unsigned get( int year ) const;
   // Description: Returns the last year of data.
   //
   // Returns: The last year of data.
   int getLastYear() const { return(lastYear); }
   void set( int year, unsigned value );
   std::string toString( int firstyr, int lastyr ) const;
};
