// $Id: QcPacked.h 1.10 2006/04/17 14:49:57EDT 044579 Development  $
//
// Definition of class to hold 8 quarters of coverage amounts in one word.

#pragma once

#include "boost/serialization/access.hpp"

// {group:Calculation Classes}
// Description: Holds 8 annual quarters of coverage amounts in one word (4
// bytes). Each value is in 4 bits, and can take values from 0 to 4.
//
// Remarks: This class is used in QcArray to save space.
class QcPacked
{
   friend class boost::serialization::access;
   // Description: Archives the data.
   //
   // Remarks: When the class Archive corresponds to an output archive, the
   // & operator is defined similar to <<. Likewise, when the class Archive is
   // a type of input archive, the & operator is defined similar to >>.
   //
   // Arguments:
   //   ar: The archive to use.
   //   version: The version of the archive to use.
   template< class Archive >
   void serialize( Archive& ar, const unsigned int version )
      { ar & qc0_1 & qc2_3 & qc4_5 & qc6_7; }
public:
   // Description: Number of elements in this class.
   static const unsigned NUM_QCS = 8;
protected:
   // Description: First and second quarter of coverage amounts.
   unsigned char qc0_1;
   // Description: Third and fourth quarter of coverage amounts.
   unsigned char qc2_3;
   // Description: Fifth and sixth quarter of coverage amounts.
   unsigned char qc4_5;
   // Description: Seventh and eighth quarter of coverage amounts.
   unsigned char qc6_7;
public:
   // Description: Initialize all values to 0.
   QcPacked() : qc0_1(0), qc2_3(0), qc4_5(0), qc6_7(0) { }
   unsigned get( int index ) const;
   void set( int index, unsigned value );
};
