// $Id: ScaledEarnFactors.h 1.6 2007/02/06 12:01:54EST 044579 Development  $
//
// Declarations needed for scaled earnings factors class.

#pragma once

#include <vector>
#include <iosfwd>
class EarnProject;
class AverageWage;

// {group:Calculation Classes}
// Description: The ScaledEarnFactors class manages scaled earner amounts.
//
// Remarks: The factors are read in from an open file. They begin at firstAge
// and go through lastAge. There are three levels of scaled earnings: high,
// average, and low.
class ScaledEarnFactors
{
protected:
   // Description: Vector of high earner factors.
   std::vector< double > highFactors;
   // Description: Vector of average earner factors.
   std::vector< double > averageFactors;
   // Description: Vector of low earner factors.
   std::vector< double > lowFactors;
   // Description: Width of field when writing to an output file.
   int fieldWidth;
   // Description: Number of decimal places when writing to an output file.
   int numDecimals;
   // Description: Base age of data.
   const int firstAge;
   // Description: Last age of data.
   const int lastAge;
public:
   ScaledEarnFactors( int newFirstAge, int newLastAge );
   ~ScaledEarnFactors();
   double getAverageEarnFactor( int theAge ) const;
   // Description: Returns number of decimal places in output.
   //
   // Returns: Number of decimal places in output.
   int getDecimals() const { return(numDecimals); }
   // Description: Returns first age.
   //
   // Returns: First age.
   int getFirstAge() const { return(firstAge); }
   double getHighEarnFactor( int theAge ) const;
   // Description: Returns last age.
   //
   // Returns: Last age.
   int getLastAge() const { return(lastAge); }
   double getLowEarnFactor( int theAge ) const;
   // Description: Returns width of output.
   //
   // Returns: Width of output.
   int getWidth() const { return(fieldWidth); }
   void read( std::istream& in, int ageStart, int ageEnd );
   void setAverageEarnings( EarnProject& earnProject,
      const AverageWage& averageWage, int birthYear, int ageStart,
      int ageEnd );
   // Description: Sets number of decimals in output field.
   //
   // Arguments:
   //   newWidth: New number of decimals in output.
   void setDecimals( int newDecimals ) { numDecimals = newDecimals; }
   void setHighEarnings( EarnProject& earnProject,
      const AverageWage& averageWage, int birthYear, int ageStart,
      int ageEnd );
   void setLowEarnings( EarnProject& earnProject,
      const AverageWage& averageWage, int birthYear, int ageStart,
      int ageEnd );
   // Description: Sets width of output field.
   //
   // Arguments:
   //   newWidth: New width of output field.
   void setWidth( int newWidth ) { fieldWidth = newWidth; }
   void write( std::ostream& out, int ageStart, int ageEnd );
private:
   ScaledEarnFactors& operator=( const ScaledEarnFactors& );
};
