// $Id: Sex.h 1.7 2006/11/08 10:59:52EST 044579 Development  $
//
// Declarations needed for sex indicator class.

#pragma once

#include <string>

// {group:Miscellaneous Classes}
// Description: Indicator for sex type.
//
// Remarks: Most functions are inline for efficiency.
class Sex
{
public:
   // Description: The enumerated sex indicator.
   enum sex_type {
      MALE,  // Male.
      FEMALE,  // Female.
      NUM_SEX  // Number of sexes.
   };
private:
   // Description: The sex code (see sex_type).
   int theCode;
public:
   // Description: Constructor.
   //
   // Remarks: The default constructor sets the sex code to MALE.
   Sex() : theCode(MALE) { }
   // Arguments:
   //   newCode: New sex code. If omitted, sex is initialized to MALE.
   Sex( sex_type newCode ) : theCode(newCode) { }
   // Arguments:
   //   sex: The Sex to copy from.
   Sex( const Sex& sex ) : theCode(sex.theCode) { }
   // Description: Destructor.
   //
   // Remarks: Does nothing.
   ~Sex() { }
   // Description: Copies from another Sex.
   //
   // Arguments:
   //   sex: The Sex to copy from.
   Sex& operator=( const Sex& sex ) { theCode = sex.theCode; }
   // Description: Returns output label for sex of worker.
   //
   // Returns: Output label for sex of worker.
   std::string toString() const { return(theCode == MALE ?
      std::string("male") : std::string("female") ); }
   std::string toString( const std::string& format ) const;
   static void check( int newSex );
};
