// $Id: SgaDerived.h 1.3 2002/06/07 12:22:34EDT sfmckay Exp  $
//
// Declarations to handle derived classes of the SgaGeneral class.

#ifndef __SGADERIVED_H
#define __SGADERIVED_H

#include "SgaGeneral.h"

// {group:Calculation Classes}
// Description: Manages the annual SGA amounts (historical
//   and projected) for blind beneficiaries.
//
// Remarks: Manages the annual SGA amounts (historical
//   and projected) for blind beneficiaries.
class SgaBlindA : public SgaGeneral
{
   public:
      SgaBlindA( int newLastYear );
      void project( const DoubleAnnual& averageWages );
};

// {group:Calculation Classes}
// Description: Manages the monthly SGA amounts (historical
//   and projected) for blind beneficiaries (as of December).
//
// Remarks: Manages the monthly SGA amounts (historical
//   and projected) for blind beneficiaries (as of December).
class SgaBlindM : public SgaGeneral
{
   public:
      SgaBlindM( int newLastYear );
};

// {group:Calculation Classes}
// Description: Manages the annual SGA minimum amounts
//   (historical and projected) for non-blind beneficiaries.
//
// Remarks: Manages the annual SGA minimum amounts
//   (historical and projected) for non-blind beneficiaries.
class SgaMinA : public SgaGeneral
{
   public:
      SgaMinA( int newLastYear );
      void project( const DoubleAnnual& averageWages );
};

// {group:Calculation Classes}
// Description: Manages the monthly SGA minimum amounts
//   (historical and projected) for non-blind beneficiaries (as of December).
//
// Remarks: Manages the monthly SGA minimum amounts
//   (historical and projected) for non-blind beneficiaries (as of December).
class SgaMinM : public SgaGeneral
{
   public:
      SgaMinM( int newLastYear );
      void project( const DoubleAnnual& averageWages );
};

// {group:Calculation Classes}
// Description: Manages the annual SGA maximum amounts
//   (historical and projected) for non-blind beneficiaries.
//
// Remarks: Manages the annual SGA maximum amounts
//   (historical and projected) for non-blind beneficiaries.
class SgaMaxA : public SgaGeneral
{
   public:
      SgaMaxA( int newLastYear );
      void project( const DoubleAnnual& averageWages );
};

// {group:Calculation Classes}
// Description: Manages the monthly SGA maximum amounts
//   (historical and projected) for non-blind beneficiaries (as of December).
//
// Remarks: Manages the monthly SGA maximum amounts
//   (historical and projected) for non-blind beneficiaries (as of December).
class SgaMaxM : public SgaGeneral
{
   public:
      SgaMaxM( int newLastYear );
};

#endif  // ifndef __SGADERIVED_H
