// $Id: SgaGeneral.h 1.6 2003/12/02 17:16:27EST sfmckay Exp  $
//
// Declarations to handle historical and projected SGA (Substantial Gainful
// Activity) amounts, stored in arrays.

#ifndef __SGAGENERAL_H
#define __SGAGENERAL_H

#include "dbleann.h"

// {group:Calculation Classes}
// Description: Parent of classes to manage the
//   SGA (Substantial Gainful Activity) amounts (historical and projected).
//
// Remarks: Any users of this class should make sure to call the project
//   function (for monthly projections) because the constructor only
//   initializes the historical data.
//
// The only thing here that might ever need to be updated is FIRST_PROJ_YEAR.
// This does NOT need to be updated for every TR. For example, in the 2005
// TR, the FIRST_PROJ_YEAR could still be 2001, even thought 2001 is really
// an historical year. This is because the only information the projection
// needs is the updated Average Wage Series (which does get updated every
// year). Once the average wages are updated, the projections will work
// automatically.
//
// So the only reason to change the FIRST_PROJ_YEAR would be if there was
// some change in the law that would not let the projections kick off from
// 2000 amounts. In such a case, make sure to:
//    1) Set FIRST_PROJ_YEAR correctly (in this file).
//    2) Go to the function SgaMinM::project() in the file SgaDerived.cpp,
//       and update the hard-coded number that over-writes the data value
//       in year FIRST_PROJ_YEAR - 1. This number should match the max
//       value for the corresponding year.
//    3) In the file SgaDerived.cpp, update all the calls to construct an
//       SgaGeneral with the proper base years passed in (if they have
//       changed).
//    4) In the file SgaDerived.cpp, update all the constructors which
//       initialize data. They should make sure to initialize the data
//       for all years up to (but not including) FIRST_PROJ_YEAR - 1.
class SgaGeneral : public DoubleAnnual
{
   protected:
      // Year of base SGA amount used for projections.
      int baseSgaYear;
      // Year of base Average Wage used for projections.
      int baseAverageWageYear;
      // First year of projection (2001).
      static const int FIRST_PROJ_YEAR = 2001;
   protected:
      static double project1( double baseAmount, double numerator,
         double denominator, double previous );
   public:
      SgaGeneral( int newLastYear, int newBaseSgaYear );
      virtual ~SgaGeneral();
      void convertMonthToAnnual( const SgaGeneral& sgaM );
      virtual void project( const DoubleAnnual& averageWages );
};

#endif  // ifndef __SGAGENERAL_H
