// $Id: SpecMin.h 1.13 2006/11/08 10:59:52EST 044579 Development  $
//
// Declarations needed for class to manage special minimum pia calculation
// functions.

#pragma once

#include "OldPia.h"

// {group:Calculation Classes}
// Description: Manages the functions required for calculation of a
//   special minimum Social Security benefit.
//
// Remarks: An instance of this class is used in PiaCal.
class SpecMin : public OldPia
{
protected:
   // Description: Number of years of coverage in special minimum
   // in excess of 10, up to 30.
   int specMinYearsExcess;
   // Description: Special minimum dollar amount per year of coverage.
   double specMinAmount;
   // Description: Total number of years of coverage.
   int yearsTotal;
public:
   SpecMin( const WorkerDataGeneral& newWorkerData,
      const PiaData& newPiaData, const PiaParams& newPiaParams,
      int newMaxyear );
   virtual ~SpecMin();
   void calculate();
   // Description: Returns number of years of coverage in special minimum
   //   in excess of 10, up to 30.
   //
   // Returns: Number of years of coverage in special minimum
   //   in excess of 10, up to 30.
   int getSpecMinYearsExcess() const { return(specMinYearsExcess); }
   // Description: Returns special minimum dollar amount per year of coverage.
   //
   // Returns: Special minimum dollar amount per year of coverage.
   double getSpecMinAmount() const { return(specMinAmount); }
   // Description: Returns number of years of coverage.
   //
   // Returns: Number of years of coverage.
   int getYearsTotal() const { return(yearsTotal); }
   void initialize();
   bool isApplicable();
   // Description: Sets special minimum dollar amount per year of coverage.
   //
   // Arguments:
   //   newAmount: New dollar amount per year of coverage.
   void setSpecMinAmount( double newAmount ) { specMinAmount = newAmount; }
   // Description: Sets number of years of coverage in special minimum in
   //   excess of 10, up to 30.
   //
   // Arguments:
   //   newYears: New number of years of coverage.
   void setSpecMinYearsExcess( int newYears ) { specMinYearsExcess = newYears; }
   virtual int specMinYearsExcessCal() const;
   static bool isApplicable( const WorkerDataGeneral& workerData );
private:
   SpecMin operator=( SpecMin newSpecMin );
};
