// $Id: TaxBenefits.h 1.6 2002/06/07 12:22:34EDT sfmckay Exp  $
//
// Declarations needed for class to manage tax on benefits functions.

#ifndef __TAXBENEFITS_H
#define __TAXBENEFITS_H

// {group:Calculation Classes}
// Description: Contains the functions required to calculate
//   the tax on a Social Security benefit.
//
// Remarks: Contains the functions required to calculate
//   the tax on a Social Security benefit.
class TaxBenefits
{
   public:
      // OASDI threshold for single taxpayers.
      static const double SINGLEOASDITHRESHOLD;
      // OASDI threshold for married taxpayers.
      static const double MARRIEDOASDITHRESHOLD;
      // OASDHI threshold for single taxpayers.
      static const double SINGLEOASDHITHRESHOLD;
      // OASDHI threshold for married taxpayers.
      static const double MARRIEDOASDHITHRESHOLD;
      // OASDHI tax for single taxpayers in first tier.
      static const double SINGLEOASDHITAX;
      // OASDHI tax for married taxpayers in first tier.
      static const double MARRIEDOASDHITAX;
   public:
      TaxBenefits();
      virtual ~TaxBenefits();
      virtual double deductionsCal( unsigned startAge, double aggContribs,
         double taxRecovered, int year ) const;
      virtual double getProportion( int ) const;
      virtual double getThreshold( bool married, int ) const;
      double taxOasdi( int year, double magi, double benefits,
         bool married ) const;
      virtual double taxOasdhi( int year, double magi, double benefits,
         bool married ) const;
};

#endif  // __TAXBENEFITS_H
