// $Id: TaxData.h 1.8 2006/11/08 11:00:08EST 044579 Development  $
//
// Declarations for class to manage tax rates and taxes paid.

#pragma once

#include <vector>
#include "dbleann.h"
#include "TaxRates.h"

// {group:Calculation Classes}
// Description: Manages the Social Security payroll and
//   self-employed taxes paid by a worker.
//
// Remarks: An instance of this class is used in the Anypia program.
class TaxData
{
public:
   // Description: Dimension limits.
   enum YEAR_GROUP {
      YEARS1937_50 = 0,  // Years 1937 to 1950.
      YEARS1937PLUS,     // All years starting with 1937.
      NUMYEARPERIODS     // Number of year periods.
   };
   // Description: OASI taxes paid by year.
   DoubleAnnual taxesOasi;
   // Description: DI taxes paid by year.
   DoubleAnnual taxesDi;
   // Description: OASDI taxes paid by year.
   DoubleAnnual taxesOasdi;
   // Description: HI taxes paid by year.
   DoubleAnnual taxesHi;
   // Description: OASDHI taxes paid by year.
   DoubleAnnual taxesOasdhi;
protected:
   // Description: Total taxes over all years in 2 time periods.
   //
   // Remarks: There are 5 types of taxes in 2 time periods (1937-50 and
   //   1937+) (see TaxRates::trustfundType).
   std::vector< double > taxTotal[TaxRates::NUMTRUSTFUNDTYPES];
   // Description: Maximum year allowed.
   int maxyear;
public:
   TaxData( int lastYear );
   // Description: Destroys a TaxData instance.
   ~TaxData() { }
   // Description: Returns total taxes paid for a trust fund type and a period
   // of years.
   //
   // Returns: Total taxes paid for a trust fund type and a period of years.
   //
   // Arguments:
   //   trustfund: Type of taxes.
   //   yearGroup: Group of years to use (see taxTotal).
   double getTaxesTotal( TaxRates::trustfundType trustfund,
      YEAR_GROUP yearGroup ) const
      { return(taxTotal[trustfund][yearGroup]); }
   void oasdhiTaxCal();
   void totalTaxCal();
};
