// $Id: Trace.h 1.4 2006/11/08 11:00:09EST 044579 Development  $
//
// Declarations for class to trace execution of code.

#pragma once

#include <vector>
#if !defined(SHORTFILENAMES)
#include "TraceListener.h"
#else
#include "trlish"
#endif

// {group:Miscellaneous Classes}
// Description: Controls the logfiles used to trace execution of code.
//
// Remarks: This class maintains a vector of TraceListener objects.  When
//   a Trace function is called, the corresponding function is called for each
//   TraceListener object.  Note that all public functions are static, and
//   there is no public constructor.  Simply use the static functions
//   directly, without an instance of Trace, i.e. Trace::writeLine("abc").
class Trace
{
private:
   // Description: The vector of TraceListener objects.
   static std::vector< TraceListener* > listeners;
private:
   Trace();
   Trace( const Trace& );
   ~Trace();
   Trace& operator=( const Trace& ) { return *this; }
public:
   static void close();
   static void flush();
   static void write( const std::string& str );
   static void write( const char *str );
   static void writeLine( const std::string& str );
   static void writeLine( const char *str );
   // Description: Returns the vector of TraceListener objects.
   //
   // Returns: The vector of TraceListener objects.
   static std::vector< TraceListener* >& getListeners() { return listeners; }
};
