// $Id: TraceListener.h 1.4 2006/11/08 11:00:08EST 044579 Development  $
//
// Declarations for parent of classes that listen for Trace output.

#pragma once

#include <string>

// {group:Miscellaneous Classes}
// Description: The parent of classes that listen for Trace output.
//
// Remarks: Child classes are DefaultTraceListener (not yet implemented) and
// TextWriterTraceListener.
class TraceListener
{
protected:
   TraceListener();
public:
   // Description: Closes this TraceListener.
   //
   // Remarks: The default version does nothing.
   virtual void close() { }
   // Description: Flushes the output of this TraceListener.
   //
   // Remarks: The default version does nothing.
   virtual void flush() { }
   // Description: Write a string of output, without a newline.
   //
   // Arguments:
   //   str: The string to write.
   virtual void write( const std::string& str ) = 0;
   virtual void write( const char *str ) = 0;
   // Description: Write a string of output, with a newline.
   //
   // Arguments:
   //   str: The string to write.
   virtual void writeLine( const std::string& str ) = 0;
   virtual void writeLine( const char *str ) = 0;
   virtual ~TraceListener();
};
