// $Id: WageIndGeneral.h 1.11 2006/11/08 11:00:08EST 044579 Development  $
//
// Declarations needed for parent of classes to manage wage-indexed pia
// calculation functions.

#pragma once

#include "PiaMethod.h"

// {group:Calculation Classes}
// Description: Parent of all classes that manage the functions required for
//   calculation of a wage indexed Social Security benefit.
//
// Remarks: Parent of all classes that manage the functions required for
//   calculation of a wage indexed Social Security benefit.
class WageIndGeneral : public PiaMethod
{
public:
   // Description: Bend points for MFB formula.
   BendMfb bendMfb;
   // Description: Bend points for PIA formula.
   BendPia bendPia;
   // Description: Wage-indexed MFB formula percentages.
   PercMfb percMfb;
   // Description: Wage-indexed PIA formula percentages.
   PercPia percPia;
   // Description: Windfall PIA formula percentages.
   PercPia percWind;
   // Description: Portion of AIME in each interval of PIA formula.
   double portionAime[3];
   // Description: Portion of AIME PIA in each interval of MFB formula.
   double portionPiaElig[4];
   // Description: MFB at entitlement before real-wage-gain adjustment.
   BenefitAmount mfbRealWageGain;
   // Description: PIA at entitlement before real-wage-gain adjustment.
   BenefitAmount piaRealWageGain;
protected:
   // Description: Windfall indicator.
   WindfallElimType windfallInd;
   // Description: Number of years of coverage for windfall elimination.
   int yearsTotal;
   // Description: Average wage in indexing year.
   double indexYearAvgWage;
public:
   WageIndGeneral( const WorkerDataGeneral& newWorkerData,
      const PiaData& newPiaData, const PiaParams& newPiaParams,
      int newMaxyear, const std::string& newTitle, pia_type newMethod );
   virtual ~WageIndGeneral();
   double aimepiaCal( const double portionAime[], const PercPia& percPiaTemp,
      int year );
   void bendPointCal( int eligYear, BendPia& bendPiaTemp ) const;
   double deconvertAme( const BendPia& bendPiaTemp,
      const PercPia& percPiaTemp ) const;
   // Description: Returns average wage in indexing year.
   //
   // Returns: Average wage in indexing year.
   double getIndexYearAvgWage() const { return indexYearAvgWage; }
   // Description: Returns windfall indicator in wage-indexed method.
   //
   // Returns: Windfall indicator in wage-indexed method.
   PiaMethod::WindfallElimType getWindfall() const { return(windfallInd); }
   int getYearsTotal() const;
   void indexEarnings( int year1, int year2, int year3,
      const DoubleAnnual& earnings, DoubleAnnual& uearn,
      DoubleAnnual& vearn, const DoubleAnnual& fq );
   void initialize();
   void realWageGainAdj( int eligYear );
   // Description: Sets windfall indicator in wage-indexed method.
   //
   // Arguments:
   //   newWindfall: New windfall indicator.
   void setWindfall( WindfallElimType newWindfall )
      { windfallInd = newWindfall; }
   void windfallCal();
   static void setPortionAime( double amesub, double aimepart[],
      const BendPia& bendPiaTemp );
private:
   WageIndGeneral& operator=( WageIndGeneral& newWageIndGeneral );
};
