// $Id: avgwg.h 1.16 2006/04/17 14:48:23EDT 044579 Development  $
//
// Declarations needed for class to manage array of average wages.

#pragma once

#include <cmath>
#include "boost/serialization/base_object.hpp"
#include "dbleann.h"
#include "Floor.h"

class Awinc;

// {group:Calculation Classes}
// Description: Manages an array of average wage indexing amounts, or any
//   other earnings series.
//
// Remarks: Manages an array of average wage indexing amounts, or any
//   other earnings series.
class AverageWage : public DoubleAnnual
{
   friend class boost::serialization::access;
   // Description: Archives the data.
   //
   // Remarks: When the class Archive corresponds to an output archive, the
   // & operator is defined similar to <<. Likewise, when the class Archive is
   // a type of input archive, the & operator is defined similar to >>.
   //
   // Arguments:
   //   ar: The archive to use.
   //   version: The version of the archive to use.
   template< class Archive >
   void serialize( Archive& ar, const unsigned int version )
      { ar & boost::serialization::base_object<DoubleAnnual>(*this); }
public:
   AverageWage( int newBaseYear, int newLastYear );
   ~AverageWage();
   int endYear() const;
   void project( const Awinc& averageWageInc, int firstYeart );
   void project( double factor, int firstYeart, int lastYeart );
   void projectBack( int year, double factor );
   void projectForward( int year, double factor );
   int startYear() const;
   // Description: Projects an earnings amount forward for one year.
   //
   // Remarks: The version with a year argument calls the static version with
   // an amount and a factor.
   //
   // Returns: The projected earnings.
   //
   // Arguments:
   //   amount: Earnings amount.
   //   factor: Multiplicative factor used to increase previous year.
   static double projectForward( double amount, double factor )
      { return round(factor * amount); }
   // Description: Projects an earnings amount back for one year.
   //
   // Remarks: The version with a year argument calls the static version with
   // an amount and a factor.
   //
   // Returns: The backward-projected earnings.
   //
   // Arguments:
   //   amount: Earnings amount.
   //   factor: Multiplicative factor used to decrease from following year.
   static double projectBack( double amount, double factor )
      { return round(amount / factor); }
   // Description: Rounds an earnings amount to 2 decimal places.
   //
   // Returns: Rounded earnings.
   //
   // Arguments:
   //   wage: Earnings to round.
   static double round( double wage )
      { return (FLOOR(wage * 100.0 + 0.5)) / 100.0; }
};
