// $Id: awbidat.h 1.15 2006/11/08 10:57:57EST 044579 Development  $
//
// Class to manage historical Social Security parameters.

#pragma once

#include "dbleann.h"

// {group:Calculation Classes}
// Description: Manages the historical Social Security parameters.
//
// Remarks: Manages the historical Social Security parameters:
//   historical benefit increases, average wages, OASDI wage bases, old-law
//   wage bases, and HI wage bases. The AwbiData class cannot be instantiated;
//   use one of its subclasses:  AwbiDataFile or AwbiDataNonFile.
class AwbiData
{
public:
   // Description: Year when HI wage base first differs from OASDI base.
   static const int HI_BASE_YEAR = 1991;
   // Description: Historical benefit increases.
   DoubleAnnual cpiinc;
   // Description: Historical average wages.
   DoubleAnnual fq;
   // Description: Historical OASDI wage bases.
   DoubleAnnual baseOasdi;
   // Description: Historical old-law wage bases.
   DoubleAnnual base77;
   // Description: Historical HI wage bases.
   DoubleAnnual baseHi;
protected:
   // Description: Last year of wage bases to read or write.
   int lastYear;
   // Description: Maximum projected year.
   int maxyear;
public:
   AwbiData( int newLastYear, int newMaxyear );
   explicit AwbiData( int newMaxyear );
   virtual ~AwbiData();
   // Description: Gets last year of wage bases.
   //
   // Returns: Last year of wage bases.
   int getLastYear() const { return(lastYear); }
   virtual void read();
   // Description: Set data values.
   virtual void setData() = 0;
   // Description: Sets last year of each set of data.
   //
   // Arguments:
   //   newLastYear: Last year of wage bases.
   void setLastYear ( int newLastYear ) { lastYear = newLastYear; }
   virtual void write();
};
