// $Id: bendpia.h 1.11 2006/11/08 14:19:21EST 044579 Development  $
//
// Declarations needed for class to manage array of PIA formula bend points.

#pragma once

#include <cstddef>
#include "avgwg.h"

// {group:Calculation Classes}
// Description: Manages the array of bend points used in the PIA formula.
//
// Remarks: An instance of this class is used in WageIndGeneral.
class BendPia
{
private:
   // Description: Dimension limits.
   enum DimLimits {
      // Number of percentages.
      MAXBP = 3
   };
   // Description: Array of bend points.
   double theData[MAXBP];
public:
   // Description: Three bend points from 1979.
   static const double BP1979[MAXBP];
   // Description: The type of data in this array.
   typedef double value_type;
   // Description: An iterator for this array.
   typedef double* iterator;
   // Description: A const iterator for this array.
   typedef const double* const_iterator;
   // Description: A reference for this array.
   typedef double& reference;
   // Description: A const reference for this array.
   typedef const double& const_reference;
   // Description: The type of size in this array.
   typedef std::size_t size_type;
   // Description: The type of difference in this array.
   typedef ptrdiff_t difference_type;
   BendPia();
   ~BendPia();
   // Description: Returns a pia formula bend point.
   //
   // Remarks: There is a const and a non-const version.
   //
   // Returns: A pia formula bend point.
   //
   // Arguments:
   //   index: Index of bend point desired (0-2).
   reference operator[]( std::size_t index ) { return theData[index]; }
   const_reference operator[]( std::size_t index ) const { return theData[index]; }
   // Description: Returns bend points as a simple array.
   //
   // Returns: Percentages as a simple array.
   double* as_array() { return theData; }
   // Description: Returns beginning of array.
   //
   // Remarks: There is a const and a non-const version.
   //
   // Returns: Beginning of array.
   iterator begin() { return theData; }
   const_iterator begin() const { return theData; }
   void deleteContents();
   // Description: Returns one past end of array.
   //
   // Remarks: There is a const and a non-const version.
   //
   // Returns: One past end of array.
   iterator end() { return theData + MAXBP; }
   const_iterator end() const { return theData + MAXBP; }
   // Description: Returns maximum number of bend points.
   //
   // Returns: Number of bend points.
   size_type max_size() const { return MAXBP; }
   void project( int eligYear, const AverageWage& fq );
   // Description: Returns number of bend points.
   //
   // Returns: Number of bend points.
   size_type size() const { return MAXBP; }
};
