// $Id: biproj.h 1.18 2006/11/08 10:58:17EST 044579 Development  $
//
// Declarations for class to manage projected benefit increases.

#pragma once

#include "dbleann.h"

// {group:Calculation Classes}
// Description: Abstract parent of classes that manage the file of projected
//   benefit increases.
//
// Remarks: Abstract parent of classes that manage the file of projected
//   benefit increases.
class Biproj
{
protected:
   // Description: First year of data.
   int firstYear;
   // Description: Title of projected benefit increases.
   std::string biprojTitle;
   // Description: Titles of projected benefit increase assumptions
   std::string beninc[3];
public:
   // Description: Array of projected benefit increases.
   DoubleAnnual theData;
public:
   Biproj( int newIstart, int newMaxyear );
   virtual ~Biproj();
   // Description: Returns first year of data.
   //
   // Returns: First year of data.
   int getFirstYear() const { return firstYear; }
   // Description: Returns title of assumptions.
   //
   // Returns: Title of assumptions.
   const std::string& getTitle() const { return biprojTitle; }
   // Description: Read benefit increases.
   virtual void read( int ) = 0;
   void setCpiinc( int year, double newCpiinc );
   // Description: Set benefit increases for one alternative.
   virtual void setData( int ) = 0;
   virtual void setData( int, const DoubleAnnual& ) = 0;
   void setFirstYear( int newFirstYear );
   // Description: Sets title for one alternative.
   virtual void setTitle( int ) = 0;
   virtual void setTitle( int, const std::string& ) = 0;
   // Description: Save benefit increases.
   virtual void write( int ) = 0;
   static void cpiincCheck( double cpiinct );
};
