// $Id: bpmfbout.h 1.10 2006/11/08 10:58:18EST 044579 Development  $
//
// Declarations needed for class to manage array of mfb formula bend points.

#pragma once

#include "dbleann.h"
#include "avgwg.h"

// {group:Calculation Classes}
// Description: Manages the array of mfb formula bend points.
//
// Remarks: This class is used to store all the bend points for all years, so
//   they do not have to be recalculated for every benefit calculation.
class BpMfbOut
{
protected:
   // Description: Array of first mfb bend points.
   DoubleAnnual bpmfb1;
   // Description: Array of second mfb bend points.
   DoubleAnnual bpmfb2;
   // Description: Array of third mfb bend points.
   DoubleAnnual bpmfb3;
public:
   BpMfbOut( int newLastYear );
   BpMfbOut( int newBaseYear, int newLastYear );
   // Description: Returns first bend point for specified year.
   //
   // Returns: First bend point for specified year.
   //
   // Arguments:
   //   year: Year for which first bend point is desired.
   double getBpmfb1( int year ) const { return(bpmfb1[year]); }
   // Description: Returns second bend point for specified year.
   //
   // Returns: Second bend point for specified year.
   //
   // Arguments:
   //   year: Year for which second bend point is desired.
   double getBpmfb2( int year ) const { return(bpmfb2[year]); }
   // Description: Returns third bend point for specified year.
   //
   // Returns: Third bend point for specified year.
   //
   // Arguments:
   //   year: Year for which third bend point is desired.
   double getBpmfb3( int year ) const { return(bpmfb3[year]); }
   void setData( const AverageWage& averageWage, int firstYear = 1979 );
   void setData( int year, double bp1, double bp2, double bp3 );
};
