// $Id: bppiaout.h 1.10 2006/11/08 10:58:18EST 044579 Development  $
//
// Declarations needed for class to manage array of pia formula bend points.

#pragma once

#include "dbleann.h"
#include "avgwg.h"

// {group:Calculation Classes}
// Description: Manages the array of pia formula bend points.
//
// Remarks: This class is used to store all the bend points for all years, so
//   they do not have to be recalculated for every benefit calculation.
class BpPiaOut
{
protected:
   // Description: Array of first pia bend points.
   DoubleAnnual bppia1;
   // Description: Array of second bend points.
   DoubleAnnual bppia2;
public:
   BpPiaOut( int newLastYear );
   BpPiaOut( int newBaseYear, int newLastYear );
   // Description: Returns first bend point for specified year.
   //
   // Returns: First bend point for specified year.
   //
   // Arguments:
   //   year: Year for which first bend point is desired.
   double getBppia1( int year ) const { return(bppia1[year]); }
   // Description: Returns second bend point for specified year.
   //
   // Returns: Second bend point for specified year.
   //
   // Arguments:
   //   year: Year for which second bend point is desired.
   double getBppia2( int year ) const { return(bppia2[year]); }
   void setData( const AverageWage& averageWage, int firstYear = 1979 );
   void setData( int year, double bp1, double bp2 );
};
