// $Id: cachupf.h 1.13 2006/11/08 10:58:17EST 044579 Development  $
//
// Declarations needed for class to manage file of catch-up benefit increases.

#pragma once

#include "cachup.h"

// {group:Calculation Classes}
// Description: Abstract parent of classes that manage a file of catch-up
//   benefit increases.
//
// Remarks: Abstract parent of classes that manage a file of catch-up benefit
//   increases.
class CatchupDoc
{
public:
   // Description: Catch-up benefit increases.
   Catchup catchup;
   // Description: True to allow nonzero catch-up increases.
   bool allownonzero[4];
public:
   CatchupDoc();
   explicit CatchupDoc( int newCstart );
   virtual ~CatchupDoc();
   // Description: Checks for existence of catch-up increase.
   //
   // Returns: True if specified catch-up increase exists, false otherwise.
   //
   // Arguments:
   //   eligYear: Year of eligibility.
   //   calYear: Calendar year of increase.
   bool exist( int eligYear, int calYear ) const
      { return(catchup.exist(eligYear, calYear)); }
   // Description: Returns one catch-up increase.
   //
   // Returns: One catch-up increase.
   //
   // Arguments:
   //   eligYear: Year of eligibility.
   //   calYear: Calendar year of increase.
   double get( int eligYear, int calYear ) const
      { return(catchup.get(eligYear, calYear)); }
   // Description: Reads catch-up increases.
   virtual void read( int ) = 0;
   // Description: Sets catch-up increases for one alternative.
   virtual void setData ( int ) = 0;
   virtual void setData ( int, const Catchup& ) = 0;
   // Description: Writes catch-up increases.
   virtual void write( int ) = 0;
};
