// $Id: comppd.h 1.6 2006/11/08 10:58:17EST 044579 Development  $
//
// Declarations for class to manage computation period variables.

#pragma once

// {group:Calculation Classes}
// Description: Manages the number of elapsed years, dropout years, and
//   computation years.
//
// Remarks: Two instances of this class are used in PiaData.
class CompPeriod
{
protected:
   // Description: Base year (1936 (for old-start) or 1950 (for new-start)).
   int baseYear;
   // Description: Number of years wholly or partially within a period
   //   of disability, within the elapsed years.
   int diYears;
   // Description: Number of computation years.
   int n;
   // Description: Number of dropout years.
   int nDrop;
   // Description: Number of elapsed years.
   int nElapsed;
public:
   CompPeriod( int newBaseYear );
   void deleteContents();
   // Description: Returns base year (1936 or 1950).
   //
   // Returns: Base year (1936 or 1950).
   int getBaseYear() const { return(baseYear); }
   // Description: Returns number of years wholly or partially within a
   //   period of disability, within the elapsed years.
   //
   // Returns: Number of years wholly or partially within a
   //   period of disability, within the elapsed years.
   int getDiYears() const { return(diYears); }
   // Description: Returns number of computation years.
   //
   // Returns: Number of computation years.
   int getN() const { return(n); }
   // Description: Returns number of dropout years.
   //
   // Returns: Number of dropout years.
   int getNDrop() const { return(nDrop); }
   // Description: Returns number of elapsed years.
   //
   // Returns: Number of elapsed years.
   int getNElapsed() const { return(nElapsed); }
   // Description: Sets number of years wholly or partially within a
   //   period of disability, within the elapsed years.
   //
   // Arguments:
   //   newDiYears: New number of disability years.
   void setDiYears( int newDiYears ) { diYears = newDiYears; }
   // Description: Sets number of computation years.
   //
   // Arguments:
   //   newN: New number of computation years.
   void setN( int newN ) { n = newN; }
   // Description: Sets number of dropout years.
   //
   // Arguments:
   //   newNDrop: New number of dropout years.
   void setNDrop( int newNDrop ) { nDrop = newNDrop; }
   // Description: Sets number of elapsed years.
   //
   // Arguments:
   //   newNElapsed: New number of elapsed years.
   void setNElapsed( int newNElapsed ) { nElapsed = newNElapsed; }
};
