// $Id: config.h 1.16 2006/11/08 10:58:18EST 044579 Development  $
//
// Declarations for class to manage configuration information.

#pragma once

// {group:Calculation Classes}
// Description: Parent of classes that manage the configuration information
//   used by the PIA calculation program.
//
// Remarks: This class is abstract; use ConfigFile or ConfigNonFile.
class Config
{
protected:
   // Description: Long output indicator.
   //
   // Remarks:
   //
   // True - long output.
   // False - short output.
   bool longOutput;
   // Description: Screen font point size.
   int screenPoints;
   // Description: Printer font point size.
   int printerPoints;
   // Description: Top margin in inches.
   float topMargin;
   // Description: Left margin in inches.
   float leftMargin;
public:
   Config();
   virtual ~Config();
   // Description: Returns left margin in inches.
   //
   // Returns: Left margin in inches.
   float getLeftMargin() const { return(leftMargin); }
   // Description: Returns long output indicator.
   //
   // Returns: Long output indicator.
   bool getLongOutput() const { return(longOutput); }
   // Description: Returns printer font point size.
   //
   // Returns: Printer font point size.
   int getPrinterPoints() const { return(printerPoints); }
   // Description: Returns screen font point size.
   //
   // Returns: Screen font point size.
   int getScreenPoints() const { return(screenPoints); }
   // Description: Returns top margin in inches.
   //
   // Returns: Top margin in inches.
   float getTopMargin() const { return(topMargin); }
   // Description: Read a Config.
   virtual void read() = 0;
   // Description: Sets left margin in inches.
   //
   // Arguments:
   //   newLeftMargin: New left margin in inches.
   void setLeftMargin( float newLeftMargin )  { leftMargin = newLeftMargin; }
   // Description: Sets long output indicator.
   //
   // Arguments:
   //   newLongOutput: New long output indicator.
   void setLongOutput( bool newLongOutput ) { longOutput = newLongOutput; }
   // Description: Sets printer font point size.
   //
   // Arguments:
   //   newPrinterPoints: New printer font point size.
   void setPrinterPoints( int newPrinterPoints )
      { printerPoints = newPrinterPoints; }
   // Description: Sets screen font point size.
   //
   // Arguments:
   //   newScreenPoints: New screen font point size.
   void setScreenPoints( int newScreenPoints )
      { screenPoints = newScreenPoints; }
   // Description: Sets top margin in inches.
   //
   // Arguments:
   //   newTopMargin: New top margin in inches.
   void setTopMargin( float newTopMargin ) { topMargin = newTopMargin; }
   // Description: Writes a Config.
   virtual void write() = 0;
};
