// $Id: dblemth.h 1.4 2006/11/08 10:58:37EST 044579 Development  $
//
// Declarations needed for class to manage an array of monthly doubles.

#pragma once

#include <vector>
class DateMoyr;
class QtrYear;

// {group:Miscellaneous Classes}
// Description: Manages an array of monthly doubles.
//
// Remarks: Manages an array of monthly doubles.
class DoubleMonth
{
protected:
   // Description: Double array.
   std::vector< double > theData;
   // Description: Width of field for output.
   int width;
   // Description: Base year of data.
   int baseYear;
   // Description: Last year of data.
   int lastYear;
   // Description: Number of decimal places for output.
   int precision;
   // Description: Width of output line.
   int lineWidth;
public:
   DoubleMonth();
   DoubleMonth( int newBaseYear, int newLastYear );
   // Description: Destructor.
   //
   // Remarks: Does nothing.
   ~DoubleMonth() { }
   void assign( const DoubleMonth& newData, int firstYeart, int lastYeart );
   void assign( double newDouble, int firstYeart, int lastYeart );
   double average( int year ) const;
   double getAt( const DateMoyr& dateMoyr ) const;
   // Description: Returns base year.
   //
   // Returns: Base year.
   int getBaseYear() const { return(baseYear); }
   // Description: Returns last year.
   //
   // Returns: Last year.
   int getLastYear() const { return(lastYear); }
   // Description: Returns line width for output.
   //
   // Returns: Line width for output.
   int getLineWidth() const { return lineWidth; }
   // Description: Returns precision for output.
   //
   // Returns: Precision for output.
   int getPrecision() const { return precision; }
   // Description: Returns field width for output.
   //
   // Returns: Field width for output.
   int getWidth() const { return width; }
   void initialize( int newBaseYear, int newLastYear );
   int nmonCal( int year ) const;
   double qaverage( const QtrYear& qtrYear ) const;
   void read( std::istream& in, int firstYeart, int lastYeart );
   void setAt( const DateMoyr& dateMoyr, double newData );
   // Description: Initializes line width for output.
   //
   // Arguments:
   //   newLineWidth: New line width for output.
   void setLineWidth( int newLineWidth ) { lineWidth = newLineWidth; }
   // Description: Initializes precision for output.
   //
   // Arguments:
   //   newPrecision: New value of precision for output.
   void setPrecision( int newPrecision ) { precision = newPrecision; }
   // Description: Initializes field width for output.
   //
   // Arguments:
   //   newWidth: New value of field width for output.
   void setWidth( int newWidth ) { width = newWidth; }
   void write( std::ostream& out, int firstYeart, int lastYeart );
};
