// $Id: dbleqtr.h 1.4 2006/11/08 10:58:37EST 044579 Development  $
//
// Declarations needed for class to manage an array of quarterly doubles.

#pragma once

#include <vector>
class DoubleMonth;
class QtrYear;

// {group:Miscellaneous Classes}
// Description: Manages an array of quarterly doubles.
//
// Remarks: Manages an array of quarterly doubles.
class DoubleQuarter
{
protected:
   // Description: Double data.
   std::vector< double > theData;
   // Description: Width of output field.
   int width;
   // Description: Base year of data.
   int baseYear;
   // Description: Last year of data.
   int lastYear;
   // Description: Number of decimal places on output.
   int precision;
   // Description: Width of output line.
   int lineWidth;
public:
   DoubleQuarter();
   DoubleQuarter( int newBaseYear, int newLastYear );
   // Description: Destructor.
   //
   // Remarks: Does nothing.
   ~DoubleQuarter() { }
   double anninc( const QtrYear& qtrYear ) const;
   double anninc3( const QtrYear& qtrYear ) const;
   void assign( const DoubleMonth& doubleMonth,
      const QtrYear& firstQtrYear, const QtrYear& lastQtrYear );
   void assign( const DoubleQuarter& doubleQuarter, int firstYeart,
      int lastYeart );
   void assign( double newData, int firstYeart, int lastYeart );
   double average( int year ) const;
   double getAfter( const QtrYear& qtrYear ) const;
   double getAt( const QtrYear& qtrYear ) const;
   // Description: Returns base year.
   //
   // Returns: Base year.
   int getBaseYear() const { return(baseYear); }
   double getBefore( const QtrYear& qtrYear ) const;
   // Description: Returns last year.
   //
   // Returns: Last year.
   int getLastYear() const { return(lastYear); }
   // Description: Returns output line width.
   //
   // Returns: Output line width.
   int getLineWidth() const { return lineWidth; }
   // Description: Returns field width on output.
   //
   // Returns: Field width on output.
   int getWidth() const { return width; }
   void initialize( int newBaseYear, int newLastYear );
   void multiply( const DoubleQuarter& doubleQuarter, int firstYeart,
      int lastYeart );
   void read( std::istream& in, int firstYeart, int lastYeart );
   void setAt( const QtrYear& qtrYear, double newData );
   // Description: Initializes output line width.
   //
   // Arguments:
   //   newLineWidth: New output line width.
   void setLineWidth( int newLineWidth ) { lineWidth = newLineWidth; }
   // Description: Initializes precision on output.
   //
   // Arguments:
   //   newPrecision: New value of precision on output.
   void setPrecision( int newPrecision ) { precision = newPrecision; }
   // Description: Initializes field width.
   //
   // Arguments:
   //   newWidth: New value of field width.
   void setWidth( int newWidth ) { width = newWidth; }
   void write( std::ostream& out, int firstYeart, int lastYeart );
};
