// $Id: dinscode.h 1.15 2006/11/08 10:58:36EST 044579 Development  $
//
// Declarations needed for class to manage disability insured status code.

#pragma once

// {group:Calculation Classes}
// Description: Represents one disability insured status code.
//
// Remarks: An instance of this class is used in PiaData. An array of instances
// is used in DisInsCodeArray.
class DisInsCode
{
public:
   // Description: Disability insured status code types.
   //
   // Remarks: Most of these codes come from the CWHS.  The last one is added
   // for use in OACT programs.
   enum DisInsCodeType {
      // 0 - active (no QC's to date).
      NOQCS,
      // 1 - disability insured (fully insured and meets 20/40).
      FULLAND2040,
      // 2 - disability insured (fully insured and meets special test).
      FULLANDSPECIAL,
      // 3 - disability insured (current DI beneficiary).
      FULLANDDIB,
      // 4 - disability insured (based on blindness).
      FULLANDBLIND,
      // 5 - not fully insured or 20/40 (but some QC's to date).
      NOTFULLNOT2040,
      // 6 - not fully insured, but meets 20/40.
      NOTFULLHAS2040,
      // 7 - fully insured, but does not meet 20/40 or special test.
      FULLNOT2040,
      // 8 - death (was a primary beneficiary).
      PRIMARYDEATH,
      // 9 - death (was never a primary beneficiary).
      NONPRIMARYDEATH,
      // T - insured for totalization benefits.
      TOTALIZED
   };
protected:
   // Description: Disability insured status code.
   DisInsCodeType theCode;
public:
   DisInsCode();
   DisInsCode( DisInsCodeType newCode );
   // Description: Returns true if the DisInsCodeType's are equal.
   //
   // Returns: True if the DisInsCodeType's are equal.
   //
   // Arguments:
   //   newCode: The disability insured status code to compare against.
   bool operator==( const DisInsCode& newCode ) const
      { return (theCode == newCode.theCode); }
   // Description: Returns the disability insured status code.
   //
   // Returns: The disability insured status code.
   DisInsCodeType get() const { return theCode; }
   // Description: Returns disability insured status.
   //
   // Returns: True if disability insured, false otherwise.
   bool isDisabilityInsured() const
   { return(theCode == FULLAND2040 || theCode == FULLANDSPECIAL ||
     theCode == FULLANDDIB || theCode == FULLANDBLIND); }
   // Description: Returns disability benefit receipt status.
   //
   // Returns: True if receiving disability benefit, false otherwise.
   bool isDiBenie() const
   { return(theCode == TOTALIZED || theCode == FULLANDDIB ||
     theCode == FULLANDBLIND); }
   // Description: Sets the disability insured status code.
   //
   // Arguments:
   //   newCode: New code to use.
   void set( DisInsCodeType newCode ) { theCode = newCode; }
   // Description: Returns the disability insured status code as a character.
   //
   // Remarks: Calls the static version of this function using the stored code.
   //
   // Returns: The disability insured status code as a character.
   char toChar() const { return(toChar(theCode)); }
   static char toChar( DisInsCodeType newCode );
   static DisInsCodeType ChartoCode( char dinscodechar );
};
