// $Id: document.h 1.12 2006/01/04 17:28:24EST 044579 Exp  $
//
// Declarations for class to manage generic document.

#pragma once

#include "genfile.h"

// {group:Miscellaneous Classes}
// Description: Manages a generic document.
//
// Remarks: This class is meant to be a parent of a user's document.
class Document : public Genfile
{
protected:
   // Description: The core file name, before modifiers or extensions.
   std::string corename;
   // Description: Title of the document.
   std::string docTitle;
public:
   Document();
   Document( const std::string& newCorename, const std::string& newDirectory );
   virtual ~Document();
   std::string errormesg();
   // Description: Returns the modifier on the file name.
   //
   // Returns: The modifier on the file name.
   std::string getModifier() const
      { return pathname.substr(corename.length()); }
   // Description: Returns full pathname.
   //
   // Returns: Full pathname.
   std::string getPathname() { return(pathname); }
   // Description: Returns title of this document.
   //
   // Returns: Title of this document.
   const std::string& getTitle() const { return(docTitle); }
   std::string readmesg();
   // Description: Sets the core part of the file name, before modifiers or
   // extensions.
   //
   // Remarks: Also sets the pathname to the corename.
   //
   // Arguments:
   //   newCorename: The new core name.
   void setCorename( const std::string& newCorename )
      { pathname = corename = newCorename; }
   void setExtension( const std::string& newExtension );
   // Description: Sets the modifier on the file name.
   //
   // Arguments:
   //   newModifier: The new file modifier.
   void setModifier( const std::string& newModifier )
      { pathname = corename + newModifier; }
   void setPath( const std::string& newPath );
   void setPathAndModifier( const std::string& newPath,
      const std::string& newModifier );
   // Description: Sets full pathname.
   //
   // Arguments:
   //   newPathName: New full pathname.
   void setPathname( const std::string& newPathname )
      { pathname = newPathname; }
   // Description: Sets title of this document.
   //
   // Arguments:
   //   newTitle: New title of this document.
   void setTitle( const std::string& newTitle ) { docTitle = newTitle; }
   std::string writemesg();
};
