// $Id: floatqtr.h 1.12 2006/11/08 10:58:36EST 044579 Development  $
//
// Declarations needed for class to manage an array of quarterly floats.

#pragma once

#include <vector>
class FloatMonth;
class QtrYear;

// {group:Miscellaneous Classes}
// Description: Manages an array of quarterly floats.
//
// Remarks: Manages an array of quarterly floats.
class FloatQuarter
{
protected:
   // Description: Float data.
   std::vector< float > theData;
   // Description: Width of output field.
   int width;
   // Description: Base year of data.
   int baseYear;
   // Description: Last year of data.
   int lastYear;
   // Description: Number of decimal places on output.
   int precision;
   // Description: Width of output line.
   int lineWidth;
public:
   FloatQuarter();
   FloatQuarter( int newBaseYear, int newLastYear );
   float anninc( const QtrYear& qtrYear ) const;
   float anninc3( const QtrYear& qtrYear ) const;
   void assign( const FloatMonth& floatMonth, const QtrYear& firstQtrYear,
      const QtrYear& lastQtrYear );
   void assign( const FloatQuarter& floatQuarter, int firstYeart,
      int lastYeart );
   void assign( float newData, int firstYeart, int lastYeart );
   float average( int year ) const;
   float getAfter( const QtrYear& qtrYear ) const;
   float getAt( const QtrYear& qtrYear ) const;
   // Description: Returns base year.
   //
   // Returns: Base year.
   int getBaseYear() const { return(baseYear); }
   float getBefore( const QtrYear& qtrYear ) const;
   // Description: Returns last year.
   //
   // Returns: Last year.
   int getLastYear() const { return(lastYear); }
   // Description: Returns output line width.
   //
   // Returns: Output line width.
   int getLineWidth() const { return lineWidth; }
   // Description: Returns field width on output.
   //
   // Returns: Field width on output.
   int getWidth() const { return width; }
   void initialize( int newBaseYear, int newLastYear );
   void multiply( const FloatQuarter& floatQuarter, int firstYeart,
      int lastYeart );
   void read( std::istream& in, int firstYeart, int lastYeart );
   void setAt( const QtrYear& qtrYear, float newData );
   // Description: Initializes output line width.
   //
   // Arguments:
   //   newLineWidth: New output line width.
   void setLineWidth( int newLineWidth ) { lineWidth = newLineWidth; }
   // Description: Initializes precision on output.
   //
   // Arguments:
   //   newPrecision: New value of precision on output.
   void setPrecision( int newPrecision ) { precision = newPrecision; }
   // Description: Initializes field width.
   //
   // Arguments:
   //   newWidth: New value of field width.
   void setWidth( int newWidth ) { width = newWidth; }
   void write( std::ostream& out, int firstYeart, int lastYeart );
};
