// $Id: foinfo.h 1.13 2005/12/12 09:43:29EST 044579 Exp  $
//
// Declarations for class to manage field office information.

#pragma once

#include <string>

// {group:Calculation Classes}
// Description: Parent of classes that manage the name and address of the
//   field office.
//
// Remarks: This class is abstract; use FieldOfficeInfoFile or
//   FieldOfficeInfoNonFile.
class FieldOfficeInfo
{
public:
   // Description: Number of address lines (4).
   static const int numLines = 4;
protected:
   // Description: Field office address.
   std::string foaddr[numLines];
   // Description: Field office manager name.
   std::string foname;
   // Description: Field office manager title.
   std::string fotitle;
public:
   FieldOfficeInfo();
   virtual ~FieldOfficeInfo();
   // Description: Returns one line of field office address.
   //
   // Returns: One line of field office address.
   //
   // Arguments:
   //   line: Desired line (0 to 3).
   const std::string& getAddress( int line ) const { return(foaddr[line]); }
   // Description: Returns field office manager's name.
   //
   // Returns: Field office manager's name.
   const std::string& getFieldOfficeName() const { return(foname); }
   // Description: Returns field office manager's title.
   //
   // Returns: Field office manager's title.
   const std::string& getFieldOfficeTitle() const { return(fotitle); }
   // Description: Sets one line of field office address.
   //
   // Arguments:
   //   line: Desired line (0 to 3).
   //   newAddress: New address line.
   void  setAddress( int line, const std::string& newAddress )
      { foaddr[line] = newAddress; }
   // Description: Sets field office info.
   virtual void setData() = 0;
   // Description: Sets field office manager's name.
   //
   // Arguments:
   //   newName: New name.
   void setFieldOfficeName( const std::string& newName ) { foname = newName; }
   // Description: Sets field office manager's title.
   //
   // Arguments:
   //   newTitle: New title.
   void setFieldOfficeTitle( const std::string& newTitle )
      { fotitle = newTitle; }
   // Description: Read field office info.
   virtual void read() = 0;
   // Description: Write field office info.
   virtual void write() = 0;
};
