// $Id: frzyrs.h 1.7 2006/11/08 10:58:36EST 044579 Development  $
//
// Declarations for class to manage freeze period variables.

#pragma once

// {group:Calculation Classes}
// Description: Manages the years in a freeze period.  The
//   years may be wholly or partially within a freeze period.
//
// Remarks: Two instances of this class are used in PiaData.
class FreezeYears
{
protected:
   // Description: First year in latest period of disability.
   int year1;
   // Description: Last year in latest period of disability.
   int year2;
   // Description: First year in prior period of disability.
   int year3;
   // Description: Last year in prior period of disability.
   int year4;
public:
   FreezeYears();
   // Description: Zeroes all variables.
   void deleteContents() { year1 = year2 = year3 = year4 = 0; }
   // Description: Returns first year in latest period of disability.
   //
   // Returns: First year in latest period of disability.
   int getYear1() const { return(year1); }
   // Description: Returns last year in latest period of disability.
   //
   // Returns: Last year in latest period of disability.
   int getYear2() const { return(year2); }
   // Description: Returns first year in prior period of disability.
   //
   // Returns: First year in prior period of disability.
   int getYear3() const { return(year3); }
   // Description: Returns last year in prior period of disability.
   //
   // Returns: Last year in prior period of disability.
   int getYear4() const { return(year4); }
   bool hasYears1() const;
   bool hasYears2() const;
   bool isFreezeYear ( int year ) const;
   // Description: Sets first year in latest period of disability.
   //
   // Arguments:
   //   newYear1: New first year in latest period.
   void setYear1( int newYear1 ) { year1 = newYear1; }
   // Description: Sets last year in latest period of disability.
   //
   // Arguments:
   //   newYear2: New last year in latest period.
   void setYear2( int newYear2 ) { year2 = newYear2; }
   // Description: Sets first year in prior period of disability.
   //
   // Arguments:
   //   newYear3: New first year in prior period.
   void setYear3( int newYear3 ) { year3 = newYear3; }
   // Description: Sets last year in prior period of disability.
   //
   // Arguments:
   //   newYear4: New last year in prior period.
   void setYear4( int newYear4 ) { year4 = newYear4; }
};
