// $Id: msdates.h 1.19 2006/04/17 14:49:43EDT 044579 Development  $
//
// Declarations needed for class to manage one military service dates record.

#pragma once

#include "boost/serialization/access.hpp"
#include "datemoyr.h"

// {group:Calculation Classes}
// Description: Manages one period of military service dates.
//
// Remarks: An array of these is stored in MilServDatesVec.
class MilServDates
{
   friend class boost::serialization::access;
   // Description: Archives the data.
   //
   // Remarks: When the class Archive corresponds to an output archive, the
   // & operator is defined similar to <<. Likewise, when the class Archive is
   // a type of input archive, the & operator is defined similar to >>.
   //
   // Arguments:
   //   ar: The archive to use.
   //   version: The version of the archive to use.
   template< class Archive >
   void serialize( Archive& ar, const unsigned int version )
      { ar & startDate & endDate & count1 & count2 & theType; }
public:
   // Description: Starting date of military service.
   DateMoyr startDate;
   // Description: Ending date of military service.
   DateMoyr endDate;
   // Description: First possible date of military service wage credits.
   static const DateMoyr firstMilServDate;
   // Description: Last possible date of military service wage credits.
   static const DateMoyr lastMilServDate;
protected:
   // Description: Record number for this ssn.
   int count1;
   // Description: Total record count for this ssn.
   int count2;
   // Description: Record type.
   //
   // Remarks:
   //
   // F - found in folder.
   // N - not proven.
   // P - proven.
   char theType;
public:
   MilServDates();
   ~MilServDates();
   void check() const;
   void deleteContents();
   // Description: Checks an ending date for validity.
   //
   // Remarks: The version with no arguments passes the stored value to the
   // static version with 1 argument.
   void endDateCheck() const { endDateCheck(endDate); }
   // Description: Returns this record number.
   //
   // Returns: This record number.
   int getCount1() const { return(count1); }
   // Description: Returns the number of records in this set.
   //
   // Returns: The number of records in this set.
   int getCount2() const { return(count2); }
   std::string getDatesString() const;
   double getEarn  ( unsigned year ) const;
   double getEarn3750() const;
   int getQc3750() const;
   int getQcov( unsigned year ) const;
   // Description: Returns the type of record.
   //
   // Returns: The type of record.
   char getType() const { return(theType); }
   void parseDates( const std::string& line );
   void parseLine( const std::string& line );
   // Description: Sets this record number.
   //
   // Arguments:
   //   newCount1: New record number.
   void setCount1( int newCount1 ) { count1 = newCount1; }
   // Description: Sets the number of records in this set.
   //
   // Arguments:
   //   newCount2: New number of records in this set.
   void setCount2( int newCount2 ) { count2 = newCount2; }
   // Description: Sets the type of record.
   //
   // Arguments:
   //   newType: New type of record.
   void setType( char newType ) { theType = newType; }
   // Description: Checks a starting date for validity.
   //
   // Remarks: The version with no arguments passes the stored value to the
   // static version with 1 argument.
   void startDateCheck() const { startDateCheck(startDate); }
   std::string toFormattedString() const;
   std::string toString() const;
   static void endDateCheck( const DateMoyr& date );
   static void startDateCheck( const DateMoyr& date );
};
