// $Id: page.h 1.13 2006/11/08 10:59:16EST 044579 Development  $
//
// Declarations for class to manage page counters.

#pragma once

#include <vector>
#include "document.h"

// {group:Miscellaneous Classes}
// Description: Manages a vector of page counters.
//
// Remarks: Manages a vector of page counters for use in
//   runstreams with multiple programs, such as ssgiat, ssgbp, and jrunfunds.
class PageCounters : public Document
{
protected:
   // Description: Page counters.
   std::vector< int > theData;
public:
   explicit PageCounters( int maxCounters );
   // Description: Destructor.
   //
   // Remarks: Does nothing.
   ~PageCounters() { }
   void deleteContents();
   // Description: Returns page counter for one slot.
   //
   // Returns: Page counter for one slot.
   //
   // Arguments:
   //   slot: Page counter slot to get.
   int get( int slot ) const { return(theData[slot]); }
   void read();
   // Description: Sets page counter for one slot.
   //
   // Arguments:
   //   slot: Page counter slot to use.
   //   newPageNum: New page number.
   void set( int slot, int newPageNum ) { theData[slot] = newPageNum; }
   void update( int slot );
   void write();
private:
   operator=( const PageCounters& );
};
