// $Id: percpia.h 1.12 2006/11/08 14:19:21EST 044579 Development  $
//
// Declarations needed for class to manage array of PIA formula percentages.

#pragma once

#include <cstddef>

// {group:Calculation Classes}
// Description: Manages the array of percentages used in the PIA formula.
//
// Remarks: An instance of this class is a member of the WageIndGeneral class.
class PercPia
{
private:
   // Description: Dimension limits.
   enum DimLimits {
      // Number of percentages.
      MAXPERC = 3
   };
   // Description: Array of percentages.
   double theData[MAXPERC];
public:
   // Description: Number of years of coverage that negates the windfall
   // elimination provision.
   static const int WINDFALL_YEARS = 30;
   // Description: The three percentages for the regular benefit formula.
   static const double PERC[MAXPERC];
   // Description: The first percentage under the windfall elimination
   // provision.
   static const double WINDFALL_PERC;
public:
   // Description: The type of data in this array.
   typedef double value_type;
   // Description: An iterator for this array.
   typedef double* iterator;
   // Description: A const iterator for this array.
   typedef const double* const_iterator;
   // Description: A reference for this array.
   typedef double& reference;
   // Description: A const reference for this array.
   typedef const double& const_reference;
   // Description: The type of size in this array.
   typedef std::size_t size_type;
   // Description: The type of difference in this array.
   typedef ptrdiff_t difference_type;
   PercPia();
   ~PercPia();
   // Description: Returns a pia formula percentage. There are const and
   //   non-const versions.
   //
   // Returns: A pia formula percentage.
   //
   // Arguments:
   //   index: Index of percentage desired (0-2).
   reference operator[]( std::size_t index ) { return theData[index]; }
   const_reference operator[]( std::size_t index ) const { return theData[index]; }
   // Description: Returns percentages as a simple array.
   //
   // Returns: Percentages as a simple array.
   double* as_array() { return theData; }
   // Description: Returns beginning of array.
   //
   // Returns: Beginning of array.
   iterator begin() { return theData; }
   const_iterator begin() const { return theData; }
   // Description: Returns one past end of array.
   //
   // Returns: One past end of array.
   iterator end() { return theData + MAXPERC; }
   const_iterator end() const { return theData + MAXPERC; }
   // Description: Returns maximum number of percentages.
   //
   // Returns: Number of percentages.
   size_type max_size() const { return MAXPERC; }
   void reset();
   // Description: Returns number of percentages.
   //
   // Returns: Number of percentages.
   size_type size() const { return MAXPERC; }
   void windfall( int eligYear, int benefitDate, int specMinTot );
};
