// $Id: piaparmsAny.h 1.14 2006/11/08 10:59:36EST 044579 Development  $
//
// Declarations needed for piaparmsAny class.

#pragma once

#include "dbleann.h"
#include "piaparmsLC.h"

// {group:Calculation Classes}
// Description: Manages the additional Social Security parameters required to
//   calculate Social Security benefits in the Anypia program.
//
// Remarks: Manages the additional Social Security parameters required to
//   calculate Social Security benefits in the Anypia program.
class PiaParamsAny : public PiaParamsLC
{
protected:
   // Description: High wage, 1937 to maxyear.
   DoubleAnnual wageHigh;
   // Description: Low wage, 1937 to maxyear.
   DoubleAnnual wageMin;
public:
   PiaParamsAny( int newIstart, int newMaxyear, AwbiData& awbiData,
      const LawChangeArray& newLawChange );
   virtual ~PiaParamsAny();
   // Description: Returns array of high earnings.
   //
   // Returns: Array of high earnings.
   const DoubleAnnual& getWageHighArray() const { return(wageHigh); }
   // Description: Returns high earnings for one year.
   //
   // Returns: High earnings for specified year.
   //
   // Arguments:
   //   year:  Year for which high earnings are desired.
   double getWageHigh( int year ) const { return(wageHigh[year]); }
   // Description: Returns array of low earnings.
   //
   // Returns: Array of low earnings.
   const DoubleAnnual& getWageMinArray() const { return(wageMin); }
   // Description: Returns low earnings for one year.
   //
   // Returns: Low earnings for specified year.
   //
   // Arguments:
   //   year:  Year for which low earnings are desired.
   double getWageMin( int year ) const { return(wageMin[year]); }
   void highProj();
   void minProj();
   void projectFq();
private:
   PiaParamsAny operator=( PiaParamsAny newPiaParamsAny );
};
