// $Id: piaparmsLC.h 1.46 2007/02/28 15:03:45EST 044579 Development  $
//
// Declarations needed for piaparmsLC class.

#pragma once

#include "piaparms.h"
class LawChangeArray;
#include "wbgenrlLC.h"

// {group:Calculation Classes}
// Description: Manages the changed law Social Security parameters required to
//   calculate Social Security benefits.
//
// Remarks: Manages the changed law Social Security parameters required to
//   calculate Social Security benefits.
class PiaParamsLC : public PiaParams
{
protected:
   // Description: Wage base under present law, 1937 to maxyear.
   WageBaseLC baseOasdi;
   // Description: Old-law wage bases (ignoring 1979-81 ad hoc increases), 1937
   //   to maxyear.
   WageBaseOldLawLC base77;
   // Description: Alternate benefit increases, 1937 to maxyear.
   DoubleAnnual altCpiinc;
   // Description: Dollar amount caps on the COLA for each year.
   DoubleAnnual colaCaps;
   // Description: Indexing series for pia formula bend points when a mixture
   //   of average wages and other amounts.
   AverageWage fqbppia;
   // Description: Indexing series for earnings record when a mixture
   //   of average wages and other amounts.
   AverageWage fqindex;
   // Description: Law change data.
   const LawChangeArray& lawChange;
   // Description: Dollar amount caps on the COLA for the MFB for each year.
   DoubleAnnual mfbColaCaps;
   // Description: Array of extra special minimum pias.
   std::vector< double > specMinPiaExtra;
   // Description: Array of extra special minimum mfbs.
   std::vector< double > specMinMfbExtra;
public:
   PiaParamsLC( int newIstart, int newMaxyear, AwbiData& awbiData,
      const LawChangeArray& newLawChange );
   PiaParamsLC( int newMaxyear, const LawChangeArray& newLawChange );
   virtual ~PiaParamsLC();
   double applyCola( double pia, int year ) const;
   double applyCola( double pia, int year, int eligYear ) const;
   double applyColaMfb( double mfb, int year, double pia ) const;
   double applyColaMfb( double mfb, int year, int eligYear,
     double pia ) const;
   Age earlyAgeOabCal( Sex::sex_type sex, const boost::gregorian::date& kbirth ) const;
   double factorAgedSpouseCal( int eligYear, int benYear ) const;
   double factorAgedWidCal( int monthsArdri, const Age& age,
      int eligYear, const DateMoyr& benefitDate ) const;
   double factorArAgedSpouseCal( int monthsArdri ) const;
   double factorArCal( int monthsArdri ) const;
   double factorDisWidCal( int eligYear, const DateMoyr& benefitDate ) const;
   Age fullRetAgeCal( int eligYear ) const;
   Age fullRetAgeCalDI( int eligYear, int currentYear ) const;
   // Description: Returns the array of OASDI wage bases.
   //
   // Returns: The array of OASDI wage bases.
   const WageBase& getBaseOasdiArray() const { return baseOasdi; }
   // Description: Returns one OASDI wage base.
   //
   // Returns: One OASDI wage base.
   //
   // Arguments:
   //   year: Year for which base is desired.
   double getBaseOasdi( int year ) const { return baseOasdi[year]; }
   // Description: Returns the array of old-law wage bases.
   //
   // Returns: The array of old-law wage bases.
   const WageBaseOldLaw& getBase77Array() const { return base77; }
   // Description: Returns one old-law wage base.
   //
   // Returns: One old-law wage base.
   //
   // Arguments:
   //   year: Year for which base is desired.
   double getBase77( int year ) const { return base77[year]; }
      double getChildcareDropoutAmount( int eligYear, int benYear ) const;
      double getColaCap( int year ) const;
      double getCpiinc( int year ) const;
      const DoubleAnnual& getCpiincArray() const;
      const AverageWage& getFqBppia() const;
      const AverageWage& getFqIndex() const;
      int getMarrLengthForDivBen( const DateMoyr& dateMoyr ) const;
      int getMaxChildcareAge() const;
      int  getMaxChildcareDropoutYears( int eligYear, int benYear ) const;
      double getMfbColaCap( int year ) const;
      double getSpecMinPia( const DateMoyr& dateMoyr, int yoc ) const;
      double getSpecMinMfb( const DateMoyr& dateMoyr, int yoc ) const;
      void initdata();
      Age  maxDibAge( int year ) const;
      void projectCpiinc();
      void projectFq();
      void projectPerc();
      void projectSpecMin( int baseYear, int lastYear );
      void resizeSpecMin();
      double ribLimCal( double widowBen, double oabPia, double oabBen,
         const DateMoyr& benefitDate ) const;
      void setData( AwbiData& awbiData );
      int  specMinMaxYears() const;
      int  specMinMaxYears( int eligYear, int benYear ) const;
      double specMinAmountCal( const DateMoyr& date ) const;
      void updateBases();
      void updateBases( const DoubleAnnual& userbase,
         const DoubleAnnual& userbase77, int ibasch, int firstYeart,
         int lastYeart );
   protected:
      void setAltCpiinc();
      void setColaCap( double cap, int year );
      void setFqBppia();
      void setFqIndex();
      void setMfbColaCap( double cap, int year );
   private:
      PiaParamsLC operator=( PiaParamsLC& newPiaParamsLC );
};
