// $Id: piaparmsPL.h 1.26 2007/02/28 15:03:45EST 044579 Development  $
//
// Declarations needed for pia calculation parameters using present law only.

#pragma once

#include "piaparms.h"

// {group:Calculation Classes}
// Description: Manages the present law Social Security 
//   parameters required to calculate Social Security benefits.
//
// Remarks: Manages the present law Social Security 
//   parameters required to calculate Social Security benefits.
class PiaParamsPL : public PiaParams
{
protected:
   // Description: Wage base under present law, 1937 to maxyear.
   WageBase baseOasdi;
   // Description: Old-law wage bases (ignoring 1979-81 ad hoc increases), 1937
   //   to maxyear.
   WageBaseOldLaw base77;
public:
   PiaParamsPL( int newIstart, int newMaxyear, AwbiData& awbiData );
   explicit PiaParamsPL( int newMaxyear );
   ~PiaParamsPL();
   Age earlyAgeOabCal( Sex::sex_type sex, const boost::gregorian::date& kbirth ) const;
   double factorAgedSpouseCal( int eligYear, int benYear ) const;
   double factorAgedWidCal( int monthsArdri, const Age& age, int,
      const DateMoyr& benefitDate ) const;
   double factorArAgedSpouseCal( int monthsArdri ) const;
   double factorArCal( int monthsArdri ) const;
   double factorDisWidCal( int, const DateMoyr& benefitDate ) const;
   Age fullRetAgeCal( int eligYear ) const;
   Age fullRetAgeCalDI( int eligYear, int currentYear ) const;
   // Description: Returns the array of OASDI wage bases.
   //
   // Returns: The array of OASDI wage bases.
   const WageBase& getBaseOasdiArray() const { return baseOasdi; }
   // Description: Returns one OASDI wage base.
   //
   // Returns: One OASDI wage base.
   //
   // Arguments:
   //   year: Year for which base is desired.
   double getBaseOasdi( int year ) const { return baseOasdi[year]; }
   // Description: Returns the array of old-law wage bases.
   //
   // Returns: The array of old-law wage bases.
   const WageBaseOldLaw& getBase77Array() const { return base77; }
   // Description: Returns one old-law wage base.
   //
   // Returns: One old-law wage base.
   //
   // Arguments:
   //   year: Year for which base is desired.
   double getBase77( int year ) const { return base77[year]; }
      double getChildcareDropoutAmount( int, int ) const;
      double getColaCap( int year ) const;
      const AverageWage& getFqBppia() const;
      const AverageWage& getFqIndex() const;
      int getMarrLengthForDivBen( const DateMoyr& dateMoyr ) const;
      int getMaxChildcareAge() const;
      int getMaxChildcareDropoutYears( int, int ) const;
      double getMfbColaCap( int year ) const;
      Age maxDibAge( int year ) const;
      void projectCpiinc();
      double ribLimCal( double widowBen, double oabPia, double oabBen,
         const DateMoyr& benefitDate ) const;
      void setData( AwbiData& awbiData );
      double specMinAmountCal( const DateMoyr& date ) const;
      int specMinMaxYears() const;
      int specMinMaxYears( int eligYear, int benYear ) const;
      void setColaCap( double cap, int year );
      void setMfbColaCap( double cap, int year );
      void updateBases();
      void updateBases( const DoubleAnnual& userbase,
         const DoubleAnnual& userbase77, int ibasch, int firstYeart,
         int lastYeart );
};
