// $Id: piaread.h 1.30 2006/11/08 10:59:36EST 044579 Development  $
//
// Declarations needed for class to read worker data.

#pragma once

#include <string>
class UserAssumptions;
class SecondaryArray;
class PiaDataArray;
class WorkerDataArray;
class WorkerData;

// {group:Calculation Classes}
// Description: Reads the basic data required to calculate a Social Security
//   benefit.
//
// Remarks: This version is used in programs such as microsimulations, which do
// not use Social Security Statements or factors to project earnings. For
// programs that do use those things, such as Anypia, use the subclass
// PiaReadAny.
class PiaRead
{
   protected:
      // Worker data.
      WorkerData& workerData;
      // Widow and other family member basic data.
      WorkerDataArray& widowDataArray;
      // Widow and other family member calculation data.
      PiaDataArray& widowArray;
      // User-specified assumptions.
      UserAssumptions& userAssumptions;
      // Secondary benefit information.
      SecondaryArray& secondaryArray;
      // Temporary first year of assumptions.
      int istart2;
      // Description: Number of columns at beginning of each line reserved for
      //   line number.
      //
      // Remarks: The Anypia program uses 2 columns; other programs that
      //   require more than 99 lines use 3 columns.
      static int width;
      // Description: Number of columns for earnings and bases.
      static int earnWidth;
   public:
      // Input line.
      std::string inputLine;
      // True if a line has been read but not used.
      bool    unusedLine;
      // Type of input line.
      int     lineType;
public:
   PiaRead( WorkerData& newWorkerData, WorkerDataArray& newWidowDataArray,
      PiaDataArray& newWidowData, UserAssumptions& newUserAssumptions,
      SecondaryArray& newSecondary );
   // Description: Returns width of earnings or base field.
   //
   // Returns: Width of earnings or base field.
   int getEarnWidth() { return(earnWidth); }
   // Description: Returns width of field for line number in file.
   //
   // Returns: Width of field for line number in file.
   int getWidth() { return(width); }
      void   parseAssump( const std::string& line );
      void   parseAw  ( int lineNumber, const std::string& line );
      virtual void parseBack( const std::string& );
      void   parseBases( int lineNumber, const std::string& line );
      void   parseBases77( int lineNumber, const std::string& line );
      void   parseBendate( const std::string& line );
      void   parseBi  ( int lineNumber, const std::string& line );
      void   parseBlind( const std::string& line );
      void   parseCatchup( int lineNumber, const std::string& line );
      void   parseChildCareYears( const std::string& line );
      void   parseDeath( const std::string& line );
      void   parseDeemed( const std::string& line );
      void   parseDisab1( const std::string& line );
      void   parseDisab2( const std::string& line );
      virtual void parseEarnOasdi( int lineNumber, const std::string& line );
      void   parseEarnHi( int lineNumber, const std::string& line );
      virtual void parseEarnType( const std::string& );
      void   parseFamilyMember( int i, const std::string& line );
      virtual void parseFwrd( const std::string& );
      void   parseMsdates( const std::string& line );
      void   parseNhaddr( int lineNumber, const std::string& line );
      void   parseNhname( const std::string& line );
      void   parseOabent( const std::string& line );
      virtual void parsePebes( const std::string& );
      void   parsePubpen( const std::string& line );
      void   parsePubpenReservist( const std::string& line );
      void   parseQc1 ( const std::string& line );
      void   parseQc2 ( const std::string& line );
      void   parseSsn ( const std::string& line );
      void   parseTaxType( const std::string& line );
      void   parseTitleaw( const std::string& line );
      void   parseTitlebi( const std::string& line );
      void   parseTob ( const std::string& line );
      void   parseTotalize( const std::string& line );
      void   parseYears( const std::string& line );
      unsigned int read( std::istream& in );
      virtual void setEarnProjectYears( int, int );
   // Description: Sets width of earnings or base field.
   //
   // Arguments:
   //   newWidth: New width of earnings or base field.
   void setEarnWidth( int newWidth ) { earnWidth = newWidth; }
   virtual void setPebsData();
   // Description: Sets width of field for line number in file,
   //
   // Arguments:
   //   newWidth: New width of field for line number.
   void setWidth( int newWidth ) { width = newWidth; }
private:
   PiaRead operator=( const PiaRead& newPiaRead );
};
