// $Id: piawrite.h 1.26 2006/11/08 10:59:36EST 044579 Development  $
//
// Declarations needed for class to write out worker data.

#pragma once

#include <string>
class UserAssumptions;
class SecondaryArray;
class WorkerDataArray;
class PiaDataArray;
class WorkerData;

// {group:Calculation Classes}
// Description: Writes out the basic data required to calculate a
//   Social Security benefit.
//
// Remarks: This version is used in programs such as microsimulations, which do
// not use Social Security Statements or factors to project earnings. For
// programs that do use those things, such as Anypia, use the subclass
// PiaWriteAny.
class PiaWrite
{
   protected:
      // Worker data.
      const WorkerData& workerData;
      // Widow and other family member basic data.
      const WorkerDataArray& widowDataArray;
      // Widow and other family member calculation data.
      const PiaDataArray& widowArray;
      // User-specified assumptions.
      const UserAssumptions& userAssumptions;
      // Secondary benefit information.
      const SecondaryArray& secondaryArray;
      // Description: Number of columns at beginning of each line reserved for
      //   line number.
      //
      // Remarks: The Anypia program uses 2 columns; other programs that
      //   require more than 99 lines use 3 columns.
      static int width;
      // Description: Number of columns for earnings and bases.
      static int earnWidth;
      // Description: Number of decimal places for earnings and bases.
      static int numDecimals;
public:
   PiaWrite ( const WorkerData& newWorkerData,
      const WorkerDataArray& newWidowDataArray,
      const PiaDataArray& newWidowArray,
      const UserAssumptions& newUserAssumptions,
      const SecondaryArray& newSecondaryArray );
   // Description: Returns width of earnings or base field.
   //
   // Returns: Width of earnings or base field.
   int getEarnWidth() { return(earnWidth); }
   // Description: Returns number of decimal places for earnings or base.
   //
   // Returns: Number of decimal places for earnings or base.
   int getNumDecimals() { return(numDecimals); }
   // Description: Returns width of field for line number in file.
   //
   // Returns: Width of field for line number in file.
   int getWidth() { return(width); }
   // Description: Sets width of earnings or base field.
   //
   // Arguments:
   //   newWidth: New width of earnings or base field.
   void setEarnWidth( int newWidth ) { earnWidth = newWidth; }
   // Description: Sets number of decimal places for earnings or base.
   //
   // Arguments:
   //   newNumDecimals: New number of decimals.
   void setNumDecimals( int newNumDecimals ) { numDecimals = newNumDecimals; }
   // Description: Sets width of field for line number in file.
   //
   // Arguments:
   //   newWidth: New width of column for line number.
   void setWidth( int newWidth ) { width = newWidth; }
      void   write     ( std::ostream& out );
      virtual void writeAssump( std::ostream& out ) const;
      void   writeAw   ( std::ostream& out ) const;
      virtual void writeBack( std::ostream& ) const;
      void   writeBases( std::ostream& out ) const;
      void   writeBenDate( std::ostream& out ) const;
      void   writeBi   ( std::ostream& out ) const;
      void   writeBlind( std::ostream& out ) const;
      void   writeChildCareYears( std::ostream& out ) const;
      void   writeDeath( std::ostream& out ) const;
      void   writeDeemed( std::ostream& out ) const;
      void   writeDisab1( std::ostream& out ) const;
      void   writeDisab2( std::ostream& out ) const;
      virtual void writeEarnOasdi( std::ostream& out ) const;
      void   writeEarnHi( std::ostream& out ) const;
      virtual void writeEarnType( std::ostream& ) const;
      void   writeFamilyMember( std::ostream& out, int i ) const;
      void   writeFamilyMembers( std::ostream& out ) const;
      virtual void writeFwrd( std::ostream& ) const;
      void   writeMsdates( std::ostream& out ) const;
      void   writeNhaddr( std::ostream& out ) const;
      void   writeNhname( std::ostream& out ) const;
      void   writeOabEnt( std::ostream& out ) const;
      virtual void writePebes( std::ostream& ) const;
      void   writePubpen( std::ostream& out ) const;
      void   writePubpenReservist( std::ostream& out ) const;
      void   writeQc1  ( std::ostream& out ) const;
      void   writeQc2  ( std::ostream& out ) const;
      void   writeRailRoad( std::ostream& out ) const;
      void   writeSsn  ( std::ostream& out ) const;
      void   writeTaxType( std::ostream& out ) const;
      void   writeTob  ( std::ostream& out ) const;
      void   writeTotalize( std::ostream& out ) const;
      void   writeYears( std::ostream& out ) const;
private:
   PiaWrite operator=( const PiaWrite& newPiaWrite );
};
