// $Id: railroad.h 1.19 2006/04/17 14:49:56EDT 044579 Development  $
//
// Declarations needed for class to manage edited railroad record.

#pragma once

#include "boost/serialization/access.hpp"
#include "dbleann.h"
#include "QcArray.h"

// {group:Calculation Classes}
// Description: Manages the railroad data for one worker.
//
// Remarks: Each record contains railroad quarters of coverage for 1937-50
//   (total) and for each year from 1951 to 1977.  It also contains railroad
//   earnings for 1937-50 (total) and for each year from 1951 to the last year.
class RailRoadData
{
   friend class boost::serialization::access;
   // Description: Archives the data.
   //
   // Remarks: When the class Archive corresponds to an output archive, the
   // & operator is defined similar to <<. Likewise, when the class Archive is
   // a type of input archive, the & operator is defined similar to >>.
   //
   // Arguments:
   //   ar: The archive to use.
   //   version: The version of the archive to use.
   template< class Archive >
   void serialize( Archive& ar, const unsigned int version )
      { ar & qc3750 & earn3750 & firstYear & lastYear & qc & earnings; }
protected:
   // Description: Total railroad qc's, 1937 to 1950.
   int qc3750;
   // Description: Total railroad earnings, 1937 to 1950.
   double earn3750;
   // Description: First year of railroad earnings.
   int firstYear;
   // Description: Last year of railroad earnings.
   int lastYear;
public:
   // Description: Annual railroad qc's, from 1951 to 1977.
   QcArray qc;
   // Description: Annual railroad earnings, starting in 1951.
   DoubleAnnual earnings;
public:
   explicit RailRoadData( int year );
   ~RailRoadData();
   void deleteContents();
   std::string get3750String( int width, int decimals ) const;
   std::string getDecadeEarningsString( int decade, int width,
      int decimals ) const;
   int getDecades() const;
  // Description: Returns total earnings 1937 to 1950.
   //
   // Returns: Total earnings 1937 to 1950.
   double getEarn3750() const { return(earn3750); }
   // Description: Returns first year of earnings.
   //
   // Returns: First year of earnings.
   int getFirstYear() const { return firstYear; }
   // Description: Returns last year of earnings.
   //
   // Returns: Last year of earnings.
   int getLastYear() const { return lastYear; }
   // Description: Returns total qc's 1937 to 1950.
   //
   // Returns: Total qc's 1937 to 1950.
   int getQc3750() const { return(qc3750); }
   std::string getQcString() const;
   std::string getYearsString() const;
   bool isNonzero() const;
   void parse3750( const std::string& line, int width );
   void parseEarnings( int decade, const std::string& line, int width );
   void parseQcs( const std::string& line );
   void parseYears( const std::string& line );
   // Description: Sets total earnings 1937 to 1950.
   //
   // Arguments:
   //   newEarn3750: New total earnings.
   void setEarn3750( double newEarn3750 ) { earn3750 = newEarn3750; }
   // Description: Sets first year of earnings.
   //
   // Arguments:
   //   newFirstYear: New first year of earnings.
   void setFirstYear( int newFirstYear ) { firstYear = newFirstYear; }
   // Description: Sets last year of earnings.
   //
   // Arguments:
   //   newLastYear: New last year of earnings.
   void setLastYear( int newLastYear ) { lastYear = newLastYear; }
   // Description: Sets total quarters of coverage 1937 to 1950.
   //
   // Arguments:
   //   newQc3750: New total quarters of coverage.
   void setQc3750( int newQc3750 ) { qc3750 = newQc3750; }
};
