// $Id: ssn.h 1.13 2006/11/08 10:59:52EST 044579 Development  $
//
// Declarations for class to manage Social Security number.

#pragma once

#include <string>
#include "boost/serialization/access.hpp"

// {group:Miscellaneous Classes}
// Description: Manages a Social Security number string, and the 3
//   parts of an ssn separately as strings.
//
// Remarks: An instance of this class is a member of WorkerData.
class Ssn
{
   friend class boost::serialization::access;
   // Description: Archives the data.
   //
   // Remarks: When the class Archive corresponds to an output archive, the
   // & operator is defined similar to <<. Likewise, when the class Archive is
   // a type of input archive, the & operator is defined similar to >>.
   //
   // Arguments:
   //   ar: The archive to use.
   //   version: The version of the archive to use.
   template< class Archive >
   void serialize( Archive& ar, const unsigned int version )
      { ar & ssnPart & ssnFull & ssnWithHyphens; }
protected:
   // Description: First 3 digits, middle 2 digits, and last 4 digits.
   std::string ssnPart[3];
   // Description: Full 9 digits, without hyphens.
   std::string ssnFull;
   // Description: Output as 11 characters:  xxx-xx-xxxx.
   std::string ssnWithHyphens;
public:
   Ssn();
   Ssn( const std::string& newSsnPart1, const std::string& newSsnPart2,
      const std::string& newSsnPart3 );
   Ssn( const std::string& newSsn );
   Ssn( const Ssn& ssn );
   // Description: Destructor.
   //
   // Remarks: Does nothing.
   ~Ssn() { }
   Ssn& operator=( const Ssn& ssn );
   bool operator<( const Ssn& ssntemp ) const;
   bool operator==( const Ssn& ssntemp ) const;
   void deleteContents();
   // Description: Returns first part of ssn.
   //
   // Returns: First part of ssn.
   const std::string& getPart1() const { return(ssnPart[0]); }
   // Description: Returns second part of ssn.
   //
   // Returns: Second part of ssn.
   const std::string& getPart2() const { return(ssnPart[1]); }
   // Description: Returns third part of ssn.
   //
   // Returns: Third part of ssn.
   const std::string& getPart3() const { return(ssnPart[2]); }
   void setPart1( const std::string& newPart1 );
   void setPart2( const std::string& newPart2 );
   void setPart3( const std::string& newPart3 );
   void setSsnFull( const std::string& newSsnFull );
   void setSsnFull( const std::string& newSsnPart1,
      const std::string& newSsnPart2, const std::string& newSsnPart3 );
   long toNumber() const;
   std::string toString() const;
   std::string toString( const std::string& format ) const;
   void update();
};
