// $Id: BitAnnual.cpp 1.1 2003/05/22 13:23:23Z sfmckay Exp $
//
// Functions to handle BitAnnual arrays for linux.

#include "oactcnst.h"
#include "BitAnnual.h"

using namespace std;

// GENERAL NOTE:
// When adding functions to this class, or changing the implementation
// of existing functions, be careful not to use square brackets ( [] )
// to access 'data' unless you're really sure of what you're doing.
// This is because there are different implementations of this class
// depending on whether you're using NT or Linux. Instead, use the
// setBit() and getBit() functions.

// Description: Initializes first and last years.
//
// Arguments:
//   newBaseYear: New base year.
//   newLastYear: New last year.
//
// Remarks: On the linux system, data is a vector of BitPacked's -- so the
// constructor needs to know how many to create. On other systems (which
// conform to the standard and have a BitSet class built in), data is a
// BitSet and doesn't need any parameters because the default constructor
// initializes all of the bits to zero.
BitAnnual::BitAnnual( int newBaseYear, int newLastYear ) :
data((newLastYear - newBaseYear) / U_NUMBITS + 1),
baseYear(newBaseYear), lastYear(newLastYear)
{ }

// Description: Returns true if any bit is set, false otherwise.
//
// Returns: True if any bit is set, false otherwise.
bool BitAnnual::any() const
{
   for (unsigned i = 0; i < data.size(); i++) {
      if (data[i].any())
         return true;
   }
   return false;
}

// Description: Zeroes out all data values.
void BitAnnual::deleteContents()
{
   for (unsigned i = 0; i < data.size(); i++)
      data[i].deleteContents();
}
