// $Id: BitAnnualInlines.h 1.1 2003/05/22 13:23:12Z sfmckay Exp $
//
// Inline functions for class to manage an array of annual bits for Windows.

#pragma once
#ifndef __BITANNUALINLINES_H
#define __BITANNUALINLINES_H   1   // Prevent multiple includes

// Description: Returns one constant value of data.
//
// Returns: One constant value of data.
//
// Throws: PiaException of type PIA_IDS_BITANN1 if year is out of range (only
//   in debug mode).
//
// Arguments:
//   year: Year for which data is desired.
inline bool BitAnnual::getBit( int year ) const
{
#if !defined(NDEBUG)
   if (year < baseYear || year > lastYear) {
      throw PiaException(PIA_IDS_BITANN1);
   }
#endif
   int indexYear = year - baseYear;
   return data[indexYear / U_NUMBITS].get(indexYear % U_NUMBITS);
}

// Description: Sets one value of data.
//
// Throws: PiaException of type PIA_IDS_BITANN1 if year is out of range (only
//   in debug mode).
//
// Arguments:
//   year: Year for which data is to be set.
//   bit: Value to set (0 for false, any other value for true).
inline void BitAnnual::setBit( int year, int bit )
{
#if !defined(NDEBUG)
   if (year < baseYear || year > lastYear) {
      throw PiaException(PIA_IDS_BITANN1);
   }
#endif
   int indexYear = year - baseYear;
   data[indexYear / U_NUMBITS].set(indexYear % U_NUMBITS, bit);
}

#endif    // __BITANNUALINLINES_H
