// $Id: OutfileHTML.cpp 1.4 2008/01/07 10:19:36EST 729915 Development  $
//
// Various functions used in print routines.

#include "OutFileHTML.h"
#include "Resource.h"
#include "PiaException.h"
#include "comma.h"

using namespace std;

// Description: Initializes OutFileHTML.
//
// Remarks: It uses an extension of ".html". The version without a directory
// argument uses the current working directory.
//
// Arguments:
//   newCorename: Name of output file.
OutFileHTML::OutFileHTML( const std::string& newCorename ) :
Outfile(newCorename, ".html"), cssPage("tables.css")
{ }

// Arguments:
//   newDirectory: Name of parent directory.
OutFileHTML::OutFileHTML( const std::string& newDirectory,
const std::string& newCorename ) :
Outfile(newDirectory, newCorename, ".html"), cssPage("../tables.css")
{ }

// Description: Destructor.
OutFileHTML::~OutFileHTML()
{ }

// Description: Writes title to html file.
void OutFileHTML::pgtitle()
{
   string temp;

   pageNum++;
   if (pageNum == 1) {
      temp = "<h1 class=\"FirstHeader\">";
   }
   else {
      temp = "<h1 class=\"LaterHeader\">";
   }
   for (int i = 0; i < PAGE_TITLE_LINES; i++) {
      temp += gettitle(i);
      temp += "<br>";
   }
   temp += "</h1>";
   printLine(temp);
   advanceLine();
   return;
}

// Description: Writes format statement for starting an html table.
//
// Arguments:
//   percent: percentage of full width of the web page used.
void OutFileHTML::StartTable( int percent )
{
   string temp;

   temp += "<table cellspacing=\"0\" width=\"";
   temp += poutNoComma(percent,2,0);
   temp += "%\">";
   printLine(temp);
   return;
}

// Description: Writes table ending information.
void OutFileHTML::EndTable()
{
   printLine("</table>");
   return;
}

// Description: Writes whitle row starting information.
void OutFileHTML::StartWhiteRow()
{
   printLine("<tr>");
   return;
}

// Description: Writes gray row starting information.
void OutFileHTML::StartGrayRow()
{
   printLine("<tr align=\"right\" bgcolor=\"#DFDFD5\" valign=\"bottom\">");
}

// Description: Writes row ending information.
void OutFileHTML::EndRow()
{
   printLine("</tr>");
   return;
}

// Description: Writes format statement for starting an html caption.
//
// Arguments:
//   caption: The title of the web page table.
void OutFileHTML::Caption( const std::string& caption )
{
   printLine("<caption><p class=\"TableTitleFirst\"><b>");
   advanceLine();
   printLine(caption);
   printLine("</caption>");
   return;
}

// Description: Writes format statement for a text cell starting a row.
//
// Arguments:
//   rowstub: The contain of the text cell.
void OutFileHTML::RowStub( const std::string& rowstub )
{
   printLine("<td valign=\"top\"><p class=\"CellBody\">" +
      rowstub + "</p></td>");
   return;
}

// Description: Writes format statement for a header cell.
//
// Arguments:
//   rowspan: the number of row span of the cell, default 1.
//   colspan: the number of colunm span of the cell, default 1.
//   cellheader: The content of the header cell.
void OutFileHTML::CellHeader(int rowspan, int colspan,
                             const std::string& cellheader )
{
   printLine("<th rowspan=\"" + poutNoComma(rowspan,1,0) + 
      "\" colspan=\"" + poutNoComma(colspan,1,0) + "\" align=\"center\"" +
      " valign=\"top\"><p class=\"CellHeading\">" + cellheader + "</p></th>");
   return;
}

// Description: Writes format statement for a text cell align right.
//
// Arguments:
//   stringright: The content of the text cell.
void OutFileHTML::PrintStringRight( const std::string& stringright )
{
   printLine("<td valign=\"bottom\"><p class=\"CellBodyRight\">" +
      stringright + "</p></td>");
   return;
}

// Description: Writes format statement for printing an 2decimals.
//
// Arguments:
//   decimals: decimals to be print in 2 decimals.
void OutFileHTML::Print2Decimal( double decimal )
{
   string temp;

   temp += "<td valign=\"bottom\"><p class=\"CellBodyRight\">";
   temp += poutNoComma(decimal,10,2);
   temp += "</p></td>";
   printLine(temp);
   return;
}

// Description: Writes format statement for printing an integer.
//
// Arguments:
//   integer: decimals to be print in 2 decimals.
void OutFileHTML::PrintInteger( int integer )
{
   string temp;

   temp += "<td valign=\"bottom\"><p class=\"CellBodyRight\">";
   temp += poutNoComma(integer,12,0);
   temp += "</p></td>";
   printLine(temp);
   advanceLine();
   return;
}

// Description: Writes html header information.
//
// Arguments:
//   webTitle: The title in the web page title bar.
void OutFileHTML::header( const std::string& webTitle )
{
   printLine("<html>");
   advanceLine();
   printLine("<head>");
   printLine("  <link rel=\"stylesheet\" href=\"" + cssPage +
      "\" charset=\"ISO-8859-1\" type=\"text/css\"></link>");
   string temp("  <title>");
   temp += webTitle;
   temp += "</title>";
   printLine(temp);
   printLine("</head>");
   advanceLine();
   printLine("<body>");
   return;
}

// Description: Writes html footer information.
void OutFileHTML::footer()
{
   advanceLine();
   printLine("</body>");
   advanceLine();
   printLine("</html>");
   return;
}
