// $Id: StringParser.cpp 1.9 2003/05/22 09:26:28EDT sfmckay Exp  $
//
// Functions to parse a string.

#include "StringParser.h"
#include "isspace.h"

using namespace std;

// Description:  Parses a string into its delimited parts.
//
// Remarks: The version with only one argument uses a space as the delimiter.
//
// Returns: A vector of the strings contained in the input.
//
// Arguments:
//   str: The string to parse.
std::vector< std::string > parseString( const std::string& str )
{
   bool atEnd = true;  // indicator for being at end of a word
   int begin = -1,  // beginning character of word
      end = -1;  // ending character of word
   vector< string > retvec;  // return vector

   for (string::size_type idx = 0; idx < str.size(); idx++) {
      if (ISSPACE(str[idx])) {
         // if not already at end of word, take care of this word
         if (!atEnd) {
            // this is new end of word
            end = idx - 1;
            atEnd = true;
            // push this word onto vector
            retvec.push_back(str.substr(begin, end - begin + 1));
         }
      }
      else {
         // if at end of a word, this is now a new word
         if (atEnd) {
            begin = idx;
            atEnd = false;
         }
      }
   }
   // if at end of line without a space, finish parsing final word
   if (str.size() > 0 && end < begin) {
      end = str.size();
      retvec.push_back(str.substr(begin, end - begin + 1));
   }
   return retvec;
}

// Arguments:
//   str: The string to parse.
//   sep: The separator character.  If omitted, a space is used.
std::vector< std::string > parseString( const std::string& str, char sep )
{
   bool atEnd = true;  // indicator for being at end of a word
   int begin = -1,  // beginning character of word
      end = -1;  // ending character of word
   vector< string > retvec;  // return vector

   for (string::size_type idx = 0; idx < str.size(); idx++) {
      if (str[idx] == sep) {
         // if not already at end of word, take care of this word
         if (!atEnd) {
            // this is new end of word
            end = idx - 1;
            atEnd = true;
            // push this word onto vector
            retvec.push_back(str.substr(begin, end - begin + 1));
         }
      }
      else {
         // if at end of a word, this is now a new word
         if (atEnd) {
            begin = idx;
            atEnd = false;
         }
      }
   }
   // if at end of line without a separator, finish parsing final word
   if (str.size() > 0 && end < begin) {
      end = str.size();
      retvec.push_back(str.substr(begin, end - begin + 1));
   }
   return retvec;
}
