// $Id: age.cpp 1.19 2007/03/09 17:08:45EST 044579 Development  $
//
// Functions to handle age.

#include <sstream>
#include "age.h"
#include "PiaException.h"
#include "Resource.h"

using namespace std;

// Description: Compares (years,months) ages.
//
// Returns: True if this age is less than argument, false otherwise.
//
// Arguments:
//   newAge: Age to compare this one to.
bool Age::operator<( const Age& newAge ) const
{
   // check years
   if (yearsOfAge != newAge.yearsOfAge)
      return(yearsOfAge < newAge.yearsOfAge);
   // same years, so check months
   return(monthsOfAge < newAge.monthsOfAge);
}

// Description: Checks for months in bounds.
//
// Throws: PiaException of type PIA_IDS_AGEMONTH if months is greater than 11.
void Age::monthsCheck() const
{
   if (getMonths() > 11)
      throw PiaException(PIA_IDS_AGEMONTH);
}

// Description: Returns string with age as years and months.
//
// Returns: A string such as "65 and 6 months".
std::string Age::toString() const
{
   monthsCheck();
   ostringstream strm;
   strm << getYears() << " and " << getMonths()
      << ((getMonths() == 1) ? " month" : " months");
   return(strm.str());
}
