// $Id: comma.cpp 1.13 2002/08/12 12:26:31EDT sfmckay Exp  $
//
// Various functions to convert a number to a string with commas and a
// given number of decimal places.

#include "comma.h"

using namespace std;

// Description: Inserts commas into a formatted string representing a number.
//
// Arguments:
//   start: String without commas, to be returned with commas.
//   dec: Number of decimal places.
//   point: Indicator for decimal point.
//   sign: Indicator for negative sign.
void pcomma( std::string& start, int dec, int point, int sign )
{
   int len = static_cast<int>(start.length());
   // number of commas or blanks to insert
   int ncomma = (len - sign - dec - point - 1) / 3;
   if (ncomma > 0) {
      // insert commas
      for (int i1 = 1; i1 <= ncomma; i1++) {
         start.insert(len - 3 * i1 - dec - point, ",");
      }
   }
}

// Description: Inserts blanks or zeroes on the left of a formatted string
//   representing a number.
//
// Arguments:
//   start: String without blanks, to be returned with blanks.
//   width: Minimum width of field.
//   zeroFill: True if should zero fill on left.
void pblank( std::string& start, int width, bool zeroFill )
{
   const char *fillchar = zeroFill ? "0" : " ";
   int len = static_cast<int>(start.length());
   // number of blanks needed
   int nblank = width - len;
   if (nblank > 0) {
      for (int i1 = 0; i1 < nblank; i1++)
         start.insert(i1, fillchar);
   }
}
