// $Id: date.cpp 1.13 2007/03/08 14:10:04EST 044579 Development  $
//
// Functions to handle generic date.

#include "date.h"
#include "Resource.h"
#include "PiaException.h"
#include "boost/date_time/gregorian/greg_date.hpp"

using namespace std;

// Description: Lowest year that is acceptable (1800).
unsigned Date::lowyear = 1800;
// Description: Highest year that is acceptable (2100).
unsigned Date::highyear = 2100;

// Description: Checks for month in bounds.
//
// Throws: PiaException of type PIA_IDS_DATEMONTH if bad month.
//
// Arguments:
//   month: Month to check.
void Date::monthCheck( unsigned month )
{
   if (month < boost::date_time::Jan || month > boost::date_time::Dec)
      throw PiaException(PIA_IDS_DATEMONTH);
}

// Description: Checks for year in bounds.
//
// Throws: PiaException of type PIA_IDS_DATEYEAR if bad year.
//
// Arguments:
//   year: Year to check.
void Date::yearCheck( unsigned year )
{
   if (year < lowyear || year > highyear)
      throw PiaException(PIA_IDS_DATEYEAR);
}

// Description: Adds years to the specified date.
//
// Returns: The incremented date.
//
// Remarks: The years could be negative. A day of February 29 is changed to
// February 28 to be sure there is no leap-year problem.
//
// Arguments:
//   theDate: The date to add to.
//   years: The number of years to add.
boost::gregorian::date Date::addYears( boost::gregorian::date theDate,
 int years )
{
   const unsigned short month = theDate.month();
   const unsigned short day = theDate.day();
   const unsigned short day1 = (month == boost::date_time::Feb && day == 29) ?
      28 : day;
   return boost::gregorian::date(
      static_cast<unsigned short>(theDate.year() + years), month, day1);
}
