// $Id: document.cpp 1.12 2006/01/04 17:27:58EST 044579 Exp  $
//
// Functions for Document class.

#include "document.h"
#include "Path.h"

using namespace std;

// Description: Constructor.
//
// Remarks: The default constructor initializes the parent
//   directory to "". The title is set to "" in all constructors.
Document::Document() : Genfile(), corename(), docTitle()
{
   pathname = corename;
}

// Arguments:
//   newCorename: New core file name, before modifiers or extensions.
//   newDirectory: New directory holding this document.
Document::Document( const std::string& newCorename,
 const std::string& newDirectory ) :
Genfile(newDirectory), corename(newCorename), docTitle()
{
   pathname = Path::combine(newDirectory, corename);
}

// Description: Destroys document.
Document::~Document()
{ }

// Description: Returns message when reading from file.
//
// Returns: Message when reading from file.
std::string Document::readmesg()
{
   string tempmesg("Reading ");
   tempmesg += docTitle;
   tempmesg += " from ";
   tempmesg += getPathname();
   return tempmesg;
}

// Description: Returns message when writing to file.
//
// Returns: Message when writing to file.
std::string Document::writemesg()
{
   string tempmesg("Writing ");
   tempmesg += docTitle;
   tempmesg += " to ";
   tempmesg += getPathname();
   return tempmesg;
}

// Description: Returns message when error reading from file.
//
// Returns: Message when error reading from file.
std::string Document::errormesg()
{
   string tempmesg("Error reading ");
   tempmesg += docTitle;
   return tempmesg;
}

// Description: Sets the path and modifier on the file name.
//
// Arguments:
//   newPath: The new path.
//   newModifier: The new file modifier.
void Document::setPathAndModifier( const std::string& newPath,
 const std::string& newModifier )
{
   pathname = Path::combine(newPath, corename) + newModifier;
}

// Description: Sets the path and modifier on the file name.
//
// Arguments:
//   newPath: The new path.
void Document::setPath( const std::string& newPath )
{
   pathname = Path::combine(newPath, pathname);
}

// Description: Sets the extension on the file name.
//
// Arguments:
//   newExtension: The new file extension.
void Document::setExtension( const std::string& newExtension )
{
   pathname = Path::changeExtension(pathname, newExtension);
}
