// $Id: genfile.cpp 1.11 2006/11/08 11:03:42EST 044579 Development  $
//
// Functions to handle a generic file.

#include <fstream>
#include "genfile.h"
#include "Resource.h"
#include "PiaException.h"

using namespace std;

// Description: Constructor.
//
// Remarks: The default constructor initializes the parent directory to "".
Genfile::Genfile() : pathname()
{ }

// Arguments:
//   newDirectory: New parent directory or full pathname.
Genfile::Genfile( const std::string& newDirectory ) : pathname(newDirectory)
{ }

// Description: Destroys a Genfile.
Genfile::~Genfile()
{ }

// Description: Opens a file for output with fixed fields for floats.
//
// Throws: PiaException of type PIA_IDS_GENFILE1 if unable to open file.
//
// Arguments:
//   out: Output stream.
void Genfile::openout( std::ofstream& out )
{
   // open with group write permission
   // out.open(pathname.getfullname(), ios::out, 0664);
   out.open(pathname.c_str(), ios::out);
   if (!out.is_open()) {
      throw PiaException(PIA_IDS_GENFILE1);
   }
   out.setf(ios::fixed,ios::floatfield);
}

// Description: Opens a file for appended output with fixed fields for floats.
//
// Throws: PiaException of type PIA_IDS_GENFILE2 if unable to open file.
//
// Arguments:
//   out: Output stream.
void Genfile::openapp( std::ofstream& out )
{
   out.open(pathname.c_str(), ios::app);
   if (!out.is_open()) {
      throw PiaException(PIA_IDS_GENFILE2);
   }
   out.setf(ios::fixed, ios::floatfield);
}

// Description: Opens a file for input.
//
// Throws: PiaException of type PIA_IDS_GENFILE3 if unable to open file.
//
// Arguments:
//   in: Input stream.
void Genfile::openin( std::ifstream& in )
{
   // in.open(pathname.getfullname().c_str(), ios::in | ios::nocreate);
   in.open(pathname.c_str(), ios::in);
   if (!in.is_open()) {
      throw PiaException(PIA_IDS_GENFILE3);
   }
}
