// $Id: outfile.cpp 1.30 2007/03/09 17:08:45EST 044579 Development  $
//
// Functions to write out headings in output files.

#include "outfile.h"
#include "Path.h"
#include "Trace.h"
#include "boost/date_time/gregorian/gregorian.hpp"

using namespace std;

// Description: Initializes output file core name and extension.
//
// Arguments:
//   newCorename: New core file name.
//   newExtension: New extension on the file name.
Outfile::Outfile( const std::string& newCorename,
 const std::string& newExtension ) :
Document(newCorename, ""), pageNum(0), dateModyyr(), command1(), command2()
{
   pathname = Path::changeExtension(newCorename, newExtension);
}

// Description: Destroys an Outfile structure.
Outfile::~Outfile( )
{ }

// Description: Sets printer information.
//
// Arguments:
//   newCommand1: New first part of printer command.
//   newCommand2: New second part of printer command.
void Outfile::setprninfo( const std::string& newCommand1,
const std::string& newCommand2 )
{
   command1 = newCommand1;
   command2 = newCommand2;
}

// Description: Writes html header information.
void Outfile::header()
{
   printLine("<html>");
   advanceLine();
   printLine("<head>");
   printLine("  <link rel=\"stylesheet\" href=\"tables.css\" "
      "charset=\"ISO-8859-1\" type=\"text/css\"></link>");
   string temp("  <title>");
   temp += gettitle(1);
   temp += "</title>";
   printLine(temp);
   printLine("</head>");
   advanceLine();
   printLine("<body>");
}

// Description: Writes html footer information.
void Outfile::footer()
{
   advanceLine();
   printLine("</body>");
   advanceLine();
   printLine("</html>");
}

// Description: Writes title to html file.
void Outfile::pgtitlehtml()
{
   string temp;

   pageNum++;
   if (pageNum == 1) {
      temp = "<h1 class=\"FirstHeader\">";
   }
   else {
      temp = "<h1 class=\"LaterHeader\">";
   }
   for (int i = 0; i < PAGE_TITLE_LINES; i++) {
      temp += gettitle(i);
      temp += "<br>";
   }
   temp += "</h1>";
   printLine(temp);
   advanceLine();
   return;
}

// Description: Initializes output file core name and extension.
//
// Arguments:
//   newCorename: New core file name.
//   newExtension: New extension on the file name.
Out132::Out132( const std::string& newCorename,
 const std::string& newExtension ) : Outfile(newCorename, newExtension)
{ }

// Description: Writes date, time, 2-line title, and page to 132-column print
//   file.
void Out132::pgtitle()
{
   pageNum++;
   formfeed();
   ostringstream ss;
   ss << "  Date      Time           ";
   unsigned length = static_cast<unsigned>(gettitle(0).length());
   unsigned spacecount = (length < 95u) ? (95u - length) / 2u : 0u;
   ss << setw(spacecount) << ' ' << gettitle(0)
      << setw(spacecount) << ' ' << "Page " << pageNum;
   printLine(ss.str());
   ss.str("");
   ss << boost::gregorian::day_clock::local_day();
   length = static_cast<unsigned>(gettitle(1).length());
   spacecount = (length < 95u) ? (95u - length) / 2u : 0u;
   ss << setw(spacecount) << ' ' << gettitle(1);
   printLine(ss.str());
   advanceLine();
   advanceLine();
   return;
}

// Description: Prepares header strings for output.
//
// Arguments:
//   stringTable: String table to put results into.
//   count: Output count of number of lines prepared.
//   pageNum: Page counter.
//   newPageTitle: Title array.
void Out132::prepareStrings( std::string* stringTable, int* count,
 int* pageNum, const std::string* newPageTitle )
{
   pageNum++;
   ostringstream ss;
   ss << "  Date      Time           ";
   unsigned length = static_cast<unsigned>(newPageTitle[0].length());
   unsigned spacecount = (length < 95u) ? (95u - length) / 2u : 0u;
   ss << setw(spacecount) << ' ' << newPageTitle[0]
      << setw(spacecount) << ' ' << "Page " << *pageNum;
   stringTable[(*count)++] = ss.str();
   ss.str("");
   ss << boost::gregorian::day_clock::local_day();
   length = static_cast<unsigned>(newPageTitle[1].length());
   spacecount = (length < 95u) ? (95u - length) / 2u : 0u;
   ss << setw(spacecount) << ' ' << newPageTitle[1];
   stringTable[(*count)++] = ss.str();
   stringTable[(*count)++] = "";
   stringTable[(*count)++] = "";
}

// Description: Initializes output file core name and extension.
//
// Arguments:
//   newCorename: New core file name.
//   newExtension: New extension on the file name.
Out80::Out80( const std::string& newCorename,
 const std::string& newExtension ) : Outfile(newCorename, newExtension)
{ }

// Description: Writes date, time, 1-line title, and page to 80-column print
//   file.
void Out80::pgtitle()
{
   pageNum++;
   formfeed();
   stringstream ss;
   ss << boost::gregorian::day_clock::local_day()
      << setw(43) << ' ' << "Page " << pageNum;
   printLine(ss.str());
   for (int i = 0; i < PAGE_TITLE_LINES; i++) {
      if (gettitle(i).length() > 0) {
         string temp(" ");
         unsigned length = static_cast<unsigned>(gettitle(i).length());
         unsigned spacecount = (length < 74u) ? (74u - length) / 2u : 0u;
         temp.append(spacecount, ' ');;
         temp += gettitle(i);
         printLine(temp);
      }
   }
   advanceLine();
   advanceLine();
   return;
}

// Description: Prepares header strings for output.
//
// Arguments:
//   stringTable: String table to put results into.
//   count: Output count of number of lines prepared.
//   pageNum: Page counter.
//   newPageTitle: Title array.
void Out80::prepareStrings( string* stringTable, int* count, int* pageNum,
const std::string* newPageTitle )
{
   (*pageNum)++;
   stringstream ss;
   ss << boost::gregorian::day_clock::local_day();
   ss << setw(43) << ' ' << "Page " << *pageNum;
   stringTable[(*count)++] = ss.str();
   for (int i = 0; i < PAGE_TITLE_LINES; i++, (*count)++) {
      if (newPageTitle[i].length() > 0) {
         stringTable[*count] = " ";
         unsigned length = static_cast<unsigned>(newPageTitle[i].length());
         unsigned spacecount = (length < 74u) ? (74u - length) / 2u : 0u;
         stringTable[*count].append(spacecount, ' ');
         stringTable[*count] += newPageTitle[i];
      }
   }
   stringTable[(*count)++] = "";
   stringTable[(*count)++] = "";
   return;
}

// Description: Sends print file to printer.
//
// Remarks: This currently does not work.
//
// Returns: 0.
int Outfile::printout()
{
   const string command = command1 + " " + pathname + " " + command2;
   // if (system(command))
   //    return(79);
   // else
      return(0);
}
