// $Id: page.cpp 1.17 2006/11/08 11:03:41EST 044579 Development  $
//
// Functions to read and write out page counters.

#include <fstream>
#include "page.h"
#include "Resource.h"
#include "PiaException.h"
#include "Trace.h"

using namespace std;

// Error code.
static const unsigned int PIA_IDS_PAGE1 = 1;
// Error code.
static const unsigned int PIA_IDS_PAGE2 = 2;
// Error code.
static const unsigned int PIA_IDS_PAGE3 = 3;

// Description: Initializes page file name and array size.
//
// Arguments:
//   maxCounters: Maximum number of page counters.
PageCounters::PageCounters( int maxCounters ) :
Document("page", ""), theData(maxCounters)
{ }

// Description: Zeroes out page counters.
void PageCounters::deleteContents()
{
   fill(theData.begin(), theData.end(), 0);
}

// Description: Reads page counters from a file named "page".
//
// Throws: PiaException of type PIA_IDS_PAGE1 if unable to open input file.
//   PiaException of type PIA_IDS_PAGE2 if unable to read all values
//   successfully.
void PageCounters::read()
{
   int temp;  // temporary integer

   ifstream in(pathname.c_str(), ios::in);
   if (!in.is_open())
      throw PiaException(PIA_IDS_PAGE1);
   Trace::writeLine("Reading page counters");
   for (unsigned i = 0; i < theData.size(); i++) {
      if (!(in >> temp))
         throw PiaException(PIA_IDS_PAGE2);
      theData[i] = temp;
   }
   in.close();
}

// Description: Updates all subsequent page counters and writes them out.
//
// Arguments:
//   slot: Slot after which all page counters are updated.
void PageCounters::update( int slot )
{
   const int temp = theData[slot];
   fill(theData.begin() + slot + 1, theData.end(), temp);
   write();
}

// Description: Writes page counters out to a file named "page".
//
// Throws: PiaException of type PIA_IDS_PAGE3 if unable to open output file.
void PageCounters::write()
{
   ofstream out(pathname.c_str(), ios::out);
   if (!out.is_open())
      throw PiaException(PIA_IDS_PAGE3);
   out.setf(ios::fixed, ios::floatfield);
   Trace::writeLine("Writing page counters");
   for (unsigned i = 0; i < theData.size(); i++)
      out << " " << theData[i];
   out << endl;
   out.close();
}
