// $Id: Assumptions.cpp 1.16 2002/09/09 12:03:13EDT sfmckay Exp  $
//
// Functions to handle PIA parameter assumptions.

#include "Assumptions.h"
#include "UserAssumptions.h"
#include "BaseYearNonFile.h"

using namespace std;

// Description: Initializes years.
//
// Arguments:
//   newIstart: Year after last known benefit increase. If not specified, the
//     year in BaseYearNonFile is used.
//   newMaxyear: Maximum projected year
Assumptions::Assumptions( int newIstart, int newMaxyear ) :
istart(newIstart), maxyear(newMaxyear)
{ }

// Arguments:
//   newMaxyear: Maximum projected year
Assumptions::Assumptions( int newMaxyear ) :
istart(BaseYearNonFile::YEAR), maxyear(newMaxyear)
{ }

// Description: Destructor.
Assumptions::~Assumptions()
{ }

// Description: Returns an average wage increase assumption title.
//
// Returns: An average wage increase assumption title.
//
// Arguments:
//   altNum: Number of assumption (1 to UserAssumptions::PEBS_ASSUM).
const std::string& Assumptions::getAverageWage( int altNum )
{
   setAwincProjTitle(altNum);
   return getAwincProj().getTitle();
}

// Description: Returns a benefit increase assumption title.
//
// Returns: A benefit increase assumption title.
//
// Arguments:
//   altNum: Number of assumption (1 to UserAssumptions::PEBS_ASSUM).
const std::string& Assumptions::getBenefitInc( int altNum )
{
   setBiProjTitle(altNum);
   return getBiProj().getTitle();
}
