// $Id: AssumptionsFile.cpp 1.16 2002/04/04 13:48:01EST sfmckay Exp  $
//
// Functions to handle PIA parameter assumptions.

#include "AssumptionsFile.h"
#include "oactcnst.h"
#include "baseyear.h"

using namespace std;

// Description: Initializes arrays.
//
// Arguments:
//   newIstart: Year after last known benefit increase.
//   newMaxyear: Maximum projected year.
//   newDirectory: Directory with conversion table file.
AssumptionsFile::AssumptionsFile( int newIstart, int newMaxyear,
const std::string& newDirectory ) :
Assumptions(newIstart, newMaxyear), awincProj(1978, newMaxyear, newDirectory),
biProj(YEAR79, newMaxyear, newDirectory),
catchupDoc(newIstart, newDirectory)
{
   setIstart(newIstart);
}

// Description: Destructor.
AssumptionsFile::~AssumptionsFile()
{ }

// Description: Reads stored benefit increases from disk.
//
// Arguments:
//   altNum: Desired alternative (1-4).
void AssumptionsFile::benefitIncMenu( int altNum )
{
   biProj.read(altNum);
   catchupDoc.read(altNum);
}

// Description: Reads stored average wage increases from disk.
//
// Arguments:
//   altNum: Desired alternative (1-4).
void AssumptionsFile::averageWageMenu( int altNum )
{
   awincProj.read(altNum);
}

// Description: Sets the current year, including for the members.
//
// Throws: PiaException if year is out of range (only in debug mode).
//
// Arguments:
//   newIstart: New current year.
void AssumptionsFile::setIstart( int newIstart )
{
#ifndef NDEBUG
   BaseYear::yearCheck(newIstart);
#endif
   istart = newIstart;
   catchupDoc.catchup.setCstart(newIstart);
   biProj.setFirstYear(newIstart);
   awincProj.setFirstYear(newIstart - 1);
}
