// $Id: AssumptionsNonFile.cpp 1.14 2002/09/09 12:03:13EDT sfmckay Exp  $
//
// Functions to handle PIA parameter assumptions stored with the code.

#include "AssumptionsNonFile.h"
#include "oactcnst.h"
#include "BaseYearNonFile.h"

using namespace std;

// Description: Initializes arrays.
//
// Arguments:
//   newIstart: Year after last known benefit increase. If not specified, the
//     year in BaseYearNonFile is used.
//   newMaxyear: Maximum projected year.
AssumptionsNonFile::AssumptionsNonFile( int newIstart, int newMaxyear ) :
Assumptions(newIstart, newMaxyear), awincProj(1978, newMaxyear),
biProj(YEAR79, newMaxyear), catchupDoc(newIstart)
{
   setIstart(newIstart);
}

// Arguments:
//   newMaxyear: Maximum projected year.
AssumptionsNonFile::AssumptionsNonFile( int newMaxyear ) :
Assumptions(newMaxyear), awincProj(1978, newMaxyear),
biProj(YEAR79, newMaxyear), catchupDoc(BaseYearNonFile::YEAR)
{
   setIstart(BaseYearNonFile::YEAR);
}

// Description: Destructor.
AssumptionsNonFile::~AssumptionsNonFile()
{ }

// Description: Reads stored benefit increases from a static array.
//
// Arguments:
//   altNum: Desired alternative (1-4).
void AssumptionsNonFile::benefitIncMenu( int altNum )
{
   // set benefit increases
   biProj.setData(altNum);
   biProj.setTitle(altNum);
   // set catch-up increases
   catchupDoc.setData(altNum);
}

// Description: Reads stored average wage increases from a static array.
//
// Arguments:
//   altNum: Desired alternative (1-4).
void AssumptionsNonFile::averageWageMenu( int altNum )
{
   // set average wage increases
   awincProj.setData(altNum);
   awincProj.setTitle(altNum);
}

// Description: Sets the current year, including for the members.
//
// Throws: PiaException if year is out of range (only in debug mode).
//
// Arguments:
//   newIstart: New current year.
void AssumptionsNonFile::setIstart( int newIstart )
{
#ifndef NDEBUG
   BaseYear::yearCheck(newIstart);
#endif
   istart = newIstart;
   catchupDoc.catchup.setCstart(newIstart);
   biProj.setFirstYear(newIstart);
   awincProj.setFirstYear(newIstart - 1);
}
