// $Id: AwincDoc.cpp 1.10 2006/11/08 11:04:33EST 044579 Development  $
//
// Functions to handle stored projected average wage increases.

#include "AwincDoc.h"
#include "avgwg.h"
#include "Resource.h"
#include "oactcnst.h"
#include "PiaException.h"
#include "comma.h"
#include "baseyear.h"

using namespace std;

static const char* other = "Other";
static const char* avgwage1 =
   "Old PEBES calculation (1-percent real wage increases)";

// Description: Initializes projected average wage increase info.
//
// Arguments:
//   newIstart: Starting year of average wage increases.
//   newMaxyear: Maximum projected year.
AwincDoc::AwincDoc( int newIstart, int newMaxyear ) :
firstYear(newIstart), awincTitle(), awinc(newMaxyear)
{
   awinc.setPrecision(6);
   // assign titles for non-TR assumptions
   avgwage[1] = avgwage1;
   avgwage[2] = other;
}

// Description: Destructor.
AwincDoc::~AwincDoc()
{ }

// Description: Sets average wage increase for specified year.
//
// Arguments:
//   year: Year of average wage increase to set.
//   newFqinc: New average wage increase.
void AwincDoc::setFqinc( int year, double newFqinc )
{
   Awinc::fqincCheck(newFqinc);
   awinc[year] = newFqinc;
}

// Description: Sets first year of data.
//
// Throws: PiaException if year is out of range (only in debug mode).
//
// Arguments:
//   newFirstYear: New first year of data.
void AwincDoc::setFirstYear( int newFirstYear )
{
#ifndef NDEBUG
   BaseYear::yearCheck(newFirstYear);
#endif
   firstYear = newFirstYear;
   avgwage[0] = "No increase beyond ";
   avgwage[0] += poutNoComma(newFirstYear - 1);
   avgwage[0] += " average wage (Statement)";
}
