// $Id: BenefitAmount.cpp 1.18 2006/11/08 11:04:33EST 044579 Development  $
//
// Functions to handle a Social Security benefit amount.

#include "BenefitAmount.h"
#include "Resource.h"
#include "oactcnst.h"
#include "PiaException.h"
#include "comma.h"

using namespace std;

// Arguments:
//   theAmount: Amount to be rounded.
double BenefitAmount::round( double theAmount, int year )
{
#ifndef NDEBUG
   if (year < YEAR37)
      throw PiaException(PIA_IDS_ROUND);
#endif
   // round down to lower dime for June 1982 and later increases
   if (year >= amend82year) {
      return floor(10.0 * theAmount + 0.0005) / 10.0;
   }
   // for rounding-up to dime, use half-cent rule for 1972 and earlier
   // increases; for 1973-81 benefit increases, round up to dime in
   // any case not already an exact multiple of $.10.  (q is fraction of $.01.)
   const double q = (year >= amend73year) ? 0.009 : 0.499;
   // number of cents that PIA exceeds a multiple of a dime
   const double x100 = fmod(theAmount * 100.0, 10.0);
   if (x100 < q) {
   // if within tolerance of q, do not round up
      theAmount -= x100 / 100.0;
   }
   // otherwise round up to dime
   else {
      theAmount += 0.10 - x100 / 100.0;
   }
   return theAmount;
}

// Arguments:
//   theAmount: Amount to be unrounded.
double BenefitAmount::unround( double theAmount, int year )
{
#ifndef NDEBUG
   if (year < YEAR37)
      throw PiaException(PIA_IDS_ROUND);
#endif
   // round up to higher dime for June 1982 and later increases
   if (year > amend82year) {
      return floor(10.0 * theAmount + 0.999) / 10.0;
   }
   // for rounding-down to dime, use half-cent rule for 1972 and earlier
   // increases; for 1973-81 benefit increases, round down to dime in
   // any case not already an exact multiple of $.10.  (q is fraction of $.01.)
   const double q = (year >= amend73year) ? 9.99 : 9.501;
   // number of cents that PIA is less than a multiple of a dime
   const double x100 = 10.0 - fmod(theAmount * 100.0, 10.0);
   if (x100 > q) {
   // if within tolerance of q, do not round down
      theAmount += x100 / 100.0;
   }
   // otherwise round down to dime
   else {
      theAmount += x100 / 100.0 - 0.10;
   }
   return theAmount;
}

// Description: Returns benefit amount as a string with 2 decimal places.
//
// Returns: Benefit amount as a string with 2 decimal places.
//
// Remarks: The version with no argument acts the same as an "n" argument.
//
// Arguments:
//   format: Format to use.
//
//     @table
//     value  meaning
//     "n"    use comma thousands separator.
//     other  do not use comma thousands separator.
std::string BenefitAmount::toString( const std::string& format ) const
{
   if (format.length() < 1)
      return pout(theAmt, 8, 2, false, false);
   switch (format[0]) {
   case 'n':
      return pout(theAmt, 8, 2, true, false);
   default:
      return pout(theAmt, 8, 2, false, false);
   }
}

std::string BenefitAmount::toString() const
{
   return pout(theAmt, 8, 2, true, false);
}
