// $Id: BenefitAmountArray.cpp 1.10 2006/11/08 11:04:33EST 044579 Development  $
//
// Functions to handle a an array of Social Security benefit amounts.

#include "BenefitAmountArray.h"

using namespace std;

// Description: Initializes the last year.
//
// Remarks: The first year is set to 1937. The default version initializes the
// last year to 0 and the data array to zero size. The version with an argument
// resizes the data array to cover the span of years from 1937 to the specified
// year.
//
// Throws: PiaException of type PIA_IDS_BENARRAY1 (in debug version) if year
//   is out of range.
BenefitAmountArray::BenefitAmountArray() : theData(), lastYear(0), dirty(false)
{ }

// Arguments:
//   year: New last year.
BenefitAmountArray::BenefitAmountArray( int year ) :
theData(year - YEAR37 + 1), lastYear(year), dirty(false)
{
#ifndef NDEBUG
   if (year < YEAR37)
      throw PiaException(PIA_IDS_BENARRAY1);
#endif
}

// Description: Deletes allocated memory.
BenefitAmountArray::~BenefitAmountArray()
{ }

// Description: Initializes last year.
//
// Remarks: Resizes the data array to cover the span of years from 1937 to the
// specified year.
//
// Throws: PiaException of type PIA_IDS_BENARRAY1 (in debug version) if year
//   is out of range.
//
// Arguments:
//   year: New last year.
void BenefitAmountArray::initialize( int year )
{
#ifndef NDEBUG
   if (year < YEAR37)
      throw PiaException(PIA_IDS_BENARRAY1);
#endif
   theData.resize(year - YEAR37 + 1);
   lastYear = year;
}

// Description: Sets all values to zero.
void BenefitAmountArray::deleteContents()
{
   if (dirty) {
      for (int i = YEAR37; i <= lastYear; i++)
         theData[i - YEAR37].set(0.0);
      dirty = false;
   }
}
