// $Id: ChildCareCalcLC.cpp 1.14 2005/10/06 11:55:37EDT 044579 Exp  $
//
// Functions to calculate a wage-indexed PIA with childcare dropout years.

#include "ChildCareCalcLC.h"
#include "LawChangeArray.h"
#include "LawChangeCHILDCAREDROPOUT.h"

using namespace std;

// Description: Initializes a ChildCareCalcLC instance.
//
// Arguments:
//   newWorkerData: Worker data.
//   newPiaData: Pia calculation data.
//   newPiaParams: Pia calculation parameters.
//   newMaxyear: Maximum year of projection.
//   newLawChange: Law change parameters.
ChildCareCalcLC::ChildCareCalcLC( const WorkerDataGeneral& newWorkerData,
const PiaData& newPiaData, const PiaParams& newPiaParams, int newMaxyear,
const LawChangeArray& newLawChange ) :
ChildCareCalc(newWorkerData, newPiaData, newPiaParams, newMaxyear),
lawChange(newLawChange)
{ }

// Description: Destructor.
ChildCareCalcLC::~ChildCareCalcLC()
{ }

// Description: Determines applicability of method.
//
// Remarks: The version with no arguments calls the static version with 5
//   arguments.
//
// Returns: True if this method is applicable, false otherwise.
bool ChildCareCalcLC::isApplicable()
{
   if (isApplicable(workerData, piaData, ioasdi, lawChange)) {
      iapp = APPLICABLE;
      return(true);
   }
   return(false);
}

// Arguments:
//   workerData: Worker data.
//   piaData: Pia calculation data.
//   ioasdi: Type of benefit.
//   lawChange: Law change parameters.
bool ChildCareCalcLC::isApplicable( const WorkerDataGeneral& workerData,
const PiaData& piaData, WorkerDataGeneral::ben_type ioasdi,
const LawChangeArray& lawChange )
{
   // see if lawchange is effective
   LawChangeCHILDCAREDROPOUT *lawChangeCHILDCAREDROPOUT =
      lawChange.lawChangeCHILDCAREDROPOUT;
   if (lawChangeCHILDCAREDROPOUT->isEffective(
      piaData.getEligDate().getYear(),
      workerData.getBenefitDate().getYear())) {
      return(true);
   }
   return ChildCareCalc::isApplicable(workerData, piaData, ioasdi);
}

// Description: Returns maximum number of childcare dropout years.
//
// Returns: Maximum number of childcare dropout years.
int ChildCareCalcLC::childCareDropMaxCal() const
{
   int i1 = piaData.compPeriodNew.getNDrop();
   // get maximum number of childcare dropout years
   int i2 = piaParams.getMaxChildcareDropoutYears(
      piaData.getEligDate().getYear(),
      workerData.getBenefitDate().getYear());
   if (i1 < i2) {
      // can have up to 3 total dropout years, but must have at least 2
      // computation years
      return min(i2 - i1, piaData.compPeriodNew.getN() - 2);
   }
   else {
      // already have maximum dropout years
      return 0;
   }
}
