// $Id: DibGuarLC.cpp 1.2 2005/10/06 11:55:51EDT 044579 Exp  $
//
// Functions to calculate a DIB guarantee PIA with law changes.

#include "DibGuarLC.h"
#include "UserAssumptions.h"
#include "Resource.h"
#include "piaparms.h"
#include "LawChangeArray.h"

using namespace std;

// Description: Initializes a DibGuarLC instance.
//
// Arguments:
//   newWorkerData: Worker basic data.
//   newPiaData: Pia calculation data.
//   newPiaParams: Pia calculation parameters.
//   newMaxyear: Maximum year of projection.
//   newLawChange: Law change parameters.
DibGuarLC::DibGuarLC( const WorkerDataGeneral& newWorkerData,
const PiaData& newPiaData, const PiaParams& newPiaParams, int newMaxyear,
const LawChangeArray& newLawChange ) :
DibGuar(newWorkerData, newPiaData, newPiaParams, newMaxyear),
lawChange(newLawChange)
{ }

// Description: Destructor.
DibGuarLC::~DibGuarLC()
{ }

// Description: Determines applicability of method.
//
// Remarks: The version with no arguments calls the static version with 6
//   arguments.
//
// Returns: True if method is applicable.
bool DibGuarLC::isApplicable()
{
   if (isApplicable(workerData.getEntDate(), workerData.getBenefitDate(),
      workerData, piaData, ioasdi, lawChange)) {
      iapp = APPLICABLE;
      return(true);
   }
   else
      return(false);
}

// Arguments:
//   entDate: The date of entitlement.
//   benefitDate: The date of benefit.
//   workerData: Worker basic data.
//   piaData: Pia calculation data.
//   ioasdi: Type of benefit.
//   lawChange: Law change parameters.
bool DibGuarLC::isApplicable( const DateMoyr& entDate,
const DateMoyr& benefitDate, const WorkerDataGeneral& workerData,
const PiaData& piaData, WorkerDataGeneral::ben_type ioasdi,
const LawChangeArray& lawChange )
{
   LawChange *lawChangeNODIBGUAR = lawChange.lawChange[LawChange::NODIBGUAR];
   // skip DIB guarantee calculation if NODIBGUAR lawchange is set
   if (lawChangeNODIBGUAR->isEffective(entDate.getYear(),
      benefitDate.getYear())) {
      return(false);
   }
   return DibGuar::isApplicable(workerData, piaData, ioasdi);
}
