// $Id: DisInsCodeArray.cpp 1.15 2006/11/08 11:04:49EST 044579 Development  $
//
// Functions to read and write a disability insured status record.

#include "DisInsCodeArray.h"

using namespace std;
using namespace std::rel_ops;

// Description: Initializes the first and last years.
//
// Remarks: Resizes the data array to cover the specified span of years.
//
// Arguments:
//   newFirstYear: New first year of data.
//   newLastYear: New last year of data.
DisInsCodeArray::DisInsCodeArray( int newFirstYear, int newLastYear ) :
theCodes(newLastYear - newFirstYear + 1), firstYear(newFirstYear),
lastYear(newLastYear)
{ }

// Description: Sets data for specified years.
//
// Arguments:
//   newDataArray: Array of new values of data.
//   firstDataYear: First year of data to set.
//   lastDataYear: Last year of data to set.
void DisInsCodeArray::assign( const DisInsCodeArray& newDataArray,
int firstDataYear, int lastDataYear )
{
   int year1 = max(firstYear, newDataArray.firstYear);
   year1 = max(year1, firstDataYear);
   int year2 = min(lastYear, newDataArray.lastYear);
   year2 = min(year2, lastDataYear);
   copy(newDataArray.theCodes.begin() + year1 - newDataArray.firstYear,
      newDataArray.theCodes.begin() + year2 + 1 - newDataArray.firstYear,
      theCodes.begin() + year1 - firstYear);
}

// Arguments:
//   newData: New value of data to be used for all specified years.
void DisInsCodeArray::assign( const DisInsCode& newData, int firstDataYear,
int lastDataYear )
{
   int year1 = max(firstYear, firstDataYear);
   int year2 = min(lastYear, lastDataYear);
   fill(theCodes.begin() + year1 - firstYear,
      theCodes.begin() + year2 + 1 - firstYear, newData);
}

// Description: Zeroes out all data values.
void DisInsCodeArray::deleteContents()
{
   // Iterator is used to loop through the vector.
   vector< DisInsCode >::iterator theIterator;
   for (theIterator = theCodes.begin(); theIterator != theCodes.end();
      theIterator++) {
      *theIterator = DisInsCode::NOQCS;
   }
}

// Description: Returns true if any insured status code is other than
// DisInsCode::NOQCS.
//
// Returns: True if any insured status code is other than DisInsCode::NOQCS.
bool DisInsCodeArray::isNonzero() const
{
   for (int i = firstYear; i <= lastYear; i++) {
      if (theCodes[i - firstYear].get() != DisInsCode::NOQCS)
         return(true);
   }
   return(false);
}

// Description: Returns data for one disability insured status code array
//   as a string.
//
// Returns: Data for one disability insured status code array as a string.
std::string DisInsCodeArray::toString() const
{
   string s;
   for (int i = 0; i <= lastYear - firstYear; i++)
      s += theCodes[i].toChar();
   return(s);
}
