// $Id: InsCodeArray.cpp 1.11 2006/11/08 11:04:49EST 044579 Development  $
//
// Functions to handle an array of insured status codes.

#include "InsCodeArray.h"

using namespace std;
using namespace std::rel_ops;

// Description: Initializes the first and last years.
//
// Remarks: Resizes the data array to cover the specified span of years.
//
// Arguments:
//   newFirstYear: New first year of data.
//   newLastYear: New last year of data.
InsCodeArray::InsCodeArray( int newFirstYear, int newLastYear ) :
theCodes(newLastYear - newFirstYear + 1), firstYear(newFirstYear),
lastYear(newLastYear)
{ }

// Description: Zeroes out all data values.
void InsCodeArray::deleteContents()
{
   // Iterator is used to loop through the vector.
   vector< InsCode >::iterator theIterator;
   for (theIterator = theCodes.begin(); theIterator != theCodes.end();
      theIterator++) {
      *theIterator = InsCode::NOQCS;
   }
}
// Description: Sets data for specified years.
//
// Arguments:
//   newDataArray: Array of new values of data.
//   firstDataYear: First year of data to set.
//   lastDataYear: Last year of data to set.
void InsCodeArray::assign( const InsCodeArray& newDataArray, int firstDataYear,
   int lastDataYear )
{
   int year1 = max(firstYear, newDataArray.firstYear);
   year1 = max(year1, firstDataYear);
   int year2 = min(lastYear, newDataArray.lastYear);
   year2 = min(year2, lastDataYear);
   copy(newDataArray.theCodes.begin() + year1 - newDataArray.firstYear,
      newDataArray.theCodes.begin() + year2 + 1 - newDataArray.firstYear,
      theCodes.begin() + year1 - firstYear);
}

// Arguments:
//   newData: New value of data to be used for all specified years.
void InsCodeArray::assign(const InsCode& newData, int firstDataYear,
int lastDataYear )
{
   int year1 = max(firstYear, firstDataYear);
   int year2 = min(lastYear, lastDataYear);
   fill(theCodes.begin() + year1 - firstYear,
      theCodes.begin() + year2 + 1 - firstYear, newData);
}

// Description: Returns true if any insured status code is other than
// InsCode::NOQCS.
//
// Returns: True if any insured status code is other than InsCode::NOQCS.
bool InsCodeArray::isNonzero() const
{
   for (int i = firstYear; i <= lastYear; i++)
      if (theCodes[i - firstYear].get() != InsCode::NOQCS)
         return(true);
   return(false);
}

// Description: Returns data for one insured status code array as a string.
//
// Returns: Data for one insured status code array as a string.
std::string InsCodeArray::toString() const
{
   string s;
   for (int i = 0; i <= lastYear - firstYear; i++)
      s += theCodes[i].toChar();
   return(s);
}
