// $Id: LawChangeAGE65COMP.cpp 1.5 2003/05/22 09:27:11EDT sfmckay Exp  $
//
// Functions needed for class to manage parameters for a proposal to
// increase the bend points in the benefit formula by a specified growth rate.

#include <vector>
#include "LawChangeAGE65COMP.h"
#include "PiaException.h"
#include "Resource.h"
#include "comma.h"
#include "oactcnst.h"

using namespace std;

// Description: Constructor.
LawChangeAGE65COMP::LawChangeAGE65COMP() :
LawChange("increase number of elapsed years"), step(0)
{ }

// Description: Reads all the lines required for this law-change.
//
// Arguments:
//   infile: Open input stream.
void LawChangeAGE65COMP::read( std::istream& infile )
{
   if (getInd() > 0) {
      vector< string > strvec = getFirstLine(infile);
      if (strvec.size() < 4)
         throw PiaException(PIA_IDS_LAWCHG6);
      setStep(atoi(strvec[3].c_str()));
   }
}

// Description: Writes a line with first and last years, and percentage.
//
// Arguments:
//   out: Open output stream.
void LawChangeAGE65COMP::write( std::ostream& out ) const
{
   if (getInd() > 0) {
      writeFirstLine(out);
      out << " " << poutNoComma(getStep(), 3) << endl;
   }
}

// Description: Prepares output strings for this change from present law.
//
// Arguments:
//   outputString: Table of output strings.
void LawChangeAGE65COMP::prepareStrings(
std::vector<std::string> &outputString )
{
   if (getInd() > 0) {
      outputString.push_back(getTitle());
      if (getPhaseType() == 0)
         outputString.push_back("Effective for new eligibles");
      else
         outputString.push_back("Effective immediately for all persons");
      string s("Elapsed years increase by ");
      s += poutNoComma(getInd());
      outputString.push_back(s);
      s = "Increase of 1 elapsed year every ";
      s += poutNoComma(getStep());
      s += " years";
      outputString.push_back(s);
   }
}
