// $Id: LawChangeALLEARN.cpp 1.5 2003/05/22 09:27:11EDT sfmckay Exp  $
//
// Functions needed for class to manage parameters for a proposal to
// use all years of earnings in an AIME calculation.

#include <vector>
#include "LawChangeALLEARN.h"
#include "PiaException.h"
#include "Resource.h"
#include "comma.h"
#include "oactcnst.h"

using namespace std;

// Description: Constructor.
LawChangeALLEARN::LawChangeALLEARN() :
LawChange("use all earnings in AIME computation"), step(0), yearPhasein(0)
{ }

// Description: Reads all the lines required for this law-change.
//
// Arguments:
//   infile: Open input stream.
void LawChangeALLEARN::read( std::istream& infile )
{
   if (getInd() > 0) {
      vector< string > strvec = getFirstLine(infile);
      // read phase-in information
      if (getInd() == 2) {
         if (strvec.size() < 5)
            throw PiaException(PIA_IDS_LAWCHG6);
         setYear(atoi(strvec[3].c_str()));
         setStep(atoi(strvec[4].c_str()));
      }
   }
}

// Description: Writes a line with first and last years, and step size.
//
// Arguments:
//   out: Open output stream.
void LawChangeALLEARN::write( std::ostream& out ) const
{
   if (getInd() > 0) {
      writeFirstLine(out);
      // write phase-in information
      if (getInd() == 2) {
         out << " " << getYear() << " " << getStep();
      }
      out << endl;
   }
}

// Description: Prepares output strings for this change from present law.
//
// Arguments:
//   outputString: Table of output strings.
void LawChangeALLEARN::prepareStrings( std::vector<std::string> &outputString )
{
   if (getInd() > 0) {
      outputString.push_back(getTitle());
      if (getPhaseType() == 0)
         outputString.push_back("Effective for new eligibles");
      else
         outputString.push_back("Effective immediately for all persons");
      if (getInd() == 1) {
         string s = "Use all earnings beginning ";
         s += poutNoComma(getStartYear());
         outputString.push_back(s);
      }
      if (getInd() == 2) {
         string s = "Phase in use of all earnings by 1 year every ";
         s += poutNoComma(getStep());
         s += " years, beginning ";
         s += poutNoComma(getYear());
         outputString.push_back(s);
         s = "Use all earnings beginning ";
         s += poutNoComma(getStartYear());
         outputString.push_back(s);
      }
   }
}
