// $Id: LawChangeBPFRACWAGE.cpp 1.6 2003/05/22 09:27:12EDT sfmckay Exp  $
//
// Functions needed for class to manage parameters for a proposal to
// increase the bend points in the benefit formula by a fraction of average
// wage growth.

#include <vector>
#include "LawChangeBPFRACWAGE.h"
#include "PiaException.h"
#include "Resource.h"
#include "comma.h"

using namespace std;

// Description: Constructor.
LawChangeBPFRACWAGE::LawChangeBPFRACWAGE() :
LawChange("bend points increasing at fraction of wage rate"), pbp(0.0)
{ }

// Description: Reads all the lines required for this law-change.
//
// Arguments:
//   infile: Open input stream.
void LawChangeBPFRACWAGE::read( std::istream& infile )
{
   if (getInd() > 0) {
      vector< string > strvec = getFirstLine(infile);
      if (strvec.size() < 4)
         throw PiaException(PIA_IDS_LAWCHG6);
      setProportionBendPoints(atof(strvec[3].c_str()));
   }
}

// Description: Writes a line with first and last years, and percentage.
//
// Arguments:
//   out: Open output stream.
void LawChangeBPFRACWAGE::write( std::ostream& out ) const
{
   if (getInd() > 0) {
      writeFirstLine(out);
      out << poutNoComma(getProportionBendPoints(), 4, 2) << endl;
   }
}

// Description: Prepares output strings for this change from present law.
//
// Arguments:
//   outputString: Table of output strings.
void LawChangeBPFRACWAGE::prepareStrings(
std::vector<std::string> &outputString )
{
   if (getInd() > 0) {
      outputString.push_back(getTitle());
      if (getPhaseType() == 0)
         outputString.push_back("Effective for new eligibles");
      else
         outputString.push_back("Effective immediately for all persons");
      string s("Bend points are ");
      s += poutComma(getProportionBendPoints(), 4, 2);
      s += " wage-indexed from ";
      s += poutNoComma(getStartYear());
      s += " to ";
      s += poutNoComma(getEndYear());
      outputString.push_back(s);
   }
}
