// $Id: LawChangeBPMINCONST.cpp 1.6 2003/05/22 09:27:12EDT sfmckay Exp  $
//
// Functions needed for class to manage parameters for a proposal to
// increase the bend points in the benefit formula by the wage rate minus
// a constant.

#include "LawChangeBPMINCONST.h"
#include "PiaException.h"
#include "Resource.h"
#include "comma.h"
#include "oactcnst.h"

using namespace std;

// Description: Constructor.
LawChangeBPMINCONST::LawChangeBPMINCONST() :
LawChange("bend points increasing at wage rate minus a constant"), cp(0.f)
{ }

// Description: Reads all the lines required for this law-change.
//
// Arguments:
//   infile: Open input stream.
void LawChangeBPMINCONST::read( std::istream& infile )
{
   if (getInd() > 0) {
      vector< string > strvec = getFirstLine(infile);
      if (strvec.size() < 4)
         throw PiaException(PIA_IDS_LAWCHG6);
      setConstantPerc((float)atof(strvec[3].c_str()));
   }
}

// Description: Writes a line with first and last years, and percentage.
//
// Arguments:
//   out: Open output stream.
void LawChangeBPMINCONST::write( std::ostream& out ) const
{
   if (getInd() > 0) {
      writeFirstLine(out);
      out << " " << poutNoComma(getConstantPerc(), 4, 2) << endl;
   }
}

// Description: Prepares output strings for this change from present law.
//
// Arguments:
//   outputString: Table of output strings.
void LawChangeBPMINCONST::prepareStrings(
std::vector<std::string> &outputString )
{
   if (getInd() > 0) {
      outputString.push_back(getTitle());
      if (getPhaseType() == 0)
         outputString.push_back("Effective for new eligibles");
      else
         outputString.push_back("Effective immediately for all persons");
      string s = poutComma(getConstantPerc(), 3, 2);
      s += " percent subtracted from wage increase factor";
      outputString.push_back(s);
      s = "for increase in bend points from ";
      s += poutNoComma(getStartYear());
      s += " to ";
      s += poutNoComma(getEndYear());
      outputString.push_back(s);
   }
}
