// $Id: LawChangeBPSPECRATE.cpp 1.8 2003/05/22 09:27:12EDT sfmckay Exp  $
//
// Functions needed for class to manage parameters for a proposal to
// increase the bend points in the benefit formula by a specified growth rate.

#include <vector>
#include "LawChangeBPSPECRATE.h"
#include "PiaException.h"
#include "Resource.h"
#include "comma.h"
#include "oactcnst.h"

using namespace std;

// Description: Constructor.
LawChangeBPSPECRATE::LawChangeBPSPECRATE() :
LawChange("bend points increasing at specified rates"),
bpinc(YEAR79, endYearLC)
{ }

// Description: Reads all the lines required for this law-change.
//
// Arguments:
//   infile: Open input stream.
void LawChangeBPSPECRATE::read( std::istream& infile )
{
   if (getInd() > 0) {
      vector< string > strvec = getFirstLine(infile);
      int i3 = 3;
      for (int i1 = getStartYear(); i1 <= getEndYear(); i1++, i3++) {
         float ftemp = (float)atof(strvec[i3].c_str());
         setBendPiaInc(i1, ftemp);
      }
   }
}

// Description: Writes a line with first and last years, and percentage.
//
// Arguments:
//   out: Open output stream.
void LawChangeBPSPECRATE::write( std::ostream& out ) const
{
   if (getInd() > 0) {
      writeFirstLine(out);
      out << " ";
      for (int i1 = getStartYear(); i1 <= getEndYear(); i1++) {
         out << poutNoComma(getBendPiaInc(i1), 4, 2) << " ";
      }
      out << endl;
   }
}

// Description: Prepares output strings for this change from present law.
//
// Arguments:
//   outputString: Table of output strings.
void LawChangeBPSPECRATE::prepareStrings(
std::vector<std::string> &outputString )
{
   if (getInd() > 0) {
      outputString.push_back(getTitle());
      if (getPhaseType() == 0)
         outputString.push_back("Effective for new eligibles");
      else
         outputString.push_back("Effective immediately for all persons");
      string s("Bend points are indexed from ");
      s += poutNoComma(getStartYear());
      s += " to ";
      s += poutNoComma(getEndYear());
      s += " by:";
      outputString.push_back(s);
      s = "";
      for (int i2 = getStartYear(); i2 <= getEndYear(); i2++) {
         s += poutComma(getBendPiaInc(i2), 7, 2);
      }
      outputString.push_back(s);
   }
}
