// $Id: LawChangeCHILDCARECREDIT.cpp 1.7 2005/07/13 09:03:03EDT mmorris Exp  $
//
// Functions needed for class to manage parameters for a proposal to
// provide child care credit years.

#include <vector>
#include "LawChangeCHILDCARECREDIT.h"
#include "PiaException.h"
#include "Resource.h"
#include "comma.h"
#include "oactcnst.h"
#include "StringParser.h"
#include "percpia.h"

using namespace std;

// Description: Constructor.
LawChangeCHILDCARECREDIT::LawChangeCHILDCARECREDIT() :
LawChange("childcare credit years"), fqRatio(0.0), maxAge(0), maxYears(0),
avgEarnPct(0.0), numTopEarnYears(0), numDropExtremeEarnYears(0),
childCareYearsBeforeEffYear(false)
{ }

// Description: Reads all the lines required for this law-change.
//
// Remarks: There are 2 types of child care credit proposals. The first
// is based on a set percentage of the current year's wage base. And the
// second is based on the person's earnings history.
//
// Arguments:
//   infile: Open input stream.
void LawChangeCHILDCARECREDIT::read( std::istream& infile )
{
   if (getInd() > 0) {
      vector< string > strvec = getFirstLine(infile);
      if (getInd() <= 2) {
        if (strvec.size() < 7)
          throw PiaException(PIA_IDS_LAWCHG6);
        setFqRatio(atof(strvec[3].c_str()));
        setMaxAge(atoi(strvec[4].c_str()));
        setMaxYears(atoi(strvec[5].c_str()));
        setChildCareYearsBeforeEffYear(atoi(strvec[6].c_str()));
      }
      else {
        if (strvec.size() < 9)
          throw PiaException(PIA_IDS_LAWCHG6);
        setAvgEarnPct(atof(strvec[3].c_str()));
        setMaxAge(atoi(strvec[4].c_str()));
        setMaxYears(atoi(strvec[5].c_str()));
        setNumTopEarnYears(atoi(strvec[6].c_str()));
        setNumDropExtremeEarnYears(atoi(strvec[7].c_str()));
        setChildCareYearsBeforeEffYear(atoi(strvec[8].c_str()));
      }
   }
}

// Description: Writes a line with first and last years, and percentage.
//
// Arguments:
//   out: Open output stream.
void LawChangeCHILDCARECREDIT::write( std::ostream& out ) const
{
   if (getInd() > 0) {
      writeFirstLine(out);
      out << endl;
      if (getInd() <= 2) {
        out << " " << poutNoComma(getFqRatio(), 5, 4) << endl;
        out << " " << getMaxAge() << endl;
        out << " " << getMaxYears() << endl;
        out << " " << (getChildCareYearsBeforeEffYear() ? "1" : "0") << endl;
      }
      else {
        out << " " << poutNoComma(getAvgEarnPct(), 5, 4) << endl;
        out << " " << getMaxAge() << endl;
        out << " " << getMaxYears() << endl;
        out << " " << getNumTopEarnYears() << endl;
        out << " " << getNumDropExtremeEarnYears() << endl;
        out << " " << (getChildCareYearsBeforeEffYear() ? "1" : "0") << endl;
      }
   }
}

// Description: Prepares output strings for this change from present law.
//
// Arguments:
//   outputString: Table of output strings.
void LawChangeCHILDCARECREDIT::prepareStrings(
std::vector<std::string> &outputString )
{
   if (getInd() > 0) {
      outputString.push_back(getTitle());
      if (getPhaseType() == 0)
         outputString.push_back("Effective for new eligibles");
      else
         outputString.push_back("Effective immediately for all persons");
      string s = "Childcare credit years from ";
      s += poutNoComma(getStartYear());
      s += " to ";
      s += poutNoComma(getEndYear());
      outputString.push_back(s);
      s = "for children less than or equal to age ";
      s += poutNoComma(getMaxAge());
      outputString.push_back(s);
      if (getInd() <= 2) {
        s = "Credit equals ";
        s += poutNoComma(getFqRatio(), 5, 4);
        s += " times average wage, for a maximum of ";
        s += poutNoComma(getMaxYears());
        s += " credit years";
        outputString.push_back(s);
      }
      else {
        s = "Credit equals ";
        s += poutNoComma(getAvgEarnPct(), 5, 4);
        s += " times the person's average earnings of the top ";
        s += poutNoComma(getNumTopEarnYears());
        s += " years excluding ";
        s += poutNoComma(getNumDropExtremeEarnYears());
        s += " extreme year(s) of earnings at each end of these top earnings";
        s += ", for a maximum of ";
        s += poutNoComma(getMaxYears());
        s += " credit years";
        outputString.push_back(s);
      }
      s = "Child-care years ";
      s += (getChildCareYearsBeforeEffYear()) ? "can" : "can not";
      s += " be credited for years before first effective year";
      outputString.push_back(s);
      s = "Quarters of coverage ";
      s += (getInd() == 1 || getInd() == 3) ? "are" : "are not";
      s += " credited for child-care years";
      outputString.push_back(s);
   }
}
