// $Id: LawChangeCHILDCAREDROPOUT.cpp 1.5 2003/05/22 09:27:13EDT sfmckay Exp  $
//
// Functions needed for class to manage parameters for a proposal to
// provide child care dropout years.

#include <vector>
#include "LawChangeCHILDCAREDROPOUT.h"
#include "PiaException.h"
#include "Resource.h"
#include "comma.h"
#include "oactcnst.h"
#include "StringParser.h"
#include "percpia.h"

using namespace std;

// Description: Constructor.
LawChangeCHILDCAREDROPOUT::LawChangeCHILDCAREDROPOUT() :
LawChange("childcare dropout years"), fqRatio(0.0),
maxAge(0), maxYears(0)
{ }

// Description: Reads all the lines required for this law-change.
//
// Arguments:
//   infile: Open input stream.
void LawChangeCHILDCAREDROPOUT::read( std::istream& infile )
{
   if (getInd() > 0) {
      vector< string > strvec = getFirstLine(infile);
      if (strvec.size() < 6)
         throw PiaException(PIA_IDS_LAWCHG6);
      setFqRatio(atof(strvec[3].c_str()));
      setMaxAge(atoi(strvec[4].c_str()));
      setMaxYears(atoi(strvec[5].c_str()));
   }
}

// Description: Writes a line with first and last years, and percentage.
//
// Arguments:
//   out: Open output stream.
void LawChangeCHILDCAREDROPOUT::write( std::ostream& out ) const
{
   if (getInd() > 0) {
      writeFirstLine(out);
      out << " " << poutNoComma(getFqRatio(), 5, 4) << endl;
      out << " " << getMaxAge() << endl;
      out << " " << getMaxYears() << endl;
      out << endl;
   }
}

// Description: Prepares output strings for this change from present law.
//
// Arguments:
//   outputString: Table of output strings.
void LawChangeCHILDCAREDROPOUT::prepareStrings(
std::vector<std::string> &outputString )
{
   if (getInd() > 0) {
      outputString.push_back(getTitle());
      if (getPhaseType() == 0)
         outputString.push_back("Effective for new eligibles");
      else
         outputString.push_back("Effective immediately for all persons");
      string s = "Childcare dropout years from ";
      s += poutNoComma(getStartYear());
      s += " to ";
      s += poutNoComma(getEndYear());
      s += " for children less than or equal to age ";
      s += poutNoComma(getMaxAge());
      outputString.push_back(s);
      s = "Earnings must be less than  ";
      s += poutNoComma(getFqRatio(), 5, 4);
      s += " times average wage, for maximum of ";
      s += poutNoComma(getMaxYears());
      s += " dropout years";
      outputString.push_back(s);
   }
}
