// $Id: LawChangeCOLACHANGE.cpp 1.6 2004/03/31 14:01:52EST sfmckay Exp  $
//
// Functions needed for class to manage parameters for a proposal to
// change the benefit increases (COLAs).

#include <vector>
#include "LawChangeCOLACHANGE.h"
#include "PiaException.h"
#include "Resource.h"
#include "comma.h"
#include "oactcnst.h"
#include "StringParser.h"
#include "percpia.h"

using namespace std;

// Description: Constructor.
//
// Remarks: It sets the colaAdj and piaPercentile to zero.
LawChangeCOLACHANGE::LawChangeCOLACHANGE() :
LawChange("ad hoc COLA change"), colaAdj(0.0f), piaPercentile(0)
{ }

// Description: Reads the one line required for this law-change.
//
// Remarks: It reads the first and last years, and either the percentage
// increase or decrease in COLA (for type 1), or the pia percentile (for type
// 2).
//
// Arguments:
//   infile: Open input stream.
void LawChangeCOLACHANGE::read( std::istream& infile )
{
   if (getInd() > 0) {
      vector< string > strvec = getFirstLine(infile);
      if (getInd() == 1) {
         if (strvec.size() < 4)
            throw PiaException(PIA_IDS_LAWCHG6);
         setColaAdj((float)atof(strvec[3].c_str()));
      }
      if (getInd() == 2) {
         if (strvec.size() < 4)
            throw PiaException(PIA_IDS_LAWCHG6);
         setPiaPercentile(atoi(strvec[3].c_str()));
      }
   }
}

// Description: Writes a line with this law-change.
//
// Remarks: The line has the first and last years, and either the percentage
// increase or decrease in COLA (for type 1), or the pia percentile (for type
// 2).
//
// Arguments:
//   out: Open output stream.
void LawChangeCOLACHANGE::write( std::ostream& out ) const
{
   if (getInd() > 0) {
      writeFirstLine(out);
      if (getInd() == 1) {
         out << " "  << poutNoComma(getColaAdj(), 1, 4);
      }
      if (getInd() == 2) {
         out << " "  << poutNoComma(getPiaPercentile(), 1, 4);
      }
      out << endl;
   }
}

// Description: Prepares output strings for this change from present law.
//
// Arguments:
//   outputString: Table of output strings.
void LawChangeCOLACHANGE::prepareStrings(
std::vector<std::string> &outputString )
{
   if (getInd() > 0) {
      string s;
      if (getInd() == 1) {
         s = "Change in COLA of ";
         s += poutNoComma(getColaAdj(), 1, 2);
      }
      if (getInd() == 2) {
         s = "Capping the COLA based on the ";
         s += poutNoComma(getPiaPercentile());
         s += "th percentile";
      }
      s += " begins in ";
      s += poutNoComma(getStartYear());
      outputString.push_back(s);
   }
}
