// $Id: LawChangeDROPOUTCHG.cpp 1.5 2003/05/22 09:27:13EDT sfmckay Exp  $
//
// Functions needed for class to manage parameters for a proposal to
// reduce the number of dropout years in a pia calculation.

//#include "PragmaWarningDisable4786.h"
#include <vector>
#include "LawChangeDROPOUTCHG.h"
#include "PiaException.h"
#include "Resource.h"
#include "comma.h"
#include "oactcnst.h"

using namespace std;

// Description: Constructor.
LawChangeDROPOUTCHG::LawChangeDROPOUTCHG() :
LawChange("reduce number of dropout years"), step(0)
{ }

// Description: Reads all the lines required for this law-change.
//
// Arguments:
//   infile: Open input stream.
void LawChangeDROPOUTCHG::read( std::istream& infile )
{
   if (getInd() > 0) {
      vector< string > strvec = getFirstLine(infile);
      if (strvec.size() < 4)
         throw PiaException(PIA_IDS_LAWCHG6);
      setStep(atoi(strvec[3].c_str()));
   }
}

// Description: Writes a line with first and last years, and step size.
//
// Arguments:
//   out: Open output stream.
void LawChangeDROPOUTCHG::write( std::ostream& out ) const
{
   if (getInd() > 0) {
      writeFirstLine(out);
      out << " " << poutNoComma(getStep(), 3) << endl;
   }
}

// Description: Prepares output strings for this change from present law.
//
// Arguments:
//   outputString: Table of output strings.
void LawChangeDROPOUTCHG::prepareStrings(
std::vector<std::string> &outputString )
{
   if (getInd() > 0) {
      outputString.push_back(getTitle());
      if (getPhaseType() == 0)
         outputString.push_back("Effective for new eligibles");
      else
         outputString.push_back("Effective immediately for all persons");
      string s = "Dropout years decrease by ";
      s += poutNoComma(getInd());
      outputString.push_back(s);
      s = "Decrease of 1 dropout year every ";
      s += poutNoComma(getStep());
      s += " years";
      outputString.push_back(s);
   }
}
