// $Id: LawChangeMARRLENGTH.cpp 1.5 2003/05/22 09:27:14EDT sfmckay Exp  $
//
// Functions needed for class to manage parameters for a proposal to
// change the length of marriage requirement for divorced spouse benefits.

#include <vector>
#include "LawChangeMARRLENGTH.h"
#include "PiaException.h"
#include "Resource.h"
#include "comma.h"
#include "oactcnst.h"

using namespace std;

// Description: Constructor.
LawChangeMARRLENGTH::LawChangeMARRLENGTH() :
LawChange("change number of years of marriage required"),
marrLengthForDivBen(0)
{ }

// Description: Reads all the lines required for this law-change.
//
// Arguments:
//   infile: Open input stream.
void LawChangeMARRLENGTH::read( std::istream& infile )
{
   if (getInd() > 0) {
      vector< string > strvec = getFirstLine(infile);
      if (strvec.size() < 4)
         throw PiaException(PIA_IDS_LAWCHG6);
      setMarrLengthForDivBen(atoi(strvec[3].c_str()));
   }
}

// Description: Writes a line with first and last years, and step size.
//
// Arguments:
//   out: Open output stream.
void LawChangeMARRLENGTH::write( std::ostream& out ) const
{
   if (getInd() > 0) {
      writeFirstLine(out);
      out << " " << poutNoComma(getMarrLengthForDivBen(), 3) << endl;
   }
}

// Description: Prepares output strings for this change from present law.
//
// Arguments:
//   outputString: Table of output strings.
void LawChangeMARRLENGTH::prepareStrings(
std::vector<std::string> &outputString )
{
   if (getInd() > 0) {
      outputString.push_back(getTitle());
      if (getPhaseType() == 0)
         outputString.push_back("Effective for new eligibles");
      else
         outputString.push_back("Effective immediately for all persons");
      string s = "Change the number of years of marriage needed for a";
      outputString.push_back(s);
      s = "divorced spouse benefit to ";
      s += poutNoComma(getMarrLengthForDivBen());
      s += " starting in ";
      s += poutNoComma(getStartYear());
      outputString.push_back(s);
   }
}
