// $Id: LawChangePSAACCT.cpp 1.7 2005/10/06 11:55:51EDT 044579 Exp  $
//
// Functions needed for class to manage parameters for a proposal to
// introduce individual accounts.

#include <vector>
#include "LawChangePSAACCT.h"
#include "PiaException.h"
#include "Resource.h"
#include "comma.h"
#include "oactcnst.h"
#include "StringParser.h"
#include "percpia.h"

using namespace std;

// Description: Constructor.
LawChangePSAACCT::LawChangePSAACCT() :
LawChange("add PSA accounts"),
annuityToDib(false), percToSpouse(0.0), annIntRate(0.0),
annuityOffset(false), annuityType(Psa::ANNUITY_SL), buysAnnuity(false),
contribDist(0), contribStartAge(0), lumpSumAtFra(false), lumpSumPerc(0.0),
numContribBps(0), taxAnnuityInd(0), toSpouseOnDeathInd(0),
rebalanceAccounts(false), unisexInd(Psa::UNISEX_SL_AND_JS)
{
   fill_n(adminFee, (int)Psa::NUM_INVESTMENTS, 0.0);
   fill_n(investMean, (int)Psa::NUM_INVESTMENTS, 0.0);
   fill_n(investStdDev, (int)Psa::NUM_INVESTMENTS, 0.0);
   fill_n(investPerc, (int)Psa::NUM_INVESTMENTS, 0.0);
   fill_n(mngmtFee, (int)Psa::NUM_INVESTMENTS, 0.0);
   fill_n(contribYears, (int)MAXCONTRIBRATEYEARS, 0);
   for (int i = 0; i < MAXCONTRIBRATEYEARS; i++) {
      for (int j = 0; j < Psa::MAXCONTRIBRATES; j++) {
         contribBps[i][j] = 0.0;
         contribRates[i][j] = 0.0;
      }
   }
}

// Description: Reads all the lines required for this law-change.
//
// Arguments:
//   infile: Open input stream.
void LawChangePSAACCT::read( std::istream& infile )
{
   string str;  // input string

   if (getInd() > 0) {
      vector< string > strvec = getFirstLine(infile);
      if (strvec.size() != 18)
         throw PiaException(PIA_IDS_LAWCHG6);
      int i3 = 3;
      setPercToSpouse(atof(strvec[i3++].c_str()));
      setUnisexInd((Psa::UnisexType)atoi(strvec[i3++].c_str()));
      setAnnIntRate(atof(strvec[i3++].c_str()));
      setContribDist(atoi(strvec[i3++].c_str()));
      setTaxAnnuityInd(atoi(strvec[i3++].c_str()));
      setAnnuityToDib(atoi(strvec[i3++].c_str()));
      setToSpouseOnDeathInd(atoi(strvec[i3++].c_str()));
      setAnnuityOffset(atoi(strvec[i3++].c_str()));
      setContribStartAge(atoi(strvec[i3++].c_str()));
      setLumpSumPerc(atof(strvec[i3++].c_str()));
      setNumContribBps(atoi(strvec[i3++].c_str()));
      setLumpSumAtFra(atoi(strvec[i3++].c_str()));
      setBuysAnnuity(atoi(strvec[i3++].c_str()));
      setAnnuityType((Psa::AnnuityType)atoi(strvec[i3++].c_str()));
      setRebalanceAccounts(atoi(strvec[i3++].c_str()));
      getline(infile, str);
      if (infile.eof() || infile.fail())
         throw PiaException(PIA_IDS_LAWCHG6);
      strvec = parseString(str);
      if (static_cast<int>(strvec.size()) != Psa::NUM_INVESTMENTS *
         (4 + (getContribDist() == 1 ? 1 : 0)))
         throw PiaException(PIA_IDS_LAWCHG6);
      i3 = 0;
      for (int i2 = 0; i2 < Psa::NUM_INVESTMENTS; i2++) {
         const Psa::InvestmentType type = static_cast<Psa::InvestmentType>(i2);
         setInvestMean(type, atof(strvec[i3++].c_str()));
         setInvestStdDev(type, atof(strvec[i3++].c_str()));
         setAdminFee(type, atof(strvec[i3++].c_str()));
         setMngmtFee(type, atof(strvec[i3++].c_str()));
         // read proportions of contributions going to the investment
         if (getContribDist() == 1) {
            setInvestPerc(type, atof(strvec[i3++].c_str()));
         }
      }
      // get contribution rates
      for (int i2 = 0; i2 < getInd(); i2++) {
         getline(infile, str);
         if (infile.eof() || infile.fail())
            throw PiaException(PIA_IDS_LAWCHG6);
         strvec = parseString(str);
         if (strvec.size() < static_cast<unsigned>(2 + 2 * getNumContribBps()))
            throw PiaException(PIA_IDS_LAWCHG6);
         setContribYears(i2, atoi(strvec[0].c_str()));
         setContribRates(i2, 0, atof(strvec[1].c_str()));
         for (int i4 = 0; i4 < getNumContribBps(); i4++) {
            setContribBps(i2, i4, atof(strvec[2+2*i4].c_str()));
            setContribRates(i2, 1+i4, atof(strvec[3+2*i4].c_str()));
         }
      }
   }
}

// Description: Writes all the lines required for this law-change.
//
// Arguments:
//   out: Open output stream.
void LawChangePSAACCT::write( std::ostream& out ) const
{
   if (getInd() > 0) {
      writeFirstLine(out);
      out << " " << poutNoComma(getPercToSpouse(), 5, 3);
      out << " " << poutNoComma(getUnisexInd());
      out << " " << poutNoComma(getAnnIntRate(), 5, 3);
      out << " " << poutNoComma(getContribDist());
      out << " " << poutNoComma(getTaxAnnuityInd());
      out << " " << (getAnnuityToDib() ? " 1 " : " 0 ");
      out << " " << poutNoComma(getToSpouseOnDeathInd());
      out << " " << (getAnnuityOffset() ? " 1 " : " 0 ");
      out << " " << poutNoComma(getContribStartAge());
      out << " " << poutNoComma(getLumpSumPerc(), 5, 3);
      out << " " << poutNoComma(getNumContribBps());
      out << " " << (getLumpSumAtFra() ? " 1 " : " 0 ");
      out << " " << (getBuysAnnuity() ? " 1 " : " 0 ");
      out << " " << poutNoComma(getAnnuityType());
      out << " " << (getRebalanceAccounts() ? " 1 " : " 0 ");
      int i;
      for (i = 0; i < Psa::NUM_INVESTMENTS; i++) {
         const Psa::InvestmentType type = static_cast<Psa::InvestmentType>(i);
         out << " " << poutNoComma(getInvestMean(type), 5, 3);
         out << " " << poutNoComma(getInvestStdDev(type), 5, 3);
         out << " " << poutNoComma(getAdminFee(type), 5, 3);
         out << " " << poutNoComma(getMngmtFee(type), 5, 3);
         // write proportions of contributions going to each investment
         if (getContribDist() == 1) {
            out << " " << poutNoComma(getInvestPerc(type), 5, 3);
         }
      }
      for (i = 0; i < getInd(); i++) {
         out << " " << poutNoComma(getContribYears(i));
         out << " " << poutNoComma(getContribRates(i, 0), 5, 3);
         for (int j = 0; j < getNumContribBps(); j++) {
            out << " " << poutNoComma(getContribBps(i, j+1), 5, 3);
            out << " " << poutNoComma(getContribRates(i, j+1), 5, 3);
         }
      }
      out << endl;
   }
}

// Description: Prepares output strings for this change from present law.
//
// Arguments:
//   outputString: Table of output strings.
void LawChangePSAACCT::prepareStrings( std::vector<std::string> &outputString )
{
   if (getInd() > 0) {
      outputString.push_back(getTitle());
      if (getPhaseType() == 0)
         outputString.push_back("Effective for new eligibles");
      else
         outputString.push_back("Effective immediately for all persons");
      string s("Amount of contribution (as multiplier) going to spouse: ");
      s += poutNoComma(getPercToSpouse(), 5, 3);
      outputString.push_back(s);
      switch (getUnisexInd()) {
      case 0:
         outputString.push_back("Using unisex annuity factors for SL and JS.");
         break;
      case 1:
         s = "Using unisex annuity factors for SL, and sex-specific for JS.";
         outputString.push_back(s);
         break;
      case 2:
         s = "Using sex-specific annuity factors for SL, and unisex for JS.";
         outputString.push_back(s);
         break;
      case 3:
         outputString.push_back(
            "Using sex-specific annuity factors for SL and JS.");
         break;
      default:
         outputString.push_back("");
      }
      s = "Interest rate used for calculating annuity factors: ";
      s += poutNoComma(getAnnIntRate(), 1, 2);
      s += "%";
      outputString.push_back(s);
      int i;
      for (i = 0; i < Psa::NUM_INVESTMENTS; i++) {
         const Psa::InvestmentType type = static_cast<Psa::InvestmentType>(i);
         s = "Mean and standard deviation of return rate of investment ";
         s += poutNoComma(i);
         s += ": ";
         s += poutNoComma(getInvestMean(type), 6, 4);
         s += " and ";
         s += poutNoComma(getInvestStdDev(type), 6, 4);
         outputString.push_back(s);
         s = "Administrative and management fees for investment ";
         s += poutNoComma(i);
         s += ": ";
         s += poutNoComma(getAdminFee(type), 6, 4);
         s += " and ";
         s += poutNoComma(getMngmtFee(type), 6, 4);
         outputString.push_back(s);
         if (getContribDist() == 1) {
            s = "Percentage of PSA contribution going to investment ";
            s += poutNoComma(i);
            s += ": ";
            s += poutNoComma(getInvestPerc(type), 5, 3);
            outputString.push_back(s);
         }
      }
      if (getContribDist() == 0) {
         outputString.push_back("Split between investments varies by age");
      }
      switch (getTaxAnnuityInd()) {
      case 0:
         outputString.push_back("No tax on PSA annuities");
         break;
      case 1:
         outputString.push_back(
            "Tax PSA annuities like Social Security benefits");
         break;
      default:
         outputString.push_back("Tax PSA annuities like regular income.");
      }
      s = "DIBs ";
      s += (getAnnuityToDib() ? "are" : "are not");
      s += " eligible for annuities from the PSAs.";
      outputString.push_back(s);
      s = "Upon death of the PSA holder, the account ";
      switch (getToSpouseOnDeathInd()) {
      case 0:
         s += "does not get transferred to anyone";
         break;
      case 1:
         s += "transfers to the current spouse, if any";
         break;
      default:
         s += "transfers to the most recent live spouse (current or divorced)";
      }
      outputString.push_back(s);
      s = "PSA annuity calculations are ";
      switch (getAnnuityType()) {
      case 0:
         s += "always straight life, for both single and married people.";
         break;
      default:
         s += "straight life for single people, joint and 2/3 survivor ";
         s += "for married people.";
      }
      outputString.push_back(s);
      s = "PSA annuities ";
      s += (getAnnuityOffset() ? "are" : "are not");
      s += " used to offset the regular OASDI benefits.";
      outputString.push_back(s);
      s = "Contributions to the PSA start at age ";
      s += poutNoComma(getContribStartAge());
      outputString.push_back(s);
      s = "Upon conversion of the PSA to an annuity, the person ";
      s += "receives a lump sum payment of ";
      s += poutNoComma(getLumpSumPerc(), 1, 3);
      s += " percent of the PSA.";
      outputString.push_back(s);
      s = "The contribution rate calculation has ";
      s += poutNoComma(getNumContribBps());
      s += " bend point(s) in it.";
      outputString.push_back(s);
      s = "If a person attains FRA and is not eligible for an annuity";
      s += " then the PSA ";
      s += (getLumpSumAtFra() ? "is" : "is not");
      s += " paid out in full as a lump sum payment.";
      outputString.push_back(s);
      s = "PSA is ";
      s += (getBuysAnnuity() ? "used to buy an" : "diminished by the");
      s += " annuity.";
      outputString.push_back(s);
      s = "Investment accounts ";
      s += (getRebalanceAccounts() ? "are" : "are not");
      s += " re-balanced each year";
      outputString.push_back(s);
      outputString.push_back(
         "PSA contribution rates and bend points (by starting year):");
      for (i = 0; i < getInd(); i++) {
         s = "  ";
         s += poutNoComma(getContribYears(i));
         s += " ";
         s += poutNoComma(getContribRates(i, 0), 1, 4);
         for (int j = 0; j < getNumContribBps(); j++) {
            s += " ";
            s += poutNoComma(getContribBps(i, j), 1, 4);
            s += " ";
            s += poutNoComma(getContribRates(i, j+1), 1, 4);
         }
         outputString.push_back(s);
      }
   }
}
