// $Id: LawChangeRead.cpp 1.40 2005/12/14 17:36:46EST 044579 Exp  $
//
// Functions to read law-change variables from a file.

#include <fstream>
#include <cmath>  // for pow
#include "LawChangeRead.h"
#include "Resource.h"
#include "oactcnst.h"
#include "StringParser.h"
#include "PiaException.h"
#include "LawChangeBPFRACWAGE.h"

using namespace std;

// Description: Initializes law-change reference.
//
// Arguments:
//   newLawChange: Law-change indicators.
LawChangeRead::LawChangeRead ( LawChangeArray& newLawChange ) :
lawChange(newLawChange)
{ }

// Description: Reads indicators for change from present law.
//
// Remarks: The version with no arguments opens an input file and passes it to
//   the version with one argument.
//
// Throws: PiaException of type PIA_IDS_LAWCHG7 if unable to open input file.
//   PiaException of type PIA_IDS_LAWCHG6 if unable to parse input line.
void LawChangeRead::read()
{
   ifstream in(lawChange.getPathname().c_str(), ios::in);
   if (!in.is_open())
      throw PiaException(PIA_IDS_LAWCHG7);
   read(in);
   in.close();
}

// Arguments:
//   infile: Open input stream.
void LawChangeRead::read( std::istream& infile )
{
   string str;  // input string

   // read line with indicators
   getline(infile, str);
   vector< string > strvec = parseString(str);
   if (strvec.size() < LawChange::MAXLCH)
      throw PiaException(PIA_IDS_LAWCHG6);
   // parse the indicators
   for (int i1 = 0; i1 < LawChange::MAXLCH; i1++) {
      const int i3 = atoi(strvec[i1].c_str());
      if (i3 < 0)
         throw PiaException(PIA_IDS_LAWCHG6);
      lawChange.lawChange[i1]->setInd(i3);
   }
   lawChange.indTotalCal();
   // read additional parameters
   for (int i1 = 0; i1 < LawChange::MAXLCH; i1++) {
      lawChange.lawChange[i1]->read(infile);
   }
}
