// $Id: LawChangeWAGEBASECHG.cpp 1.5 2003/05/22 09:27:16EDT sfmckay Exp  $
//
// Functions needed for class to manage parameters for a proposal to
// change the OASDI and/or old-law wage bases.

#include <vector>
#include "LawChangeWAGEBASECHG.h"
#include "PiaException.h"
#include "Resource.h"
#include "comma.h"
#include "oactcnst.h"
#include "StringParser.h"
#include "percpia.h"

using namespace std;

// Description: Constructor.
LawChangeWAGEBASECHG::LawChangeWAGEBASECHG() :
LawChange("ad hoc wage base change"), baseOasdi(YEAR37, endYearLC),
base77(YEAR37, endYearLC)
{ }

// Description: Reads all the lines required for this law-change.
//
// Arguments:
//   infile: Open input stream.
void LawChangeWAGEBASECHG::read( std::istream& infile )
{
   string str;

   if (getInd() > 0) {
      vector< string > strvec = getFirstLine(infile);
      // read wage bases if 1 or 3
      if (getInd() %2 == 1) {
         getline(infile, str);
         if (infile.eof() || infile.fail())
            throw PiaException(PIA_IDS_LAWCHG6);
         strvec = parseString(str);
         // parse bases
         int i3 = 0;
         for (int i1 = getStartYear(); i1 <= getEndYear(); i1++) {
            double dtemp = atof(strvec[i3++].c_str());
            setBaseOasdi(i1, dtemp);
         }
      }
      // read 1977-law wage bases if 2 or 3
      if (getInd() >= 2) {
         getline(infile, str);
         if (infile.eof() || infile.fail())
            throw PiaException(PIA_IDS_LAWCHG6);
         strvec = parseString(str);
         // parse remaining bases
         int i3 = 0;
         for (int i1 = getStartYear(); i1 <= getEndYear(); i1++) {
            double dtemp = atof(strvec[i3++].c_str());
            setBase77(i1, dtemp);
         }
      }
   }
}

// Description: Writes a line with first and last years, and percentage.
//
// Arguments:
//   out: Open output stream.
void LawChangeWAGEBASECHG::write( std::ostream& out ) const
{
   if (getInd() > 0) {
      writeFirstLine(out);
      out << endl;
      // write oasdi bases
      if (getInd() % 2 == 1) {
         for (int i1 = getStartYear(); i1 <= getEndYear(); i1++)
            out << " " << poutNoComma(getBaseOasdi(i1), 4, 2);
         out << endl;
      }
      // write old-law bases
      if (getInd() >= 2) {
         for (int i1 = getStartYear(); i1 <= getEndYear(); i1++)
            out << " " << poutNoComma(getBase77(i1), 4, 2);
         out << endl;
      }
   }
}

// Description: Prepares output strings for this change from present law.
//
// Arguments:
//   outputString: Table of output strings.
void LawChangeWAGEBASECHG::prepareStrings(
std::vector<std::string> &outputString )
{
   string s;

   if (getInd() > 0) {
      outputString.push_back(getTitle());
      if (getPhaseType() == 0)
         outputString.push_back("Effective for new eligibles");
      else
         outputString.push_back("Effective immediately for all persons");
      if (getInd() == 1 || getInd() == 3) {
         string s = "Ad hoc OASDI wage bases from ";
         s += poutNoComma(getStartYear());
         s += " to ";
         s += poutNoComma(getEndYear());
         outputString.push_back(s);
      }
      if (getInd() == 2 || getInd() == 3) {
         string s = "Ad hoc old-law wage bases from ";
         s += poutNoComma(getStartYear());
         s += " to ";
         s += poutNoComma(getEndYear());
         outputString.push_back(s);
      }
   }
}
