// $Id: LawChangeWrite.cpp 1.38 2005/12/14 17:36:46EST 044579 Exp  $
//
// Functions to write law-change variables to a file.

#include <fstream>
#include <cmath>  // for pow
#include "LawChangeWrite.h"
#include "comma.h"
#include "Resource.h"
#include "oactcnst.h"
#include "PiaException.h"

using namespace std;

// Description: Initializes references to data.
//
// Arguments:
//   newLawChange: Law-change indicators to write out.
LawChangeWrite::LawChangeWrite ( LawChangeArray& newLawChange ) :
lawChange(newLawChange)
{ }

// Description: Writes indicators for change from present law.
//
// Remarks: The version with no arguments opens an output file and passes it
//   to the version with one argument.
//
// Throws: PiaException of type PIA_IDS_LAWCHG8 if unable to open output file.
void LawChangeWrite::write()
{
   ofstream out(lawChange.getPathname().c_str(), ios::out);
   if (!out.is_open())
      throw PiaException(PIA_IDS_LAWCHG8);
   write(out);
   out.close();
}

// Arguments:
//   out: Open output stream.
void LawChangeWrite::write( std::ostream& out )
{
   // write line with indicators
   for (int i1 = 0; i1 < LawChange::MAXLCH; i1++) {
      out << poutNoComma(lawChange.lawChange[i1]->getInd(), 3) << endl;
   }
   // write details for each law-change
   for (int i1 = 0; i1 < LawChange::MAXLCH; i1++) {
      lawChange.lawChange[i1]->write(out);
   }
}
