// $Id: OldStartLC.cpp 1.22 2005/10/06 11:55:52EDT 044579 Exp  $
//
// Functions to calculate an old-start PIA with law changes

#include "OldStartLC.h"
#include "pibtable.h"
#include "LawChangeArray.h"

// Description: Initializes an old start instance with law changes.
//
// Arguments:
//   newWorkerData: Worker data.
//   newPiaData: Pia calculation data.
//   newPiaParams: Pia calculation parameters.
//   newMaxyear: Maximum projection year.
//   newEntDate: The date of entitlement.
//   newLawChange: Law-change parameters.
OldStartLC::OldStartLC( const WorkerDataGeneral& newWorkerData,
const PiaData& newPiaData, const PiaParams& newPiaParams,
int newMaxyear, const DateMoyr& newEntDate,
const LawChangeArray& newLawChange ) :
OldStart(newWorkerData, newPiaData, newPiaParams, newMaxyear, newEntDate),
lawChange(newLawChange)
{ }

// Description: Destructor.
OldStartLC::~OldStartLC()
{ }

// Description: Determines applicability of method.
//
// Remarks: The version with no arguments calls the static version with 4
// arguments.
//
// Returns: True if method is applicable, false otherwise.
bool OldStartLC::isApplicable()
{
   if (isApplicable(entDate, workerData.getBenefitDate(), piaData,
      lawChange)) {
      iapp = APPLICABLE;
      return(true);
   }
   else
      return(false);
}

// Arguments:
//   entDate: The date of entitlement.
//   benefitDate: The date of benefit.
//   piaData: Benefit calculation data.
//   lawChange: Law change parameters.
bool OldStartLC::isApplicable( const DateMoyr& entDate,
const DateMoyr& benefitDate, const PiaData& piaData,
const LawChangeArray& lawChange )
{
   if (lawChange.lawChange[LawChange::NOOLDSTART]->isEffective(
      entDate.getYear(), benefitDate.getYear())) {
      return(false);
   }
   return OldStart::isApplicable(piaData);
}
