// $Id: PiaTableLC.cpp 1.23 2005/10/06 11:55:54EDT 044579 Exp  $
//
// Functions to calculate a Pia Table PIA with law change parameters.

#include "PiaTableLC.h"
#include "LawChangeArray.h"

// Description: Initializes a PiaTableLC instance.
//
// Arguments:
//   newWorkerData: Worker basic data.
//   newPiaData: Pia calculation data.
//   newPiaParams: Pia calculation parameters.
//   newMaxyear: Maximum year of projection.
//   newLawChange: Law change parameters.
//   entitDate: Entitlement date of benefit.
PiaTableLC::PiaTableLC( const WorkerDataGeneral& newWorkerData,
const PiaData& newPiaData, const PiaParams& newPiaParams, int newMaxyear,
const LawChangeArray& newLawChange, const DateMoyr& entitDate ) :
PiaTable(newWorkerData, newPiaData, newPiaParams, newMaxyear),
lawChange(newLawChange), entDate(entitDate)
{ }

// Description: Destructor.
PiaTableLC::~PiaTableLC()
{ }

// Description: Determines applicability of method.
//
// Remarks: The version with no arguments calls the static version with 5
//   arguments.
//
// Returns: True if method is applicable.
bool PiaTableLC::isApplicable()
{
   if (isApplicable(workerData, piaData, ioasdi, lawChange, entDate)) {
      iapp = APPLICABLE;
      return(true);
   }
   return(false);
}

// Arguments:
//   workerData: Worker basic data.
//   piaData: Pia calculation data.
//   ioasdi: Type of benefit.
//   lawChange: Law change parameters.
//   entitDate: Entitlement date.
bool PiaTableLC::isApplicable( const WorkerDataGeneral& workerData,
const PiaData& piaData, WorkerDataGeneral::ben_type ioasdi,
const LawChangeArray& lawChange, const DateMoyr& entitDate )
{
   LawChange *lawChangePRE1977LAW = lawChange.lawChange[LawChange::PRE1977LAW];
   // do old-law calculation if PRE1977LAW lawchange is set
   if (lawChangePRE1977LAW->isEffective(entitDate.getYear(),
      workerData.getBenefitDate().getYear())) {
      return(true);
   }
   return PiaTable::isApplicable(workerData, piaData, ioasdi);
}
