// $Id: PiadataArray.cpp 1.5 2001/09/05 11:28:31EDT sfmckay Exp  $
//
// Various functions to set up data for an array of pia data structures

#include "PiadataArray.h"
#include "PiaException.h"
#include "Resource.h"

// Description: Initializes arrays used in PiadataArray.
PiaDataArray::PiaDataArray() : famSize(0)
{
   // allocate memory for pia data
   for (int i = 0; i < MAXFAMSIZE; i++)
      piaData[i] = new PiaData();
}

// Description: Releases memory.
PiaDataArray::~PiaDataArray()
{
   // release memory for pia data
   for (int i = 0; i < MAXFAMSIZE; i++)
      delete piaData[i];
}

// Description: Resets all values to zero.
void PiaDataArray::deleteContents()
{
   // reset all benefit data
   for (int i = 0; i < MAXFAMSIZE; i++)
      piaData[i]->deleteContents();
   famSize = 0;
}

// Description: Sets family size (not including worker).
//
// Arguments:
//   newFamSize: Family size to use.
void PiaDataArray::setFamSize( int newFamSize )
{
   famSize = newFamSize;
}

// Description: Checks if family size is ok.
//
// Throws: PiaException of type PIA_IDS_FAMSIZE if family size is out of
//   bounds.
//
// Arguments:
//   newFamSize: Family size to check.
void PiaDataArray::famSizeCheck( int newFamSize )
{
   if (newFamSize < 0 || newFamSize > MAXFAMSIZE)
      throw PiaException(PIA_IDS_FAMSIZE);
}
