// $Id: PresValFacs.cpp 1.3 2006/11/24 08:54:44EST 044579 Development  $
//
// Functions to handle present value factors.

#include "PresValFacs.h"

// Description: Constructor.
//
// Remarks: Calculates the present value factors based on the interest rates
// passed in.
//
// Arguments:
//   intRates: Array of interest rates.
PresValFacs::PresValFacs( const DoubleAnnual &intRates ) :
DoubleAnnual(intRates.getBaseYear() - 1, intRates.getLastYear())
{
   // This factor is needed as a starting point for the multiplicative
   // present value factors.
   theData[0] = 1.0;
   project(intRates);
}

// Description: Destroys present value factors array.
PresValFacs::~PresValFacs()
{ }

// Description: Projects present value factors for the given interest rates.
//
// Arguments:
//   intRates: An array of interest rates.
void PresValFacs::project( const DoubleAnnual& intRates )
{
   for (int i = baseYear + 1; i <= getLastYear(); i++)
      theData[i - baseYear] = theData[i - baseYear - 1] / (1.0 + intRates[i]);
}
