// $Id: ReindWidLC.cpp 1.13 2007/03/08 14:11:52EST 044579 Development  $
//
// Functions to calculate a reindexed widow PIA with law changes.

#include "ReindWidLC.h"
#include "UserAssumptions.h"
#include "Resource.h"
#include "piaparms.h"
#include "LawChangeArray.h"

using namespace std;

// Description: Initializes a ReindWidLC instance.
//
// Arguments:
//   newWorkerData: Worker basic data.
//   newPiaData: Pia calculation data.
//   newPiaParams: Pia calculation parameters.
//   newMaxyear: Maximum year of projection.
//   newWidowPiaData: Widow calculation data.
//   newWidowData: Widow basic data.
//   newSecondary: Secondary benefit data.
//   newLawChange: Law change parameters.
ReindWidLC::ReindWidLC( const WorkerDataGeneral& newWorkerData,
const PiaData& newPiaData, const PiaParams& newPiaParams, int newMaxyear,
const PiaData& newWidowPiaData, const WorkerDataGeneral& newWidowData,
Secondary& newSecondary, const LawChangeArray& newLawChange ) :
ReindWid(newWorkerData, newPiaData, newPiaParams, newMaxyear, newWidowPiaData,
newWidowData, newSecondary), lawChange(newLawChange)
{ }

// Description: Destructor.
ReindWidLC::~ReindWidLC()
{ }

// Description: Determines applicability of method.
//
// Remarks: The version with no arguments calls the static version with 5
//   arguments.
//
// Returns: True if method is applicable.
bool ReindWidLC::isApplicable()
{
   if (isApplicable(workerData, piaData, widowPiaData.getEligYear(),
      secondary, lawChange)) {
      iapp = APPLICABLE;
      return(true);
   }
   else
      return(false);
}

// Arguments:
//   workerData: Worker basic data.
//   piaData: Pia calculation data.
//   widowEligYear: Widow(er)'s year of eligibility.
//   secondary: Widow(er)'s secondary benefit information.
//   lawChange: Law change parameters.
bool ReindWidLC::isApplicable( const WorkerDataGeneral& workerData,
const PiaData& piaData, int widowEligYear, const Secondary& secondary,
const LawChangeArray& lawChange )
{
   LawChange *lawChangeNOREINDWID = lawChange.lawChange[LawChange::NOREINDWID];
   // skip re-indexed widow calculation if NOREINDWID lawchange is set
   if (lawChangeNOREINDWID->isEffective(secondary.entDate.getYear(),
      workerData.getBenefitDate().getYear())) {
      return(false);
   }
   return ReindWid::isApplicable(workerData, piaData, widowEligYear,
      secondary);
}
