// $Id: SecondaryArray.cpp 1.7 2001/09/05 11:28:37EDT sfmckay Exp  $
//
// Various functions to set up data for an array of secondary benefit
// structures.

#include "SecondaryArray.h"

// Description: Initializes arrays.
SecondaryArray::SecondaryArray()
{
   // allocate memory for pia data
   for (int i = 0; i < PiaDataArray::MAXFAMSIZE; i++) {
      Secondary *secondaryptr = new Secondary();
      secondary.push_back(secondaryptr);
   }
}

// Description: Releases memory.
SecondaryArray::~SecondaryArray()
{
   // release memory for secondary benefit
   for (int i = 0; i < PiaDataArray::MAXFAMSIZE; i++) {
      delete secondary[i];
   }
}

// Description: Resets all values to zero.
void SecondaryArray::deleteContents()
{
   // reset all benefit data
   for (int i = 0; i < PiaDataArray::MAXFAMSIZE; i++)
      secondary[i]->deleteContents();
}

// Description: Returns total family benefit before reduction for age or family
//   maximum.
//
// Returns: Total family benefit before reduction for age or family maximum.
double SecondaryArray::getTotalFullBenefit() const
{
   double temp = 0.;
   // add benefit from each family member
   for (int i = 0; i < PiaDataArray::MAXFAMSIZE; i++) {
      temp += secondary[i]->getFullBenefit();
   }
   return temp;
}

// Description: Returns total family benefit before reduction for age or family
//   maximum, excluding beneficiaries who are not affected by the maximum.
//   This is what is compared to the mfb to see if a reduction is required.
//
// Returns: Total family benefit before reduction for age or family
//   maximum, excluding beneficiaries who are not affected by the maximum.
double SecondaryArray::getTotalFullBenefitMax() const
{
   double temp = 0.;
   // add benefit from each family member
   for (int i = 0; i < PiaDataArray::MAXFAMSIZE; i++) {
      if (secondary[i]->eligibleForMax()) {
         temp += secondary[i]->getFullBenefit();
      }
   }
   return temp;
}
