// $Id: SgaDerived.cpp 1.3 2006/11/08 11:05:33EST 044579 Development  $
//
// Functions to handle derived classes of the SgaGeneral class.
// There is no need to update the data in this file with each new TR.
// See notes at the top of SgaGeneral.cpp as to when an update may
// be neccessary (and how to do it).

#include "SgaDerived.h"

using namespace std;

// Description: Constructor. Initializes data.
//
// Arguments:
//   newLastYear: New last year.
SgaBlindA::SgaBlindA( int newLastYear ) : SgaGeneral(newLastYear, 1994)
{
   // Set all years up to (but not including) FIRST_PROJ_YEAR.
   for (int i = 1961; i <= 1965; i++)
      theData[i - baseYear] = 1200.0;
   theData[1966 - baseYear] = 1500.0;
   theData[1967 - baseYear] = 1500.0;
   theData[1968 - baseYear] = 1590.0;
   for (int i = 1969; i <= 1973; i++)
      theData[i - baseYear] = 1680.0;
   theData[1974 - baseYear] = 2400.0;
   theData[1975 - baseYear] = 2400.0;
   theData[1976 - baseYear] = 2760.0;
   theData[1977 - baseYear] = 2880.0;
   theData[1978 - baseYear] = 4008.0;
   theData[1979 - baseYear] = 4500.0;
   theData[1980 - baseYear] = 5004.0;
   theData[1981 - baseYear] = 5508.0;
   theData[1982 - baseYear] = 6000.0;
   theData[1983 - baseYear] = 6600.0;
   theData[1984 - baseYear] = 6960.0;
   theData[1985 - baseYear] = 7320.0;
   theData[1986 - baseYear] = 7800.0;
   theData[1987 - baseYear] = 8160.0;
   theData[1988 - baseYear] = 8400.0;
   theData[1989 - baseYear] = 8880.0;
   theData[1990 - baseYear] = 9360.0;
   theData[1991 - baseYear] = 9720.0;
   theData[1992 - baseYear] = 10200.0;
   theData[1993 - baseYear] = 10560.0;
   theData[1994 - baseYear] = 11160.0;
   theData[1995 - baseYear] = 11280.0;
   theData[1996 - baseYear] = 11520.0;
   theData[1997 - baseYear] = 12000.0;
   theData[1998 - baseYear] = 12600.0;
   theData[1999 - baseYear] = 13320.0;
   theData[2000 - baseYear] = 14040.0;
}

// Description: Projects SGA amounts. Should not be used becuase projections
//   are for monthly amount, but this class deals with annual amounts.
//
// Throws: PiaException of type PIA_IDS_SGAPROJ (always).
void SgaBlindA::project( const DoubleAnnual& )
{
   throw PiaException(PIA_IDS_SGAPROJ);
}

// Description: Constructor. Initializes data.
//
// Arguments:
//   newLastYear: New last year.
SgaBlindM::SgaBlindM( int newLastYear ) : SgaGeneral(newLastYear, 1994)
{
   // Set all years up to (but not including) FIRST_PROJ_YEAR.
   // For years 1961 to 1967, there was actually a min and max value
   // (the same as for the non-blind). We'll just use the max.
   for (int i = 1961; i <= 1965; i++)
      theData[i - baseYear] = 100.0;
   theData[1966 - baseYear] = 125.0;
   theData[1967 - baseYear] = 125.0;
   for (int i = 1968; i <= 1973; i++)
      theData[i - baseYear] = 140.0;
   theData[1974 - baseYear] = 200.0;
   theData[1975 - baseYear] = 200.0;
   theData[1976 - baseYear] = 230.0;
   theData[1977 - baseYear] = 240.0;
   theData[1978 - baseYear] = 334.0;
   theData[1979 - baseYear] = 375.0;
   theData[1980 - baseYear] = 417.0;
   theData[1981 - baseYear] = 459.0;
   theData[1982 - baseYear] = 500.0;
   theData[1983 - baseYear] = 550.0;
   theData[1984 - baseYear] = 580.0;
   theData[1985 - baseYear] = 610.0;
   theData[1986 - baseYear] = 650.0;
   theData[1987 - baseYear] = 680.0;
   theData[1988 - baseYear] = 700.0;
   theData[1989 - baseYear] = 740.0;
   theData[1990 - baseYear] = 780.0;
   theData[1991 - baseYear] = 810.0;
   theData[1992 - baseYear] = 850.0;
   theData[1993 - baseYear] = 880.0;
   theData[1994 - baseYear] = 930.0;
   theData[1995 - baseYear] = 940.0;
   theData[1996 - baseYear] = 960.0;
   theData[1997 - baseYear] = 1000.0;
   theData[1998 - baseYear] = 1050.0;
   theData[1999 - baseYear] = 1110.0;
   theData[2000 - baseYear] = 1170.0;
}

// Description: Constructor. Initializes data.
//
// Arguments:
//   newLastYear: New last year.
SgaMinA::SgaMinA( int newLastYear ) : SgaGeneral(newLastYear, 2000)
{
   // Set all years up to (but not including) FIRST_PROJ_YEAR.
   for (int i = 1961; i <= 1965; i++)
      theData[i - baseYear] = 600.0;
   theData[1966 - baseYear] = 900.0;
   theData[1967 - baseYear] = 900.0;
   theData[1968 - baseYear] = 990.0;
   for (int i = 1969; i <= 1973; i++)
      theData[i - baseYear] = 1080.0;
   theData[1974 - baseYear] = 1560.0;
   theData[1975 - baseYear] = 1560.0;
   theData[1976 - baseYear] = 1800.0;
   theData[1977 - baseYear] = 1920.0;
   theData[1978 - baseYear] = 2040.0;
   theData[1979 - baseYear] = 2160.0;
   for (int i = 1980; i <= 1989; i++)
      theData[i - baseYear] = 2280.0;
   for (int i = 1990; i <= 2000; i++)
      theData[i - baseYear] = 3600.0;
   // If FIRST_PROJ_YEAR ever gets moved up later than 2001, then we'll
   // need to add some values here. Use the same values as for the max.
}

// Description: Projects SGA amounts. Should not be used becuase projections
//   are for monthly amount, but this class deals with annual amounts.
//
// Throws: PiaException of type PIA_IDS_SGAPROJ (always).
void SgaMinA::project( const DoubleAnnual& )
{
   throw PiaException(PIA_IDS_SGAPROJ);
}

// Description: Constructor. Initializes data.
//
// Arguments:
//   newLastYear: New last year.
SgaMinM::SgaMinM( int newLastYear ) : SgaGeneral(newLastYear, 2000)
{
   // Set all years up to (but not including) FIRST_PROJ_YEAR.
   for (int i = 1961; i <= 1965; i++)
      theData[i - baseYear] = 50.0;
   theData[1966 - baseYear] = 75.0;
   theData[1967 - baseYear] = 75.0;
   for (int i = 1968; i <= 1973; i++)
      theData[i - baseYear] = 90.0;
   theData[1974 - baseYear] = 130.0;
   theData[1975 - baseYear] = 130.0;
   theData[1976 - baseYear] = 150.0;
   theData[1977 - baseYear] = 160.0;
   theData[1978 - baseYear] = 170.0;
   theData[1979 - baseYear] = 180.0;
   for (int i = 1980; i <= 1989; i++)
      theData[i - baseYear] = 190.0;
   for (int i = 1990; i <= 2000; i++)
      theData[i - baseYear] = 300.0;
   // If FIRST_PROJ_YEAR ever gets moved up later than 2001, then we'll
   // need to add some values here. Use the same values as for the max.
}

// Description: Projects SGA amounts.
//
// Remarks: Starting in FIRST_PROJ_YEAR, there is no more min amount in use.
// So we'll set the min to be the same as the max for the projections.
// In order to duplicate the max projected values, we need to
// temporarily set the FIRST_PROJ_YEAR - 1 min amount to be the same
// as the max amount for that year and then start the projection.
// Afterwards we're done with the projection, reset it to its real value.
//
// Arguments:
//   averageWages: Average wages to use for projection.
void SgaMinM::project( const DoubleAnnual& averageWages )
{
   const double tempAmount = theData[FIRST_PROJ_YEAR - 1 - baseYear];
   theData[FIRST_PROJ_YEAR - 1 - baseYear] = 700.0;
   SgaGeneral::project(averageWages);
   theData[FIRST_PROJ_YEAR - 1 - baseYear] = tempAmount;
}

// Description: Constructor. Initializes data.
//
// Arguments:
//   newLastYear: New last year.
SgaMaxA::SgaMaxA( int newLastYear ) : SgaGeneral(newLastYear, 2000)
{
   // Set all years up to (but not including) FIRST_PROJ_YEAR.
   for (int i = 1961; i <= 1965; i++)
      theData[i - baseYear] = 1200.0;
   theData[1966 - baseYear] = 1500.0;
   theData[1967 - baseYear] = 1500.0;
   theData[1968 - baseYear] = 1590.0;
   for (int i = 1969; i <= 1973; i++)
      theData[i - baseYear] = 1680.0;
   theData[1974 - baseYear] = 2400.0;
   theData[1975 - baseYear] = 2400.0;
   theData[1976 - baseYear] = 2760.0;
   theData[1977 - baseYear] = 2880.0;
   theData[1978 - baseYear] = 3120.0;
   theData[1979 - baseYear] = 3360.0;
   for (int i = 1980; i <= 1989; i++)
      theData[i - baseYear] = 3600.0;
   for (int i = 1990; i <= 1998; i++)
      theData[i - baseYear] = 6000.0;
   theData[1999 - baseYear] = 7200.0;
   theData[2000 - baseYear] = 8400.0;
}

// Description: Projects SGA amounts. Should not be used because projections
//   are for monthly amount, but this class deals with annual amounts.
//
// Throws: PiaException of type PIA_IDS_SGAPROJ (always).
void SgaMaxA::project( const DoubleAnnual& )
{
   throw PiaException(PIA_IDS_SGAPROJ);
}

// Description: Constructor. Initializes data.
//
// Arguments:
//   newLastYear: New last year.
SgaMaxM::SgaMaxM( int newLastYear ) : SgaGeneral(newLastYear, 2000)
{
   // Set all years up to (but not including) FIRST_PROJ_YEAR.
   for (int i = 1961; i <= 1965; i++)
      theData[i - baseYear] = 100.0;
   theData[1966 - baseYear] = 125.0;
   theData[1967 - baseYear] = 125.0;
   for (int i = 1968; i <= 1973; i++)
      theData[i - baseYear] = 140.0;
   theData[1974 - baseYear] = 200.0;
   theData[1975 - baseYear] = 200.0;
   theData[1976 - baseYear] = 230.0;
   theData[1977 - baseYear] = 240.0;
   theData[1978 - baseYear] = 260.0;
   theData[1979 - baseYear] = 280.0;
   for (int i = 1980; i <= 1989; i++)
      theData[i - baseYear] = 300.0;
   for (int i = 1990; i <= 1998; i++)
      theData[i - baseYear] = 500.0;
   theData[1999 - baseYear] = 700.0;
   theData[2000 - baseYear] = 700.0;
}
