// $Id: SpecMinLC.cpp 1.14 2005/10/06 11:55:55EDT 044579 Exp  $
//
// Functions to calculate a special minimum PIA, including changes from
// present law

#include "SpecMinLC.h"

using namespace std;

// Description: Initializes a SpecMinLC instance.
//
// Arguments:
//   newWorkerData: Worker basic data.
//   newPiaData: Pia calculation data.
//   newPiaParams: Pia calculation parameters.
//   newMaxyear: Maximum year of projection.
//   newLawChange: Law-change parameters.
SpecMinLC::SpecMinLC( const WorkerDataGeneral& newWorkerData,
const PiaData& newPiaData, const PiaParams& newPiaParams,
int newMaxyear, const LawChangeArray& newLawChange ) :
SpecMin(newWorkerData, newPiaData, newPiaParams, newMaxyear),
lawChange(newLawChange)
{ }

// Description: Destructor.
SpecMinLC::~SpecMinLC()
{ }

// Description: Limits usable years of coverage.
//
// Returns: Usable years of coverage (in excess of 10, up to 20, or however
//   changed by law change).
int SpecMinLC::specMinYearsExcessCal() const
{
   // limit usable years of coverage to those in excess of 10, up to specified
   // number of usable years
   return(min(max(yearsTotal - 10, 0), piaParams.specMinMaxYears(
      piaData.getEligDate().getYear(),
      workerData.getBenefitDate().getYear())));
}

// Description: Determines applicability of method.
//
// Remarks: The version with no arguments calls the static version with 2
//   arguments.
//
// Returns: True if method is applicable.
bool SpecMinLC::isApplicable()
{
   if (isApplicable(workerData, lawChange)) {
      iapp = APPLICABLE;
      return(true);
   }
   else
      return(false);
}

// Arguments:
//   workerData: Worker basic data.
bool SpecMinLC::isApplicable( const WorkerDataGeneral& workerData,
const LawChangeArray& )
{
   return SpecMin::isApplicable(workerData);
}
