// $Id: TaxData.cpp 1.6 2006/11/08 11:05:34EST 044579 Development  $
//
// Various functions with taxes and tax rates

#include "TaxData.h"
#include "wrkrdata.h"
#include "oactcnst.h"

using namespace std;

// Description: Initializes arrays.
//
// Arguments:
//   lastYear: Maximum projected year.
TaxData::TaxData( int lastYear ) : taxesOasi(YEAR37, lastYear),
taxesDi(YEAR37, lastYear), taxesOasdi(YEAR37, lastYear),
taxesHi(YEAR37, lastYear), taxesOasdhi(YEAR37, lastYear), maxyear(lastYear)
{
   // allocate memory for total tax array
   for (int i = 0; i < TaxRates::NUMTRUSTFUNDTYPES; i++) {
      taxTotal[i].resize(NUMYEARPERIODS);
   }
}

// Description: Calculates total taxes paid over a lifetime.
//
// Remarks: Calculates total taxes paid over a lifetime.  Assumes that OASDI
//   and OASDHI taxes have already been calculated via a call to
//   oasdhiTaxCal.
void TaxData::totalTaxCal()
{
   // find total OASI taxes
   double dtemp = 0.0;
   for (int i = YEAR37; i <= YEAR50; i++)
      dtemp += taxesOasi[i];
   taxTotal[TaxRates::OASITF][YEARS1937_50] = dtemp;
   for (int i = YEAR51; i <= maxyear; i++)
      dtemp += taxesOasi[i];
   taxTotal[TaxRates::OASITF][YEARS1937PLUS] = dtemp;
   // find total DI taxes
   dtemp = 0.0;
   for (int i = YEAR37; i <= YEAR50; i++)
      dtemp += taxesDi[i];
   taxTotal[TaxRates::DITF][YEARS1937_50] = dtemp;
   for (int i = YEAR51; i <= maxyear; i++)
      dtemp += taxesDi[i];
   taxTotal[TaxRates::DITF][YEARS1937PLUS] = dtemp;
   // find total OASDI taxes
   dtemp = 0.0;
   for (int i = YEAR37; i <= YEAR50; i++)
      dtemp += taxesOasdi[i];
   taxTotal[TaxRates::OASDITF][YEARS1937_50] = dtemp;
   for (int i = YEAR51; i <= maxyear; i++)
      dtemp += taxesOasdi[i];
   taxTotal[TaxRates::OASDITF][YEARS1937PLUS] = dtemp;
   // find total HI taxes
   dtemp = 0.0;
   for (int i = YEAR37; i <= YEAR50; i++)
      dtemp += taxesHi[i];
   taxTotal[TaxRates::HITF][YEARS1937_50] = dtemp;
   for (int i = YEAR51; i <= maxyear; i++)
      dtemp += taxesHi[i];
   taxTotal[TaxRates::HITF][YEARS1937PLUS] = dtemp;
   // find total OASDHI taxes
   dtemp = 0.0;
   for (int i = YEAR37; i <= YEAR50; i++)
      dtemp += taxesOasdhi[i];
   taxTotal[TaxRates::OASDHITF][YEARS1937_50] = dtemp;
   for (int i = YEAR51; i <= maxyear; i++)
      dtemp += taxesOasdhi[i];
   taxTotal[TaxRates::OASDHITF][YEARS1937PLUS] = dtemp;
}

// Description: Calculates OASDI and OASDHI taxes paid over a lifetime.
//
// Remarks: Calculates OASDI and OASDHI taxes paid over a lifetime.
//   Assumes that OASI, DI, and HI taxes have already been calculated.
void TaxData::oasdhiTaxCal()
{
   // find OASDI and OASDHI taxes
   for (int i = YEAR37; i <= maxyear; i++) {
      taxesOasdi[i] = taxesOasi[i] + taxesDi[i];
      taxesOasdhi[i] = taxesOasdi[i] + taxesHi[i];
   }
}
