// $Id: TaxRatesLC.cpp 1.7 2006/11/08 11:05:54EST 044579 Development  $
//
// Various functions with changed law tax rates.

#include "TaxRatesLC.h"
#include "LawChangeArray.h"
#include "LawChangeTAXRATECHG.h"

using namespace std;

// Description: Initializes arrays.
//
// Arguments:
//   lastYear: Maximum projected year.
//   newLawChange: Law change data.
TaxRatesLC::TaxRatesLC( int lastYear, const LawChangeArray& newLawChange ) :
TaxRates(lastYear), lawChange(newLawChange)
{
   initialize();
}

// Description: Destroys a TaxRatesLC instance.
TaxRatesLC::~TaxRatesLC()
{ }

// Description: Sets all tax rates, using historical rates unless overridden by
//   rates in law change data.
void TaxRatesLC::initialize()
{
   int i;  // loop counter

   LawChangeTAXRATECHG *lawChangeTAXRATECHG = lawChange.lawChangeTAXRATECHG;
   if (lawChangeTAXRATECHG->getInd() > 0 &&
      lawChangeTAXRATECHG->getNumTaxrates() > 0) {
      setHistRates(lawChangeTAXRATECHG->getYearTaxrate(0));
      // handle intermediate tax rates
      for (i = 0; i < lawChangeTAXRATECHG->getNumTaxrates() - 1; i++) {
         for (int year = lawChangeTAXRATECHG->getYearTaxrate(i);
         year < min(lawChangeTAXRATECHG->getYearTaxrate(i+1), maxyear);
         year++) {
            setRates(year, EMPLOYEERATE,
               lawChangeTAXRATECHG->getTaxrate(i, TaxRates::EMPLOYEERATE,
                  TaxRates::OASITF),
               lawChangeTAXRATECHG->getTaxrate(i, TaxRates::EMPLOYEERATE,
                  TaxRates::DITF),
               lawChangeTAXRATECHG->getTaxrate(i, TaxRates::EMPLOYEERATE,
                  TaxRates::OASDITF));
            setRates(year, SELFEMPRATE,
               lawChangeTAXRATECHG->getTaxrate(i, TaxRates::SELFEMPRATE,
                  TaxRates::OASITF),
               lawChangeTAXRATECHG->getTaxrate(i, TaxRates::SELFEMPRATE,
                  TaxRates::DITF),
               lawChangeTAXRATECHG->getTaxrate(i, TaxRates::SELFEMPRATE,
                  TaxRates::OASDITF));
         }
      }
      // handle final tax rate
      i = lawChangeTAXRATECHG->getNumTaxrates() - 1;
      for (int year = lawChangeTAXRATECHG->getYearTaxrate(i); year <= maxyear;
      year++) {
         setRates(year, EMPLOYEERATE,
            lawChangeTAXRATECHG->getTaxrate(i, TaxRates::EMPLOYEERATE,
               TaxRates::OASITF),
            lawChangeTAXRATECHG->getTaxrate(i, TaxRates::EMPLOYEERATE,
               TaxRates::DITF),
            lawChangeTAXRATECHG->getTaxrate(i, TaxRates::EMPLOYEERATE,
               TaxRates::OASDITF));
         setRates(year, SELFEMPRATE,
            lawChangeTAXRATECHG->getTaxrate(i, TaxRates::SELFEMPRATE,
               TaxRates::OASITF),
            lawChangeTAXRATECHG->getTaxrate(i, TaxRates::SELFEMPRATE,
               TaxRates::DITF),
            lawChangeTAXRATECHG->getTaxrate(i, TaxRates::SELFEMPRATE,
               TaxRates::OASDITF));
      }
   }
   else {
      setHistRates(maxyear);
   }
}
