// $Id: TransGuarLC.cpp 1.24 2007/03/08 14:12:02EST 044579 Development  $
//
// Functions to calculate a transitional guarantee PIA with changes from
// present law.

#include "TransGuarLC.h"
#include "LawChangeArray.h"
#include "oactcnst.h"

using namespace std;

// Description: Initializes a TransGuarLC instance.
//
// Arguments:
//   newWorkerData: Worker basic data.
//   newPiaData: Pia calculation data.
//   newPiaParams: Pia calculation parameters.
//   newMaxyear: Maximum year of projection.
//   newLawChange: Law-change parameters.
TransGuarLC::TransGuarLC( const WorkerDataGeneral& newWorkerData,
const PiaData& newPiaData, const PiaParams& newPiaParams, int newMaxyear,
const LawChangeArray& newLawChange ) :
TransGuar(newWorkerData, newPiaData, newPiaParams, newMaxyear),
lawChange(newLawChange)
{ }

// Description: Destructor.
TransGuarLC::~TransGuarLC()
{ }

// Description: Determines applicability of method.
//
// Remarks: The version with no arguments calls the static version with 4
//   arguments.
//
// Returns: True if method is applicable.
bool TransGuarLC::isApplicable()
{
   if (isApplicable(workerData, piaData, ioasdi, lawChange)) {
      iapp = APPLICABLE;
      return(true);
   }
   else
      return(false);
}

// Arguments:
//   workerData: Worker basic data.
//   piaData: Pia calculation data.
//   ioasdi: Type of benefit.
//   lawChange: Law-change parameters.
bool TransGuarLC::isApplicable( const WorkerDataGeneral& workerData,
const PiaData& piaData, WorkerDataGeneral::ben_type ioasdi,
const LawChangeArray& lawChange )
{
   try {
   int itrans = 5;  // transitional guarantee period
   LawChange *lawChangeTRANSGUAR1 = lawChange.lawChange[LawChange::TRANSGUAR1];
   if (lawChangeTRANSGUAR1->getInd() == 2)
      itrans = 10;
   // date of age 62
   const boost::gregorian::date age62 =
     Date::addYears(piaData.getBirthDateMinus1(), 62);
   if (piaData.getEligYear() >= YEAR79 &&
      static_cast<int>(piaData.getEligDate().getYear()) < YEAR79 + itrans &&
      ioasdi != WorkerDataGeneral::DISABILITY &&
      (ioasdi != WorkerDataGeneral::SURVIVOR ||
      !(workerData.getDeathDate() < age62)) &&
      !workerData.getTotalize() && workerData.getIbegin() < YEAR79) {
      return(true);
   }
   else {
      return(false);
   }
   } catch (exception& e) {
      throw PiaException(string("In TransGuarLC::isApplicable: ") + e.what());
   }
}
