// $Id: WageIndLC.cpp 1.18 2005/10/06 11:55:55EDT 044579 Exp  $
//
// Functions to calculate a wage-indexed PIA with changes from present law.

#include "WageIndLC.h"
#include "LawChangeArray.h"

// Description: Initializes a WageIndLC instance.
//
// Arguments:
//   newWorkerData: Worker basic data.
//   newPiaData: Pia calculation data.
//   newPiaParams: Pia calculation parameters.
//   newMaxyear: Maximum year of projection.
//   newLawChange: Law-change parameters.
//   entitDate: Entitlement date.
WageIndLC::WageIndLC( const WorkerDataGeneral& newWorkerData,
const PiaData& newPiaData, const PiaParams& newPiaParams, int newMaxyear,
const LawChangeArray& newLawChange, const DateMoyr& entitDate ) :
WageInd(newWorkerData, newPiaData, newPiaParams, newMaxyear),
lawChange(newLawChange), entDate(entitDate)
{ }

// Description: Destructor.
WageIndLC::~WageIndLC()
{ }

// Description: Determines applicability of method.
//
// Remarks: The version with no arguments calls the static version with 4
//   arguments.
//
// Returns: True if method is applicable.
bool WageIndLC::isApplicable()
{
   if (isApplicable(workerData, piaData, lawChange, entDate)) {
      iapp = APPLICABLE;
      return(true);
   }
   return(false);
}

// Arguments:
//   workerData: Worker basic data.
//   piaData: Pia calculation data.
//   lawChange: Law-change parameters.
//   entitDate: Entitlement date.
bool WageIndLC::isApplicable( const WorkerDataGeneral& workerData,
const PiaData& piaData, const LawChangeArray& lawChange,
const DateMoyr& entitDate)
{
   LawChange *lawChangePRE1977LAW = lawChange.lawChange[LawChange::PRE1977LAW];
   if (lawChangePRE1977LAW->isEffective(entitDate.getYear(),
      workerData.getBenefitDate().getYear())) {
      return(false);
   }
   return WageInd::isApplicable(workerData, piaData);
}
