// $Id: WorkerDataArray.cpp 1.5 2001/09/07 15:53:51EDT sfmckay Exp  $
//
// Various functions to set up data for an array of worker data structures

#include "WorkerDataArray.h"
#include "PiaException.h"
#include "Resource.h"

// Description: Initializes arrays used in WorkerDataArray.
WorkerDataArray::WorkerDataArray() : famSize(0)
{
   // allocate memory for pia data
   for (int i = 0; i < MAXFAMSIZE; i++)
      workerData[i] = new WorkerData();
}

// Description: Releases memory.
WorkerDataArray::~WorkerDataArray()
{
   // release memory for pia data
   for (int i = 0; i < MAXFAMSIZE; i++)
      delete workerData[i];
}

// Description: Resets all values to zero.
void WorkerDataArray::deleteContents()
{
   // reset all benefit data
   for (int i = 0; i < MAXFAMSIZE; i++)
      workerData[i]->deleteContents();
   famSize = 0;
}

// Description: Sets family size (not including worker).
//
// Arguments:
//   newFamSize: Family size to use.
void WorkerDataArray::setFamSize( int newFamSize )
{
   famSize = newFamSize;
}

// Description: Checks if family size is ok.
//
// Throws: PiaException of type PIA_IDS_FAMSIZE if out of bounds.
//
// Arguments:
//   newFamSize: Family size to check.
void WorkerDataArray::famSizeCheck( int newFamSize )
{
   if (newFamSize < 0 || newFamSize > MAXFAMSIZE)
      throw PiaException(PIA_IDS_FAMSIZE);
}
