// $Id: awinc.cpp 1.11 2006/11/24 11:05:59EST 044579 Development  $
//
// Functions to handle projected average wage increases.

#include "awinc.h"
#include "avgwg.h"
#include "Resource.h"
#include "oactcnst.h"
#include "PiaException.h"

// Description: Initializes width and precision.
//
// Arguments:
//   newLastYear: Last year of array.
Awinc::Awinc( int newLastYear ) : DoubleAnnual(YEAR37, newLastYear)
{
   setWidth(10);
   setPrecision(6);
}

// Arguments:
//   newBaseYear: First year of array. When this argument is omitted, the array
//     starts in 1937.
//   newLastYear: Last year of array.
Awinc::Awinc( int newBaseYear, int newLastYear ) :
DoubleAnnual(newBaseYear, newLastYear)
{
   setWidth(10);
   setPrecision(6);
}

// Description: Checks an average wage increase.
//
// Throws: PiaException of type PIA_IDS_FQINC1 if average wage increase is out
//   of range.
//
// Arguments:
//   fqinct: Value to check.
void Awinc::fqincCheck( double fqinct )
{
   if (fqinct > 99.99 || fqinct < -9.99)
      throw PiaException(PIA_IDS_FQINC1);
}

// Description: Calculates average wage increases.
//
// Remarks: The version with an AverageWage argument calculates the annual
// increases present in that array and assigns each one to the corresponding
// slot in this array. The version with a double argument assigns all years
// after last year to the same percent increase.
//
// Arguments:
//   averageWages: Series of average wages from which to calculate increase
//     percentages.
//   firstYeart: First year of calculation.
//   lastYeart: Last year of calculation.
void Awinc::project( const AverageWage& averageWages, int firstYeart,
int lastYeart )
{
   for (int i1 = firstYeart; i1 <= lastYeart; i1++) {
      if (averageWages[i1 - 1] > 1.0)
         theData[i1 - baseYear] =
            100. * (averageWages[i1] / averageWages[i1 - 1] - 1.);
   }
}

// Arguments:
//   factor: Multiplicative factor assign to increase.
void Awinc::project( double factor, int firstYeart )
{
   const double increase = (factor - 1.0) * 100.0;
   for (int i = firstYeart; i <= getLastYear(); i++)
      theData[i - baseYear] = increase;
}
