// $Id: baseyrfl.cpp 1.11 2005/12/12 09:44:14EST 044579 Exp  $
//
// Functions to handle base year stored on disk.

#include <fstream>
#include "BaseYearFile.h"
#include "Resource.h"
#include "PiaException.h"
#include "Path.h"

using namespace std;

// Description: Initializes base year info.
//
// Arguments:
//   newDirectory: Directory with base year file.
BaseYearFile::BaseYearFile( const std::string& newDirectory ) :
BaseYear(), pathname()
{
   pathname = Path::combine(newDirectory, "baseyear.dat");
}

// Description: Reads base year from disk.
//
// Throws: PiaException of type PIA_IDS_BASEYR4 if unable to open input file.
//   PiaException of type PIA_IDS_BASEYR3 if unable to read base year.
void BaseYearFile::read()
{
   int temp;  // temporary integer

   ifstream in(pathname.c_str(), ios::in);
   if (!in.is_open())
      throw PiaException(PIA_IDS_BASEYR4);
   in >> temp;
   setYear(temp);
   if (in.eof() || in.fail())
      throw PiaException(PIA_IDS_BASEYR3);
   in.close();
}

// Description: Saves base year to disk.
//
// Throws: PiaException of type PIA_IDS_BASEYR2 if unable to open output file.
void BaseYearFile::write()
{
   ofstream out(pathname.c_str(), ios::out);
   if (!out.is_open())
      throw PiaException(PIA_IDS_BASEYR2);
   out.setf(ios::fixed, ios::floatfield);
   out << getYear() << endl;
   out.close();
}
