// $Id: bendmfb.cpp 1.12 2006/11/08 11:48:25EST 044579 Development  $
//
// Functions to handle MFB formula bend points.

#include <cmath>  // for floor
#include <algorithm>
#include "bendmfb.h"

using namespace std;

const double BendMfb::BP1979[] = { 0.0, 230.0, 332.0, 433.0 };

// Description: Constructor.
//
// Remarks: Initializes size of array to 4, and sets first bend point to 0.0.
BendMfb::BendMfb()
{
   theData[0] = 0.0;
}

// Description: Destroys bend point array.
BendMfb::~BendMfb()
{ }

// Description: Projects bend points, using 1979 bend points as a base.
//
// Throws: PiaException if average wages are not initialized (only in debug
//   mode).
//
// Arguments:
//   eligYear: Year of eligibility.
//   fq: Average wage series.
void BendMfb::project( int eligYear, const AverageWage& fq )
{
#if !defined(NDEBUG)
   if (fq[1977] == 0.0)
      throw PiaException("fq is not initialized in BendMfb::project");
#endif
   double temp = fq[eligYear - 2] / fq[1977];
   theData[1] = floor(BP1979[1] * temp + 0.5);
   theData[2] = floor(BP1979[2] * temp + 0.5);
   theData[3] = floor(BP1979[3] * temp + 0.5);
}

// Description: Zeroes out all values.
void BendMfb::deleteContents()
{
   fill(begin(), end(), 0.0);
}
