// $Id: bendpia.cpp 1.11 2006/11/08 11:48:25EST 044579 Development  $
//
// Functions to handle PIA formula bend points.

#include <cmath>  // for floor
#include <algorithm>
#include "bendpia.h"

using namespace std;

const double BendPia::BP1979[] = { 0.0, 180.0, 1085.0 };

// Description: Constructor.
//
// Remarks: Initializes size of array to 3, and sets first bend point to 0.0.
BendPia::BendPia()
{
   theData[0] = 0.0;
}

// Description: Destroys bend point array.
BendPia::~BendPia()
{ }

// Description: Projects bend points, using 1979 bend points as a base.
//
// Throws: PiaException if average wages are not initialized (only in debug
//   mode).
//
// Arguments:
//   eligYear: Year of eligibility.
//   fq: Average wage series.
void BendPia::project( int eligYear, const AverageWage& fq )
{
#if !defined(NDEBUG)
   if (fq[1977] == 0.0)
      throw PiaException("fq is not initialized in BendPia::project");
#endif
   double temp = fq[eligYear - 2] / fq[1977];
   theData[1] = floor(BP1979[1] * temp + .5);
   theData[2] = floor(BP1979[2] * temp + .5);
}

// Description: Zeroes out all values.
void BendPia::deleteContents()
{
   fill(begin(), end(), 0.0);
}
