// $Id: biproj.cpp 1.17 2006/11/08 11:04:33EST 044579 Development  $
//
// Functions to handle projected benefit increases.

#include "biproj.h"
#include "Resource.h"
#include "PiaException.h"
#include "comma.h"
#include "baseyear.h"

using namespace std;

static const char* beninc1 =
   "Old PEBES calculation (no future benefit increases)";
static const char* other = "Other";

// Description: Initializes projected benefit increase info.
//
// Remarks: Resizes the data array to cover the specified span of years.
//
// Arguments:
//   newIstart: Starting year of benefit increases.
//   newMaxyear: Maximum projected year.
Biproj::Biproj( int newIstart, int newMaxyear ) :
firstYear(newIstart), biprojTitle(), theData(newIstart, newMaxyear)
{
   theData.setPrecision(1);
   // assign titles for non-TR assumptions
   beninc[1] = beninc1;
   beninc[2] = other;
}

// Description: Destructor.
Biproj::~Biproj()
{ }

// Description: Sets one benefit increase.
//
// Arguments:
//   year: Year of benefit increase to set
//   cpiinct: Value to use.
void Biproj::setCpiinc( int year, double cpiinct )
{
   cpiincCheck(cpiinct);
   theData[year] = cpiinct;
}

// Description: Checks a benefit increase.
//
// Throws: PiaException of type PIA_IDS_CPIINC1 if benefit increase is out of
//   range.
//
// Arguments:
//   cpiinct: Value to check.
void Biproj::cpiincCheck( double cpiinct )
{
   if (cpiinct > 99.99 || cpiinct < 0.0) {
      throw PiaException(PIA_IDS_CPIINC1);
   }
}

// Description: Sets first year of data.
//
// Throws: PiaException if year is out of range (only in debug mode).
//
// Arguments:
//   newFirstYear: New first year of data.
void Biproj::setFirstYear( int newFirstYear )
{
#ifndef NDEBUG
   BaseYear::yearCheck(newFirstYear);
#endif
   firstYear = newFirstYear;
   beninc[0] = "No increase beginning with ";
   beninc[0] += poutNoComma(newFirstYear);
   beninc[0] += " benefit increase (Statement)";
}
