// $Id: bpmfbout.cpp 1.9 2001/08/13 10:15:38EDT sfmckay Exp  $
//
// Functions to handle array of mfb formula bend points.

#include "bpmfbout.h"
#include "bendmfb.h"
#include "oactcnst.h"

// Description: Initializes arrays.
//
// Arguments:
//   newLastYear: Maximum year of projection.
BpMfbOut::BpMfbOut( int newLastYear ) :
bpmfb1(YEAR79, newLastYear), bpmfb2(YEAR79, newLastYear),
bpmfb3(YEAR79, newLastYear)
{ }

// Arguments:
//   newBaseYear: Starting year of array. If the base year is not specified,
//     the arrays start in 1979.
//   newLastYear: Maximum year of projection.
BpMfbOut::BpMfbOut( int newBaseYear, int newLastYear ) :
bpmfb1(newBaseYear, newLastYear), bpmfb2(newBaseYear, newLastYear),
bpmfb3(newBaseYear, newLastYear)
{ }

// Description: Sets data for all years.
//
// Arguments:
//   averageWage: Average wage series used to project bend points, starting in
//     specified year.
//   firstYear: Starting year of projection.
void BpMfbOut::setData( const AverageWage& averageWage, int firstYear )
{
   BendMfb bendpts;  // temporary bendpoints

   for (int year = firstYear; year <= bpmfb1.getLastYear(); year++) {
      bendpts.project(year, averageWage);
      bpmfb1[year] = bendpts[1];
      bpmfb2[year] = bendpts[2];
      bpmfb3[year] = bendpts[3];
   }
}

// Description: Sets data for one year.
//
// Arguments:
//   year: Year for which data is set.
//   bp1: Value of first bend point.
//   bp2: Value of second bend point.
//   bp3: Value of third bend point.
void BpMfbOut::setData( int year, double bp1, double bp2, double bp3 )
{
   bpmfb1[year] = bp1;
   bpmfb2[year] = bp2;
   bpmfb3[year] = bp3;
}
