// $Id: bppiaout.cpp 1.9 2001/08/13 10:15:38EDT sfmckay Exp  $
//
// Functions to handle array of pia formula bend points.

#include "bppiaout.h"
#include "bendpia.h"
#include "oactcnst.h"

// Description: Initializes arrays.
//
// Arguments:
//   newLastYear: Maximum year of projection.
BpPiaOut::BpPiaOut( int newLastYear ) :
bppia1(YEAR79, newLastYear), bppia2(YEAR79, newLastYear)
{ }

// Arguments:
//   newBaseYear: Starting year of array. If the base year is not specified,
//     the arrays start in 1979.
//   newLastYear: Maximum year of projection.
BpPiaOut::BpPiaOut( int newBaseYear, int newLastYear ) :
bppia1(newBaseYear, newLastYear), bppia2(newBaseYear, newLastYear)
{ }

// Description: Sets data for all years, or specified starting year and later.
//
// Arguments:
//   averageWage: Average wage series used to project bend points, starting
//     in specified year.
//   firstYear: Starting year of projection.
void BpPiaOut::setData( const AverageWage& averageWage, int firstYear )
{
   BendPia bendpts;  // temporary bendpoints

   for (int year = firstYear; year <= bppia1.getLastYear(); year++) {
      bendpts.project(year, averageWage);
      bppia1[year] = bendpts[1];
      bppia2[year] = bendpts[2];
   }
}

// Description: Sets data for one year.
//
// Arguments:
//   year: Year for which data is set.
//   bp1: Value of first bend point.
//   bp2: Value of second bend point.
void BpPiaOut::setData( int year, double bp1, double bp2 )
{
   bppia1[year] = bp1;
   bppia2[year] = bp2;
}
