// $Id: cachupnf.cpp 1.12 2005/01/19 16:30:17EST sfmckay Exp  $
//
// Functions to handle catch-up benefit increases stored in arrays.

#include "CatchupNonFile.h"
#include "AssumptionType.h"

// Description: Initializes catch-up benefit increase file.
//
// Arguments:
//   newCstart: Starting year of catch-up benefit increases.
CatchupNonFile::CatchupNonFile( int newCstart ) : CatchupDoc(newCstart)
{
   for (int i = 0; i < 4; i++) {
      cachuptr[i].setCstart(newCstart);
      read(i+1);
   }
}

// Description: Destroys object.
CatchupNonFile::~CatchupNonFile()
{ }

// Description: Read stored values from memory.
//
// Arguments:
//   altNum: Desired alternative number (1-4).
void CatchupNonFile::read( int altNum )
{
   cachuptr[altNum - 1].deleteContents();
   allownonzero[altNum - 1] = false;
}

// Description: Dummy function.
void CatchupNonFile::write( int )
{ }

// Description: Sets catch-up increases.
//
// Remarks: The version with one argument uses the data stored for the
//   specified alternative. The version with two arguments stores the data for
//   the specified alternative, then sets the current data to that data.
//
// Arguments:
//   altNum: Desired alternative number (1-7).
void CatchupNonFile::setData( int altNum )
{
   if (AssumptionType::isTR(altNum)) {
      catchup = cachuptr[altNum - 1];
   }
   else {
      catchup.deleteContents();
   }
}

// Arguments:
//   altNum: Desired alternative number (1-7).
//   newCatchup: New catch-up benefit increases.
void CatchupNonFile::setData( int altNum, const Catchup& newCatchup )
{
   if (AssumptionType::isTR(altNum)) {
      cachuptr[altNum - 1] = newCatchup;
   }
   setData(altNum);
}
