// $Id: configFile.cpp 1.12 2005/12/12 09:44:14EST 044579 Exp  $
//
// Functions to read and write configuration information.

#include <fstream>
#include "ConfigFile.h"
#include "Resource.h"
#include "PiaException.h"
#include "Path.h"

using namespace std;

static void scnerrc ( std::ifstream& in );

// Description: Initializes configuration.
//
// Arguments:
//   newDirectory: New directory to use.
ConfigFile::ConfigFile( const std::string& newDirectory ) : Config(),
pathname()
{
   pathname = Path::combine(newDirectory, "config.dat");
}

// Description: Destroys configuration.
ConfigFile::~ConfigFile( )
{ }

// Description: Reads the configuration from disk.
//
// Throws: PiaException of type PIA_IDS_CONFIG1 if unable to open input file.
//   PiaException of type PIA_IDS_CONFIG6 if unable to read all required data.
void ConfigFile::read()
{
   string temp;  // temporary string

   ifstream in(pathname.c_str(), ios::in);
   if (!in.is_open())
      throw PiaException(PIA_IDS_CONFIG1);
   getline(in, temp);
   if (in.eof() || in.fail())
      scnerrc(in);
   bool longOutputt = (atoi(temp.c_str()) > 0) ? true : false;
   setLongOutput(longOutputt);
   getline(in, temp);
   if (in.eof() || in.fail())
      scnerrc(in);
   int screenPointst = atoi(temp.c_str());
   setScreenPoints(screenPointst);
   getline(in, temp);
   if (in.eof() || in.fail())
      scnerrc(in);
   int printerPointst = atoi(temp.c_str());
   setPrinterPoints(printerPointst);
   in.close();
}

// Description: Saves the configuration to disk.
//
// Throws: PiaException of type PIA_IDS_CONFIG5 if unable to open output file.
void ConfigFile::write()
{
   ofstream out(pathname.c_str(), ios::out);
   if (!out.is_open())
      throw PiaException(PIA_IDS_CONFIG5);
   out.setf(ios::fixed, ios::floatfield);
   out << (getLongOutput() ? 1 : 0) << endl;
   out << getScreenPoints() << endl;
   out << getPrinterPoints() << endl;
   out.close();
}

// Description: Handles configuration error.
//
// Throws: PiaException of type PIA_IDS_CONFIG6 if unable to read all required
//   data.
//
// Arguments:
//   in: Input stream.
static void scnerrc( std::ifstream& in )
{
   in.close();
   throw PiaException(PIA_IDS_CONFIG6);
}
