// $Id: foinfofl.cpp 1.12 2005/12/12 09:44:15EST 044579 Exp  $
//
// Functions to handle field office information stored on disk.

#include <fstream>
#include "FieldOfficeInfoFile.h"
#include "Resource.h"
#include "PiaException.h"
#include "Path.h"

using namespace std;

static void scnerrf ( ifstream& in );

// Description: Initializes field office info.
//
// Arguments:
//   newDirectory: Directory with field office file.
FieldOfficeInfoFile::FieldOfficeInfoFile( const std::string& newDirectory ) :
FieldOfficeInfo(), pathname()
{
   pathname = Path::combine(newDirectory, "fo.dat");
}

// Description: Destroys field office info.
FieldOfficeInfoFile::~FieldOfficeInfoFile()
{ }

// Description: Reads field office information from disk.
//
// Throws: PiaException of type PIA_IDS_FOINFO1 if unable to open input file.
//   PiaException of type PIA_IDS_FOINFO2 if unable to read all required data.
void FieldOfficeInfoFile::read()
{
   string line;  // input line

   ifstream in(pathname.c_str(), ios::in);
   if (!in.is_open())
      throw PiaException(PIA_IDS_FOINFO1);
   getline(in, line);
   if (in.eof() || in.fail())
      scnerrf(in);
   setFieldOfficeName(line);
   getline(in, line);
   if (in.eof() || in.fail())
      scnerrf(in);
   setFieldOfficeTitle(line);
   for (int i1 = 0; i1 < numLines; i1++) {
      getline(in, line);
      if (in.eof() || in.fail())
         scnerrf(in);
      setAddress(i1, line);
   }
   in.close();
}

// Description: Saves field office information to disk.
//
// Throws: PiaException of type PIA_IDS_FOINFO3 if unable to open output file.
void FieldOfficeInfoFile::write()
{
   ofstream out(pathname.c_str(), ios::out);
   if (!out.is_open())
      throw PiaException(PIA_IDS_FOINFO3);
   out << getFieldOfficeName() << endl;
   out << getFieldOfficeTitle() << endl;
   for (int i1 = 0; i1 < numLines; i1++)
      out << getAddress(i1) << endl;
   out.close();
}

// Description: Dummy function for file version.
void FieldOfficeInfoFile::setData()
{ }

// Description: Handles field office file error.
//
// Arguments:
//   in: Input stream.
static void scnerrf( std::ifstream& in )
{
   in.close();
   throw PiaException(PIA_IDS_FOINFO2);
}
