// $Id: frzyrs.cpp 1.5 2001/08/15 15:28:25EDT sfmckay Exp  $
//
// Functions involving freeze period variables.

#include "frzyrs.h"

// Description: Creates a FreezeYears. All years are initialized to 0.
FreezeYears::FreezeYears () : year1(0), year2(0), year3(0), year4(0)
{ }

// Description: Returns true if any years in latest freeze period.
//
// Returns: True if any years in latest freeze period.
bool FreezeYears::hasYears1() const
{
   return(year1 > 0 && year2 >= year1);
}

// Description: Returns true if any years in prior freeze period.
//
// Returns: True if any years in prior freeze period.
bool FreezeYears::hasYears2() const
{
   return(year3 > 0 && year4 >= year3);
}

// Description: Returns true if year is wholly within a period of disability,
//   false otherwise.
//
// Returns: True if year is wholly within a period of disability,
//   false otherwise.
//
// Arguments:
//   year: Year considered.
bool FreezeYears::isFreezeYear( int year ) const
{
   if (year >= year1 && year <= year2)
      return(true);
   if (year >= year3 && year <= year4)
      return(true);
   return(false);
}
