// $Id: pebs.cpp 1.14 2007/11/07 07:27:49EST 277133 Development  $
//
// Functions to handle Statement data.

#include "pebs.h"
#include "PiaException.h"
#include "Resource.h"

using namespace std;
#include "boost/date_time/gregorian/gregorian.hpp"

const Age Pebs::age70(70, 0);

// Description: Initializes Pebs instance.
//
// Remarks: Initializes size of arrays to MAXPEBS and zeroes out all data.
Pebs::Pebs() : benefitPebs(MAXPEBS), agePlan(0), agePlan2(0), mfbPebs(MAXPEBS),
monthnow(0), piaPebs(MAXPEBS), qcTotal(0), qcDisReq(0), qcDisTotal(0),
qcDisYears(0), qcReq(MAXPEBS), pebsOab(0), pebsDib(0)
{ }

// Description: Initializes all variables to default values.
void Pebs::deleteContents()
{
   agePlan = monthnow = 0;
}

// Description: Sets month of Statement processing. If a month is not
//   specified, the current month is used.
//
// Throws: PiaException of type PIA_IDS_PEBESMONTH if month is out of range
//   (only in debug mode).
//
// Arguments:
//   monthnowt: New month of processing.
void Pebs::setMonthnow( int monthnowt )
{
#ifndef NDEBUG
   monthnowCheck(monthnowt);
#endif
   monthnow = monthnowt;
}

void Pebs::setMonthnow()
{
   boost::gregorian::date datetemp = boost::gregorian::day_clock::local_day();
   setMonthnow(datetemp.month());
}

// Description: Sets planned age of retirement in Statement case.
//
// Throws: PiaException of type PIA_IDS_AGEPLAN if planned age of retirement
//   is out of range (debug mode only).
//
// Arguments:
//   newAgePlan: New planned age of retirement.
void Pebs::setAgePlan( int newAgePlan )
{
#ifndef NDEBUG
   agePlanCheck(newAgePlan);
#endif
   agePlan = newAgePlan;
}

// Description: Checks for correct month of Statement processing.
//
// Remarks: The version with no argument calls the static version with one
//   argument, using the stored month of processing.
//
// Throws: PiaException of type PIA_IDS_PEBESMONTH if month is out of range.
void Pebs::monthnowCheck() const
{
   monthnowCheck(monthnow);
}

// Arguments:
//   monthnowt: Month to check.
void Pebs::monthnowCheck( int monthnowt )
{
   if (monthnowt < boost::date_time::Jan || monthnowt > boost::date_time::Dec)
      throw PiaException(PIA_IDS_PEBESMONTH);
}

// Description: Checks planned age of retirement in Statement case.
//
// Throws: PiaException of type PIA_IDS_AGEPLAN if planned age of retirement
//   is out of range.
//
// Arguments:
//   agePlant: The age to check.
void Pebs::agePlanCheck( int agePlant )
{
   if (agePlant < 0 || agePlant > 99)
      throw PiaException(PIA_IDS_AGEPLAN);
}
