// $Id: percpia.cpp 1.13 2006/11/08 11:48:25EST 044579 Development  $
//
// Functions to handle PIA formula percentages.

#include <algorithm>
#include "percpia.h"

using namespace std;

// Description: The three percentages for the regular benefit formula.
const double PercPia::PERC[] = { 0.90, 0.32, 0.15 };
// Description: The first percentage under the windfall elimination provision.
const double PercPia::WINDFALL_PERC = 0.40;

// Description: Initializes size of array and all values.
//
// Remarks: It does that by calling the reset function.
PercPia::PercPia()
{
   reset();
}

// Description: Destroys percentages array
PercPia::~PercPia()
{ }

// Description: Resets percentages to original values.
void PercPia::reset()
{
   copy(PERC, PERC + MAXPERC, theData);
}

// Description: Sets first PIA formula percentage for windfall
//   elimination provision.
//
// Arguments:
//   eligYear: Year of eligibility.
//   benefitDate: Year of benefit.
//   specMinTot: Years of coverage.
void PercPia::windfall( int eligYear, int benefitDate, int specMinTot )
{
   if (eligYear < 1985 || specMinTot >= WINDFALL_YEARS) {
      theData[0] = PERC[0];
      return;
   }
   // set a temporary percentage
   double rv = (eligYear > 1989) ? WINDFALL_PERC :
      PERC[0] - 0.10 * static_cast<double>(eligYear - 1985);
   // check for years of coverage guarantee (changes beginning with
   // benefits paid in 1989)
   const double annualPct = (benefitDate >= 1989) ? 0.05 : 0.10;
   const double totalPct =
      annualPct * static_cast<double>(WINDFALL_YEARS - specMinTot);
   if (PERC[0] - totalPct > rv)
      rv = PERC[0] - totalPct;
   theData[0] = rv;
}
