// $Id: qc.cpp 1.22 2006/11/08 11:05:34EST 044579 Development  $
//
// Functions to handle an annual number of quarters of coverage.

#include <cmath>  // for floor
#include "qc.h"
#include "oactcnst.h"
#include "PiaException.h"
#include "Resource.h"

using namespace std;

// Description: Checks annual quarters of coverage for one year.
//
// Throws: PiaException of type PIA_IDS_QCANN if number of quarters of coverage
//   is greater than MAXQCSINYEAR.
//
// Arguments:
//   newNumber: Value to check.
void Qc::check( unsigned newNumber )
{
   if (newNumber > MAXQCSINYEAR)
      throw PiaException(PIA_IDS_QCANN);
}

// Description: Returns number of quarters of coverage for one year, applying
//   annual test.
//
// Returns: Number of quarters of coverage for one year. The number cannot
// exceed MAXQCSINYEAR.
//
// Arguments:
//   earnings: Earnings in the year.
//   qcAmount: Amount required for one quarter of coverage.
unsigned Qc::qcCal( double earnings, double qcAmount )
{
   return(min(MAXQCSINYEAR, static_cast<unsigned>(floor(earnings / qcAmount))));
}
