// $Id: qcamt.cpp 1.15 2006/11/08 11:05:34EST 044579 Development  $
//
// Functions to handle quarter of coverage amount calculations.

#include <string>
#include "qcamt.h"
#include "PiaException.h"
#include "oactcnst.h"

using namespace std;

// Description: The quarter of coverage amount in 1978.
const double Qcamt::qcamt1978 = 250.0;
// Description: The quarter of coverage amount prior to 1978.
const double Qcamt::qcamt1977 = 50.0;

// Description: Initializes width and precision.
//
// Remarks: The version with one argument starts the data array in 1937.
//
// Arguments:
//   newLastYear: New last year of data.
Qcamt::Qcamt( int newLastYear ) : DoubleAnnual(YEAR37, newLastYear)
{
   setWidth(6);
   setPrecision(0);
   assign(qcamt1977, baseYear, AUTO_YEAR - 1);
   theData[AUTO_YEAR - baseYear] = qcamt1978;
}

// Arguments:
//   newBaseYear: New base year of data. If not specified, array starts in
//     1937.
Qcamt::Qcamt( int newBaseYear, int newLastYear ) :
DoubleAnnual(newBaseYear, newLastYear)
{
   setWidth(6);
   setPrecision(0);
   assign(qcamt1977, baseYear, AUTO_YEAR- 1);
   theData[AUTO_YEAR - baseYear] = qcamt1978;
}

// Description: Destroys a Qcamt array.
Qcamt::~Qcamt()
{ }

// Description: Projects quarter of coverage amounts.
//
// Remarks: Projects beginning
//   maximum of specified year or 1978, and continues to last year of data.
//
// Throws: PiaException of type PIA_IDS_QCAMT if average wages have not been
//   set (only in debug mode).
//
// Arguments:
//   averageWages: Average wages to use in projection.
//   firstYeart: First year of projection.
void Qcamt::project( const DoubleAnnual& averageWages, int firstYeart )
{
   // do not start projecting before 1978
   const int year78 = max(AUTO_YEAR, firstYeart);
   for (int i = year78; i <= getLastYear(); i++) {
#if !defined(NDEBUG)
      if (averageWages[AUTO_YEAR - 2] < 1.0)
         throw PiaException(PIA_IDS_QCAMT);
#endif
      double factor = averageWages[i - 2] / averageWages[AUTO_YEAR - 2];
      const int k = static_cast<int>
         (((factor * theData[AUTO_YEAR - baseYear]) + 4.99) / 10.0);
      theData[i - baseYear] = static_cast<double>(k) * 10.0;
   }
}
