// $Id: wbgenrlLC.cpp 1.16 2006/11/08 11:05:54EST 044579 Development  $
//
// Functions to handle wage base calculations with law changes.

#include <cmath>  // for floor
#include "wbgenrlLC.h"
#include "LawChangeArray.h"
#include "LawChangeWAGEBASECHG.h"

using namespace std;

// Description: Initializes type of projection to present law.
//
// Remarks: The version without a newBaseYear argument starts the data array
// in 1937.
//
// Arguments:
//   newLawChange: Law change parameters.
//   newLastYear: Last year of projection.
WageBaseLC::WageBaseLC( const LawChangeArray& newLawChange, int newLastYear ) :
WageBase(newLastYear), lawChange(newLawChange)
{ }

// Arguments:
//   newBaseYear: First year of data. If omitted, first year is 1937.
WageBaseLC::WageBaseLC( const LawChangeArray& newLawChange, int newBaseYear,
int newLastYear ) :
WageBase(newBaseYear, newLastYear), lawChange(newLawChange)
{ }

// Description: Initializes type of projection to old law.
//
// Remarks: The version without a newBaseYear argument starts the data array
// in 1937.
//
// Arguments:
//   newLawChange: Law change parameters.
//   newLastYear: Last year of projection.
WageBaseOldLawLC::WageBaseOldLawLC( const LawChangeArray& newLawChange,
int newLastYear ) :
WageBaseOldLaw(newLastYear), lawChange(newLawChange)
{ }

// Arguments:
//   newBaseYear: First year of data. If omitted, first year is 1937.
WageBaseOldLawLC::WageBaseOldLawLC( const LawChangeArray& newLawChange,
int newBaseYear, int newLastYear ) :
WageBaseOldLaw(newBaseYear, newLastYear), lawChange(newLawChange)
{ }

// Description: Projects oasdi wage bases with law changes.
//
// Arguments:
//   avgwages: Average wages for wage base projection.
//   cpi: Benefit increases.
//   firstYeart: First year of projection.
//   lastYeart: Last year of projection.
void WageBaseLC::project( const DoubleAnnual& avgwages, const DoubleAnnual& cpi,
int firstYeart, int lastYeart )
{
   LawChangeWAGEBASECHG *lawChangeWAGEBASECHG = lawChange.lawChangeWAGEBASECHG;
   if (lawChangeWAGEBASECHG->getInd() == 1 ||
      lawChangeWAGEBASECHG->getInd() == 3) {
      // project oasdi bases before using ad hoc bases
      WageBaseGeneral::project(avgwages, cpi, firstYeart,
         lawChangeWAGEBASECHG->getStartYear() - 1);
      // use ad hoc bases
      for (int i = lawChangeWAGEBASECHG->getStartYear();
      i <= lawChangeWAGEBASECHG->getEndYear(); i++) {
         theData[i - baseYear] = lawChangeWAGEBASECHG->getBaseOasdi(i);
      }
      // project oasdi bases after using ad hoc bases
      projectLC(avgwages, cpi, lawChangeWAGEBASECHG->getEndYear());
   }
   else {
      // project oasdi bases using present law
      WageBaseGeneral::project(avgwages, cpi, firstYeart, lastYeart);
   }
}

// Description: Projects 1977 law wage bases with law changes.
//
// Arguments:
//   avgwages: Average wages for wage base projection.
//   cpi: Benefit increases.
//   firstYeart: First year of projection.
//   lastYeart: Last year of projection.
void WageBaseOldLawLC::project( const DoubleAnnual& avgwages,
const DoubleAnnual& cpi, int firstYeart, int lastYeart )
{
   LawChangeWAGEBASECHG *lawChangeWAGEBASECHG = lawChange.lawChangeWAGEBASECHG;
   if (lawChangeWAGEBASECHG->getInd() == 2 ||
      lawChangeWAGEBASECHG->getInd() == 3) {
      // project oasdi bases before using ad hoc bases
      WageBaseGeneral::project(avgwages, cpi, firstYeart,
         lawChangeWAGEBASECHG->getStartYear() - 1);
      // use ad hoc bases
      for (int i = lawChangeWAGEBASECHG->getStartYear();
      i <= lawChangeWAGEBASECHG->getEndYear(); i++) {
         theData[i - baseYear] = lawChangeWAGEBASECHG->getBase77(i);
      }
      // project oasdi bases after using ad hoc bases
      projectLC(avgwages, cpi, lawChangeWAGEBASECHG->getEndYear());
   }
   else {
      // project oasdi bases using present law
      WageBaseGeneral::project(avgwages, cpi, firstYeart, lastYeart);
   }
}
