// $Id: AnypiaOut.h 1.13 2006/11/08 14:18:50EST 044579 Development  $
//
// Declarations for class to manage all output pages from Anypia.

#pragma once

#include <vector>
class WorkerData;
class PiaData;
class PiaCalAny;
class PiaOut;
class PebsOut;
class PageOut;

// {group:PiaOut Classes}
// Description: Manages all output pages from the Anypia program.
//
// Remarks: An instance of this class is used in the Anypia program.
class AnypiaOut
{
protected:
   // Description: Array of pages to print.
   std::vector< const PageOut* > pages;
   // Description: Benefit calculation data.
   const WorkerData* workerData;
   // Description: Benefit calculation data.
   const PiaData* piaData;
   // Description: Benefit calculation formulas.
   const PiaCalAny* piaCal;
   // Description: Output pages for non-Statement calculations.
   const PiaOut* piaOut;
   // Description: Output pages for Statement calculations.
   const PebsOut* pebsOut;
public:
   AnypiaOut();
   void fillPageSlots( bool valid, bool longOutput );
   // Description: Returns one page to print.
   //
   // Returns: One page to print.
   //
   // Arguments:
   //   index: Index of page to print (0-based).
   const PageOut* getPage( int index ) const { return pages[index]; }
   // Description: Returns number of pages to print.
   //
   // Returns: Number of pages to print.
   unsigned getPageCount() const { return (unsigned)pages.size(); }
   // Description: Sets pointer to Statement output.
   //
   // Arguments:
   //   newPebsOut: New Statement output.
   void setPebsOut( const PebsOut* newPebsOut ) { pebsOut = newPebsOut; }
   // Description: Sets pointer to pia calculation results.
   //
   // Arguments:
   //   newPiaCal: New pia calculation results.
   void setPiaCal( const PiaCalAny* newPiaCal ) { piaCal = newPiaCal; }
   // Description: Sets pointer to pia calculation data.
   //
   // Arguments:
   //   newPiaData: New pia calculation data.
   void setPiaData( const PiaData* newPiaData ) { piaData = newPiaData; }
   // Description: Sets pointer to pia calculation output.
   //
   // Arguments:
   //   newPiaOut: New pia calculation output.
   void setPiaOut( const PiaOut* newPiaOut ) { piaOut = newPiaOut; }
   // Description: Sets pointer to worker data.
   //
   // Arguments:
   //   newWorkerData: New worker data.
   void setWorkerData( const WorkerData* newWorkerData )
      { workerData = newWorkerData; }
};
