// $Id: ChildCareCalc1Page.cpp 1.12 2006/01/05 15:34:04EST 044579 Exp  $
//
// Function to write out wage indexed earnings with childcare dropout years.

#include "ChildCareCalc1Page.h"
#include "ChildCareCalc.h"
#include "comma.h"
#include "FormatString.h"
#include "PiaException.h"
#include "Resource.h"

using namespace std;

// Description: Initializes ChildCareCalc1Page.
//
// Arguments:
//   newPiaCal: Benefit calculation parameters and results.
ChildCareCalc1Page::ChildCareCalc1Page( const PiaCalAny& newPiaCal ) :
PiaPageOut(), workerData(newPiaCal.workerData), piaData(newPiaCal.piaData),
piaCal(newPiaCal)
{ }

// Description: Destructor.
ChildCareCalc1Page::~ChildCareCalc1Page()
{ }

// Description: Prepares wage indexed strings with childcare dropout years for
//   printing.
void ChildCareCalc1Page::prepareStrings()
{
   try {
      const ChildCareCalc* childCareCalc = piaCal.childCareCalc;
      if (childCareCalc != (const ChildCareCalc*)0 &&
         childCareCalc->getApplicable() > 0) {
         const AverageWage& earnings = workerData.getTotalize() ?
            piaData.earnTotalizedLimited : piaData.earnOasdiLimited;
         pageTitle[0] = childCareCalc->getTitle();
         outputString.clear();
         prepareHeader();
         const int earn50 = piaData.getEarn50(workerData.getTotalize() ?
            PiaData::EARN_WITH_TOTALIZATION : PiaData::EARN_NO_TOTALIZATION);
         printIndexedEarningsTable(*childCareCalc, piaData,
            piaData.getEligYear(), earnings, earn50);
         // print noninsured message
         nonIns(piaData.getFinsCode2());
         if (workerData.getJoasdi() == WorkerDataGeneral::DISABILITY)
            disInsOut(piaData);
         outputString.push_back("");
         printNameSsn(workerData);
      }
   } catch (PiaException e) {
      throw PiaException(PIA_IDS_WISTRING);
   }
}
