// $Id: ChildCareCalc2Page.cpp 1.16 2006/01/05 15:34:04EST 044579 Exp  $
//
// Function to write out wage indexed calculation with childcare dropout years.

#include "ChildCareCalc2Page.h"
#include "ChildCareCalc.h"
#include "comma.h"
#include "FormatString.h"
#include "cminmax.h"
#include "PiaException.h"
#include "Resource.h"
#include "UserAssumptions.h"

using namespace std;

// Description: Initializes ChildCareCalc2Page.
//
// Arguments:
//   newPiaCal: Benefit calculation parameters and results.
ChildCareCalc2Page::ChildCareCalc2Page( const PiaCalAny& newPiaCal ) :
PiaPageOut(), workerData(newPiaCal.workerData), piaData(newPiaCal.piaData),
piaParams(newPiaCal.piaParams), piaCal(newPiaCal),
userAssumptions(newPiaCal.userAssumptions)
{ }

// Description: Destructor.
ChildCareCalc2Page::~ChildCareCalc2Page()
{ }

// Description: Prepares wage indexed strings with childcare dropout years for
//   printing.
void ChildCareCalc2Page::prepareStrings()
{
   string s;  // temporary string

   try {
      const ChildCareCalc* childCareCalc = piaCal.childCareCalc;
      if (childCareCalc != (const ChildCareCalc*)0 &&
         childCareCalc->getApplicable() > 0) {
         pageTitle[0] = childCareCalc->getTitle();
         const int year0 = childCareCalc->getCpiYear(PiaMethod::FIRST_YEAR);
         const int year1 = childCareCalc->getCpiYear(PiaMethod::YEAR_ELIG);
         const int year2 = childCareCalc->getCpiYear(PiaMethod::YEAR_ENT);
         const int year3 = childCareCalc->getCpiYear(PiaMethod::YEAR_BEN);
         outputString.clear();
         prepareHeader();
         baseYearOut(piaData.getEligYear() - 2);
         compYear(workerData, piaData, piaData.compPeriodNew);
         // prepare childcare dropout years
         s = "Maximum number of childcare dropout years = ";
         s += poutNoComma(childCareCalc->getChildCareDropMax());
         outputString.push_back(s);
         outputString.push_back("");
         s = "Number of usable childcare dropout years = ";
         s += poutNoComma(childCareCalc->getChildCareDrop());
         outputString.push_back(s);
         outputString.push_back("");
         s = "Adjusted number of computation years = ";
         s += poutNoComma(childCareCalc->getAdjustedN());
         outputString.push_back(s);
         outputString.push_back("");
         s = "AIME = ";
         s += poutComma(childCareCalc->getftearn(), 4, 2);
         s += "/(";
         s += poutNoComma(childCareCalc->getAdjustedN());
         s += "*12) = ";
         s += poutComma(childCareCalc->getAme());
         outputString.push_back(s);
         outputString.push_back("");
         piaBpOut(childCareCalc->bendPia);
         mfbBpOut(childCareCalc->bendMfb);
         BenefitAmount dtemp;
         if (childCareCalc->getWindfall() == PiaMethod::HAS30YEARS ||
            childCareCalc->getWindfall() == PiaMethod::NOWINDFALLELIM) {
            dtemp = childCareCalc->piaElig[year0];
         }
         else {
            dtemp = childCareCalc->getPiaWindfall();
         }
         piaEligOut(childCareCalc->percPia, childCareCalc->portionAime,
            dtemp);
         if (childCareCalc->getWindfall() != PiaMethod::NOWINDFALLELIM) {
            pubPenOut(*childCareCalc,
               static_cast<double>(piaData.getPubpenApp(workerData)),
               workerData.getPubpenDate());
         }
         mfbOut(*childCareCalc, childCareCalc->portionPiaElig,
            childCareCalc->percMfb, childCareCalc->getAme());
         if (year2 >= year1)
            biOut(*childCareCalc, piaParams, piaData.getEligYear(), 1, 3);
         if (year3 > year2) {
            piamfb1(*childCareCalc);
            biOut(*childCareCalc, piaParams, piaData.getEligYear(), 2, 3);
         }
         if (piaData.getEligYear() > UserAssumptions::getIstart() &&
            userAssumptions.getIaltaw() == 
               AssumptionType::PEBS_ASSUM) {
            printRealWageGain(piaData.getEligYear(),
               UserAssumptions::getIstart(), *childCareCalc,
               childCareCalc->piaRealWageGain, childCareCalc->mfbRealWageGain);
         }
         piamfb2(*childCareCalc);
         // print noninsured message
         nonIns(piaData.getFinsCode2());
         if (workerData.getJoasdi() == WorkerDataGeneral::DISABILITY)
            disInsOut(piaData);
         outputString.push_back("");
         printNameSsn(workerData);
      }
   } catch (PiaException e) {
      throw PiaException(PIA_IDS_WISTRING);
   }
}
