// $Id: DibGuarPage.cpp 1.4 2006/01/05 15:34:04EST 044579 Exp  $
//
// Function to write out disability guarantee calculation.

#include "DibGuarPage.h"
#include "DibGuar.h"
#include "comma.h"
#include "FormatString.h"
#include "PiaException.h"
#include "Resource.h"

using namespace std;

// Description: Initializes DibGuarPage.
//
// Arguments:
//   newPiaCal: Benefit calculation parameters and results.
DibGuarPage::DibGuarPage( const PiaCalAny& newPiaCal ) : PiaPageOut(),
workerData(newPiaCal.workerData), piaData(newPiaCal.piaData),
piaParams(newPiaCal.piaParams), piaCal(newPiaCal)
{ }

// Description: Destructor.
DibGuarPage::~DibGuarPage()
{ }

// Description: Prepares frozen minimum strings for printing.
void DibGuarPage::prepareStrings()
{
   string s;  // temporary string

   try {
      const DibGuar* dibGuarPtr = piaCal.dibGuar;
      if (dibGuarPtr != (const DibGuar *)0 && dibGuarPtr->getApplicable() > 0) {
         const DibGuar& dibGuar = *dibGuarPtr;
         pageTitle[0] = dibGuar.getTitle();
         const int year0 = dibGuar.getCpiYear(PiaMethod::FIRST_YEAR);
         const int year1 = dibGuar.getCpiYear(PiaMethod::YEAR_ELIG);
         const int year2 = dibGuar.getCpiYear(PiaMethod::YEAR_ENT);
         const int year3 = dibGuar.getCpiYear(PiaMethod::YEAR_BEN);
         outputString.clear();
         prepareHeader();
         s = "PIA at cessation of prior disability = ";
         s += BenefitAmount(dibGuar.piaElig[year0]).toString();
         outputString.push_back(s);
         outputString.push_back("");
         s = "MFB at cessation of prior disability = ";
         s += BenefitAmount(dibGuar.getCessationMfbOrig()).toString();
         outputString.push_back(s);
         if (dibGuar.getDiMaxApplies()) {
            outputString.push_back("(Disability Maximum applies)");
         }
         else {
            outputString.push_back("(Disability Maximum does not apply)");
         }
         outputString.push_back("");
         switch (dibGuar.getConvertedMfbType()) {
         case DibGuar::POST1995_NOCHANGE:
            break;
         case DibGuar::POST1995_DECONVERTED:
            s = "Deconverted PIA at onset of prior disability = ";
            s += BenefitAmount(dibGuar.getRawPia()).toString();
            outputString.push_back(s);
            outputString.push_back("");
            s = "Raw MFB at onset of prior disability = ";
            s += BenefitAmount(dibGuar.getRawMfb()).toString();
            outputString.push_back(s);
            outputString.push_back("");
            s = "Converted MFB at cessation of prior disability = ";
            s += BenefitAmount(dibGuar.getCessationMfbConv()).toString();
            outputString.push_back(s);
            outputString.push_back("");
            break;
         case DibGuar::PRE1996_PRE1979_LAST12:
         case DibGuar::PRE1996_POST1978_LAST12:
         case DibGuar::PRE1996_NOTLAST12:
            s = "Converted MFB at cessation of prior disability = ";
            s += BenefitAmount(dibGuar.getCessationMfbConv()).toString();
            outputString.push_back(s);
            outputString.push_back("");
            break;
         default:
            throw PiaException(
               "DibGuarPage::prepareStrings: Illegal convertedMfbType");
         }
         if (year2 >= year1) {
            biOut(dibGuar, piaParams, piaData.getEligYear(), 1, 3);
         }
         else {
            outputString.push_back(
               "No CPI increases applied before entitlement");
            if (dibGuar.getColasApply()) {
               outputString.push_back(
                  "(no CPI increase occurred before entitlement)");
            }
            else {
               outputString.push_back(
                  "(more than 12 months between cessation and new entitlement)");
            }
            outputString.push_back("");
         }
         if (year3 > year2) {
            if (dibGuar.getIoasdi() == WorkerDataGeneral::SURVIVOR) {
               piamfbDeath(dibGuar);
            }
            else {
               piamfb1(dibGuar);
            }
            biOut(dibGuar, piaParams, piaData.getEligYear(), 2, 3);
         }
         piamfb2(dibGuar);
         // print noninsured message
         nonIns(piaData.getFinsCode2());
         if (workerData.getJoasdi() == WorkerDataGeneral::DISABILITY)
            disInsOut(piaData);
         outputString.push_back("");
         printNameSsn(workerData);
      }
   } catch (PiaException&) {
      throw PiaException(PIA_IDS_FMSTRING);
   }
}

// Description: Prepares PIA and MFB at death in a string table.
//
// Arguments:
//   piaMethod: Pia calculation method.
void DibGuarPage::piamfbDeath( const PiaMethod& piaMethod )
{
   string s("PIA at death = ");
   const int year = piaMethod.getCpiYear(PiaMethod::YEAR_ENT);
   s += BenefitAmount(piaMethod.piaElig[year]).toString();
   outputString.push_back(s);
   outputString.push_back("");
   s = "MFB at death = ";
   s += BenefitAmount(piaMethod.mfbElig[year]).toString();
   outputString.push_back(s);
   outputString.push_back("");
}
