// $Id: EarningsPage.cpp 1.17 2006/01/05 15:34:04EST 044579 Exp  $
//
// Function to write out earnings.

#include "EarningsPage.h"
#include "comma.h"
#include "FormatString.h"
#include "PiaException.h"
#include "Resource.h"
#include "piaparms.h"
#include "WageBase.h"
#include "UserAssumptions.h"
#include "oactcnst.h"

using namespace std;

// Description: Initializes EarningsPage.
//
// Arguments:
//   newPiaCal: Benefit calculation parameters and results.
EarningsPage::EarningsPage( const PiaCalAny& newPiaCal ) : PiaPageOut(),
workerData(newPiaCal.workerData), piaData(newPiaCal.piaData),
piaParams(newPiaCal.piaParams), piaCal(newPiaCal),
userAssumptions(newPiaCal.userAssumptions)
{ }

// Description: Destructor.
EarningsPage::~EarningsPage()
{ }

// Description: Prepares earnings strings for printing.
//
// Throws: PiaException of type PIA_IDS_TWOPAGE2 if any exceptions are caught.
void EarningsPage::prepareStrings()
{
   string s;  // temporary string

   try {
      pageTitle[0] = "Earnings Used in PIA Calculation";
      outputString.clear();
      prepareHeader();
      int i3 = workerData.getTotalize() ? piaData.getIbeginTotal() :
         piaData.getIbeginAll();
      int i4 = workerData.getTotalize() ? piaData.getIendTotal() :
         piaData.getIendAll();
      s = "                                 Amount    Quarters";
      if (workerData.getTotalize())
         s += "  Relative     Attri-";
      outputString.push_back(s);
      s = "          Annual      Maximum     per         of   ";
      if (workerData.getTotalize())
         s += "  earnings      buted";
      outputString.push_back(s);
      s = "year     earnings     earnings     QC      coverage";
      if (workerData.getTotalize())
         s += "  position    earnings";
      outputString.push_back(s);
      outputString.push_back("");
      for (int i1 = i3; i1 <= i4; ++i1) {
         s = poutNoComma(i1);
         if (piaData.getIbeginAll() != YEAR50 || i1 != YEAR50 ||
            workerData.getTotalize()) {
            s += poutComma(piaData.earnOasdiLimited[i1], 13, 2);
         }
         else {
            s += poutComma(piaData.getEarnTotal50(
               PiaData::EARN_NO_TOTALIZATION), 13, 2);
         }
         s += poutComma(piaParams.getBaseOasdi(i1), 13, 2);
         if (i1 > workerData.getQcLumpYear() || workerData.hasQcsByYear()) {
            if (i1 > workerData.getQcLumpYear() && i1 > YEAR50)
               s += poutComma(piaParams.qcamt[i1], 10, 2);
            else
               s += "          ";
            if (i1 > YEAR50)
               s += poutNoComma(piaData.qcov.get(i1), 9);
            else {
               if (i1 < YEAR50)
                  s += "         ";
               else
                  s += poutNoComma(piaData.getQcTotal50(), 9);
            }
            if (workerData.getTotalize()) {
               s += poutNoComma(piaData.relEarnPosition[i1], 11, 5);
               s += poutComma(piaData.earnTotalizedLimited[i1], 13, 2);
            }
         }
         outputString.push_back(s);
      }
      outputString.push_back("");
      if (!workerData.hasQcsByYear()) {
         s = "QC's for ";
         s += poutNoComma(workerData.getQcLumpYear());
         s += " and earlier                    ";
         s += poutNoComma(workerData.getQctottd(), 4);
         outputString.push_back(s);
         outputString.push_back("");
      }
      if (workerData.getTotalize()) {
         AfxFormatString1(s, PIA_IDS_RELERNOUT,
            poutNoComma(piaData.getRelEarnPositionAverage(), 4, 3));
         outputString.push_back(s);
      }
      if ((int)workerData.getBenefitDate().getYear() >
         UserAssumptions::getIstart() &&
         workerData.getIend() > UserAssumptions::getIstart()) {
            AfxFormatString1(s, PIA_IDS_PROBASOUT, BaseChangeType::toString(
               userAssumptions.getIbasch()));
         outputString.push_back(s);
      }
      // print noninsured message
      nonIns(piaData.getFinsCode2());
      // print unused earnings message
      if (piaData.getEarnYear() < workerData.getIend()) {
         outputString.push_back("");
         AfxFormatString1(s, PIA_IDS_UNEARNOUT, "");
         outputString.push_back(s);
      }
      if (workerData.getJoasdi() == WorkerDataGeneral::DISABILITY) {
         // print disability-insured message
         outputString.push_back("");
         disInsOut(piaData);
      }
      if (piaData.getOverMax()) {
         // print truncated earnings message
         outputString.push_back("");
         AfxFormatString1(s, PIA_IDS_ERNLIMOUT, "");
         outputString.push_back(s);
      }
      outputString.push_back("");
      printNameSsn(workerData);
   } catch (PiaException e) {
      throw PiaException(PIA_IDS_TWOPAGE2);
   }
}
