// $Id: FamilyPage.cpp 1.13 2007/03/09 17:10:00EST 044579 Development  $
//
// Function to write out family benefits.

#include "FamilyPage.h"
#include "comma.h"
#include "FormatString.h"
#include "PiaException.h"
#include "Resource.h"
#include "PiadataArray.h"
#include "WorkerDataArray.h"
#include "SecondaryArray.h"
#include "DateFormatter.h"

using namespace std;

// Description: Initializes FamilyPage.
//
// Arguments:
//   newPiaCal: Benefit calculation parameters and results.
FamilyPage::FamilyPage( const PiaCalAny& newPiaCal ) : PiaPageOut(),
workerData(newPiaCal.workerData), piaData(newPiaCal.piaData),
widowDataArray(newPiaCal.widowDataArray), widowArray(newPiaCal.widowArray),
piaCal(newPiaCal), secondaryArray(newPiaCal.secondaryArray)
{ }

// Description: Destructor.
FamilyPage::~FamilyPage()
{ }

// Description: Prepares strings for family members page.
void FamilyPage::prepareStrings()
{
   string s;  // temporary string

   // do not prepare this page if no family
   if (widowArray.getFamSize() == 0)
      return;
   pageTitle[0] = "Family members' benefits";
   outputString.clear();
   prepareHeader();
   for (int i = 0; i < widowArray.getFamSize(); i++) {
      Secondary* secondaryt = secondaryArray.secondary[i];
      WorkerData* widowData = widowDataArray.workerData[i];
      PiaData* widowPiaData = widowArray.piaData[i];
      // stop when reaching a blank bic
      if (secondaryt->bic.getMajorBic() == ' ')
         break;
      outputString.push_back("");
      s = "Family member ";
      s += poutNoComma(i+1);
      s += ":";
      outputString.push_back(s);
      // write type of benie
      AfxFormatString1(s, PIA_IDS_JSURVOUT,
         (workerData.getJoasdi() == WorkerData::SURVIVOR) ?
         secondaryt->bic.getSurvivorType() : secondaryt->bic.getLifeAuxType());
      outputString.push_back(s);
      // write date of birth
      AfxFormatString1(s, PIA_IDS_DOBOUT,
         DateFormatter::toString(widowData->getBirthDate()));
      outputString.push_back(s);
      // write date of onset for disabled widow
      if (secondaryt->bic.getMajorBic() == 'W') {
         AfxFormatString1(s, PIA_IDS_WIDDIBOUT,
            DateFormatter::toString(widowData->disabPeriod[0].getOnsetDate()));
         outputString.push_back(s);
      }
      // write date of entitlement
      AfxFormatString1(s, PIA_IDS_SURVENTOUT,
         DateFormatter::toString(secondaryt->entDate));
      outputString.push_back(s);
      // write full retirement age for aged spouse or widow(er)
      if (secondaryt->bic.isReducible() &&
         secondaryt->bic.getMajorBic() != 'W') {
         if (secondaryt->bic.getMajorBic() == 'D')
            AfxFormatString1(s, PIA_IDS_NRAWIDOUT,
               widowPiaData->fullRetAge.toString());
         else
            AfxFormatString1(s, PIA_IDS_NRAWIFEOUT,
               widowPiaData->fullRetAge.toString());
         outputString.push_back(s);
      }
      // write benefit factor
      AfxFormatString1(s, PIA_IDS_BENFOUT,
         poutNoComma(secondaryt->getBenefitFactor(), 8, 3));
      outputString.push_back(s);
      // write full benefit
      AfxFormatString1(s, PIA_IDS_FULLBEN,
         BenefitAmount(secondaryt->getFullBenefit()).toString());
      outputString.push_back(s);
      // write benefit after mfb
      AfxFormatString1(s, PIA_IDS_MFBBEN,
         BenefitAmount(secondaryt->getBenefit()).toString());
      outputString.push_back(s);
      // write age reduction info
      if (secondaryt->bic.isReducible()) {
         AfxFormatString1(s, PIA_IDS_ARFMOUT,
            poutNoComma(secondaryt->getMonthsArdri(), 8));
         outputString.push_back(s);
         AfxFormatString1(s, PIA_IDS_ARFFOUT,
            poutNoComma(secondaryt->getArf(), 8, 3));
         outputString.push_back(s);
      }
      // write benefit reduced for age
      AfxFormatString1(s, PIA_IDS_BEN1OUT,
         BenefitAmount(secondaryt->getReducedBenefit()).toString());
      outputString.push_back(s);
      AfxFormatString1(s, PIA_IDS_BEN2OUT,
         BenefitAmount(secondaryt->getRoundedBenefit()).toString());
      outputString.push_back(s);
   }
// The following is a debugging quantity which is not needed at the moment.
//   s = "Total Family Benefit: ";
//   s += BenefitAmount(secondaryArray.getTotalFullBenefit()).toString();
//   outputString.push_back(s);
}
