// $Id: FrozMinPage.cpp 1.10 2006/01/05 15:34:05EST 044579 Exp  $
//
// Function to write out frozen minimum calculation.

#include "FrozMinPage.h"
#include "FrozMin.h"
#include "comma.h"
#include "FormatString.h"
#include "cminmax.h"
#include "PiaException.h"
#include "Resource.h"

using namespace std;

// Description: Initializes FrozMinPage.
//
// Arguments:
//   newPiaCal: Benefit calculation parameters and results.
FrozMinPage::FrozMinPage( const PiaCalAny& newPiaCal ) : PiaPageOut(),
workerData(newPiaCal.workerData), piaData(newPiaCal.piaData),
piaParams(newPiaCal.piaParams), piaCal(newPiaCal)
{ }

// Description: Destructor.
FrozMinPage::~FrozMinPage()
{ }

// Description: Prepares frozen minimum strings for printing.
void FrozMinPage::prepareStrings()
{
   string s;  // temporary string

   try {
      const FrozMin* frozMin = piaCal.frozMin;
      if (frozMin != (const FrozMin *)0 && frozMin->getApplicable() > 0) {
         pageTitle[0] = frozMin->getTitle();
         const int year0 = frozMin->getCpiYear(PiaMethod::FIRST_YEAR);
         const int year1 = frozMin->getCpiYear(PiaMethod::YEAR_ELIG);
         const int year2 = frozMin->getCpiYear(PiaMethod::YEAR_ENT);
         const int year3 = frozMin->getCpiYear(PiaMethod::YEAR_BEN);
         outputString.clear();
         prepareHeader();
         s = "PIA at eligibility = ";
         s += BenefitAmount(frozMin->piaElig[year0]).toString();
         outputString.push_back(s);
         outputString.push_back("");
         s = "MFB at eligibility = ";
         s += BenefitAmount(frozMin->mfbElig[year0]).toString();
         outputString.push_back(s);
         outputString.push_back("");
         if (year2 >= year1)
            biOut(*frozMin, piaParams, piaData.getEligYear(), 1, 3);
         if (year3 > year2) {
            piamfb1(*frozMin);
            biOut(*frozMin, piaParams, piaData.getEligYear(), 2, 3);
         }
         piamfb2(*frozMin);
         // print noninsured message
         nonIns(piaData.getFinsCode2());
         if (workerData.getJoasdi() == WorkerDataGeneral::DISABILITY)
            disInsOut(piaData);
         outputString.push_back("");
         printNameSsn(workerData);
      }
   } catch (PiaException e) {
      throw PiaException(PIA_IDS_FMSTRING);
   }
}
