// $Id: OldStart1Page.cpp 1.10 2006/01/05 15:34:05EST 044579 Exp  $
//
// Function to write out old start calculation.

#include "OldStart1Page.h"
#include "OldStart.h"
#include "comma.h"
#include "FormatString.h"
#include "PiaException.h"
#include "Resource.h"
#include "oactcnst.h"

using namespace std;

// Description: Initializes OldStart1Page.
//
// Arguments:
//   newPiaCal: Benefit calculation parameters and results.
OldStart1Page::OldStart1Page( const PiaCalAny& newPiaCal ) : PiaPageOut(),
workerData(newPiaCal.workerData), piaData(newPiaCal.piaData),
piaParams(newPiaCal.piaParams), piaCal(newPiaCal)
{ }

// Description: Destructor.
OldStart1Page::~OldStart1Page()
{ }

// Description: Prepares old start strings for printing.
void OldStart1Page::prepareStrings()
{
   try {
      const OldStart* oldStart = (const OldStart*)piaCal.oldStart;
      if (oldStart != (const OldStart*)0 && oldStart->getApplicable() > 0) {
         pageTitle[0] = oldStart->getTitle();
         outputString.clear();
         const AverageWage& earnings = workerData.getTotalize() ?
            piaData.earnTotalizedLimited : piaData.earnOasdiLimited;
         prepareHeader();
         outputString.push_back(
            "                         Imputed      High n");
         outputString.push_back(
            "Year      Earnings      Earnings      Years");
         outputString.push_back("");
         for (int i1 = YEAR37; i1 <= piaData.getEarnYear(); i1++) {
            string s = poutNoComma(i1);
            if (workerData.getIbegin() != YEAR50 || i1 != YEAR50)
               s += poutComma(earnings[i1], 14, 2);
            else {
               const double earnTotal50 = piaData.getEarnTotal50(
                  workerData.getTotalize() ? PiaData::EARN_WITH_TOTALIZATION :
                  PiaData::EARN_NO_TOTALIZATION);
               s += poutComma(earnTotal50, 14, 2);
            }
            s += poutComma(oldStart->earnIndexed[i1], 14, 2);
            if (oldStart->iorder[i1] > 0)
               s += poutComma(oldStart->earnIndexed[i1], 14, 2);
            outputString.push_back(s);
         }
         outputString.push_back("");
         // print noninsured message
         nonIns(piaData.getFinsCode2());
         if (workerData.getJoasdi() == WorkerDataGeneral::DISABILITY)
            disInsOut(piaData);
         outputString.push_back("");
         printNameSsn(workerData);
      }
   } catch (PiaException&) {
      throw PiaException(PIA_IDS_OSSTRING);
   }
}
