// $Id: OldStart2Page.cpp 1.18 2006/01/05 15:34:06EST 044579 Exp  $
//
// Function to write out old start calculation.

#include "OldStart2Page.h"
#include "OldStart.h"
#include "WageInd.h"
#include "comma.h"
#include "FormatString.h"
#include "cminmax.h"
#include "PiaException.h"
#include "Resource.h"
#include "piaparms.h"

using namespace std;

// Description: Years of old-start Social Security Acts.
const char *OldStart2Page::iyros[OldStart::NUM_OLD_START_TYPES] = {
   "1939", "1950", "1950", "1965", "1967", "1977", "1977", "1990"
};

// Description: Sub-titles of old-start Social Security Acts.
const char *OldStart2Page::ios77[OldStart::NUM_OLD_START_TYPES] = {
   "", "1950 Conversion Table", "1958 Conversion Table", "", "",
   "Pre-1977 Act PIA Table", "December 1978 PIA Table",
   "Pre-1977 Act PIA Table"
};

// Description: Initializes OldStart2Page.
//
// Arguments:
//   newPiaCal: Benefit calculation parameters and results.
OldStart2Page::OldStart2Page( const PiaCalAny& newPiaCal ) : PiaPageOut(),
workerData(newPiaCal.workerData), piaData(newPiaCal.piaData),
piaParams(newPiaCal.piaParams), piaCal(newPiaCal)
{ }

// Description: Destructor.
OldStart2Page::~OldStart2Page()
{ }

// Description: Prepares old start strings for printing.
void OldStart2Page::prepareStrings()
{
   try {
      const OldStart* oldStart = (const OldStart*)piaCal.oldStart;
      if (oldStart != (const OldStart*)0 && oldStart->getApplicable() > 0) {
         pageTitle[0] = oldStart->getTitle();
         outputString.clear();
         prepareHeader();
         string s = "Quarters of coverage after 1950 = ";
         s += poutNoComma(piaData.getQcTotal51());
         outputString.push_back(s);
         outputString.push_back("");
         compYear(workerData, piaData, piaData.compPeriodOld);
         s = "AME = ";
         s += poutComma(oldStart->getftearn(), 4, 2);
         s += "/(";
         s += poutNoComma(piaData.compPeriodOld.getN());
         s += "*12) = ";
         s += poutComma(oldStart->getAmeOs());
         outputString.push_back(s);
         outputString.push_back("");
         s = "Applicable method: ";
         s += iyros[oldStart->getMethodOs()];
         s += " Act";
         outputString.push_back(s);
         if (strlen(ios77[oldStart->getMethodOs()])) {
            s = "  ";
            s += ios77[oldStart->getMethodOs()];
            outputString.push_back(s);
         }
         outputString.push_back("");
         outputString.push_back(
            "PIB before applying increment years = ");
         s = "   ";
         s += poutComma(piaParams.getPercOS(0), 4, 2);
         s += " * ";
         s += poutComma(oldStart->portionAme[0]);
         s += " +";
         outputString.push_back(s);
         s = "   ";
         s += poutComma(piaParams.getPercOS(1), 4, 2);
         s += " * ";
         s += poutComma(oldStart->portionAme[1]);
         s += " = ";
         s += poutComma(oldStart->getPib(), 4, 2);
         outputString.push_back(s);
         outputString.push_back("");
         s = "Increment years = ";
         if (oldStart->isOs1977_90()) {
            const double earnTotal50 = piaData.getEarnTotal50(
               workerData.getTotalize() ? PiaData::EARN_WITH_TOTALIZATION :
               PiaData::EARN_NO_TOTALIZATION);
            s += poutComma(earnTotal50);
            s += "/";
            s += poutComma(PiaParams::amtperincyr);
            s += " = ";
         }
         s += poutNoComma(oldStart->getIncyrs());
         outputString.push_back(s);
         outputString.push_back("");
         s = "PIB after applying increment years = ";
         s += poutComma(oldStart->getPibInc(), 4, 2);
         outputString.push_back(s);
         outputString.push_back("");
         const int year0 = oldStart->getCpiYear(PiaMethod::FIRST_YEAR);
         const int year2 = oldStart->getCpiYear(PiaMethod::YEAR_ENT);
         const int year3 = oldStart->getCpiYear(PiaMethod::YEAR_BEN);
         switch (oldStart->getMethodOs())
         {
         case OldStart::OS1950:
            s = "1950 PIA = ";
            s += BenefitAmount(oldStart->piaElig[year0]).toString();
            outputString.push_back(s);
            outputString.push_back("");
            s = "1950 MFB = ";
            s += BenefitAmount(oldStart->mfbElig[year0]).toString();
            outputString.push_back(s);
            outputString.push_back("");
            break;
         case OldStart::OS1958:
         case OldStart::OS1965:
         case OldStart::OS1967:
         case OldStart::OS1977_78:
         case OldStart::OS1977_79:
         case OldStart::OS1990:
            s = "New-start AME = ";
            s += poutComma(oldStart->getAme());
            outputString.push_back(s);
            outputString.push_back("");
            switch (oldStart->getMethodOs())
            {
            case OldStart::OS1977_78:
            case OldStart::OS1990:
               osTableOut(*oldStart);
               if (year2 >= year0)
                  biOut(*oldStart, piaParams, piaData.getEligYear(), 0, 0);
               if (year3 > year2)
                  biOut(*oldStart, piaParams, piaData.getEligYear(), 2, 3);
               break;
            case OldStart::OS1977_79:
               s = "PIA at eligibility = ";
               if (oldStart->getWindfall() == PiaMethod::NOWINDFALLELIM &&
                  !workerData.getTotalize()) {
                  s += BenefitAmount(oldStart->piaElig[year0]).toString();
               }
               else {
                  if (oldStart->getWindfall() != PiaMethod::NOWINDFALLELIM)
                     s += oldStart->getPiaWindfall().toString();
                  else
                     s += oldStart->getPiaEligTotal().toString();
               }
               outputString.push_back(s);
               outputString.push_back("");
               if (oldStart->getWindfall() != PiaMethod::NOWINDFALLELIM) {
                  pubPenOut(*oldStart,
                     static_cast<double>(piaData.getPubpenApp(workerData)),
                     workerData.getPubpenDate());
               }
               if (workerData.getTotalize()) {
                  totPiaOut(*oldStart, piaData.getQcTotal(),
                     piaData.compPeriodNew.getN());
                  rawPiaOut(oldStart->piaElig[year0]);
               }
               mfbBpOut(oldStart->bendMfb);
               if (piaCal.wageInd == (WageInd*)0) {
                  mfbOut(*oldStart, oldStart->portionPiaElig,
                     oldStart->percMfb);
               }
               else {
                  mfbOut(*oldStart, oldStart->portionPiaElig,
                     oldStart->percMfb, piaCal.wageInd->getAme());
               }
               if (year2 >= oldStart->getCpiYear(PiaMethod::YEAR_ELIG))
                  biOut(*oldStart, piaParams, piaData.getEligYear(), 1, 3);
               if (year3 > year2) {
                  piamfb1(*oldStart);
                  biOut(*oldStart, piaParams, piaData.getEligYear(), 2, 3);
               }
               break;
            default:
               break;
            }
            break;
         default:
            break;
         }
         piamfb2(*oldStart);
         // print noninsured message
         nonIns(piaData.getFinsCode2());
         if (workerData.getJoasdi() == WorkerDataGeneral::DISABILITY)
            disInsOut(piaData);
         outputString.push_back("");
         printNameSsn(workerData);
      }
   } catch (PiaException&) {
      throw PiaException(PIA_IDS_OSSTRING);
   }
}

// Description: Prepares windfall calculation.
//
// Arguments:
//   oldStart: Old-start calculation method.
//   pubpen: Amount of public pension.
//   pubpenDate: Starting date of public pension.
void OldStart2Page::pubPenOut( const OldStart& oldStart, double pubpen,
   const DateMoyr& pubpenDate )
{
   nonpenOut(pubpen, pubpenDate);
   outputString.push_back("");
   outputString.push_back("PIA after windfall:");
   string s = "   ";
   s += oldStart.getPiaWindfall().toString();
   s += " - .5*";
   s += poutComma(min(oldStart.getPiaWindfall().get(), pubpen), 4, 2);
   outputString.push_back(s);
   s = "   = ";
   const int year = oldStart.getCpiYear(PiaMethod::FIRST_YEAR);
   s += BenefitAmount(oldStart.piaElig[year]).toString();
   outputString.push_back(s);
   outputString.push_back("");
}
