// $Id: OnePage.cpp 1.18 2007/03/09 17:10:00EST 044579 Development  $
//
// Function to write out one-page summary of results.

#include "OnePage.h"
#include "PiaTable.h"
#include "TransGuar.h"
#include "WageInd.h"
#include "comma.h"
#include "FormatString.h"
#include "PiaException.h"
#include "Resource.h"
#include "boost/date_time/gregorian/gregorian.hpp"
#include "DateFormatter.h"

using namespace std;

// Description: Initializes OnePage.
//
// Arguments:
//   newPiaCal: Benefit calculation parameters and results.
OnePage::OnePage( const PiaCalAny& newPiaCal ) : PiaPageOut(),
workerData(newPiaCal.workerData), piaData(newPiaCal.piaData), piaCal(newPiaCal)
{ }

// Description: Destructor.
OnePage::~OnePage()
{ }

// Description: Prepares strings for 1-page summary.
void OnePage::prepareStrings()
{
   int firstyr;  // first year to print out
   int lastyr;  // last year to print out

   try {
      outputString.clear();
      if (workerData.getJoasdi() == WorkerDataGeneral::PEBS_CALC)
         return;
      switch (workerData.getJoasdi())
      {
      case WorkerDataGeneral::OLD_AGE:
         outputString.push_back(
            "                   R E T I R E M E N T   E S T I M A T E");
         break;
      case WorkerDataGeneral::SURVIVOR:
         outputString.push_back(
            "                     S U R V I V O R   E S T I M A T E");
         break;
      case WorkerDataGeneral::DISABILITY:
         outputString.push_back(
            "                   D I S A B I L I T Y   E S T I M A T E");
         break;
      default:
         break;
      }
      outputString.push_back("");
      outputString.push_back("");
      string s = "                                               ";
      s += DateFormatter::toString(boost::gregorian::day_clock::local_day());
      outputString.push_back(s);
      printNameSsn(workerData);
      AfxFormatString1(s, PIA_IDS_DOBOUT,
         DateFormatter::toString(workerData.getBirthDate()));
      outputString.push_back(s);
      if (workerData.getJoasdi() == WorkerDataGeneral::SURVIVOR) {
         AfxFormatString1(s, PIA_IDS_DOBOUT,
            DateFormatter::toString(workerData.getDeathDate()));
         outputString.push_back(s);
      }
      if (workerData.getJoasdi() == WorkerDataGeneral::DISABILITY) {
         AfxFormatString1(s, PIA_IDS_ONSETOUT,
            DateFormatter::toString(workerData.disabPeriod[0].getOnsetDate()));
         outputString.push_back(s);
      }
      outputString.push_back("");
      outputString.push_back("");
      outputString.push_back(
         "                      R E G U L A R   E A R N I N G S");
      outputString.push_back("");
      outputString.push_back("");
      const double earnTotal50 =
         piaData.getEarnTotal50(PiaData::EARN_NO_TOTALIZATION);
      if (earnTotal50 > 0.0) {
         s = "50 ";
         s += poutComma(earnTotal50, 10, 2);
         outputString.push_back(s);
         firstyr = 1951;
      }
      else {
         firstyr = (workerData.getIbegin() > 1950) ?
            5 * ((workerData.getIbegin() - 1) / 5) + 1 : 1951;
      }
      lastyr = 5 * ((workerData.getIend() - 1) / 5) + 5;
      printEarn(firstyr, lastyr, 0);
      if ((piaCal.piaTable != (PiaTable*)0 && piaCal.piaTable->getApplicable())
         || (piaCal.transGuar != (TransGuar*)0 &&
         piaCal.transGuar->getApplicable())) {
         outputString.push_back("");
         s = "Dividend:  ";
         if (piaCal.piaTable != (PiaTable*)0 &&
            piaCal.piaTable->getApplicable() > 0) {
            s += poutComma(
               piaCal.piaTable->getftearn(), 10, 2);
         }
         else {
            s += poutComma(
               piaCal.transGuar->getftearn(), 10, 2);
         }
         s += "                                  Divisor months: ";
         s += poutNoComma(12 * piaData.compPeriodNew.getN());
         outputString.push_back(s);
      }
      outputString.push_back("");
      if (piaCal.wageInd != (WageInd*)0) {
         outputString.push_back("");
         outputString.push_back(
            "                      I N D E X E D   E A R N I N G S");
         outputString.push_back("");
         outputString.push_back("");
         printEarn(firstyr, lastyr, 1);
         outputString.push_back("");
         s = "Dividend:  ";
         s += poutComma(piaCal.wageInd->getftearn(), 13, 2);
         s += "                                  Divisor months: ";
         s += poutNoComma(12 * piaData.compPeriodNew.getN());
         outputString.push_back(s);
      }
      outputString.push_back("");
      s = " Eff.                          ";
      s += (piaData.getArf() >= 1.0) ? "Increment" : "Reduction";
      s += "              Family";
      outputString.push_back(s);
      outputString.push_back(
         " date       AIME      PIA       factor      MBA      maximum");
      outputString.push_back(
         "-------    ------    ------    ---------   ------    -------");
      const char *asterisk = (piaData.getIappn() == (int)PiaMethod::WAGE_IND ||
         piaData.getIappn() == -1) ? " " : "*";
      s = DateFormatter::toString(workerData.getBenefitDate(), "ss");
      if (piaCal.wageInd != (WageInd*)0) {
         s += poutComma(piaCal.wageInd->getAme()+.1, 9);
      }
      else {
         s += "         ";
      }
      s += "   ";
      if (piaCal.wageInd != (WageInd*)0) {
         s += piaCal.wageInd->piaEnt.toString();
      }
      else {
         s += "        ";
      }
      s += poutComma(piaData.getArf(), 12, 5);
      s += "  ";
      s += piaData.benefit.toString();
      s += asterisk;
      s += "  ";
      s += piaData.highMfb.toString();
      s += asterisk;
      outputString.push_back(s);
      outputString.push_back("");
      // print footnotes
      if (asterisk[0] == '*') {
         s = "*Based on ";
         s += piaCal.highPiaMethod->getTitle();
         outputString.push_back(s);
      }
      for (vector< PiaMethod * >::const_iterator iter = piaCal.piaMethod.begin();
      iter != piaCal.piaMethod.end(); iter++) {
        if ((*iter)->getMethod() != PiaMethod::WAGE_IND &&
            (*iter)->getApplicable() > 0) {
            s = "   ";
            s += (*iter)->getTitle();
            s += " PIA: ";
            s += (*iter)->piaEnt.toString();
            outputString.push_back(s);
            if ((*iter)->getMethod() == PiaMethod::SPEC_MIN) {
               AfxFormatString1(s, PIA_IDS_SPYRS2OUT,
                  poutNoComma((*iter)->getYearsTotal()));
               outputString.push_back(s);
            }
        }
      }
      // print windfall message
      if (piaCal.wageInd != (WageInd*)0) {
         if (piaCal.wageInd->getWindfall() != PiaMethod::NOWINDFALLELIM) {
            if (piaCal.wageInd->getWindfall() == PiaMethod::HAS30YEARS)
               outputString.push_back("WEP considered, but not applied");
            else
               outputString.push_back("WEP applied");
         }
      }
      // print uninsured message
      nonIns(piaData.getFinsCode2());
      // print disability insured message
      if (workerData.getJoasdi() == WorkerDataGeneral::DISABILITY)
         disInsOut(piaData);
   } catch (PiaException e) {
      throw PiaException(PIA_IDS_ONEPAGE);
   }
}

// Description: Prepares table of earnings.
//
// Arguments:
//   firstyr: First year of earnings.
//   lastyr: Last year of earnings
//   tier: Tier of table to print.
//     0 for actual earnings,
//     1 for indexed earnings.
void OnePage::printEarn( int firstyr, int lastyr, int tier )
{
   int lines = (lastyr - firstyr + 1) / 5;
   for (int i1 = firstyr; i1 < firstyr + lines; i1++) {
      string s = "";
      for (int i2 = 0; i2 < 5; i2++) {
         int i3 = i1 + i2 * lines;
         int year = i3 % 100;
         if (year == 0)
            s += "  00";
         else {
            s += (year < 10) ? "  0" : "  ";
            s += poutNoComma(year);
         }
         if (tier == 0)
            s += poutComma(piaData.earnOasdiLimited[i3], 11, 2);
         else {
            s += poutComma(piaCal.wageInd->earnIndexed[i3], 11, 2);
         }
      }
      outputString.push_back(s);
   }
}
