// $Id: PebsEarnings.cpp 1.15 2006/11/08 11:06:14EST 044579 Development  $
//
// Function to write out Social Security Statement earnings page.

#include <cmath>  // for floor
#include "PebsEarnings.h"
#include "UserAssumptions.h"
#include "comma.h"
#include "FormatString.h"
#include "PiaException.h"
#include "Resource.h"
#include "PebsOut.h"
#include "WageBase.h"

using namespace std;

// Description: Initializes PebsEarnings.
//
// Arguments:
//   newWorkerData: Worker basic data.
//   newPiaData: Pia calculation data.
//   newPiaParams: Pia calculation parameters.
//   newTaxData: Taxes paid.
PebsEarnings::PebsEarnings( const WorkerData& newWorkerData,
const PiaData& newPiaData, const PiaParams& newPiaParams,
const TaxData& newTaxData ) : PebsPageOut(),
workerData(newWorkerData), piaData(newPiaData), piaParams(newPiaParams),
taxData(newTaxData)
{ }

// Description: Destructor.
PebsEarnings::~PebsEarnings()
{ }

// Description: Prepares page of earnings for printing.
void PebsEarnings::prepareStrings()
{
   outputString.clear();
   prepareHeader(workerData);
   outputString.push_back("      Your Social Security Earnings");
   outputString.push_back("");
   outputString.push_back(
      "                   SOCIAL SECURITY                 MEDICARE");
   outputString.push_back(
      "          ------------------------------  ------------------------------");
   outputString.push_back(
      "            Maximum      Your  Estimated    Maximum      Your  Estimated");
   outputString.push_back(
      "            Taxable  Reported  Taxes You    Taxable  Reported  Taxes You");
   outputString.push_back(
      "YEARS      Earnings  Earnings       Paid   Earnings  Earnings       Paid");
   outputString.push_back(hyphens);
   string s = "1937-50      $";
   s += poutComma(piaParams.getBaseOasdi(YEAR50), 5);
   s += "   $";
   s += poutComma(floor(piaData.getEarnTotal50(PiaData::EARN_NO_TOTALIZATION)),
      6);
   s += "     $";
   s += poutComma(taxData.getTaxesTotal(TaxRates::OASDITF,
      TaxData::YEARS1937_50), 5);
   outputString.push_back(s);
   for (int i1 = YEAR51; i1 < UserAssumptions::getIstart() + 1; i1++) {
      s = poutNoComma(i1);
      s += poutComma(piaParams.getBaseOasdi(i1), 15);
      if (i1 < UserAssumptions::getIstart() - 1) {
         s += poutComma(piaData.earnOasdiLimited[i1], 10);
         s += poutComma(taxData.taxesOasdi[i1], 11);
         // print HI earnings and taxes
         if (i1 > 1965) {
            if (i1 == 1966) {
               s += "    $";
               s += poutComma(piaParams.getBaseHi(i1), 6);
               s += "   $";
               s += poutComma(piaData.earnHiLimited[i1], 6);
               s += "     $";
               s += poutComma(taxData.taxesHi[i1], 5);
            }
            else {
               if (piaParams.getBaseHi(i1) > MAXEARN - 1) {
                  s += "   No limit";
               }
               else {
                  s += poutComma(piaParams.getBaseHi(i1), 11);
               }
               s += poutComma(piaData.earnHiLimited[i1], 10);
               s += poutComma(taxData.taxesHi[i1], 11);
            }
         }
      }
      else {
         if (i1 == UserAssumptions::getIstart() - 1)
            s += "            Not Yet Recorded";
      }
      outputString.push_back(s);
   }
   outputString.push_back(hyphens);
}
