// $Id: PebsEarningsInfo.cpp 1.11 2005/08/05 13:53:34EDT 277133 Exp 277133(2006/10/18 12:53:49EDT) $
//
// Function to write out Social Security Statement earnings information page.

#include "PebsEarningsInfo.h"
#include "UserAssumptions.h"
#include "comma.h"
#include "FormatString.h"
#include "cminmax.h"
#include "PiaException.h"
#include "Resource.h"
#include "PebsOut.h"
#include "WageBase.h"

using namespace std;

// Description: Initializes PebsEarningsInfo.
//
// Arguments:
//   newPiaParams: Pia calculation parameters.
PebsEarningsInfo::PebsEarningsInfo( const PiaParams& newPiaParams ) :
PebsPageOut(), piaParams(newPiaParams)
{ }

// Description: Destructor.
PebsEarningsInfo::~PebsEarningsInfo()
{ }

// Description: Prepares earnings info for printing.
void PebsEarningsInfo::prepareStrings()
{
   outputString.clear();
   outputString.push_back(equals);
   outputString.push_back("Your Earnings Record");
   outputString.push_back("");
   outputString.push_back(
      "We keep a record of the amount of earnings reported each year under");
   outputString.push_back(
      "your name and Social Security number.  When you apply for benefits,");
   outputString.push_back(
      "we check your record to see if you worked enough over the years to");
   outputString.push_back(
      "qualify.  Then we base the amount of your payments on your average");
   outputString.push_back("earnings over your working lifetime.");
   outputString.push_back("");
   outputString.push_back(
      "Almost all kinds of employment and self-employment earnings are");
   outputString.push_back("covered for Social Security and Medicare:");
   outputString.push_back("");
   outputString.push_back(
      "  Most wages have been covered by Social Security taxes since 1937");
   outputString.push_back(
      "  and most kinds of self-employment since 1951.");
   outputString.push_back(
      "  Medicare taxes on both kinds of earnings started in 1966.");
   outputString.push_back(
      "  Some Federal, State and local government workers do not pay Social");
   outputString.push_back(
      "  Security taxes, but most of them do pay Medicare taxes on their");
   outputString.push_back(
      "  \"Medicare-qualified government earnings.\"");
   outputString.push_back("");
   outputString.push_back(
      "If you work for wages, your employer reports the amount of your");
   outputString.push_back(
      "earnings to Social Security after the end of each year.  If you are");
   outputString.push_back(
      "self-employed, you report your net earnings on your yearly income");
   outputString.push_back(
      "tax return.  The chart on page 2 shows the amounts of earnings");
   outputString.push_back(
      "reported to us.  If you had more than one employer during the year,");
   outputString.push_back(
      "your earnings from all of them have been combined.");
   outputString.push_back("");
   outputString.push_back(
      "There are limits each year on how much earnings are taxable for");
   outputString.push_back(
      "Social Security and for Medicare.  If you earn more than the maximum");
   outputString.push_back(
      "amount, the extra earnings will not be shown.  The chart on page 2");
   outputString.push_back(
      "shows the maximum amount that was taxable for each year so far.");
   outputString.push_back("");
   outputString.push_back(equals);
   outputString.push_back("Your Social Security Taxes");
   outputString.push_back("");
   outputString.push_back(
      "The Internal Revenue Service collects your Social Security and");
   outputString.push_back(
      "Medicare taxes.  We do not keep that record.  To estimate the Social");
   outputString.push_back(
      "Security and Medicare taxes you paid, we multiplied your reported");
   outputString.push_back(
      "earnings by the tax rate for each year.  The amounts are shown in");
   outputString.push_back(
      "separate columns on the chart.  If you had both wages and self-");
   outputString.push_back(
      "employment earnings in the same year, we estimated the taxes as if");
   outputString.push_back(
      "the total amount was wages.  If you had both Social Security");
   outputString.push_back(
      "earnings and government earnings that qualified for Medicare in the");
   outputString.push_back(
      "same year, we estimated the combined Medicare taxes you paid.");
   outputString.push_back("");
   string s = "For ";
   s += poutNoComma(UserAssumptions::getIstart());
   s += " you and your employer each pay Social Security taxes of";
   outputString.push_back(s);
   s = "6.2 percent on the first $";
   s += poutComma(piaParams.getBaseOasdi(UserAssumptions::getIstart()), 5);
   s += " of covered wages.  You each also ";
   outputString.push_back(s);
   outputString.push_back(
      "pay Medicare taxes of 1.45 percent on all your covered wages.  If");
   outputString.push_back(
      "you are self-employed, your Social Security tax is 12.4 percent and");
   outputString.push_back(
      "your Medicare tax is 2.9 percent on the same amounts of earnings.");
   outputString.push_back("");
}
