// $Id: PebsLetter.cpp 1.6 2007/02/28 15:06:41EST 044579 Development  $
//
// Function to write out Social Security Statement letter page.

#include "PebsLetter.h"
#include "comma.h"
#include "FormatString.h"
#include "PiaException.h"
#include "Resource.h"
#include "boost/date_time/gregorian/gregorian.hpp"
#include "DateFormatter.h"

using namespace std;

// Description: Initializes PebsLetter.
//
// Arguments:
//   newWorkerData: Worker data.
//   newFieldOfficeInfo: Field office information.
PebsLetter::PebsLetter( const WorkerData& newWorkerData,
const FieldOfficeInfo& newFieldOfficeInfo ) :
PebsPageOut(), workerData(newWorkerData), fieldOfficeInfo(newFieldOfficeInfo)
{ }

// Description: Destructor.
PebsLetter::~PebsLetter()
{ }

// Description: Prepares letter for printing.
void PebsLetter::prepareStrings()
{
   string s;  // temporary string

   outputString.clear();
   outputString.push_back("");
   outputString.push_back("");
   outputString.push_back("");
   outputString.push_back("");
   for (int i1 = 0; i1 < 4; i1++) {
      if (fieldOfficeInfo.getAddress(i1).length() > 0) {
         s = "                                 ";
         s += fieldOfficeInfo.getAddress(i1);
         outputString.push_back(s);
      }
   }
   s = "                                 ";
   s += DateFormatter::toString(boost::gregorian::day_clock::local_day());
   outputString.push_back(s);
   outputString.push_back("");
   outputString.push_back(workerData.getNhname());
   for (int i1 = 0; i1 < 3; i1++) {
      if (workerData.getNhaddr(i1).length() > 0)
         outputString.push_back(workerData.getNhaddr(i1));
   }
   outputString.push_back("");
   s = "Dear ";
   s += workerData.getNhname();
   s += ":";
   outputString.push_back(s);
   outputString.push_back("");
   outputString.push_back(
      "  We are pleased to send you the Social Security Statement you ");
   outputString.push_back(
      "requested.  We hope it will help you to better understand the Social");
   outputString.push_back(
      "Security program and what it means to you and your family.  The");
   outputString.push_back(
      "statement shows the estimated amount of benefits, under current law,");
   outputString.push_back(
      "that you and your family may be eligible for now and in the future.  It");
   outputString.push_back(
      "also lists the earnings that your employers (or you, if you're self-");
   outputString.push_back(
      "employed) have reported to Social Security.  We hope you will use this");
   outputString.push_back(
      "information along with other information you may have about your savings,");
   outputString.push_back(
      "pensions and investments to help you plan for a secure financial future.");
   outputString.push_back("");
   outputString.push_back(
      "  Remember, Social Security can be an important part of your financial");
   outputString.push_back(
      "future whether you're young or old, male or female, single or married.");
   outputString.push_back(
      "It can help you when you need it most by paying you benefits when you");
   outputString.push_back(
      "retire or if you become severely disabled.  Social Security also can");
   outputString.push_back("help support your family when you die.");
   outputString.push_back("");
   outputString.push_back(
      "  Some people are concerned that Social Security won't be there in the");
   outputString.push_back(
      "future.  The program has changed in the past to meet the demands of the");
   outputString.push_back(
      "times, and it must do so again.  Today we are working to resolve long-");
   outputString.push_back(
      "range financing issues and to ensure that future generations of");
   outputString.push_back(
      "Americans can count on the same financial protections from Social");
   outputString.push_back("Security as past generations did.");
   outputString.push_back("");
   outputString.push_back("");
   outputString.push_back("");
   outputString.push_back("");
   s = "                                 ";
   s += fieldOfficeInfo.getFieldOfficeName();
   outputString.push_back(s);
   outputString.push_back("");
   s = "                                 ";
   s += fieldOfficeInfo.getFieldOfficeTitle();
   outputString.push_back(s);
   outputString.push_back("");
   outputString.push_back("");
}
