// $Id: PebsOasdiEst.cpp 1.7 2003/05/20 10:39:12EDT sfmckay Exp  $
//
// Function to write out Social Security Statement oasdi estimates page.

#include <utility>  // for rel_ops
#include "PebsOasdiEst.h"
#include "UserAssumptions.h"
#include "comma.h"
#include "FormatString.h"
#include "cminmax.h"
#include "PiaException.h"
#include "Resource.h"
#include "PebsOut.h"

using namespace std;
#if !defined(__SGI_STL_INTERNAL_RELOPS)
using namespace std::rel_ops;
#endif

// Description: Initializes PebsOasdiEst.
//
// Arguments:
//   newWorkerData: Worker data.
//   newPebs: Social Security Statement information.
PebsOasdiEst::PebsOasdiEst( const WorkerData& newWorkerData,
const Pebs& newPebs ) : PebsPageOut(),
workerData(newWorkerData), pebs(newPebs)
{ }

// Description: Destructor.
PebsOasdiEst::~PebsOasdiEst()
{ }

// Description: Prepares OASI estimates for printing.
void PebsOasdiEst::prepareStrings()
{
   string::size_type slength;

   outputString.clear();
   prepareHeader(workerData);
   outputString.push_back("Your Estimated Social Security Benefits");
   outputString.push_back(equals);
   outputString.push_back(
      "Your work under Social Security helps you and your family to qualify");
   outputString.push_back(
      "for benefit payments.  The kinds of benefits you might get are");
   outputString.push_back(
      "described below.  For each benefit, you need a certain number of");
   outputString.push_back(
      "work credits (see page 4).  Once you have enough credits, your");
   outputString.push_back(
      "benefit amount depends on your average earnings over your working");
   outputString.push_back(
      "lifetime.  We used the earnings in the chart on page 2 to figure");
   string s = "your credits and estimate your benefits.  We included any ";
   s += poutNoComma(UserAssumptions::getIstart() - 1);
   s += " and ";
   outputString.push_back(s);
   s = poutNoComma(UserAssumptions::getIstart());
   s += " earnings and any estimated future earnings you told us about.";
   outputString.push_back(s);
   outputString.push_back("");
   outputString.push_back("Retirement Benefits");
   outputString.push_back("");
   s = "To get Social Security retirement benefits, you need ";
   s += poutNoComma(pebs.getQcReq(Pebs::PEBS_OAB_DELAYED));
   s += " credits of";
   outputString.push_back(s);
   outputString.push_back(
      "work.  That is also how many you need for Medicare at age 65.  Your");
   s = "record shows that you";
   if (pebs.getQcReq(Pebs::PEBS_OAB_DELAYED) > pebs.getQcTotal())
      s += " do not";
   s += " have enough credits.";
   outputString.push_back(s);
   outputString.push_back("");
   outputString.push_back(
      "On page 5, we explain about different ages when you can retire.  If");
   outputString.push_back(
      "you worked at your present rate up to each retirement age, your");
   outputString.push_back("monthly amount would be about:");
   // early retirement benefit
   if (pebs.getPebsOab() == 3) {
      s = "  At age ";
      s += pebs.agePlan1.toString();
      s += " (reduced benefit) ";
      slength = s.size();
      s += string(65 - slength, '.');
      s += " $";
      s += poutComma(pebs.getBenefitPebs(Pebs::PEBS_OAB_EARLY), 5);
      outputString.push_back(s);
   }
   // normal retirement (or between normal retirement age and 70)
   if (pebs.getPebsOab() > 1) {
      if (pebs.oab1 > pebs.fullRetAge) {
         s = "  At age ";
         s += pebs.oab1.toString();
         s += " ";
      }
      else {
         s = "  At full-retirement age (";
         s += pebs.fullRetAge.toString();
         s += ") ";
      }
      slength = s.size();
      s += string(65 - slength, '.');
      s += " $";
      s += poutComma(pebs.getBenefitPebs(Pebs::PEBS_OAB_FULL), 5);
      outputString.push_back(s);
   }
   // delayed retirement (age 70 or later)
   if (pebs.oab2 > pebs.age70) {
      s = "  At age ";
      s += pebs.oab2.toString();
      s += " ";
   }
   else {
      s = "  At age 70 ";
   }
   slength = s.size();
   s += string(65 - slength, '.');
   s += " $";
   s += poutComma(pebs.getBenefitPebs(Pebs::PEBS_OAB_DELAYED), 5);
   outputString.push_back(s);
   if (pebs.getPebsDib() > 0) {
      outputString.push_back("");
      outputString.push_back("Disability Benefits");
      outputString.push_back("");
      s = "If you become disabled right now, you need ";
      s += poutNoComma(pebs.getQcReq(Pebs::PEBS_DISAB));
      s += " credits to qualify for";
      outputString.push_back(s);
      s = "benefits.  You had to earn ";
      s += poutNoComma(pebs.getQcDisReq());
      s += " of these credits in the last ";
      s += poutNoComma(pebs.getQcDisYears());
      s += " years.";
      outputString.push_back(s);
      s = "Your record shows that you";
      if (pebs.getQcReq(Pebs::PEBS_DISAB) > pebs.getQcTotal() ||
         pebs.getQcDisReq() > pebs.getQcDisTotal())
         s += " do not";
      s += " have enough credits in the ";
      s += poutNoComma(pebs.getQcDisYears());
      s += "-year";
      outputString.push_back(s);
      outputString.push_back("period.");
      outputString.push_back("");
      if (pebs.getQcReq(Pebs::PEBS_DISAB) > pebs.getQcTotal() ||
         pebs.getQcDisReq() > pebs.getQcDisTotal()) {
         outputString.push_back(
            "Because you do not meet both parts of the disability credits");
         outputString.push_back(
            "requirement right now, we are not giving you a benefit estimate.");
         outputString.push_back(
            "If you work in the future and earn enough credits to qualify, we");
         outputString.push_back("will give you a benefit estimate then.");
      }
      else {
         outputString.push_back("If you become disabled right now:");
         s = "  Your monthly benefit would be about ";
         s += string(27, '.');
         s += " $";
         s += poutComma(pebs.getPiaPebs(Pebs::PEBS_DISAB), 5);
         outputString.push_back(s);
         outputString.push_back(
            "  You and your family members who qualify could get up to");
         s = "  a monthly total of about ";
         s += string(38, '.');
         s += " $";
         s += poutComma(pebs.getMfbPebs(Pebs::PEBS_DISAB), 5);
         outputString.push_back(s);
         outputString.push_back(
            "These estimates may be reduced if you get workers' compensation");
         outputString.push_back("or public disability benefits.");
      }
   }
   outputString.push_back("");
   outputString.push_back("Family Benefits");
   outputString.push_back("");
   outputString.push_back(
      "If you get retirement or disability benefits, your spouse and young");
   outputString.push_back("children may also qualify for benefits.");
   outputString.push_back("");
   outputString.push_back("Survivor Benefits");
   outputString.push_back("");
   outputString.push_back(
      "If you die, certain members of your family may qualify for survivor");
   outputString.push_back(
      "benefits on your record.  See page 5 for an explanation of who may");
   outputString.push_back("qualify.");
   outputString.push_back("");
   s = "If you die right now, you need ";
   s += poutNoComma(pebs.getQcReq(Pebs::PEBS_SURV));
   s += " credits for your survivors to get";
   outputString.push_back(s);
   s = "benefits.  Your record shows you";
   if (pebs.getQcReq(Pebs::PEBS_SURV) > pebs.getQcTotal())
      s += " do not";
   s += " have enough.  If they met";
   outputString.push_back(s);
   outputString.push_back(
      "all other requirements, monthly benefit amounts would be about:");
   s = "  For your child ";
   s += string(48, '.');
   s += " $";
   s += poutComma(pebs.getBenefitPebs(Pebs::PEBS_SURV), 5);
   outputString.push_back(s);
   s = "  For your spouse who is caring for your child ";
   s += string(18, '.');
   s += " $";
   s += poutComma(pebs.getBenefitPebs(Pebs::PEBS_SURV), 5);
   outputString.push_back(s);
   s = "  When your spouse reaches full retirement age ";
   s += string(18, '.');
   s += " $";
   s += poutComma(pebs.getPiaPebs(Pebs::PEBS_SURV), 5);
   outputString.push_back(s);
   outputString.push_back(
      "  For all your family members, if others also qualify");
   s = "  (more children, for example) ";
   s += string(34, '.');
   s += " $";
   s += poutComma(pebs.getMfbPebs(Pebs::PEBS_SURV), 5);
   outputString.push_back(s);
   outputString.push_back(
      "We also may be able to pay your spouse or children a one-time death");
   outputString.push_back("benefit of $255.");
}
