// $Id: PebsWorkerInfo.cpp 1.15 2007/03/09 17:10:15EST 044579 Development  $
//
// Function to write out Social Security Statement worker information page.

#include "PebsWorkerInfo.h"
#include "UserAssumptions.h"
#include "comma.h"
#include "FormatString.h"
#include "PiaException.h"
#include "Resource.h"
#include "PebsOut.h"
#include "WageBase.h"
#include "DateFormatter.h"

using namespace std;

// Description: Initializes PebsWorkerInfo.
//
// Arguments:
//   newWorkerData: Basic worker data.
//   newPebs: Social Security Statement data.
//   newPiaParams: Pia calculation parameters.
//   newEarnProject: Projected earnings information.
PebsWorkerInfo::PebsWorkerInfo( const WorkerData& newWorkerData,
const Pebs& newPebs, const PiaParams& newPiaParams,
const EarnProject& newEarnProject ) :
PebsPageOut(), workerData(newWorkerData), pebs(newPebs),
piaParams(newPiaParams), earnProject(newEarnProject)
{ }

// Description: Destructor.
PebsWorkerInfo::~PebsWorkerInfo()
{ }

// Description: Prepares worker information for printing.
void PebsWorkerInfo::prepareStrings()
{
   double earnt;  // temporary earnings

   outputString.clear();
   outputString.push_back("THE FACTS YOU GAVE US");
   outputString.push_back("");
   string s = "Your Name ";
   s += string(61 - workerData.getNhname().length(), '.');
   s += " ";
   s += workerData.getNhname();
   outputString.push_back(s);
   s = "Your Social Security Number ";
   s += string(32, '.');
   s += " ";
   s += workerData.ssn.toString();
   outputString.push_back(s);
   string temp(DateFormatter::toString(workerData.getBirthDate()));
   s = "Your Date of Birth ";
   s += string(52 - temp.length(), '.');
   s += " ";
   s += temp;
   outputString.push_back(s);
   // print two years of lag earnings
   for (int i1 = 1; i1 >= 0; i1--) {
      s = poutNoComma(UserAssumptions::getIstart() - i1);
      s += " Earnings ";
      earnt = earnProject.earnpebs[UserAssumptions::getIstart() - i1];
      if (earnt < .01) {
         s += string(53, '.');
         s += " NONE";
      }
      else if (earnt >=
         piaParams.getBaseOasdi(UserAssumptions::getIstart() - i1)) {
         s += string(45, '.');
         s += " OVER $";
         s += poutComma(piaParams.getBaseOasdi(
            UserAssumptions::getIstart() - i1), 6);
      }
      else {
         s += string(50, '.');
         s += " $";
         s += poutComma(earnt, 6);
      }
      outputString.push_back(s);
   }
   // print future earnings
   s = "Your Estimated Future Yearly Earnings ";
   earnt = earnProject.earnpebs[UserAssumptions::getIstart() + 1];
   if (earnt < .01) {
      s += string(29, '.');
      s += " NONE";
   }
   else if (earnt >=
      piaParams.getBaseOasdi(UserAssumptions::getIstart() + 1)) {
      s += string(21, '.');
      s += " OVER $";
      s += poutComma(piaParams.getBaseOasdi(UserAssumptions::getIstart() + 1),
         6);
   }
   else {
      s += string(26, '.');
      s += " $";
      s += poutComma(earnt, 6);
   }
   outputString.push_back(s);
   s = "The Age You Plan to Retire ";
   if (pebs.getAgePlan()) {
      s += string(42, '.');
      s += " ";
      s += poutNoComma(pebs.getAgePlan2());
   }
   else {
      s += string(32, '.');
      s += " NOT PROVIDED";
   }
   outputString.push_back(s);
   s = "Your Monthly Noncovered Pension ";
   if (workerData.getPubpen() < (float).01) {
      s += string(35, '.');
      s += " NONE";
   }
   else {
      s += string(32, '.');
      s += " $";
      s += poutComma(workerData.getPubpen(), 6);
   }
   outputString.push_back(s);
   if (workerData.getTotalize()) {
      outputString.push_back(
         "Benefits Estimated Using Totalization Provision");
   }
   s = "Processing month ";
   DateMoyr datetemp(pebs.getMonthnow(), UserAssumptions::getIstart());
   s += string(54 - DateFormatter::toString(datetemp).length(), '.');
   s += " ";
   s += DateFormatter::toString(datetemp);
   outputString.push_back(s);
   outputString.push_back("");
}
