// $Id: PiaOut.cpp 1.11 2006/10/19 11:23:28EDT 277133 Development  $
//
// Functions to write out results of benefit calculation.

#include "PiaOut.h"
#include "comma.h"
#include "FormatString.h"
#include "OldStart.h"
#include "PiaTable.h"
#include "WageInd.h"
#include "TransGuar.h"
#include "SpecMin.h"
#include "ReindWid.h"
#include "FrozMin.h"
#include "oactcnst.h"
#include "cminmax.h"
#include "PiaException.h"
#include "Resource.h"
#include "EarnProject.h"
#include "PiadataArray.h"
#include "WorkerDataArray.h"
#include "SecondaryArray.h"

using namespace std;

// Description: Initializes PiaOut.
//
// Arguments:
//   piaCal: Benefit calculation parameters and results.
//   taxData: Taxes paid.
PiaOut::PiaOut( const PiaCalAny& piaCal, const TaxData& taxData ) :
summary1Page(piaCal),
summary2Page(piaCal),
summary3Page(piaCal),
summaryPage(summary1Page, summary2Page, summary3Page),
earningsPage(piaCal),
insuredPage(piaCal),
familyPage(piaCal),
oldStart1Page(piaCal),
oldStart2Page(piaCal),
piaTable1Page(piaCal),
piaTable2Page(piaCal),
wageInd1Page(piaCal),
wageInd2Page(piaCal),
transGuar1Page(piaCal),
transGuar2Page(piaCal),
specMin1Page(piaCal),
specMin2Page(piaCal),
frozMinPage(piaCal),
dibGuarPage(piaCal),
childCareCalc1Page(piaCal),
childCareCalc2Page(piaCal),
taxesPage(piaCal.workerData, piaCal.piaData, taxData),
onePage(piaCal)
{
   for (int i = 0; i < 5; i++) {
      reindWid1Page[i] = new ReindWid1Page(piaCal);
      reindWid2Page[i] = new ReindWid2Page(piaCal);
   }
}

// Description: Destructor.
PiaOut::~PiaOut()
{
   for (int i = 0; i < 5; i++) {
      delete reindWid1Page[i];
      delete reindWid2Page[i];
   }
}

// Description: Prepares strings for printing.
//
// Remarks: This should be called after setPageNum, so the number of
//   reindexed widow(er) calculations will be set.
void PiaOut::prepareStrings()
{
   summary1Page.prepareStrings();
   summary2Page.prepareStrings();
   summary3Page.prepareStrings();
   summaryPage.prepareStrings();
   earningsPage.prepareStrings();
   insuredPage.prepareStrings();
   familyPage.prepareStrings();
   oldStart1Page.prepareStrings();
   oldStart2Page.prepareStrings();
   piaTable1Page.prepareStrings();
   piaTable2Page.prepareStrings();
   wageInd1Page.prepareStrings();
   wageInd2Page.prepareStrings();
   transGuar1Page.prepareStrings();
   transGuar2Page.prepareStrings();
   specMin1Page.prepareStrings();
   specMin2Page.prepareStrings();
   for (int i = 0; i < widowCount; i++) {
      reindWid1Page[i]->prepareStrings();
      reindWid2Page[i]->prepareStrings();
   }
   frozMinPage.prepareStrings();
   dibGuarPage.prepareStrings();
   childCareCalc1Page.prepareStrings();
   childCareCalc2Page.prepareStrings();
   taxesPage.prepareStrings();
   //onePage.prepareStrings();
}

// Description: Fills out page numbers.
//
// Remarks: This should be called before prepareStrings, to set the number of
//   reindexed widow(er) calculations.
//
// Arguments:
//   piaCal: Benefit calculation parameters and results.
void PiaOut::setPageNum( const PiaCalAny& piaCal )
{
   int pageCount = 0;
   summary1Page.setPageNum(++pageCount);
   earningsPage.setPageNum(++pageCount);
   insuredPage.setPageNum(++pageCount);
   if (piaCal.widowArray.getFamSize() > 0) {
      familyPage.setPageNum(++pageCount);
   }
   for (vector< PiaMethod * >::const_iterator iter1 = piaCal.piaMethod.begin();
   iter1 != piaCal.piaMethod.end(); iter1++) {
      switch ((*iter1)->getMethod()) {
      case PiaMethod::OLD_START:
         oldStart1Page.setPageNum(++pageCount);
         oldStart2Page.setPageNum(++pageCount);
         break;
      case PiaMethod::PIA_TABLE:
         piaTable1Page.setPageNum(++pageCount);
         piaTable2Page.setPageNum(++pageCount);
         break;
      case PiaMethod::WAGE_IND:
         wageInd1Page.setPageNum(++pageCount);
         wageInd2Page.setPageNum(++pageCount);
         break;
      case PiaMethod::TRANS_GUAR:
         transGuar1Page.setPageNum(++pageCount);
         transGuar2Page.setPageNum(++pageCount);
         break;
      case PiaMethod::SPEC_MIN:
         specMin1Page.setPageNum(++pageCount);
         specMin2Page.setPageNum(++pageCount);
         break;
      case PiaMethod::FROZ_MIN:
         frozMinPage.setPageNum(++pageCount);
         break;
      case PiaMethod::DIB_GUAR:
         dibGuarPage.setPageNum(++pageCount);
         break;
      case PiaMethod::CHILD_CARE:
         childCareCalc1Page.setPageNum(++pageCount);
         childCareCalc2Page.setPageNum(++pageCount);
      }
   }
   widowCount = (int)piaCal.widowMethod.size();
   for (int i = 0; i < widowCount; i++) {
      reindWid1Page[i]->setPageNum(++pageCount);
      reindWid1Page[i]->reindWid = piaCal.widowMethod[i];
      reindWid2Page[i]->setPageNum(++pageCount);
      reindWid2Page[i]->reindWid = piaCal.widowMethod[i];
   }
   taxesPage.setPageNum(++pageCount);
}
