// $Id: PiaOut.h 1.8 2006/11/08 14:18:50EST 044579 Development  $
//
// Declarations needed for class to manage generic pia program output.

#pragma once

#include "Summary1Page.h"
#include "Summary2Page.h"
#include "Summary3Page.h"
#include "SummaryPage.h"
#include "EarningsPage.h"
#include "InsuredPage.h"
#include "FamilyPage.h"
#include "OldStart1Page.h"
#include "OldStart2Page.h"
#include "PiaTable1Page.h"
#include "PiaTable2Page.h"
#include "WageInd1Page.h"
#include "WageInd2Page.h"
#include "TransGuar1Page.h"
#include "TransGuar2Page.h"
#include "SpecMin1Page.h"
#include "SpecMin2Page.h"
#include "ReindWid1Page.h"
#include "ReindWid2Page.h"
#include "FrozMinPage.h"
#include "ChildCareCalc1Page.h"
#include "ChildCareCalc2Page.h"
#include "TaxesPage.h"
#include "OnePage.h"
#include "DibGuarPage.h"
class TaxData;
class PiaCalAny;

// {group:PiaOut Classes}
// Description: Manages all of the print output functions used in
//   the calculation of a Social Security benefit.
//
// Remarks: Manages all of the print output functions used in
//   the calculation of a Social Security benefit.
class PiaOut
{
   protected:
      // Number of reindexed widow(er) calculations.
      int widowCount;
   public:
      // Top part of summary page.
      Summary1Page summary1Page;
      // Middle part of summary page.
      Summary2Page summary2Page;
      // Bottom part of summary page.
      Summary3Page summary3Page;
      // Summary page of results.
      SummaryPage summaryPage;
      // Earnings used in calculation.
      EarningsPage earningsPage;
      // Insured status calculation.
      InsuredPage insuredPage;
      // Family members calculation.
      FamilyPage familyPage;
      // Old-start earnings.
      OldStart1Page oldStart1Page;
      // Old-start calculation.
      OldStart2Page oldStart2Page;
      // Pia table earnings.
      PiaTable1Page piaTable1Page;
      // Pia table calculation.
      PiaTable2Page piaTable2Page;
      // Wage-indexed earnings.
      WageInd1Page wageInd1Page;
      // Wage-indexed calculation.
      WageInd2Page wageInd2Page;
      // Transitional guarantee earnings.
      TransGuar1Page transGuar1Page;
      // Transitional guarantee calculation.
      TransGuar2Page transGuar2Page;
      // Special minimum earnings.
      SpecMin1Page specMin1Page;
      // Special minimum calculation.
      SpecMin2Page specMin2Page;
      // Re-indexed widow guarantee earnings.
      ReindWid1Page* reindWid1Page[5];
      // Re-indexed widow guarantee calculation.
      ReindWid2Page* reindWid2Page[5];
      // Frozen minimum calculation.
      FrozMinPage frozMinPage;
      // Disability guarantee calculation.
      DibGuarPage dibGuarPage;
      // Wage-indexed earnings with child-care dropout years.
      ChildCareCalc1Page childCareCalc1Page;
      // Wage-indexed calculation with child-care dropout years.
      ChildCareCalc2Page childCareCalc2Page;
      // Taxes calculation.
      TaxesPage taxesPage;
      // One-page output.
      OnePage onePage;
   public:
      PiaOut( const PiaCalAny& piaCal, const TaxData& taxData );
      virtual ~PiaOut();
      void   prepareStrings();
      void   setPageNum( const PiaCalAny& piaCal );
};
