// $Id: PiaPageOut.h 1.15 2006/01/05 15:34:08EST 044579 Exp  $
//
// Declarations needed for class to manage generic pia program output.

#pragma once

#include "PageOut.h"
#include "PiaMethod.h"
class WageIndGeneral;

// {group:PiaOut Classes}
// Description: Manages all of the print output functions used in
//   the calculation of a Social Security benefit.
//
// Remarks: Manages all of the print output functions used in
//   the calculation of a Social Security benefit.
class PiaPageOut : public PageOut
{
protected:
   // Description: Page number.
   int pageNum;
   // Description: Title at top of page.
   std::string pageTitle[2];
   // Description: Years of Social Security Acts.
   static const char *tableLabel[10];
   // Description: Warning for totalization benefit (less than 6 qcs, or
   // insured).
   static const std::string warnTotalization;
protected:
   static PiaMethod::cpi_year_type endYearCal( int type );
   static PiaMethod::cpi_year_type firstYearCal( int type );
public:
   PiaPageOut();
   virtual ~PiaPageOut();
   void baseYearOut( int year );
   void biOut( const PiaMethod& piaMethod, const PiaParams& piaParams,
      int eligYear, int type, int piamfb );
   void biOut( const PiaMethod& piaMethod, const PiaParams& piaParams,
      int eligYear, int firstYear, int lastYear, int piamfb );
   void compYear( const WorkerDataGeneral& workerData, const PiaData& piaData,
      const CompPeriod& compPeriod );
   void disInsOut( const PiaData& piaData );
   void disMfbOut( double capt, double amepia, BenefitAmount mfbt );
   void mfbBpOut( const BendMfb& bendMfb );
   void mfbOut( const PiaMethod& piaMethod, const double portionPiaElig[],
      const PercMfb& percMfb, double aime );
   void mfbOut( const PiaMethod& piaMethod, const double portionPiaElig[],
      const PercMfb& percMfb );
   void newTableOut( const PiaMethod&, const PiaParams& piaParams,
      int eligYear, int firstYear, int lastYear, int piamfb );
   void nonIns( char finsCode );
   void nonpenOut( double pubpen, const DateMoyr& pubpenDate );
   void osTableOut( const PiaMethod& piaMethod );
   void piaBpOut ( const BendPia& bendPia );
   void piaEligOut ( const PercPia& percPia, const double portionAime[],
      BenefitAmount piaTemp );
   void piaEntOut( BenefitAmount piaentt );
   void piamfb1( const PiaMethod& piaMethod );
   void piamfb2( const PiaMethod& piaMethod );
   void piamfb3( const PiaMethod& piaMethod );
   void prepareHeader();
   void printIndexedEarningsTable( const WageIndGeneral& wageInd,
      const PiaData& piaData, int eligYear, const AverageWage& earnings,
      int firstYear );
   void printNameSsn( const WorkerDataGeneral& workerData );
   void printRealWageGain( int eligYear, int istart,
      const PiaMethod& piaMethod, BenefitAmount rwgpia, BenefitAmount rwgmfb );
   void pubPenOut( const WageIndGeneral& wageInd, double pubpen,
      const DateMoyr& pubpenDate );
   void rawPiaOut( BenefitAmount rawpia );
   // Description: Sets page number.
   //
   // Arguments:
   //   newPageNum: New page number.
   void setPageNum( int newPageNum ) { pageNum = newPageNum; }
   void tableHead1( double avgbsyr );
   void tableHead2();
   void totPiaOut( const PiaMethod& piaMethod, int qcTotal, int n );
};
