// $Id: PiaTable1Page.cpp 1.11 2006/01/05 15:34:08EST 044579 Exp  $
//
// Function to write out pia table calculation.

#include "PiaTable1Page.h"
#include "PiaTable.h"
#include "comma.h"
#include "FormatString.h"
#include "PiaException.h"
#include "Resource.h"

using namespace std;

// Description: Initializes PiaTable1Page.
//
// Arguments:
//   newPiaCal: Benefit calculation parameters and results.
PiaTable1Page::PiaTable1Page( const PiaCalAny& newPiaCal ) : PiaPageOut(),
workerData(newPiaCal.workerData), piaData(newPiaCal.piaData),
piaParams(newPiaCal.piaParams), piaCal(newPiaCal)
{ }

// Description: Destructor.
PiaTable1Page::~PiaTable1Page()
{ }

// Description: Prepares pia table strings for printing.
void PiaTable1Page::prepareStrings()
{
   try {
      const PiaTable* piaTable = piaCal.piaTable;
      if (piaTable != (const PiaTable*)0 && piaTable->getApplicable() > 0) {
         pageTitle[0] = piaTable->getTitle();
         outputString.clear();
         const AverageWage& earnings = workerData.getTotalize() ?
            piaData.earnTotalizedLimited : piaData.earnOasdiLimited;
         prepareHeader();
         tableHead2();
         for (int i1 = piaData.getEarn50(PiaData::EARN_WITH_TOTALIZATION);
            i1 <= piaData.getEarnYear(); ++i1) {
            string s = poutNoComma(i1);
            s += poutComma(earnings[i1], 14, 2);
            if (piaTable->iorder[i1] > 0)
               s += poutComma(piaTable->earnIndexed[i1], 14, 2);
            outputString.push_back(s);
         }
         outputString.push_back("");
         // print noninsured message
         nonIns(piaData.getFinsCode2());
         if (workerData.getJoasdi() == WorkerDataGeneral::DISABILITY)
            disInsOut(piaData);
         outputString.push_back("");
         printNameSsn(workerData);
      }
   } catch (PiaException&) {
      throw PiaException(PIA_IDS_PTSTRING);
   }
}
