// $Id: PiaTable2Page.cpp 1.10 2006/01/05 15:34:08EST 044579 Exp  $
//
// Function to write out pia table calculation.

#include "PiaTable2Page.h"
#include "PiaTable.h"
#include "comma.h"
#include "FormatString.h"
#include "cminmax.h"
#include "PiaException.h"
#include "Resource.h"

using namespace std;

// Description: Initializes PiaTable2Page.
//
// Arguments:
//   newPiaCal: Benefit calculation parameters and results.
PiaTable2Page::PiaTable2Page( const PiaCalAny& newPiaCal ) : PiaPageOut(),
workerData(newPiaCal.workerData), piaData(newPiaCal.piaData),
piaParams(newPiaCal.piaParams), piaCal(newPiaCal)
{ }

// Description: Destructor.
PiaTable2Page::~PiaTable2Page()
{ }

// Description: Prepares pia table strings for printing.
void PiaTable2Page::prepareStrings()
{
   try {
      const PiaTable* piaTable = piaCal.piaTable;
      if (piaTable != (const PiaTable*)0 && piaTable->getApplicable() > 0) {
         pageTitle[0] = piaTable->getTitle();
         outputString.clear();
         prepareHeader();
         compYear(workerData, piaData, piaData.compPeriodNew);
         int entYear = piaTable->getCpiYear(PiaMethod::YEAR_ENT);
         int benYear = piaTable->getCpiYear(PiaMethod::YEAR_BEN);
         int firstYear = piaTable->getCpiYear(PiaMethod::FIRST_YEAR);
         int tableYear = piaTable->getCpiYear(PiaMethod::YEAR_TABLE);
         string s = "AME = ";
         s += poutComma(piaTable->getftearn(), 4, 2);
         s += "/(";
         s += poutNoComma(piaData.compPeriodNew.getN());
         s += "*12) = ";
         s += poutComma(piaTable->getAme());
         outputString.push_back(s);
         outputString.push_back("");
         osTableOut(*piaTable);
         if (entYear >= firstYear) {
            piamfb3(*piaTable);
            if (tableYear >= firstYear) {
               if (entYear <= tableYear) {
                  newTableOut(*piaTable, piaParams, piaData.getEligYear(), 
                     firstYear, entYear, 3);
               } else {
                  newTableOut(*piaTable, piaParams, piaData.getEligYear(), 
                     firstYear, tableYear, 3);
                  biOut(*piaTable, piaParams, piaData.getEligYear(), 
                     tableYear + 1, entYear, 3);
                  if (benYear > entYear) {
                     piamfb1(*piaTable);
                     biOut(*piaTable, piaParams, piaData.getEligYear(), 2, 3);
                  }
               }
            } else {
               biOut(*piaTable, piaParams, piaData.getEligYear(), 0, 3);
               if (benYear > entYear) {
                  piamfb1(*piaTable);
                  biOut(*piaTable, piaParams, piaData.getEligYear(), 2, 3);
               }
            }
         } else {
            if (benYear >= firstYear) {
               piamfb3(*piaTable);
               if (tableYear >= firstYear) {
                  newTableOut(*piaTable, piaParams, piaData.getEligYear(), 
                     firstYear, tableYear, 3);
                  if (benYear > tableYear) {
                     biOut(*piaTable, piaParams, piaData.getEligYear(), 
                        tableYear + 1, benYear, 3);
                  }
               } else {
                  biOut(*piaTable, piaParams, piaData.getEligYear(), 3, 3);
               }
            }
         }
         if (workerData.getTotalize()) {
            totPiaOut(*piaTable, piaData.getQcTotal(),
               piaData.compPeriodNew.getN());
         }
         piamfb2(*piaTable);
         // print noninsured message
         nonIns(piaData.getFinsCode2());
         if (workerData.getJoasdi() == WorkerDataGeneral::DISABILITY)
            disInsOut(piaData);
         outputString.push_back("");
         printNameSsn(workerData);
      }
   } catch (PiaException e) {
      throw PiaException(PIA_IDS_PTSTRING);
   }
}
