// $Id: ReindWid2Page.cpp 1.21 2007/02/28 15:06:41EST 044579 Development  $
//
// Function to write out re-indexed widow calculation.

#include "ReindWid2Page.h"
#include "ReindWid.h"
#include "comma.h"
#include "FormatString.h"
#include "PiaException.h"
#include "Resource.h"
#include "UserAssumptions.h"
#include "DateFormatter.h"

using namespace std;

// Description: Initializes ReindWid2Page.
//
// Arguments:
//   newPiaCal: Benefit calculation parameters and results.
ReindWid2Page::ReindWid2Page( const PiaCalAny& newPiaCal ) :
PiaPageOut(), workerData(newPiaCal.workerData), piaData(newPiaCal.piaData),
piaParams(newPiaCal.piaParams), piaCal(newPiaCal),
userAssumptions(newPiaCal.userAssumptions)
{ }

// Description: Destructor.
ReindWid2Page::~ReindWid2Page()
{ }

// Description: Prepares reindexed widow strings for printing.
void ReindWid2Page::prepareStrings()
{
   try {
      string s;  // temporary string
      if (reindWid != (const ReindWid*)0 && reindWid->getApplicable() > 0) {
         const WorkerDataGeneral& widowData = reindWid->widowData;
         const Secondary& secondary = reindWid->secondary;
         pageTitle[0] = reindWid->getTitle();
         outputString.clear();
         prepareHeader();
         outputString.push_back("Widow(er) information:");
         printNameSsn(widowData);
         AfxFormatString1(s, PIA_IDS_DOBOUT,
            DateFormatter::toString(widowData.getBirthDate()));
         outputString.push_back(s);
         outputString.push_back("");
         if (secondary.bic.getMajorBic() == 'W') {
            AfxFormatString1(s, PIA_IDS_WIDDIBOUT,
               DateFormatter::toString(widowData.disabPeriod[0].getOnsetDate()));
            outputString.push_back(s);
            outputString.push_back("");
         }
         baseYearOut(reindWid->getEligYear() - 2);
         compYear(workerData, piaData, piaData.compPeriodNew);
         s = "AIME = ";
         s += poutComma(reindWid->getftearn(), 4, 2);
         s += "/(";
         s += poutNoComma(piaData.compPeriodNew.getN());
         s += "*12) = ";
         s += poutComma(reindWid->getAme());
         outputString.push_back(s);
         outputString.push_back("");
         piaBpOut(reindWid->bendPia);
         piaEligOut(reindWid->percPia, reindWid->portionAime,
            reindWid->piaElig[reindWid->getCpiYear(PiaMethod::FIRST_YEAR)]);
         if (reindWid->getCpiYear(PiaMethod::YEAR_ENT) >=
            reindWid->getCpiYear(PiaMethod::YEAR_ELIG)) {
            biOut(*reindWid, piaParams, reindWid->getEligYear(), 1, 3);
         }
         if (reindWid->getCpiYear(PiaMethod::YEAR_BEN) >
            reindWid->getCpiYear(PiaMethod::YEAR_ENT)) {
            biOut(*reindWid, piaParams, reindWid->getEligYear(), 2, 3);
         }
         if (reindWid->getEligYear() > UserAssumptions::getIstart() &&
            userAssumptions.getIaltaw() == AssumptionType::PEBS_ASSUM) {
            printRealWageGain(reindWid->getEligYear(),
               UserAssumptions::getIstart(), *reindWid,
               reindWid->piaRealWageGain, reindWid->mfbRealWageGain);
         }
         piaEntOut(reindWid->piaEnt);
         outputString.push_back("");
         outputString.push_back(
            "MFB at entitlement = (same as for wage-indexed)");
         // print noninsured message
         nonIns(piaData.getFinsCode2());
         if (workerData.getJoasdi() == WorkerDataGeneral::DISABILITY)
            disInsOut(piaData);
         outputString.push_back("");
         printNameSsn(workerData);
      }
   } catch (PiaException&) {
      throw PiaException(PIA_IDS_RWSTRING);
   }
}
