// $Id: SpecMin1Page.cpp 1.12 2006/11/08 11:06:28EST 044579 Development  $
//
// Function to write out special minimum calculation.

#include "SpecMin1Page.h"
#include "SpecMin.h"
#include "comma.h"
#include "FormatString.h"
#include "PiaException.h"
#include "Resource.h"
#include "piaparms.h"
#include "oactcnst.h"

using namespace std;

// Description: Initializes SpecMin1Page.
//
// Arguments:
//   newPiaCal: Benefit calculation parameters and results.
SpecMin1Page::SpecMin1Page( const PiaCalAny& newPiaCal ) : PiaPageOut(),
workerData(newPiaCal.workerData), piaData(newPiaCal.piaData),
piaParams(newPiaCal.piaParams), piaCal(newPiaCal)
{ }

// Description: Destructor.
SpecMin1Page::~SpecMin1Page()
{ }

// Description: Prepares special minimum strings for printing.
void SpecMin1Page::prepareStrings()
{
   string s;  // temporary string

   try {
      const SpecMin* specMin = (const SpecMin*)piaCal.specMin;
      if (specMin != (SpecMin*)0 && specMin->getApplicable() > 0) {
         pageTitle[0] = specMin->getTitle();
         outputString.clear();
         prepareHeader();
         outputString.push_back("                     percent of");
         outputString.push_back("                       old-law");
         outputString.push_back(
            "                        base      required   years of");
         outputString.push_back(
            "year      earnings    required    earnings   coverage");
         outputString.push_back("");
         s = "1937-50 ";
         s += poutComma(piaData.getEarnTotal50(PiaData::EARN_NO_TOTALIZATION),
            10, 2);
         s += "                              ";
         s += poutNoComma(specMin->iorder[YEAR50], 2);
         outputString.push_back(s);
         int i3 = min(workerData.getIend(), piaData.getEarnYear());
         for (int i1 = piaData.getEarn50(PiaData::EARN_NO_TOTALIZATION);
            i1 <= i3; ++i1) {
            s = poutNoComma(i1);
            s += poutComma(piaData.earnOasdiLimited[i1], 14, 2);
            s += poutComma(piaParams.getPercSpecMin(i1), 10, 2);
            s += poutComma(piaParams.getYocAmountSpecMin(i1), 14, 2);
            s += poutNoComma(specMin->iorder[i1], 8);
            outputString.push_back(s);
         }
         outputString.push_back("");
         // print noninsured message
         nonIns(piaData.getFinsCode2());
         if (workerData.getJoasdi() == WorkerDataGeneral::DISABILITY)
            disInsOut(piaData);
         outputString.push_back("");
         printNameSsn(workerData);
      }
   } catch (PiaException&) {
      throw PiaException(PIA_IDS_SMSTRING);
   }
}
