// $Id: SpecMin2Page.cpp 1.14 2006/01/05 15:34:09EST 044579 Exp  $
//
// Function to write out special minimum calculation.

#include "SpecMin2Page.h"
#include "SpecMin.h"
#include "comma.h"
#include "FormatString.h"
#include "cminmax.h"
#include "PiaException.h"
#include "Resource.h"
#include "piaparms.h"

using namespace std;

// Description: Initializes SpecMin1Page.
//
// Arguments:
//   newPiaCal: Benefit calculation parameters and results.
SpecMin2Page::SpecMin2Page( const PiaCalAny& newPiaCal ) : PiaPageOut(),
workerData(newPiaCal.workerData), piaData(newPiaCal.piaData),
piaParams(newPiaCal.piaParams), piaCal(newPiaCal)
{ }

// Description: Destructor.
SpecMin2Page::~SpecMin2Page()
{ }

// Description: Prepares special minimum strings for printing.
void SpecMin2Page::prepareStrings()
{
   string s;  // temporary string

   try {
      const SpecMin* specMin = (const SpecMin*)piaCal.specMin;
      if (specMin != (SpecMin*)0 && specMin->getApplicable() > 0) {
         pageTitle[0] = specMin->getTitle();
         outputString.clear();
         prepareHeader();
         s = "Years of coverage = ";
         s += poutNoComma(specMin->getYearsTotal());
         outputString.push_back(s);
         outputString.push_back("");
         s = "Years of coverage over 10 (maximum 20) = ";
         s += poutNoComma(specMin->getSpecMinYearsExcess());
         outputString.push_back(s);
         outputString.push_back("");
         s = "Amount per year = ";
         s += poutComma(specMin->getSpecMinAmount(), 3, 2);
         outputString.push_back(s);
         outputString.push_back("");
         if (!(workerData.getBenefitDate() < piaParams.amend772)) {
            s = "January 1979 PIA = ";
            s += poutNoComma(specMin->getSpecMinYearsExcess());
            s += " * ";
            s += poutComma(specMin->getSpecMinAmount(), 3, 2);
            s += " = ";
            s += BenefitAmount(specMin->piaElig[specMin->getCpiYear(
               PiaMethod::FIRST_YEAR)]).toString();
            outputString.push_back(s);
            outputString.push_back("");
            if (specMin->getCpiYear(PiaMethod::YEAR_BEN) >=
               specMin->getCpiYear(PiaMethod::YEAR_ELIG)) {
               s = "MFB in January 1979 = ";
               s += BenefitAmount(specMin->mfbElig[specMin->getCpiYear(
                  PiaMethod::FIRST_YEAR)]).toString();
               outputString.push_back(s);
               outputString.push_back("");
               if (specMin->getCpiYear(PiaMethod::YEAR_ENT) >=
                  specMin->getCpiYear(PiaMethod::YEAR_ELIG)) {
                  biOut(*specMin, piaParams, piaData.getEligYear(), 1, 3);
               }
               if (specMin->getCpiYear(PiaMethod::YEAR_BEN) >
                  specMin->getCpiYear(PiaMethod::YEAR_ENT)) {
                  piamfb1(*specMin);
                  biOut(*specMin, piaParams, piaData.getEligYear(), 2, 3);
               }
            }
            piamfb2(*specMin);
         }
         else {
            s = "PIA = ";
            s += poutNoComma(specMin->getSpecMinYearsExcess());
            s += " * ";
            s += poutComma(specMin->getSpecMinAmount(), 4, 2);
            s += " = ";
            s += specMin->piaEnt.toString();
            outputString.push_back(s);
            outputString.push_back("");
            s = "MFB = ";
            s += specMin->mfbEnt.toString();
            outputString.push_back(s);
            outputString.push_back("");
         }
         // print noninsured message
         nonIns(piaData.getFinsCode2());
         if (workerData.getJoasdi() == WorkerDataGeneral::DISABILITY)
            disInsOut(piaData);
         outputString.push_back("");
         printNameSsn(workerData);
      }
   } catch (PiaException e) {
      throw PiaException(PIA_IDS_SMSTRING);
   }
}
