// $Id: Summary2Page.cpp 1.8 2003/05/20 10:39:15EDT sfmckay Exp  $
//
// Functions to write out middle part of summary page of results.

#include "Summary2Page.h"
#include "comma.h"
#include "Resource.h"
#include "FormatString.h"
#include "PiaException.h"

using namespace std;

// Description: Initializes Summary2Page.
//
// Arguments:
//   newPiaCal: Benefit calculation parameters and results.
Summary2Page::Summary2Page( const PiaCalAny& newPiaCal ) : PageOut(),
workerData(newPiaCal.workerData), piaData(newPiaCal.piaData), piaCal(newPiaCal)
{ }

// Description: Destructor.
Summary2Page::~Summary2Page()
{ }

// Description: Prepares middle part of summary page.
void Summary2Page::prepareStrings()
{
   string s;  // temporary string

   try {
      outputString.clear();
      for (vector< PiaMethod * >::const_iterator iter = piaCal.piaMethod.begin();
      iter != piaCal.piaMethod.end(); iter++) {
         outputString.push_back("");
         outputString.push_back((*iter)->getTitle());
         if ((*iter)->getApplicable()) {
            AfxFormatString1(s, PIA_IDS_PIAOUT, (*iter)->piaEnt.toString());
            outputString.push_back(s);
            AfxFormatString1(s, PIA_IDS_MFBOUT, (*iter)->mfbEnt.toString());
            outputString.push_back(s);
         }
         else
            outputString.push_back("   Not applicable");
      }
      outputString.push_back("");
      outputString.push_back("");
      outputString.push_back("");
      outputString.push_back("");
      switch (piaData.getIappn())
      {
      case PiaMethod::OLD_START:
      case PiaMethod::PIA_TABLE:
      case PiaMethod::TRANS_GUAR:
         AfxFormatString1(s, PIA_IDS_AMEOUT,
            poutComma(piaCal.highPiaMethod->getAme(), 8));
         outputString.push_back(s);
         break;
      case PiaMethod::WAGE_IND:
      case PiaMethod::REIND_WID:
         AfxFormatString1(s, PIA_IDS_AIMEOUT,
            poutComma(piaCal.highPiaMethod->getAme(), 8));
         outputString.push_back(s);
         break;
      case PiaMethod::SPEC_MIN:
         AfxFormatString1(s, PIA_IDS_SPYRSOUT, poutNoComma(
            piaCal.highPiaMethod->getYearsTotal(), 8));
         outputString.push_back(s);
      }
      AfxFormatString1(s, PIA_IDS_PIALOUT, piaData.highPia.toString());
      outputString.push_back(s);
      // print support PIA, if applicable
      if (piaData.getArfApp() > 0) {
         AfxFormatString1(s, PIA_IDS_SUPPIAOUT,
            piaData.supportPia.toString());
         outputString.push_back(s);
      }
      if (workerData.getJoasdi() != WorkerDataGeneral::SURVIVOR) {
         if (piaData.getArf() >= 1.0) {
            AfxFormatString1(s, PIA_IDS_DRCMOUT,
               poutNoComma(piaData.getMonthsArdri(), 8));
            outputString.push_back(s);
            AfxFormatString1(s, PIA_IDS_DRCFOUT,
               poutNoComma(piaData.getArf(), 8, 3));
            outputString.push_back(s);
         }
         else {
            AfxFormatString1(s, PIA_IDS_ARFMOUT,
               poutNoComma(piaData.getMonthsArdri(), 8));
            outputString.push_back(s);
            AfxFormatString1(s, PIA_IDS_ARFFOUT,
               poutNoComma(piaData.getArf(), 8, 3));
            outputString.push_back(s);
         }
         AfxFormatString1(s, PIA_IDS_BEN1OUT, piaData.benefit.toString());
         outputString.push_back(s);
         AfxFormatString1(s, PIA_IDS_BEN2OUT,
            piaData.roundedBenefit.toString());
         outputString.push_back(s);
      }
      if (piaData.getArfApp() > 0) {
         AfxFormatString1(s, (piaData.getArfApp() == 1) ?
            PIA_IDS_SPPIA1OUT : PIA_IDS_SPPIA2OUT, "");
         outputString.push_back(s);
      }
      AfxFormatString1(s, PIA_IDS_MFBLOUT, piaData.highMfb.toString());
      outputString.push_back(s);
      outputString.push_back("");
      outputString.push_back("");
      outputString.push_back("");
   } catch (PiaException e) {
      throw PiaException(PIA_IDS_TWOPAGE4);
   }
}
