// $Id: Summary3Page.cpp 1.13 2008/04/25 13:01:43EDT 277133 Development  $
//
// Functions to write out bottom part of summary page of results.

#include "Summary3Page.h"
#include "comma.h"
#include "Resource.h"
#include "FormatString.h"
#include "PiaException.h"
#include "piaparms.h"
#include "UserAssumptions.h"
#include "EarnProject.h"

using namespace std;

// Description: Initializes Summary3Page.
//
// Arguments:
//   newPiaCal: Benefit calculation parameters and results.
Summary3Page::Summary3Page( const PiaCalAny& newPiaCal ) : PiaPageOut(),
workerData(newPiaCal.workerData), piaData(newPiaCal.piaData), piaCal(newPiaCal),
userAssumptions(newPiaCal.userAssumptions), earnProject(newPiaCal.earnProject),
biProj(false),awiProj(false)
{ }

// Description: Destructor.
Summary3Page::~Summary3Page()
{ }

// Description: Prepares bottom part of summary page.
void Summary3Page::prepareStrings()
{
   string s;  // temporary output string
   biProj = false;
   awiProj = false;
   outputString.clear();
   try {
      const PiaParams& piaParams = piaCal.piaParams;
      if (workerData.need_bi(UserAssumptions::getIstart())) {
         biProj = true;
         // benefit increase assumptions
         AfxFormatString1(s, PIA_IDS_BIOUT, "");
         outputString.push_back(s);
         outputString.push_back(piaParams.getBenefitInc());
      }
      if (workerData.need_aw(UserAssumptions::getIstart(),
         earnProject.need_aw(UserAssumptions::getIstart(),
         workerData.getIend()))) {
         awiProj = true;
         // average wage assumptions
         AfxFormatString1(s, PIA_IDS_AWOUT, "");
         outputString.push_back(s);
         outputString.push_back(piaParams.getAverageWage());
      }
      // print noninsured paragraph
      nonInsPara();
      if (workerData.getJoasdi() == WorkerDataGeneral::DISABILITY) {
         outputString.push_back("");
         disInsOut(piaData);
      }
      disclaimer();
      outputString.push_back("");
   } catch (PiaException e) {
      throw PiaException(PIA_IDS_TWOPAGE5);
   }
}

// Description: Prints noninsured paragraph.
void Summary3Page::nonInsPara()
{
   string s;  // temporary string

   const char *heshe = workerData.isMale() ? "he" : "she";
   switch (piaData.getFinsCode2())
   {
   case '2':
      outputString.push_back("");
      outputString.push_back(
      "This estimate may be theoretical because the worker is currently");
      outputString.push_back("insured but not fully insured.");
      s = "A total of ";
      s += poutNoComma(piaData.getQcReq());
      s += " quarters are needed; ";
      s += heshe;
      s += " has only ";
      s += poutNoComma(piaData.getQcTotal());
      s += ".";
      outputString.push_back(s);
      break;
   case '4':
      outputString.push_back("");
      outputString.push_back(
      "This estimate is theoretical because the worker is not fully insured.");
      s = "A total of ";
      s += poutNoComma(piaData.getQcReq());
      s += " quarters are needed; ";
      s += heshe;
      s += " has only ";
      s += poutNoComma(piaData.getQcTotal());
      s += ".";
      outputString.push_back(s);
      break;
   case '5':
      outputString.push_back("");
      outputString.push_back(
      "This estimate is theoretical because the worker is not fully or");
      s = "currently insured. A total of ";
      s += poutNoComma(piaData.getQcReq());
      s += " quarters are needed for fully insured";
      outputString.push_back(s);
      s = "status; ";
      s += heshe;
      s += " has only ";
      s += poutNoComma(piaData.getQcTotal());
      s += ". A total of 6 quarters are needed for ";
      outputString.push_back(s);
      s = "currently insured status; ";
      s += heshe;
      s += " has only ";
      s += poutNoComma(piaData.getQcCurrent());
      s += ".";
      outputString.push_back(s);
      break;
   case '6':
      outputString.push_back("");
      outputString.push_back(
      "This estimate is theoretical because 6 quarters are needed to be");
      s = "eligible for a totalization benefit; the worker has only ";
      s += poutNoComma(piaData.getQcTotal());
      s += ".";
      outputString.push_back(s);
      break;
   case '7':
      outputString.push_back("");
      outputString.push_back(
      "This estimate is theoretical because the worker is fully insured.");
      s = "The worker must have fewer than ";
      s += poutNoComma(piaData.getQcReq());
      s += " quarters; ";
      s += heshe;
      s += " has ";
      s += poutNoComma(piaData.getQcTotal());
      s += ".";
      outputString.push_back(s);
      break;
   default:
      break;
   }
}

// Description: Prints bottom of summary.
//
// Arguments:
//   isPebs: True if old PEBES assumptions, false otherwise.
void Summary3Page::bottom3( bool isPebs )
{
   outputString.push_back("");
   outputString.push_back(
      "The estimates on this statement are based on your earnings");
   outputString.push_back(
      "record and any information you gave us.  We used current");
   if (isPebs) {
      outputString.push_back(
         "dollar values for these estimates.  We adjusted all future");
      outputString.push_back(
         "estimates to account for average wage growth in the national");
      outputString.push_back(
         "economy by increasing your benefit by 1 percent for each");
      outputString.push_back(
         "year between now and when you turn age 62.");
   }
   else
      outputString.push_back("dollar values for these estimates.");
}

// Description: Prints disclaimer.
//
// Remarks: The disclaimer mentions that the benefit is an estimate, 
//   and varies slightly depending on the economic assumptions used,
//   if any.  
void Summary3Page::disclaimer()
{
   outputString.push_back("");
   if ((awiProj == false || AssumptionType::isFlatOrPebs(userAssumptions.getIaltaw())) && 
       (biProj == false || AssumptionType::isFlatOrPebs(userAssumptions.getIaltbi()))) {
     if (userAssumptions.getIaltaw() == AssumptionType::PEBS_ASSUM) {
        outputString.push_back(
          "The estimates on this statement are based on your earnings");
        outputString.push_back(
          "record and any information you gave us.  We used current");
        outputString.push_back(
          "dollar values for these estimates.  We adjusted all future");
        outputString.push_back(
          "estimates to account for average wage growth in the national");
        outputString.push_back(
          "economy by increasing your benefit by 1 percent for each");
        outputString.push_back(
          "year between now and when you turn age 62.");
     } else {
        outputString.push_back(
          "The estimates on this statement are based on your earnings");
        outputString.push_back(
          "record and any information you gave us.  We used current");
        outputString.push_back("dollar values for these estimates.");
     }
   } else {
      outputString.push_back(
        "The estimates we gave are based on your earnings record and any infor-");
      outputString.push_back(
        "mation you gave us.  The estimate provided could change--it could");
      outputString.push_back(
        "increase or decrease--depending on your actual future earnings,");
      outputString.push_back(
        "future changes in the average wages of all employed persons, and on");
      outputString.push_back("future rates of inflation.");
   }
}
