// $Id: TaxesPage.cpp 1.11 2006/11/08 11:06:29EST 044579 Development  $
//
// Function to write out taxes page.

#include "TaxesPage.h"
#include "comma.h"
#include "FormatString.h"
#include "PiaException.h"
#include "Resource.h"

using namespace std;

// Description: Initializes TaxesPage.
//
// Arguments:
//   newWorkerData: Worker basic data.
//   newPiaData: Benefit calculation data.
//   newTaxData: Taxes paid.
TaxesPage::TaxesPage( const WorkerDataGeneral& newWorkerData,
const PiaData& newPiaData, const TaxData& newTaxData ) :
PiaPageOut(), workerData(newWorkerData), piaData(newPiaData),
taxData(newTaxData)
{ }

// Description: Destructor.
TaxesPage::~TaxesPage()
{ }

// Description: Prepares taxes strings for printing.
void TaxesPage::prepareStrings()
{
   try {
      outputString.clear();
      pageTitle[0] = "Taxes paid";
      prepareHeader();
      outputString.push_back("year      Earnings      OASI        DI        "
         "OASDI       HI       OASDHI");
      outputString.push_back("");
      if (workerData.getIndearn()) {
         int i1;  // loop counter
         string s;  // temporary string
         for (i1 = workerData.getIbegin(); i1 <= workerData.getIend(); i1++) {
            s = poutNoComma(i1);
            s += poutComma(piaData.earnOasdiLimited[i1], 14, 2);
            s += poutComma(taxData.taxesOasi[i1], 11, 2);
            s += poutComma(taxData.taxesDi[i1], 11, 2);
            s += poutComma(taxData.taxesOasdi[i1], 11, 2);
            s += poutComma(taxData.taxesHi[i1], 11, 2);
            s += poutComma(taxData.taxesOasdhi[i1], 11, 2);
            outputString.push_back(s);
         }
         outputString.push_back("");
         s = "Total             ";
         for (i1 = 0; i1 < 5; i1++) {
            s += poutComma(
               taxData.getTaxesTotal((TaxRates::trustfundType)i1,
               TaxData::YEARS1937PLUS), 11, 2);
         }
         outputString.push_back(s);
      }
      else {
         outputString.push_back("None");
      }
      outputString.push_back("");
      printNameSsn(workerData);
   } catch (PiaException&) {
      throw PiaException(PIA_IDS_TXSTRING);
   }
}
