// $Id: TransGuar2Page.cpp 1.13 2006/01/05 15:34:10EST 044579 Exp  $
//
// Function to write out transitional guarantee calculation.

#include "TransGuar2Page.h"
#include "TransGuar.h"
#include "WageInd.h"
#include "comma.h"
#include "FormatString.h"
#include "PiaException.h"
#include "Resource.h"

using namespace std;

// Description: Initializes TransGuar2Page.
//
// Arguments:
//   newPiaCal: Benefit calculation parameters and results.
TransGuar2Page::TransGuar2Page( const PiaCalAny& newPiaCal ) : PiaPageOut(),
workerData(newPiaCal.workerData), piaData(newPiaCal.piaData),
piaParams(newPiaCal.piaParams), piaCal(newPiaCal)
{ }

// Description: Destructor.
TransGuar2Page::~TransGuar2Page()
{ }

// Description: Prepares transitional guarantee strings for printing.
void TransGuar2Page::prepareStrings()
{
   try {
      const TransGuar* transGuar = piaCal.transGuar;
      if (transGuar != (const TransGuar*)0 && transGuar->getApplicable() > 0) {
         pageTitle[0] = transGuar->getTitle();
         outputString.clear();
         prepareHeader();
         compYear(workerData, piaData, piaData.compPeriodNew);
         string s = "AME = ";
         s += poutComma(transGuar->getftearn(), 4, 2);
         s += "/(";
         s += poutNoComma(piaData.compPeriodNew.getN());
         s += "*12) = ";
         s += poutComma(transGuar->getAme());
         outputString.push_back(s);
         outputString.push_back("");
         s = "Dec 1978 PIA = ";
         s += BenefitAmount(transGuar->piaElig[transGuar->getCpiYear(
            PiaMethod::FIRST_YEAR)]).toString();
         outputString.push_back(s);
         outputString.push_back("");
         mfbBpOut(transGuar->bendMfb);
         // Transitional guarantee is never a disability calculation, so we
         // can call mfbOut without the ame argument
         mfbOut(*transGuar, transGuar->portionPiaElig, transGuar->percMfb);
         if (transGuar->getCpiYear(PiaMethod::YEAR_ENT) >=
            transGuar->getCpiYear(PiaMethod::YEAR_ELIG)) {
            biOut(*transGuar, piaParams, piaData.getEligYear(), 1, 3);
         }
         if (transGuar->getCpiYear(PiaMethod::YEAR_BEN) >
            transGuar->getCpiYear(PiaMethod::YEAR_ENT)) {
            piamfb1(*transGuar);
            biOut(*transGuar, piaParams, piaData.getEligYear(), 2, 3);
         }
         piamfb2(*transGuar);
         // print noninsured message
         nonIns(piaData.getFinsCode2());
         if (workerData.getJoasdi() == WorkerDataGeneral::DISABILITY)
            disInsOut(piaData);
         outputString.push_back("");
         printNameSsn(workerData);
      }
   } catch (PiaException&) {
      throw PiaException(PIA_IDS_TGSTRING);
   }
}
