// $Id: WageInd2Page.cpp 1.21 2006/01/05 15:34:11EST 044579 Exp  $
//
// Function to write out wage indexed calculation.

#include "WageInd2Page.h"
#include "WageInd.h"
#include "comma.h"
#include "FormatString.h"
#include "PiaException.h"
#include "Resource.h"
#include "UserAssumptions.h"

using namespace std;

// Description: Initializes WageInd2Page.
//
// Arguments:
//   newPiaCal: Benefit calculation parameters and results.
WageInd2Page::WageInd2Page( const PiaCalAny& newPiaCal ) : PiaPageOut(),
workerData(newPiaCal.workerData), piaData(newPiaCal.piaData),
piaParams(newPiaCal.piaParams), piaCal(newPiaCal),
userAssumptions(newPiaCal.userAssumptions)
{ }

// Description: Destructor.
WageInd2Page::~WageInd2Page()
{ }

// Description: Prepares wage indexed strings for printing.
void WageInd2Page::prepareStrings()
{
   int i1;  // loop counter
   string s;  // temporary string

   try {
      const WageInd* wageInd = (const WageInd*)piaCal.wageInd;
      if (wageInd != (const WageInd*)0 && wageInd->getApplicable() > 0) {
         pageTitle[0] = wageInd->getTitle();
         outputString.clear();
         prepareHeader();
         baseYearOut(piaData.getEligYear() - 2);
         compYear(workerData, piaData, piaData.compPeriodNew);
         if (workerData.getTotalize()) {
            s = "Theoretical AIME = ";
            s += poutComma(wageInd->getftearn(), 4, 2);
            s += "/(";
            s += poutNoComma(piaData.compPeriodNew.getN());
            s += "*12) = ";
            s += poutComma(wageInd->getAmeTotal());
            outputString.push_back(s);
            outputString.push_back("");
            s = "Pro Rata AIME = ";
            s += poutComma(wageInd->getAme(), 2);
         }
         else {
            s = "AIME = ";
            s += poutComma(wageInd->getftearn(), 4, 2);
            s += "/(";
            s += poutNoComma(piaData.compPeriodNew.getN());
            s += "*12) = ";
            s += poutComma(wageInd->getAme());
         }
         outputString.push_back(s);
         outputString.push_back("");
         piaBpOut(wageInd->bendPia);
         mfbBpOut(wageInd->bendMfb);
         BenefitAmount dtemp;
         if ((wageInd->getWindfall() == PiaMethod::HAS30YEARS ||
            wageInd->getWindfall() == PiaMethod::NOWINDFALLELIM) &&
            !workerData.getTotalize()) {
            dtemp = wageInd->piaElig[wageInd->getCpiYear(PiaMethod::FIRST_YEAR)];
         }
         else {
            if (wageInd->getWindfall() == PiaMethod::REDUCEDPERC ||
               wageInd->getWindfall() == PiaMethod::ONEHALFPENSION)
               dtemp = wageInd->getPiaWindfall();
            else
               dtemp = wageInd->getPiaEligTotal();
         }
         piaEligOut(wageInd->percPia, wageInd->portionAime, dtemp);
         if (wageInd->getWindfall() != PiaMethod::NOWINDFALLELIM) {
            pubPenOut(*wageInd,
               static_cast<double>(piaData.getPubpenApp(workerData)),
               workerData.getPubpenDate());
         }
         if (workerData.getTotalize()) {
            if (wageInd->getCpiYear(PiaMethod::YEAR_ENT) >=
               wageInd->getCpiYear(PiaMethod::YEAR_ELIG))
               biOut(*wageInd, piaParams, piaData.getEligYear(), 1, 1);
            if (wageInd->getCpiYear(PiaMethod::YEAR_BEN) >
               wageInd->getCpiYear(PiaMethod::YEAR_ENT))
               biOut(*wageInd, piaParams, piaData.getEligYear(), 2, 1);
            totPiaOut(*wageInd, piaData.getQcTotal(),
               piaData.compPeriodNew.getN());
            rawPiaOut(wageInd->piaElig[wageInd->getCpiYear(PiaMethod::FIRST_YEAR)]);
            outputString.push_back("");
         }
         mfbOut(*wageInd, wageInd->portionPiaElig, wageInd->percMfb,
            wageInd->getAme());
         i1 = (workerData.getTotalize()) ? 2 : 3;
         if (wageInd->getCpiYear(PiaMethod::YEAR_ENT) >=
            wageInd->getCpiYear(PiaMethod::YEAR_ELIG)) {
            biOut(*wageInd, piaParams, piaData.getEligYear(), 1, i1);
         }
         if (wageInd->getCpiYear(PiaMethod::YEAR_BEN) >
            wageInd->getCpiYear(PiaMethod::YEAR_ENT)) {
            piamfb1(*wageInd);
            biOut(*wageInd, piaParams, piaData.getEligYear(), 2, i1);
         }
         if (piaData.getEligYear() > UserAssumptions::getIstart() &&
            userAssumptions.getIaltaw() == 
               AssumptionType::PEBS_ASSUM) {
            printRealWageGain(piaData.getEligYear(),
               UserAssumptions::getIstart(), *wageInd,
               wageInd->piaRealWageGain, wageInd->mfbRealWageGain);
         }
         piamfb2(*wageInd);
         // print noninsured message
         nonIns(piaData.getFinsCode2());
         if (workerData.getJoasdi() == WorkerDataGeneral::DISABILITY)
            disInsOut(piaData);
         outputString.push_back("");
         printNameSsn(workerData);
      }
   } catch (PiaException e) {
      throw PiaException(PIA_IDS_WISTRING);
   }
}
