// $Id: OutFile132.h 1.3 2007/10/16 14:00:03EDT 277133 Development  $
//
// Declarations needed for classes to manage print output to a file.

#pragma once

#include <fstream>
#include "outfile.h"

// {group:Windows Classes}
// Description: Manages the print output functions, when printing to a
//   file formatted for 132 columns.
//
// Remarks: Manages the print output functions, when printing to a
//   file formatted for 132 columns.
class OutFile132 : public Out132
{
private:
   // Description: Number of columns to space over on left side.
   int cols;
   // Description: String of spaces for left side margin.
   char *colstring;
public:
   OutFile132( const std::string& newCorename = std::string("") );
   OutFile132( const std::string& newCorename, const std::string& newExtension );
   ~OutFile132();
   // Description: Advances one line.
   void advanceLine() { out << std::endl; }
   // Description: Advances to next page.
   void formfeed() { out << "\14" << std::endl; }
   // Description: Returns number of columns to space over on left side.
   //
   // Returns: Number of columns to space over on left side.
   int getCols() const { return cols; }
   // Description: Returns left-hand margin string.
   //
   // Returns: Left-hand margin string.
   const char *getColString() const { return((const char *)colstring); }
   // Description: Prints one line with a carriage return.
   //
   // Arguments:
   //   str: String to print.
   void printLine( const std::string& str )
      { out << colstring << str << std::endl; }
   // Arguments:
   //   str: String to print.
   void printLine( const char* str )
      { out << colstring << str << std::endl; }
   // Description: Print a line of output with no carriage return.
   //
   // Arguments:
   //   str: String to print.
   void printLinena( const std::string& str )
      { out << colstring << str << '\r'; }
   // Arguments:
   //   str: String to print.
   void printLinena( const char* str )
      { out << colstring << str << '\r'; }
   void setCols( int newCols );
};
