// $Id: getopt.h 1.2 2003/06/02 15:29:43EDT sfmckay Exp  $
//
// Declarations for getopt.
//
// Copyright (C) 1989,90,91,92,93,94,96,97 Free Software Foundation, Inc.
// This file is part of the GNU C Library.

#pragma once
#ifndef _GETOPT_H
#define _GETOPT_H 1

#ifdef __cplusplus
extern "C" {
#endif

// Description: For communication from getopt to the caller.
//
// Remarks: When getopt finds an option that takes an argument,
// the argument value is returned here.
// Also, when ordering is RETURN_IN_ORDER,
// each non-option argv-element is returned here.
extern char *optarg;

// Description: Index in argv of the next element to be scanned.
//
// Remarks: This is used for communication to and from the caller
// and for communication between successive calls to getopt.
//
// On entry to getopt, zero means this is the first call; initialize.
//
// When getopt returns -1, this is the index of the first of the
// non-option elements that the caller should itself scan.
//
// Otherwise, optind communicates from one call to the next
// how much of argv has been scanned so far.
extern int optind;

// Description: Callers store zero here to inhibit the error message getopt
// prints for unrecognized options.
extern int opterr;

// Description: Set to an option character which was unrecognized.
extern int optopt;

// Description: Describe the long-named options requested by the application.
//
// Remarks: The long_options argument to getopt_long or getopt_long_only is a
// vector of OptionStruct's terminated by an element containing a name which
// is zero.
//
// To have a long-named option do something other than set an int to a
// compiled-in constant, such as set a value from optarg, set the option's
// flag field to zero and its val field to a nonzero value (the equivalent
// single-letter option character, if there is one).  For long options that
// have a zero flag field, getopt returns the contents of the val field.
struct OptionStruct
{
  // Name of option.
  const char *name;
  // Description: Indicator for required/optional argument.
  //
  // Remarks: no_argument (or 0) if the option does not take an argument.
  // required_argument (or 1) if the option requires an argument.
  // optional_argument (or 2) if the option takes an optional argument.
  // has_arg can't be an enum because some compilers complain about
  // type mismatches in all the code that assumes it is an int.
  int has_arg;
  // If this field is not NULL, it points to a variable
  // that is set to the value given in the field val when the option is
  // found, but left unchanged if the option is not found.
  int *flag;
  // Value to use as described in remarks.
  int val;
};

// Description: Indicator that the getopt option does not take an argument.
//
// Remarks: Used in the has_arg field of OptionStruct.
#define no_argument       0
// Description: Indicator that the getopt option requires an argument.
//
// Remarks: Used in the has_arg field of OptionStruct.
#define required_argument 1
// Description: Indicator that the getopt option takes an optional argument.
//
// Remarks: Used in the has_arg field of OptionStruct.
#define optional_argument 2

extern int getopt( int argc, char *const *argv, const char *shortopts );
extern int getopt_long( int argc, char *const *argv, const char *shortopts,
  const struct OptionStruct *longopts, int *longind );
extern int getopt_long_only( int argc, char *const *argv,
  const char *shortopts, const struct OptionStruct *longopts, int *longind );

#ifdef __cplusplus
}
#endif

#endif /* _GETOPT_H */
